#########################################################################################
# Package        HiPi::Graphics::BitmapFont::MonoEPD76
# Description  : Monochrome OLED Font
# License      : This is free software; you can redistribute it and/or modify it under
#                the same terms as the Perl 5 programming language system itself.
#########################################################################################

package HiPi::Graphics::BitmapFont::MonoEPD76;

#########################################################################################

use utf8;
use strict;
use warnings;
use parent qw( HiPi::Graphics::BitmapFont);

our $VERSION ='0.01';

my $gap_width = 0;
my $char_height = 76;
my $line_spacing = 0;
my $name = 'Mono 76';
my $space_width = 39;
 
my $symbols = {
    '33' => {    # '!'
        'width'    => 6, 
        'xoffset'  => 16, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '34' => {    # '"'
        'width'    => 18, 
        'xoffset'  => 11, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '35' => {    # '#'
        'width'    => 38, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0xF8, 0x07, 0xC0, ##                  00000        00000    
            0x00, 0x00, 0xF8, 0x07, 0xC0, ##                  00000        00000    
            0x00, 0x01, 0xF8, 0x0F, 0xC0, ##                 000000       000000    
            0x00, 0x01, 0xF0, 0x0F, 0x80, ##                 00000        00000     
            0x00, 0x01, 0xF0, 0x0F, 0x80, ##                 00000        00000     
            0x00, 0x01, 0xF0, 0x0F, 0x80, ##                 00000        00000     
            0x00, 0x03, 0xF0, 0x1F, 0x80, ##                000000       000000     
            0x00, 0x03, 0xE0, 0x1F, 0x00, ##                00000        00000      
            0x00, 0x03, 0xE0, 0x1F, 0x00, ##                00000        00000      
            0x00, 0x03, 0xE0, 0x1F, 0x00, ##                00000        00000      
            0x00, 0x07, 0xE0, 0x3F, 0x00, ##               000000       000000      
            0x00, 0x07, 0xC0, 0x3E, 0x00, ##               00000        00000       
            0x00, 0x07, 0xC0, 0x3E, 0x00, ##               00000        00000       
            0x1F, 0xFF, 0xFF, 0xFF, 0xFC, ##     00000000000000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xFF, 0xFC, ##     00000000000000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xFF, 0xFC, ##     00000000000000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xFF, 0xFC, ##     00000000000000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xFF, 0xFC, ##     00000000000000000000000000000000000
            0x00, 0x1F, 0x80, 0xFC, 0x00, ##             000000       000000        
            0x00, 0x1F, 0x00, 0xF8, 0x00, ##             00000        00000         
            0x00, 0x1F, 0x00, 0xF8, 0x00, ##             00000        00000         
            0x00, 0x1F, 0x00, 0xF8, 0x00, ##             00000        00000         
            0x00, 0x3E, 0x01, 0xF0, 0x00, ##            00000        00000          
            0x00, 0x3E, 0x01, 0xF0, 0x00, ##            00000        00000          
            0x00, 0x3E, 0x01, 0xF0, 0x00, ##            00000        00000          
            0x00, 0x3E, 0x01, 0xF0, 0x00, ##            00000        00000          
            0x00, 0x7C, 0x03, 0xE0, 0x00, ##           00000        00000           
            0x00, 0x7C, 0x03, 0xE0, 0x00, ##           00000        00000           
            0xFF, 0xFF, 0xFF, 0xFF, 0xE0, ##  00000000000000000000000000000000000   
            0xFF, 0xFF, 0xFF, 0xFF, 0xE0, ##  00000000000000000000000000000000000   
            0xFF, 0xFF, 0xFF, 0xFF, 0xE0, ##  00000000000000000000000000000000000   
            0xFF, 0xFF, 0xFF, 0xFF, 0xE0, ##  00000000000000000000000000000000000   
            0xFF, 0xFF, 0xFF, 0xFF, 0xE0, ##  00000000000000000000000000000000000   
            0x01, 0xF8, 0x0F, 0xC0, 0x00, ##         000000       000000            
            0x01, 0xF0, 0x0F, 0x80, 0x00, ##         00000        00000             
            0x01, 0xF0, 0x0F, 0x80, 0x00, ##         00000        00000             
            0x01, 0xF0, 0x0F, 0x80, 0x00, ##         00000        00000             
            0x03, 0xF0, 0x1F, 0x80, 0x00, ##        000000       000000             
            0x03, 0xE0, 0x1F, 0x00, 0x00, ##        00000        00000              
            0x03, 0xE0, 0x1F, 0x00, 0x00, ##        00000        00000              
            0x03, 0xE0, 0x1F, 0x00, 0x00, ##        00000        00000              
            0x07, 0xE0, 0x3F, 0x00, 0x00, ##       000000       000000              
            0x07, 0xC0, 0x3E, 0x00, 0x00, ##       00000        00000               
            0x07, 0xC0, 0x3E, 0x00, 0x00, ##       00000        00000               
            0x07, 0xC0, 0x3E, 0x00, 0x00, ##       00000        00000               
            0x0F, 0xC0, 0x7E, 0x00, 0x00, ##      000000       000000               
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '36' => {    # '$'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x7F, 0xF8, 0x00, ##           000000000000        
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000     
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000   
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x3F, 0xFF, 0xFF, 0xC0, ##    000000000000000000000000   
            0x3F, 0xC7, 0x0F, 0xC0, ##    00000000   000    000000   
            0x7F, 0x07, 0x01, 0xC0, ##   0000000     000       000   
            0x7E, 0x07, 0x00, 0x40, ##   000000      000         0   
            0xFE, 0x07, 0x00, 0x00, ##  0000000      000             
            0xFC, 0x07, 0x00, 0x00, ##  000000       000             
            0xFC, 0x07, 0x00, 0x00, ##  000000       000             
            0xFC, 0x07, 0x00, 0x00, ##  000000       000             
            0xFC, 0x07, 0x00, 0x00, ##  000000       000             
            0xFC, 0x07, 0x00, 0x00, ##  000000       000             
            0xFE, 0x07, 0x00, 0x00, ##  0000000      000             
            0x7F, 0x07, 0x00, 0x00, ##   0000000     000             
            0x7F, 0x87, 0x00, 0x00, ##   00000000    000             
            0x3F, 0xF7, 0x00, 0x00, ##    0000000000 000             
            0x1F, 0xFF, 0x80, 0x00, ##     00000000000000            
            0x0F, 0xFF, 0xF8, 0x00, ##      00000000000000000        
            0x07, 0xFF, 0xFE, 0x00, ##       000000000000000000      
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000     
            0x00, 0x3F, 0xFF, 0xC0, ##            0000000000000000   
            0x00, 0x07, 0xFF, 0xE0, ##               00000000000000  
            0x00, 0x07, 0x1F, 0xE0, ##               000   00000000  
            0x00, 0x07, 0x07, 0xF0, ##               000     0000000 
            0x00, 0x07, 0x03, 0xF0, ##               000      000000 
            0x00, 0x07, 0x03, 0xF8, ##               000      0000000
            0x00, 0x07, 0x01, 0xF8, ##               000       000000
            0x00, 0x07, 0x01, 0xF8, ##               000       000000
            0x00, 0x07, 0x01, 0xF8, ##               000       000000
            0x00, 0x07, 0x01, 0xF8, ##               000       000000
            0x00, 0x07, 0x01, 0xF8, ##               000       000000
            0x80, 0x07, 0x03, 0xF8, ##  0            000      0000000
            0xE0, 0x07, 0x03, 0xF0, ##  000          000      000000 
            0xF8, 0x07, 0x07, 0xF0, ##  00000        000     0000000 
            0xFF, 0x07, 0x1F, 0xE0, ##  00000000     000   00000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000   
            0x7F, 0xFF, 0xFF, 0x00, ##   00000000000000000000000     
            0x0F, 0xFF, 0xFE, 0x00, ##      0000000000000000000      
            0x00, 0xFF, 0xF0, 0x00, ##          000000000000         
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x07, 0x00, 0x00, ##               000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '37' => {    # '%'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x01, 0xF8, 0x00, 0x00, 0x00, ##         000000                       
            0x07, 0xFE, 0x00, 0x00, 0x00, ##       0000000000                     
            0x1F, 0xFF, 0x80, 0x00, 0x00, ##     00000000000000                   
            0x3F, 0xFF, 0xC0, 0x00, 0x00, ##    0000000000000000                  
            0x3F, 0xFF, 0xC0, 0x00, 0x00, ##    0000000000000000                  
            0x7E, 0x07, 0xE0, 0x00, 0x00, ##   000000      000000                 
            0x7C, 0x03, 0xE0, 0x00, 0x00, ##   00000        00000                 
            0xF8, 0x01, 0xF0, 0x00, 0x00, ##  00000          00000                
            0xF0, 0x00, 0xF0, 0x00, 0x00, ##  0000            0000                
            0xF0, 0x00, 0xF0, 0x00, 0x00, ##  0000            0000                
            0xF0, 0x00, 0xF0, 0x00, 0x00, ##  0000            0000                
            0xF0, 0x00, 0xF0, 0x00, 0x00, ##  0000            0000                
            0xF0, 0x00, 0xF0, 0x00, 0x00, ##  0000            0000                
            0x78, 0x01, 0xE0, 0x00, 0x00, ##   0000          0000                 
            0x7C, 0x03, 0xE0, 0x00, 0x00, ##   00000        00000                 
            0x3E, 0x07, 0xC0, 0x01, 0xC0, ##    00000      00000             000  
            0x3F, 0xFF, 0xC0, 0x07, 0xE0, ##    0000000000000000           000000 
            0x1F, 0xFF, 0x80, 0x3F, 0xE0, ##     00000000000000         000000000 
            0x07, 0xFE, 0x00, 0xFF, 0x00, ##       0000000000         00000000    
            0x01, 0xF8, 0x07, 0xFC, 0x00, ##         000000        000000000      
            0x00, 0x00, 0x1F, 0xE0, 0x00, ##                     00000000         
            0x00, 0x00, 0xFF, 0x80, 0x00, ##                  000000000           
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x1F, 0xF0, 0x00, 0x00, ##             000000000                
            0x00, 0x7F, 0x80, 0x00, 0x00, ##           00000000                   
            0x03, 0xFE, 0x01, 0xF8, 0x00, ##        000000000        000000       
            0x0F, 0xF0, 0x07, 0xFE, 0x00, ##      00000000         0000000000     
            0x3F, 0xC0, 0x0F, 0xFF, 0x80, ##    00000000          0000000000000   
            0x3E, 0x00, 0x1F, 0xFF, 0xC0, ##    00000            000000000000000  
            0x38, 0x00, 0x3F, 0x07, 0xC0, ##    000             000000     00000  
            0x00, 0x00, 0x3E, 0x03, 0xE0, ##                    00000       00000 
            0x00, 0x00, 0x3C, 0x01, 0xE0, ##                    0000         0000 
            0x00, 0x00, 0x78, 0x01, 0xF0, ##                   0000          00000
            0x00, 0x00, 0x78, 0x00, 0xF0, ##                   0000           0000
            0x00, 0x00, 0x78, 0x00, 0xF0, ##                   0000           0000
            0x00, 0x00, 0x78, 0x00, 0xF0, ##                   0000           0000
            0x00, 0x00, 0x78, 0x00, 0xF0, ##                   0000           0000
            0x00, 0x00, 0x78, 0x00, 0xF0, ##                   0000           0000
            0x00, 0x00, 0x3C, 0x01, 0xE0, ##                    0000         0000 
            0x00, 0x00, 0x3E, 0x03, 0xE0, ##                    00000       00000 
            0x00, 0x00, 0x3F, 0x07, 0xC0, ##                    000000     00000  
            0x00, 0x00, 0x1F, 0xFF, 0xC0, ##                     000000000000000  
            0x00, 0x00, 0x0F, 0xFF, 0x80, ##                      0000000000000   
            0x00, 0x00, 0x07, 0xFF, 0x00, ##                       00000000000    
            0x00, 0x00, 0x01, 0xFC, 0x00, ##                         0000000      
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '38' => {    # '&'
        'width'    => 37, 
        'xoffset'  => 2, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000               
            0x00, 0x1F, 0xFF, 0xC0, 0x00, ##             000000000000000           
            0x00, 0x7F, 0xFF, 0xC0, 0x00, ##           00000000000000000           
            0x00, 0xFF, 0xFF, 0xC0, 0x00, ##          000000000000000000           
            0x00, 0xFF, 0xFF, 0xC0, 0x00, ##          000000000000000000           
            0x01, 0xFE, 0x07, 0xC0, 0x00, ##         00000000      00000           
            0x01, 0xF8, 0x00, 0xC0, 0x00, ##         000000           00           
            0x03, 0xF0, 0x00, 0x00, 0x00, ##        000000                         
            0x03, 0xE0, 0x00, 0x00, 0x00, ##        00000                          
            0x03, 0xE0, 0x00, 0x00, 0x00, ##        00000                          
            0x03, 0xE0, 0x00, 0x00, 0x00, ##        00000                          
            0x03, 0xE0, 0x00, 0x00, 0x00, ##        00000                          
            0x03, 0xE0, 0x00, 0x00, 0x00, ##        00000                          
            0x03, 0xF0, 0x00, 0x00, 0x00, ##        000000                         
            0x03, 0xF0, 0x00, 0x00, 0x00, ##        000000                         
            0x01, 0xF8, 0x00, 0x00, 0x00, ##         000000                        
            0x01, 0xF8, 0x00, 0x00, 0x00, ##         000000                        
            0x00, 0xFC, 0x00, 0x00, 0x00, ##          000000                       
            0x00, 0xFE, 0x00, 0x00, 0x00, ##          0000000                      
            0x00, 0x7E, 0x00, 0x00, 0x00, ##           000000                      
            0x00, 0xFF, 0x00, 0x00, 0x00, ##          00000000                     
            0x01, 0xFF, 0x80, 0x00, 0x00, ##         0000000000                    
            0x07, 0xFF, 0xC0, 0x00, 0x00, ##       0000000000000                   
            0x0F, 0xEF, 0xC0, 0x00, 0x00, ##      0000000 000000                   
            0x0F, 0xC7, 0xE0, 0x00, 0x00, ##      000000   000000                  
            0x1F, 0x83, 0xF0, 0x01, 0xF0, ##     000000     000000           00000 
            0x3F, 0x03, 0xF8, 0x01, 0xF0, ##    000000      0000000          00000 
            0x3F, 0x01, 0xF8, 0x01, 0xF0, ##    000000       000000          00000 
            0x7E, 0x00, 0xFC, 0x01, 0xF0, ##   000000         000000         00000 
            0x7E, 0x00, 0xFE, 0x01, 0xF0, ##   000000         0000000        00000 
            0xFC, 0x00, 0x7F, 0x01, 0xF0, ##  000000           0000000       00000 
            0xFC, 0x00, 0x3F, 0x01, 0xF0, ##  000000            000000       00000 
            0xFC, 0x00, 0x1F, 0x81, 0xE0, ##  000000             000000      0000  
            0xFC, 0x00, 0x1F, 0xC3, 0xE0, ##  000000             0000000    00000  
            0xFC, 0x00, 0x0F, 0xE3, 0xE0, ##  000000              0000000   00000  
            0xFC, 0x00, 0x07, 0xE3, 0xE0, ##  000000               000000   00000  
            0xFC, 0x00, 0x03, 0xF7, 0xC0, ##  000000                000000 00000   
            0xFE, 0x00, 0x03, 0xFF, 0xC0, ##  0000000               000000000000   
            0x7E, 0x00, 0x01, 0xFF, 0x80, ##   000000                0000000000    
            0x7F, 0x00, 0x00, 0xFF, 0x00, ##   0000000                00000000     
            0x7F, 0x80, 0x00, 0xFF, 0x00, ##   00000000               00000000     
            0x3F, 0xC0, 0x00, 0xFF, 0x00, ##    00000000              00000000     
            0x3F, 0xE0, 0x01, 0xFF, 0x80, ##    000000000            0000000000    
            0x1F, 0xF8, 0x0F, 0xFF, 0x80, ##     0000000000       0000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0xC0, ##      000000000000000000000000000000   
            0x07, 0xFF, 0xFF, 0xCF, 0xE0, ##       000000000000000000000  0000000  
            0x01, 0xFF, 0xFF, 0x87, 0xF0, ##         000000000000000000    0000000 
            0x00, 0xFF, 0xFE, 0x03, 0xF0, ##          000000000000000       000000 
            0x00, 0x1F, 0xF0, 0x00, 0x00, ##             000000000                 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '39' => {    # '''
        'width'    => 6, 
        'xoffset'  => 16, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '40' => {    # '('
        'width'    => 14, 
        'xoffset'  => 13, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x7C, ##           00000
            0x00, 0xF8, ##          00000 
            0x00, 0xF8, ##          00000 
            0x01, 0xF0, ##         00000  
            0x01, 0xF0, ##         00000  
            0x03, 0xE0, ##        00000   
            0x03, 0xE0, ##        00000   
            0x07, 0xC0, ##       00000    
            0x07, 0xC0, ##       00000    
            0x0F, 0xC0, ##      000000    
            0x0F, 0x80, ##      00000     
            0x1F, 0x80, ##     000000     
            0x1F, 0x80, ##     000000     
            0x1F, 0x00, ##     00000      
            0x3F, 0x00, ##    000000      
            0x3F, 0x00, ##    000000      
            0x3E, 0x00, ##    00000       
            0x7E, 0x00, ##   000000       
            0x7E, 0x00, ##   000000       
            0x7E, 0x00, ##   000000       
            0x7E, 0x00, ##   000000       
            0x7C, 0x00, ##   00000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0x7C, 0x00, ##   00000        
            0x7E, 0x00, ##   000000       
            0x7E, 0x00, ##   000000       
            0x7E, 0x00, ##   000000       
            0x7E, 0x00, ##   000000       
            0x3E, 0x00, ##    00000       
            0x3F, 0x00, ##    000000      
            0x3F, 0x00, ##    000000      
            0x1F, 0x00, ##     00000      
            0x1F, 0x80, ##     000000     
            0x1F, 0x80, ##     000000     
            0x0F, 0x80, ##      00000     
            0x0F, 0xC0, ##      000000    
            0x07, 0xC0, ##       00000    
            0x07, 0xC0, ##       00000    
            0x03, 0xE0, ##        00000   
            0x03, 0xE0, ##        00000   
            0x01, 0xF0, ##         00000  
            0x01, 0xF0, ##         00000  
            0x00, 0xF8, ##          00000 
            0x00, 0xF8, ##          00000 
            0x00, 0x7C, ##           00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '41' => {    # ')'
        'width'    => 14, 
        'xoffset'  => 11, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF8, 0x00, ##  00000         
            0x7C, 0x00, ##   00000        
            0x7C, 0x00, ##   00000        
            0x3E, 0x00, ##    00000       
            0x3E, 0x00, ##    00000       
            0x1F, 0x00, ##     00000      
            0x1F, 0x00, ##     00000      
            0x0F, 0x80, ##      00000     
            0x0F, 0x80, ##      00000     
            0x0F, 0xC0, ##      000000    
            0x07, 0xC0, ##       00000    
            0x07, 0xE0, ##       000000   
            0x07, 0xE0, ##       000000   
            0x03, 0xE0, ##        00000   
            0x03, 0xF0, ##        000000  
            0x03, 0xF0, ##        000000  
            0x01, 0xF0, ##         00000  
            0x01, 0xF8, ##         000000 
            0x01, 0xF8, ##         000000 
            0x01, 0xF8, ##         000000 
            0x01, 0xF8, ##         000000 
            0x01, 0xF8, ##         000000 
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x00, 0xFC, ##          000000
            0x01, 0xF8, ##         000000 
            0x01, 0xF8, ##         000000 
            0x01, 0xF8, ##         000000 
            0x01, 0xF8, ##         000000 
            0x01, 0xF8, ##         000000 
            0x03, 0xF0, ##        000000  
            0x03, 0xF0, ##        000000  
            0x03, 0xF0, ##        000000  
            0x03, 0xE0, ##        00000   
            0x07, 0xE0, ##       000000   
            0x07, 0xE0, ##       000000   
            0x07, 0xC0, ##       00000    
            0x0F, 0xC0, ##      000000    
            0x0F, 0x80, ##      00000     
            0x1F, 0x80, ##     000000     
            0x1F, 0x00, ##     00000      
            0x1F, 0x00, ##     00000      
            0x3E, 0x00, ##    00000       
            0x3E, 0x00, ##    00000       
            0x7C, 0x00, ##   00000        
            0x7C, 0x00, ##   00000        
            0xF8, 0x00, ##  00000         
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '42' => {    # '*'
        'width'    => 28, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x40, 0x0F, 0x00, 0x20, ##   0          0000          0 
            0x60, 0x0F, 0x00, 0x60, ##   00         0000         00 
            0xF8, 0x0F, 0x01, 0xF0, ##  00000       0000       00000
            0xFE, 0x0F, 0x07, 0xF0, ##  0000000     0000     0000000
            0x3F, 0x0F, 0x0F, 0xC0, ##    000000    0000    000000  
            0x1F, 0xCF, 0x3F, 0x80, ##     0000000  0000  0000000   
            0x07, 0xFF, 0xFE, 0x00, ##       000000000000000000     
            0x01, 0xFF, 0xF8, 0x00, ##         00000000000000       
            0x00, 0x7F, 0xE0, 0x00, ##           0000000000         
            0x00, 0x1F, 0x80, 0x00, ##             000000           
            0x00, 0x7F, 0xE0, 0x00, ##           0000000000         
            0x01, 0xFF, 0xF8, 0x00, ##         00000000000000       
            0x07, 0xFF, 0xFE, 0x00, ##       000000000000000000     
            0x1F, 0xCF, 0x3F, 0x00, ##     0000000  0000  000000    
            0x3F, 0x0F, 0x0F, 0xC0, ##    000000    0000    000000  
            0xFE, 0x0F, 0x07, 0xF0, ##  0000000     0000     0000000
            0xF8, 0x0F, 0x01, 0xF0, ##  00000       0000       00000
            0x60, 0x0F, 0x00, 0x60, ##   00         0000         00 
            0x40, 0x0F, 0x00, 0x20, ##   0          0000          0 
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x0F, 0x00, 0x00, ##              0000            
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '43' => {    # '+'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '44' => {    # ','
        'width'    => 11, 
        'xoffset'  => 13, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xC0, ##     0000000 
            0x3F, 0xC0, ##    00000000 
            0x3F, 0x80, ##    0000000  
            0x3F, 0x80, ##    0000000  
            0x3F, 0x00, ##    000000   
            0x7F, 0x00, ##   0000000   
            0x7E, 0x00, ##   000000    
            0x7E, 0x00, ##   000000    
            0x7C, 0x00, ##   00000     
            0xFC, 0x00, ##  000000     
            0xF8, 0x00, ##  00000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '45' => {    # '-'
        'width'    => 16, 
        'xoffset'  => 11, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFF, ##  0000000000000000
            0xFF, 0xFF, ##  0000000000000000
            0xFF, 0xFF, ##  0000000000000000
            0xFF, 0xFF, ##  0000000000000000
            0xFF, 0xFF, ##  0000000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '46' => {    # '.'
        'width'    => 8, 
        'xoffset'  => 15, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '47' => {    # '/'
        'width'    => 31, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x7C, ##                           00000 
            0x00, 0x00, 0x00, 0xFC, ##                          000000 
            0x00, 0x00, 0x00, 0xFC, ##                          000000 
            0x00, 0x00, 0x01, 0xF8, ##                         000000  
            0x00, 0x00, 0x01, 0xF8, ##                         000000  
            0x00, 0x00, 0x03, 0xF0, ##                        000000   
            0x00, 0x00, 0x03, 0xF0, ##                        000000   
            0x00, 0x00, 0x07, 0xE0, ##                       000000    
            0x00, 0x00, 0x07, 0xE0, ##                       000000    
            0x00, 0x00, 0x0F, 0xC0, ##                      000000     
            0x00, 0x00, 0x0F, 0xC0, ##                      000000     
            0x00, 0x00, 0x1F, 0x80, ##                     000000      
            0x00, 0x00, 0x1F, 0x80, ##                     000000      
            0x00, 0x00, 0x1F, 0x00, ##                     00000       
            0x00, 0x00, 0x3F, 0x00, ##                    000000       
            0x00, 0x00, 0x3F, 0x00, ##                    000000       
            0x00, 0x00, 0x7E, 0x00, ##                   000000        
            0x00, 0x00, 0x7E, 0x00, ##                   000000        
            0x00, 0x00, 0xFC, 0x00, ##                  000000         
            0x00, 0x00, 0xFC, 0x00, ##                  000000         
            0x00, 0x01, 0xF8, 0x00, ##                 000000          
            0x00, 0x01, 0xF8, 0x00, ##                 000000          
            0x00, 0x03, 0xF0, 0x00, ##                000000           
            0x00, 0x03, 0xF0, 0x00, ##                000000           
            0x00, 0x07, 0xE0, 0x00, ##               000000            
            0x00, 0x07, 0xE0, 0x00, ##               000000            
            0x00, 0x0F, 0xC0, 0x00, ##              000000             
            0x00, 0x0F, 0xC0, 0x00, ##              000000             
            0x00, 0x0F, 0xC0, 0x00, ##              000000             
            0x00, 0x1F, 0x80, 0x00, ##             000000              
            0x00, 0x1F, 0x80, 0x00, ##             000000              
            0x00, 0x3F, 0x00, 0x00, ##            000000               
            0x00, 0x3F, 0x00, 0x00, ##            000000               
            0x00, 0x7E, 0x00, 0x00, ##           000000                
            0x00, 0x7E, 0x00, 0x00, ##           000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                 
            0x00, 0xFC, 0x00, 0x00, ##          000000                 
            0x01, 0xF8, 0x00, 0x00, ##         000000                  
            0x01, 0xF8, 0x00, 0x00, ##         000000                  
            0x03, 0xF0, 0x00, 0x00, ##        000000                   
            0x03, 0xF0, 0x00, 0x00, ##        000000                   
            0x03, 0xE0, 0x00, 0x00, ##        00000                    
            0x07, 0xE0, 0x00, 0x00, ##       000000                    
            0x07, 0xE0, 0x00, 0x00, ##       000000                    
            0x0F, 0xC0, 0x00, 0x00, ##      000000                     
            0x0F, 0xC0, 0x00, 0x00, ##      000000                     
            0x1F, 0x80, 0x00, 0x00, ##     000000                      
            0x1F, 0x80, 0x00, 0x00, ##     000000                      
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '48' => {    # '0'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x7F, 0xF8, 0x00, ##           000000000000         
            0x01, 0xFF, 0xFE, 0x00, ##         0000000000000000       
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x0F, 0xF0, 0x3F, 0xC0, ##      00000000      00000000    
            0x0F, 0xE0, 0x1F, 0xC0, ##      0000000        0000000    
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x1F, 0x80, 0x07, 0xE0, ##     000000            000000   
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7F, 0x00, 0x03, 0xF0, ##   0000000              000000  
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFC, 0x00, 0x00, 0xF8, ##  000000                  00000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x07, 0x80, 0xFC, ##  000000       0000       000000
            0xFC, 0x0F, 0xC0, 0xFC, ##  000000      000000      000000
            0xFC, 0x1F, 0xE0, 0xFC, ##  000000     00000000     000000
            0xFC, 0x1F, 0xE0, 0xFC, ##  000000     00000000     000000
            0xFC, 0x1F, 0xE0, 0xFC, ##  000000     00000000     000000
            0xFC, 0x1F, 0xE0, 0xFC, ##  000000     00000000     000000
            0xFC, 0x0F, 0xC0, 0xFC, ##  000000      000000      000000
            0xFC, 0x07, 0x80, 0xFC, ##  000000       0000       000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0x7C, 0x00, 0x00, 0xF8, ##   00000                  00000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF0, ##   0000000              000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x1F, 0x80, 0x07, 0xE0, ##     000000            000000   
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x0F, 0xE0, 0x1F, 0xC0, ##      0000000        0000000    
            0x0F, 0xF0, 0x3F, 0xC0, ##      00000000      00000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x01, 0xFF, 0xFE, 0x00, ##         0000000000000000       
            0x00, 0x7F, 0xF8, 0x00, ##           000000000000         
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '49' => {    # '1'
        'width'    => 26, 
        'xoffset'  => 8, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0xFF, 0x00, 0x00, ##          00000000          
            0x1F, 0xFF, 0x00, 0x00, ##     0000000000000          
            0xFF, 0xFF, 0x00, 0x00, ##  0000000000000000          
            0xFF, 0xFF, 0x00, 0x00, ##  0000000000000000          
            0xFF, 0xFF, 0x00, 0x00, ##  0000000000000000          
            0xFF, 0xFF, 0x00, 0x00, ##  0000000000000000          
            0xFE, 0x3F, 0x00, 0x00, ##  0000000   000000          
            0xE0, 0x3F, 0x00, 0x00, ##  000       000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '50' => {    # '2'
        'width'    => 28, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0xFF, 0x80, 0x00, ##          000000000           
            0x0F, 0xFF, 0xF0, 0x00, ##      0000000000000000        
            0x7F, 0xFF, 0xFC, 0x00, ##   000000000000000000000      
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000    
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000   
            0xFF, 0x80, 0x7F, 0x80, ##  000000000        00000000   
            0xFC, 0x00, 0x1F, 0xC0, ##  000000             0000000  
            0xF0, 0x00, 0x0F, 0xE0, ##  0000                0000000 
            0xC0, 0x00, 0x07, 0xE0, ##  00                   000000 
            0x00, 0x00, 0x07, 0xE0, ##                       000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000
            0x00, 0x00, 0x07, 0xE0, ##                       000000 
            0x00, 0x00, 0x07, 0xE0, ##                       000000 
            0x00, 0x00, 0x0F, 0xE0, ##                      0000000 
            0x00, 0x00, 0x0F, 0xC0, ##                      000000  
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000  
            0x00, 0x00, 0x3F, 0x80, ##                    0000000   
            0x00, 0x00, 0x3F, 0x00, ##                    000000    
            0x00, 0x00, 0x7F, 0x00, ##                   0000000    
            0x00, 0x00, 0xFE, 0x00, ##                  0000000     
            0x00, 0x01, 0xFC, 0x00, ##                 0000000      
            0x00, 0x03, 0xF8, 0x00, ##                0000000       
            0x00, 0x07, 0xF0, 0x00, ##               0000000        
            0x00, 0x0F, 0xE0, 0x00, ##              0000000         
            0x00, 0x0F, 0xE0, 0x00, ##              0000000         
            0x00, 0x1F, 0xC0, 0x00, ##             0000000          
            0x00, 0x3F, 0x80, 0x00, ##            0000000           
            0x00, 0x7F, 0x00, 0x00, ##           0000000            
            0x00, 0xFE, 0x00, 0x00, ##          0000000             
            0x01, 0xFC, 0x00, 0x00, ##         0000000              
            0x03, 0xF8, 0x00, 0x00, ##        0000000               
            0x07, 0xF0, 0x00, 0x00, ##       0000000                
            0x0F, 0xE0, 0x00, 0x00, ##      0000000                 
            0x1F, 0xC0, 0x00, 0x00, ##     0000000                  
            0x3F, 0x80, 0x00, 0x00, ##    0000000                   
            0x7F, 0x00, 0x00, 0x00, ##   0000000                    
            0xFF, 0x00, 0x00, 0x00, ##  00000000                    
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '51' => {    # '3'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0xFF, 0xC0, 0x00, ##          0000000000           
            0x1F, 0xFF, 0xF8, 0x00, ##     000000000000000000        
            0x7F, 0xFF, 0xFE, 0x00, ##   0000000000000000000000      
            0x7F, 0xFF, 0xFF, 0x00, ##   00000000000000000000000     
            0x7F, 0xFF, 0xFF, 0x80, ##   000000000000000000000000    
            0x7F, 0x80, 0x7F, 0xC0, ##   00000000        000000000   
            0x70, 0x00, 0x1F, 0xE0, ##   000               00000000  
            0x40, 0x00, 0x0F, 0xE0, ##   0                  0000000  
            0x00, 0x00, 0x07, 0xE0, ##                       000000  
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0x00, 0x00, 0x07, 0xE0, ##                       000000  
            0x00, 0x00, 0x0F, 0xE0, ##                      0000000  
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000   
            0x00, 0x00, 0x7F, 0x80, ##                   00000000    
            0x00, 0xFF, 0xFF, 0x00, ##          0000000000000000     
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000       
            0x00, 0xFF, 0xF0, 0x00, ##          000000000000         
            0x00, 0xFF, 0xFE, 0x00, ##          000000000000000      
            0x00, 0xFF, 0xFF, 0x00, ##          0000000000000000     
            0x00, 0x00, 0x7F, 0xC0, ##                   000000000   
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000   
            0x00, 0x00, 0x0F, 0xE0, ##                      0000000  
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0xC0, 0x00, 0x0F, 0xF0, ##  00                  00000000 
            0xF0, 0x00, 0x1F, 0xE0, ##  0000               00000000  
            0xFF, 0x00, 0xFF, 0xE0, ##  00000000        00000000000  
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000   
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000    
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000      
            0x3F, 0xFF, 0xF8, 0x00, ##    0000000000000000000        
            0x01, 0xFF, 0xC0, 0x00, ##         00000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '52' => {    # '4'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x1F, 0xC0, 0x00, ##                     0000000       
            0x00, 0x00, 0x3F, 0xC0, 0x00, ##                    00000000       
            0x00, 0x00, 0x3F, 0xC0, 0x00, ##                    00000000       
            0x00, 0x00, 0x7F, 0xC0, 0x00, ##                   000000000       
            0x00, 0x00, 0xFF, 0xC0, 0x00, ##                  0000000000       
            0x00, 0x00, 0xFF, 0xC0, 0x00, ##                  0000000000       
            0x00, 0x01, 0xFF, 0xC0, 0x00, ##                 00000000000       
            0x00, 0x03, 0xEF, 0xC0, 0x00, ##                00000 000000       
            0x00, 0x03, 0xEF, 0xC0, 0x00, ##                00000 000000       
            0x00, 0x07, 0xCF, 0xC0, 0x00, ##               00000  000000       
            0x00, 0x07, 0x8F, 0xC0, 0x00, ##               0000   000000       
            0x00, 0x0F, 0x8F, 0xC0, 0x00, ##              00000   000000       
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000       
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000       
            0x00, 0x3E, 0x0F, 0xC0, 0x00, ##            00000     000000       
            0x00, 0x7C, 0x0F, 0xC0, 0x00, ##           00000      000000       
            0x00, 0x7C, 0x0F, 0xC0, 0x00, ##           00000      000000       
            0x00, 0xF8, 0x0F, 0xC0, 0x00, ##          00000       000000       
            0x01, 0xF8, 0x0F, 0xC0, 0x00, ##         000000       000000       
            0x01, 0xF0, 0x0F, 0xC0, 0x00, ##         00000        000000       
            0x03, 0xE0, 0x0F, 0xC0, 0x00, ##        00000         000000       
            0x03, 0xE0, 0x0F, 0xC0, 0x00, ##        00000         000000       
            0x07, 0xC0, 0x0F, 0xC0, 0x00, ##       00000          000000       
            0x0F, 0xC0, 0x0F, 0xC0, 0x00, ##      000000          000000       
            0x0F, 0x80, 0x0F, 0xC0, 0x00, ##      00000           000000       
            0x1F, 0x00, 0x0F, 0xC0, 0x00, ##     00000            000000       
            0x3F, 0x00, 0x0F, 0xC0, 0x00, ##    000000            000000       
            0x3E, 0x00, 0x0F, 0xC0, 0x00, ##    00000             000000       
            0x7E, 0x00, 0x0F, 0xC0, 0x00, ##   000000             000000       
            0xFC, 0x00, 0x0F, 0xC0, 0x00, ##  000000              000000       
            0xF8, 0x00, 0x0F, 0xC0, 0x00, ##  00000               000000       
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000       
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '53' => {    # '5'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x3F, 0xFF, 0xFF, 0xC0, ##    000000000000000000000000   
            0x3F, 0xFF, 0xFF, 0xC0, ##    000000000000000000000000   
            0x3F, 0xFF, 0xFF, 0xC0, ##    000000000000000000000000   
            0x3F, 0xFF, 0xFF, 0xC0, ##    000000000000000000000000   
            0x3F, 0xFF, 0xFF, 0xC0, ##    000000000000000000000000   
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x7F, 0xC0, 0x00, ##    000000 000000000           
            0x3F, 0xFF, 0xF8, 0x00, ##    0000000000000000000        
            0x3F, 0xFF, 0xFE, 0x00, ##    000000000000000000000      
            0x3F, 0xFF, 0xFF, 0x00, ##    0000000000000000000000     
            0x3F, 0xFF, 0xFF, 0x80, ##    00000000000000000000000    
            0x3E, 0x00, 0xFF, 0xC0, ##    00000         0000000000   
            0x30, 0x00, 0x3F, 0xC0, ##    00              00000000   
            0x00, 0x00, 0x0F, 0xE0, ##                      0000000  
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0x80, 0x00, 0x0F, 0xE0, ##  0                   0000000  
            0xF0, 0x00, 0x3F, 0xC0, ##  0000              00000000   
            0xFE, 0x00, 0xFF, 0xC0, ##  0000000         0000000000   
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000    
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000     
            0xFF, 0xFF, 0xFC, 0x00, ##  0000000000000000000000       
            0x7F, 0xFF, 0xF0, 0x00, ##   0000000000000000000         
            0x07, 0xFF, 0x80, 0x00, ##       000000000000            
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '54' => {    # '6'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0xFC, 0x00, ##               000000000        
            0x00, 0x3F, 0xFF, 0xC0, ##            0000000000000000    
            0x00, 0xFF, 0xFF, 0xE0, ##          0000000000000000000   
            0x01, 0xFF, 0xFF, 0xE0, ##         00000000000000000000   
            0x03, 0xFF, 0xFF, 0xE0, ##        000000000000000000000   
            0x07, 0xFC, 0x03, 0xE0, ##       000000000        00000   
            0x0F, 0xF0, 0x00, 0x60, ##      00000000             00   
            0x0F, 0xE0, 0x00, 0x00, ##      0000000                   
            0x1F, 0xC0, 0x00, 0x00, ##     0000000                    
            0x1F, 0x80, 0x00, 0x00, ##     000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                      
            0x3F, 0x00, 0x00, 0x00, ##    000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                       
            0x7E, 0x00, 0x00, 0x00, ##   000000                       
            0x7E, 0x00, 0x00, 0x00, ##   000000                       
            0x7E, 0x00, 0x00, 0x00, ##   000000                       
            0x7C, 0x07, 0xF0, 0x00, ##   00000       0000000          
            0xFC, 0x3F, 0xFE, 0x00, ##  000000    0000000000000       
            0xFC, 0x7F, 0xFF, 0x80, ##  000000   0000000000000000     
            0xFC, 0xFF, 0xFF, 0xC0, ##  000000  000000000000000000    
            0xFD, 0xFF, 0xFF, 0xE0, ##  000000 00000000000000000000   
            0xFD, 0xF8, 0x1F, 0xE0, ##  000000 000000      00000000   
            0xFF, 0xE0, 0x07, 0xF0, ##  00000000000          0000000  
            0xFF, 0xC0, 0x03, 0xF0, ##  0000000000            000000  
            0xFF, 0x80, 0x03, 0xF8, ##  000000000             0000000 
            0xFF, 0x00, 0x01, 0xF8, ##  00000000               000000 
            0xFF, 0x00, 0x01, 0xF8, ##  00000000               000000 
            0xFF, 0x00, 0x00, 0xFC, ##  00000000                000000
            0xFE, 0x00, 0x00, 0xFC, ##  0000000                 000000
            0xFE, 0x00, 0x00, 0xFC, ##  0000000                 000000
            0xFE, 0x00, 0x00, 0xFC, ##  0000000                 000000
            0xFE, 0x00, 0x00, 0xFC, ##  0000000                 000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000
            0x7F, 0x00, 0x00, 0xFC, ##   0000000                000000
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000 
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000 
            0x3F, 0x80, 0x03, 0xF8, ##    0000000             0000000 
            0x1F, 0xC0, 0x03, 0xF0, ##     0000000            000000  
            0x1F, 0xE0, 0x07, 0xF0, ##     00000000          0000000  
            0x0F, 0xF8, 0x1F, 0xE0, ##      000000000      00000000   
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000   
            0x03, 0xFF, 0xFF, 0xC0, ##        00000000000000000000    
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000      
            0x00, 0xFF, 0xFE, 0x00, ##          000000000000000       
            0x00, 0x1F, 0xF0, 0x00, ##             000000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '55' => {    # '7'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x07, 0xF0, ##                       0000000 
            0x00, 0x00, 0x07, 0xE0, ##                       000000  
            0x00, 0x00, 0x07, 0xE0, ##                       000000  
            0x00, 0x00, 0x0F, 0xC0, ##                      000000   
            0x00, 0x00, 0x0F, 0xC0, ##                      000000   
            0x00, 0x00, 0x0F, 0xC0, ##                      000000   
            0x00, 0x00, 0x1F, 0x80, ##                     000000    
            0x00, 0x00, 0x1F, 0x80, ##                     000000    
            0x00, 0x00, 0x3F, 0x80, ##                    0000000    
            0x00, 0x00, 0x3F, 0x00, ##                    000000     
            0x00, 0x00, 0x3F, 0x00, ##                    000000     
            0x00, 0x00, 0x7E, 0x00, ##                   000000      
            0x00, 0x00, 0x7E, 0x00, ##                   000000      
            0x00, 0x00, 0xFE, 0x00, ##                  0000000      
            0x00, 0x00, 0xFC, 0x00, ##                  000000       
            0x00, 0x00, 0xFC, 0x00, ##                  000000       
            0x00, 0x01, 0xFC, 0x00, ##                 0000000       
            0x00, 0x01, 0xF8, 0x00, ##                 000000        
            0x00, 0x01, 0xF8, 0x00, ##                 000000        
            0x00, 0x03, 0xF0, 0x00, ##                000000         
            0x00, 0x03, 0xF0, 0x00, ##                000000         
            0x00, 0x07, 0xF0, 0x00, ##               0000000         
            0x00, 0x07, 0xE0, 0x00, ##               000000          
            0x00, 0x07, 0xE0, 0x00, ##               000000          
            0x00, 0x0F, 0xE0, 0x00, ##              0000000          
            0x00, 0x0F, 0xC0, 0x00, ##              000000           
            0x00, 0x1F, 0xC0, 0x00, ##             0000000           
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x3F, 0x80, 0x00, ##            0000000            
            0x00, 0x3F, 0x00, 0x00, ##            000000             
            0x00, 0x7F, 0x00, 0x00, ##           0000000             
            0x00, 0x7F, 0x00, 0x00, ##           0000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000              
            0x00, 0xFE, 0x00, 0x00, ##          0000000              
            0x00, 0xFC, 0x00, 0x00, ##          000000               
            0x00, 0xFC, 0x00, 0x00, ##          000000               
            0x01, 0xFC, 0x00, 0x00, ##         0000000               
            0x01, 0xF8, 0x00, 0x00, ##         000000                
            0x03, 0xF8, 0x00, 0x00, ##        0000000                
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '56' => {    # '8'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x3F, 0xF0, 0x00, ##            0000000000          
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x3F, 0xC0, 0x0F, 0xF0, ##    00000000          00000000  
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x7F, 0x00, 0x03, 0xF0, ##   0000000              000000  
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x1F, 0x80, 0x07, 0xE0, ##     000000            000000   
            0x0F, 0xC0, 0x0F, 0xE0, ##      000000          0000000   
            0x07, 0xF0, 0x3F, 0xC0, ##       0000000      00000000    
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000     
            0x00, 0xFF, 0xFE, 0x00, ##          000000000000000       
            0x00, 0xFF, 0xF8, 0x00, ##          0000000000000         
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x0F, 0xFF, 0xFF, 0x80, ##      000000000000000000000     
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFE, 0x00, 0x01, 0xFC, ##  0000000                0000000
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x3F, 0xF0, 0x3F, 0xF0, ##    0000000000      0000000000  
            0x1F, 0xFF, 0xFF, 0xE0, ##     000000000000000000000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x01, 0xFF, 0xFE, 0x00, ##         0000000000000000       
            0x00, 0x3F, 0xF0, 0x00, ##            0000000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '57' => {    # '9'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x3F, 0xE0, 0x00, ##            000000000           
            0x01, 0xFF, 0xF8, 0x00, ##         00000000000000         
            0x03, 0xFF, 0xFE, 0x00, ##        00000000000000000       
            0x0F, 0xFF, 0xFF, 0x00, ##      00000000000000000000      
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000     
            0x1F, 0xE0, 0x7F, 0xC0, ##     00000000      000000000    
            0x3F, 0x80, 0x1F, 0xE0, ##    0000000          00000000   
            0x3F, 0x00, 0x0F, 0xE0, ##    000000            0000000   
            0x7F, 0x00, 0x07, 0xF0, ##   0000000             0000000  
            0x7E, 0x00, 0x03, 0xF0, ##   000000               000000  
            0x7E, 0x00, 0x03, 0xF0, ##   000000               000000  
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x00, 0x03, 0xFC, ##  000000                00000000
            0x7E, 0x00, 0x03, 0xFC, ##   000000               00000000
            0x7E, 0x00, 0x03, 0xFC, ##   000000               00000000
            0x7F, 0x00, 0x07, 0xFC, ##   0000000             000000000
            0x3F, 0x00, 0x0F, 0xFC, ##    000000            0000000000
            0x3F, 0x80, 0x1F, 0xFC, ##    0000000          00000000000
            0x1F, 0xE0, 0x7E, 0xFC, ##     00000000      000000 000000
            0x1F, 0xFF, 0xFE, 0xFC, ##     00000000000000000000 000000
            0x0F, 0xFF, 0xFC, 0xFC, ##      000000000000000000  000000
            0x07, 0xFF, 0xF8, 0xFC, ##       0000000000000000   000000
            0x01, 0xFF, 0xF0, 0xFC, ##         0000000000000    000000
            0x00, 0x3F, 0x80, 0xFC, ##            0000000       000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000 
            0x00, 0x00, 0x01, 0xF8, ##                         000000 
            0x00, 0x00, 0x01, 0xF8, ##                         000000 
            0x00, 0x00, 0x01, 0xF8, ##                         000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000  
            0x00, 0x00, 0x03, 0xF0, ##                        000000  
            0x00, 0x00, 0x07, 0xF0, ##                       0000000  
            0x00, 0x00, 0x07, 0xE0, ##                       000000   
            0x00, 0x00, 0x0F, 0xE0, ##                      0000000   
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000    
            0x18, 0x00, 0x3F, 0xC0, ##     00             00000000    
            0x1F, 0x00, 0xFF, 0x80, ##     00000        000000000     
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000      
            0x1F, 0xFF, 0xFE, 0x00, ##     00000000000000000000       
            0x1F, 0xFF, 0xFC, 0x00, ##     0000000000000000000        
            0x0F, 0xFF, 0xF0, 0x00, ##      0000000000000000          
            0x00, 0xFF, 0x80, 0x00, ##          000000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '58' => {    # ':'
        'width'    => 8, 
        'xoffset'  => 15, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '59' => {    # ';'
        'width'    => 11, 
        'xoffset'  => 12, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xE0, ##     00000000
            0x1F, 0xC0, ##     0000000 
            0x3F, 0xC0, ##    00000000 
            0x3F, 0x80, ##    0000000  
            0x3F, 0x80, ##    0000000  
            0x3F, 0x00, ##    000000   
            0x3F, 0x00, ##    000000   
            0x7E, 0x00, ##   000000    
            0x7E, 0x00, ##   000000    
            0x7C, 0x00, ##   00000     
            0x7C, 0x00, ##   00000     
            0xF8, 0x00, ##  00000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '60' => {    # '<'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x80, ##                                  0
            0x00, 0x00, 0x00, 0x03, 0x80, ##                                000
            0x00, 0x00, 0x00, 0x1F, 0x80, ##                             000000
            0x00, 0x00, 0x00, 0x7F, 0x80, ##                           00000000
            0x00, 0x00, 0x03, 0xFF, 0x80, ##                        00000000000
            0x00, 0x00, 0x1F, 0xFF, 0x80, ##                     00000000000000
            0x00, 0x00, 0x7F, 0xFE, 0x00, ##                   00000000000000  
            0x00, 0x03, 0xFF, 0xF8, 0x00, ##                000000000000000    
            0x00, 0x0F, 0xFF, 0xC0, 0x00, ##              00000000000000       
            0x00, 0x7F, 0xFE, 0x00, 0x00, ##           00000000000000          
            0x01, 0xFF, 0xF8, 0x00, 0x00, ##         00000000000000            
            0x0F, 0xFF, 0xC0, 0x00, 0x00, ##      00000000000000               
            0x3F, 0xFE, 0x00, 0x00, 0x00, ##    0000000000000                  
            0xFF, 0xF8, 0x00, 0x00, 0x00, ##  0000000000000                    
            0xFF, 0xC0, 0x00, 0x00, 0x00, ##  0000000000                       
            0xFE, 0x00, 0x00, 0x00, 0x00, ##  0000000                          
            0xFF, 0x00, 0x00, 0x00, 0x00, ##  00000000                         
            0xFF, 0xE0, 0x00, 0x00, 0x00, ##  00000000000                      
            0xFF, 0xF8, 0x00, 0x00, 0x00, ##  0000000000000                    
            0x1F, 0xFF, 0x00, 0x00, 0x00, ##     0000000000000                 
            0x07, 0xFF, 0xE0, 0x00, 0x00, ##       00000000000000              
            0x00, 0xFF, 0xF8, 0x00, 0x00, ##          0000000000000            
            0x00, 0x3F, 0xFF, 0x00, 0x00, ##            00000000000000         
            0x00, 0x07, 0xFF, 0xE0, 0x00, ##               00000000000000      
            0x00, 0x01, 0xFF, 0xF8, 0x00, ##                 00000000000000    
            0x00, 0x00, 0x3F, 0xFF, 0x00, ##                    00000000000000 
            0x00, 0x00, 0x0F, 0xFF, 0x80, ##                      0000000000000
            0x00, 0x00, 0x01, 0xFF, 0x80, ##                         0000000000
            0x00, 0x00, 0x00, 0x7F, 0x80, ##                           00000000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x03, 0x80, ##                                000
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '61' => {    # '='
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '62' => {    # '>'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x80, 0x00, 0x00, 0x00, 0x00, ##  0                                
            0xE0, 0x00, 0x00, 0x00, 0x00, ##  000                              
            0xFC, 0x00, 0x00, 0x00, 0x00, ##  000000                           
            0xFF, 0x00, 0x00, 0x00, 0x00, ##  00000000                         
            0xFF, 0xE0, 0x00, 0x00, 0x00, ##  00000000000                      
            0xFF, 0xFC, 0x00, 0x00, 0x00, ##  00000000000000                   
            0x3F, 0xFF, 0x00, 0x00, 0x00, ##    00000000000000                 
            0x0F, 0xFF, 0xE0, 0x00, 0x00, ##      000000000000000              
            0x01, 0xFF, 0xF8, 0x00, 0x00, ##         00000000000000            
            0x00, 0x3F, 0xFF, 0x00, 0x00, ##            00000000000000         
            0x00, 0x0F, 0xFF, 0xC0, 0x00, ##              00000000000000       
            0x00, 0x01, 0xFF, 0xF8, 0x00, ##                 00000000000000    
            0x00, 0x00, 0x3F, 0xFE, 0x00, ##                    0000000000000  
            0x00, 0x00, 0x0F, 0xFF, 0x80, ##                      0000000000000
            0x00, 0x00, 0x01, 0xFF, 0x80, ##                         0000000000
            0x00, 0x00, 0x00, 0x3F, 0x80, ##                            0000000
            0x00, 0x00, 0x00, 0x7F, 0x80, ##                           00000000
            0x00, 0x00, 0x03, 0xFF, 0x80, ##                        00000000000
            0x00, 0x00, 0x0F, 0xFF, 0x80, ##                      0000000000000
            0x00, 0x00, 0x7F, 0xFC, 0x00, ##                   0000000000000   
            0x00, 0x03, 0xFF, 0xF0, 0x00, ##                00000000000000     
            0x00, 0x0F, 0xFF, 0x80, 0x00, ##              0000000000000        
            0x00, 0x7F, 0xFE, 0x00, 0x00, ##           00000000000000          
            0x03, 0xFF, 0xF0, 0x00, 0x00, ##        00000000000000             
            0x0F, 0xFF, 0xC0, 0x00, 0x00, ##      00000000000000               
            0x7F, 0xFE, 0x00, 0x00, 0x00, ##   00000000000000                  
            0xFF, 0xF8, 0x00, 0x00, 0x00, ##  0000000000000                    
            0xFF, 0xC0, 0x00, 0x00, 0x00, ##  0000000000                       
            0xFF, 0x00, 0x00, 0x00, 0x00, ##  00000000                         
            0xF8, 0x00, 0x00, 0x00, 0x00, ##  00000                            
            0xE0, 0x00, 0x00, 0x00, 0x00, ##  000                              
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '63' => {    # '?'
        'width'    => 25, 
        'xoffset'  => 8, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x01, 0xFF, 0x00, 0x00, ##         000000000         
            0x0F, 0xFF, 0xE0, 0x00, ##      000000000000000      
            0x3F, 0xFF, 0xF8, 0x00, ##    0000000000000000000    
            0xFF, 0xFF, 0xFC, 0x00, ##  0000000000000000000000   
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000  
            0xFF, 0x01, 0xFF, 0x00, ##  00000000       000000000 
            0xF8, 0x00, 0x7F, 0x00, ##  00000            0000000 
            0xE0, 0x00, 0x3F, 0x00, ##  000               000000 
            0x80, 0x00, 0x3F, 0x80, ##  0                 0000000
            0x00, 0x00, 0x1F, 0x80, ##                     000000
            0x00, 0x00, 0x1F, 0x80, ##                     000000
            0x00, 0x00, 0x1F, 0x80, ##                     000000
            0x00, 0x00, 0x1F, 0x80, ##                     000000
            0x00, 0x00, 0x1F, 0x80, ##                     000000
            0x00, 0x00, 0x3F, 0x00, ##                    000000 
            0x00, 0x00, 0x7F, 0x00, ##                   0000000 
            0x00, 0x00, 0x7E, 0x00, ##                   000000  
            0x00, 0x00, 0xFE, 0x00, ##                  0000000  
            0x00, 0x01, 0xFC, 0x00, ##                 0000000   
            0x00, 0x03, 0xF8, 0x00, ##                0000000    
            0x00, 0x07, 0xF0, 0x00, ##               0000000     
            0x00, 0x0F, 0xE0, 0x00, ##              0000000      
            0x00, 0x1F, 0xC0, 0x00, ##             0000000       
            0x00, 0x3F, 0x80, 0x00, ##            0000000        
            0x00, 0x7F, 0x00, 0x00, ##           0000000         
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0xFE, 0x00, 0x00, ##          0000000          
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '64' => {    # '@'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x7F, 0xC0, 0x00, ##                   000000000          
            0x00, 0x03, 0xFF, 0xF0, 0x00, ##                00000000000000        
            0x00, 0x1F, 0xFF, 0xFC, 0x00, ##             0000000000000000000      
            0x00, 0x3F, 0xFF, 0xFE, 0x00, ##            000000000000000000000     
            0x00, 0x7F, 0xFF, 0xFF, 0x00, ##           00000000000000000000000    
            0x01, 0xFF, 0xC0, 0x7F, 0x80, ##         00000000000       00000000   
            0x01, 0xFE, 0x00, 0x1F, 0xC0, ##         00000000            0000000  
            0x03, 0xF8, 0x00, 0x07, 0xC0, ##        0000000                00000  
            0x07, 0xF0, 0x00, 0x03, 0xE0, ##       0000000                  00000 
            0x0F, 0xE0, 0x00, 0x03, 0xE0, ##      0000000                   00000 
            0x0F, 0xC0, 0x00, 0x01, 0xE0, ##      000000                     0000 
            0x1F, 0x80, 0x00, 0x01, 0xF0, ##     000000                      00000
            0x1F, 0x00, 0x00, 0x00, 0xF0, ##     00000                        0000
            0x3F, 0x00, 0x07, 0xE0, 0xF0, ##    000000             000000     0000
            0x3E, 0x00, 0x3F, 0xF8, 0xF0, ##    00000           00000000000   0000
            0x3E, 0x00, 0x7F, 0xFC, 0xF0, ##    00000          0000000000000  0000
            0x7E, 0x00, 0xFF, 0xFE, 0xF0, ##   000000         000000000000000 0000
            0x7C, 0x01, 0xFF, 0xFF, 0xF0, ##   00000         000000000000000000000
            0x7C, 0x03, 0xFC, 0x1F, 0xF0, ##   00000        00000000     000000000
            0x7C, 0x03, 0xF0, 0x07, 0xF0, ##   00000        000000         0000000
            0xFC, 0x07, 0xE0, 0x03, 0xF0, ##  000000       000000           000000
            0xF8, 0x07, 0xC0, 0x01, 0xF0, ##  00000        00000             00000
            0xF8, 0x07, 0xC0, 0x01, 0xF0, ##  00000        00000             00000
            0xF8, 0x0F, 0x80, 0x00, 0xF0, ##  00000       00000               0000
            0xF8, 0x0F, 0x80, 0x00, 0xF0, ##  00000       00000               0000
            0xF8, 0x0F, 0x80, 0x00, 0xF0, ##  00000       00000               0000
            0xF8, 0x0F, 0x80, 0x00, 0xF0, ##  00000       00000               0000
            0xF8, 0x0F, 0x80, 0x00, 0xF0, ##  00000       00000               0000
            0xF8, 0x0F, 0x80, 0x00, 0xF0, ##  00000       00000               0000
            0xF8, 0x0F, 0x80, 0x00, 0xF0, ##  00000       00000               0000
            0xF8, 0x0F, 0x80, 0x00, 0xF0, ##  00000       00000               0000
            0xF8, 0x07, 0xC0, 0x01, 0xF0, ##  00000        00000             00000
            0xF8, 0x07, 0xC0, 0x01, 0xF0, ##  00000        00000             00000
            0x7C, 0x07, 0xE0, 0x03, 0xF0, ##   00000       000000           000000
            0x7C, 0x03, 0xF0, 0x07, 0xF0, ##   00000        000000         0000000
            0x7C, 0x03, 0xFC, 0x1F, 0xF0, ##   00000        00000000     000000000
            0x7C, 0x01, 0xFF, 0xFF, 0xF0, ##   00000         000000000000000000000
            0x7E, 0x00, 0xFF, 0xFE, 0xF0, ##   000000         000000000000000 0000
            0x3E, 0x00, 0x7F, 0xFC, 0xF0, ##    00000          0000000000000  0000
            0x3F, 0x00, 0x3F, 0xF8, 0xF0, ##    000000          00000000000   0000
            0x1F, 0x00, 0x0F, 0xE0, 0x00, ##     00000            0000000         
            0x1F, 0x80, 0x00, 0x00, 0x00, ##     000000                           
            0x0F, 0xC0, 0x00, 0x00, 0x00, ##      000000                          
            0x0F, 0xE0, 0x00, 0x00, 0x00, ##      0000000                         
            0x07, 0xF0, 0x00, 0x00, 0x00, ##       0000000                        
            0x03, 0xF8, 0x00, 0x00, 0x00, ##        0000000                       
            0x03, 0xFC, 0x00, 0x00, 0x00, ##        00000000                      
            0x01, 0xFF, 0x00, 0x00, 0x00, ##         000000000                    
            0x00, 0xFF, 0xE0, 0x0E, 0x00, ##          00000000000         000     
            0x00, 0x3F, 0xFF, 0xFE, 0x00, ##            000000000000000000000     
            0x00, 0x1F, 0xFF, 0xFF, 0x00, ##             000000000000000000000    
            0x00, 0x07, 0xFF, 0xFF, 0x00, ##               0000000000000000000    
            0x00, 0x01, 0xFF, 0xFF, 0x00, ##                 00000000000000000    
            0x00, 0x00, 0x1F, 0xF8, 0x00, ##                     0000000000       
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '65' => {    # 'A'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x0F, 0xDF, 0x00, 0x00, ##              000000 00000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000           
            0x00, 0x0F, 0x9F, 0x80, 0x00, ##              00000  000000           
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x8F, 0x80, 0x00, ##             000000   00000           
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000          
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x3F, 0x07, 0xC0, 0x00, ##            000000     00000          
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000         
            0x00, 0x3E, 0x07, 0xE0, 0x00, ##            00000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000        
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000        
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000       
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000      
            0x03, 0xF8, 0x00, 0xFC, 0x00, ##        0000000           000000      
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x03, 0xF0, 0x00, 0xFE, 0x00, ##        000000            0000000     
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000     
            0x07, 0xFF, 0xFF, 0xFE, 0x00, ##       00000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000    
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x00, ##      0000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x80, ##      00000000000000000000000000000   
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000   
            0x1F, 0xC0, 0x00, 0x1F, 0x80, ##     0000000                 000000   
            0x1F, 0x80, 0x00, 0x1F, 0x80, ##     000000                  000000   
            0x1F, 0x80, 0x00, 0x1F, 0xC0, ##     000000                  0000000  
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000  
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000  
            0x3F, 0x00, 0x00, 0x0F, 0xE0, ##    000000                    0000000 
            0x3F, 0x00, 0x00, 0x07, 0xE0, ##    000000                     000000 
            0x7F, 0x00, 0x00, 0x07, 0xE0, ##   0000000                     000000 
            0x7E, 0x00, 0x00, 0x07, 0xF0, ##   000000                      0000000
            0x7E, 0x00, 0x00, 0x07, 0xF0, ##   000000                      0000000
            0xFE, 0x00, 0x00, 0x03, 0xF0, ##  0000000                       000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '66' => {    # 'B'
        'width'    => 30, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xE0, 0x00, ##  0000000000000000000           
            0xFF, 0xFF, 0xFC, 0x00, ##  0000000000000000000000        
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000      
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000     
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000    
            0xFC, 0x00, 0x3F, 0xE0, ##  000000            000000000   
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000  
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000  
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000 
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000  
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000  
            0xFC, 0x00, 0x0F, 0xF0, ##  000000              00000000  
            0xFC, 0x00, 0x3F, 0xE0, ##  000000            000000000   
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000    
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000      
            0xFF, 0xFF, 0xFC, 0x00, ##  0000000000000000000000        
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000      
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000    
            0xFC, 0x00, 0x3F, 0xE0, ##  000000            000000000   
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000  
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000  
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000 
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000 
            0xFC, 0x00, 0x1F, 0xF0, ##  000000             000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000   
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000    
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000     
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000       
            0xFF, 0xFF, 0xE0, 0x00, ##  0000000000000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '67' => {    # 'C'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xFE, 0x00, ##                000000000      
            0x00, 0x1F, 0xFF, 0xE0, ##             0000000000000000  
            0x00, 0x7F, 0xFF, 0xF8, ##           00000000000000000000
            0x00, 0xFF, 0xFF, 0xF8, ##          000000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x03, 0xFE, 0x03, 0xF8, ##        000000000       0000000
            0x07, 0xF8, 0x00, 0x78, ##       00000000            0000
            0x0F, 0xE0, 0x00, 0x18, ##      0000000                00
            0x0F, 0xC0, 0x00, 0x08, ##      000000                  0
            0x1F, 0x80, 0x00, 0x00, ##     000000                    
            0x1F, 0x80, 0x00, 0x00, ##     000000                    
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7C, 0x00, 0x00, 0x00, ##   00000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0x7C, 0x00, 0x00, 0x00, ##   00000                       
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x80, 0x00, 0x00, ##    0000000                    
            0x1F, 0x80, 0x00, 0x00, ##     000000                    
            0x0F, 0xC0, 0x00, 0x08, ##      000000                  0
            0x0F, 0xE0, 0x00, 0x18, ##      0000000                00
            0x07, 0xF0, 0x00, 0x78, ##       0000000             0000
            0x03, 0xFE, 0x03, 0xF8, ##        000000000       0000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x00, 0xFF, 0xFF, 0xF8, ##          000000000000000000000
            0x00, 0x7F, 0xFF, 0xF8, ##           00000000000000000000
            0x00, 0x1F, 0xFF, 0xE0, ##             0000000000000000  
            0x00, 0x03, 0xFE, 0x00, ##                000000000      
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '68' => {    # 'D'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFE, 0x00, 0x00, ##  000000000000000               
            0xFF, 0xFF, 0xE0, 0x00, ##  0000000000000000000           
            0xFF, 0xFF, 0xF8, 0x00, ##  000000000000000000000         
            0xFF, 0xFF, 0xFC, 0x00, ##  0000000000000000000000        
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000      
            0xFC, 0x03, 0xFF, 0x80, ##  000000        00000000000     
            0xFC, 0x00, 0x7F, 0xC0, ##  000000           000000000    
            0xFC, 0x00, 0x1F, 0xC0, ##  000000             0000000    
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000   
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000   
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000  
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000  
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xF8, ##  000000                  00000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000  
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000  
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000   
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000   
            0xFC, 0x00, 0x1F, 0xC0, ##  000000             0000000    
            0xFC, 0x00, 0x7F, 0xC0, ##  000000           000000000    
            0xFC, 0x03, 0xFF, 0x80, ##  000000        00000000000     
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000      
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000       
            0xFF, 0xFF, 0xF8, 0x00, ##  000000000000000000000         
            0xFF, 0xFF, 0xE0, 0x00, ##  0000000000000000000           
            0xFF, 0xFE, 0x00, 0x00, ##  000000000000000               
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '69' => {    # 'E'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '70' => {    # 'F'
        'width'    => 28, 
        'xoffset'  => 7, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000  
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                      
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '71' => {    # 'G'
        'width'    => 31, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xFE, 0x00, ##                000000000        
            0x00, 0x1F, 0xFF, 0xC0, ##             000000000000000     
            0x00, 0x7F, 0xFF, 0xF0, ##           0000000000000000000   
            0x00, 0xFF, 0xFF, 0xF8, ##          000000000000000000000  
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000  
            0x03, 0xFE, 0x03, 0xF8, ##        000000000       0000000  
            0x07, 0xF8, 0x00, 0x78, ##       00000000            0000  
            0x0F, 0xE0, 0x00, 0x18, ##      0000000                00  
            0x0F, 0xC0, 0x00, 0x08, ##      000000                  0  
            0x1F, 0x80, 0x00, 0x00, ##     000000                      
            0x1F, 0x80, 0x00, 0x00, ##     000000                      
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7C, 0x00, 0x00, 0x00, ##   00000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x3F, 0xFE, ##  000000            0000000000000
            0xFC, 0x00, 0x3F, 0xFE, ##  000000            0000000000000
            0xFC, 0x00, 0x3F, 0xFE, ##  000000            0000000000000
            0xFC, 0x00, 0x3F, 0xFE, ##  000000            0000000000000
            0xFC, 0x00, 0x3F, 0xFE, ##  000000            0000000000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0x7C, 0x00, 0x00, 0x7E, ##   00000                   000000
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0x3F, 0x00, 0x00, 0x7E, ##    000000                 000000
            0x3F, 0x00, 0x00, 0x7E, ##    000000                 000000
            0x3F, 0x80, 0x00, 0x7E, ##    0000000                000000
            0x1F, 0x80, 0x00, 0x7E, ##     000000                000000
            0x1F, 0xC0, 0x00, 0x7E, ##     0000000               000000
            0x0F, 0xE0, 0x00, 0x7E, ##      0000000              000000
            0x07, 0xF0, 0x00, 0xFE, ##       0000000            0000000
            0x03, 0xFE, 0x03, 0xFE, ##        000000000       000000000
            0x01, 0xFF, 0xFF, 0xFE, ##         000000000000000000000000
            0x00, 0xFF, 0xFF, 0xFC, ##          0000000000000000000000 
            0x00, 0x7F, 0xFF, 0xF0, ##           0000000000000000000   
            0x00, 0x1F, 0xFF, 0xC0, ##             000000000000000     
            0x00, 0x03, 0xFE, 0x00, ##                000000000        
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '72' => {    # 'H'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '73' => {    # 'I'
        'width'    => 26, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '74' => {    # 'J'
        'width'    => 26, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0xFF, 0xFF, 0xC0, ##          000000000000000000
            0x00, 0xFF, 0xFF, 0xC0, ##          000000000000000000
            0x00, 0xFF, 0xFF, 0xC0, ##          000000000000000000
            0x00, 0xFF, 0xFF, 0xC0, ##          000000000000000000
            0x00, 0xFF, 0xFF, 0xC0, ##          000000000000000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000
            0x80, 0x00, 0x1F, 0x80, ##  0                  000000 
            0xC0, 0x00, 0x1F, 0x80, ##  00                 000000 
            0xE0, 0x00, 0x3F, 0x80, ##  000               0000000 
            0xF8, 0x00, 0x7F, 0x00, ##  00000            0000000  
            0xFF, 0x01, 0xFF, 0x00, ##  00000000       000000000  
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000   
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000   
            0x7F, 0xFF, 0xF8, 0x00, ##   00000000000000000000     
            0x1F, 0xFF, 0xF0, 0x00, ##     00000000000000000      
            0x01, 0xFF, 0x80, 0x00, ##         0000000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '75' => {    # 'K'
        'width'    => 34, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x7F, 0x80, ##  000000                   00000000 
            0xFC, 0x00, 0x00, 0xFF, 0x00, ##  000000                  00000000  
            0xFC, 0x00, 0x01, 0xFE, 0x00, ##  000000                 00000000   
            0xFC, 0x00, 0x03, 0xFC, 0x00, ##  000000                00000000    
            0xFC, 0x00, 0x07, 0xF8, 0x00, ##  000000               00000000     
            0xFC, 0x00, 0x07, 0xF0, 0x00, ##  000000               0000000      
            0xFC, 0x00, 0x0F, 0xE0, 0x00, ##  000000              0000000       
            0xFC, 0x00, 0x1F, 0xC0, 0x00, ##  000000             0000000        
            0xFC, 0x00, 0x3F, 0x80, 0x00, ##  000000            0000000         
            0xFC, 0x00, 0x7F, 0x00, 0x00, ##  000000           0000000          
            0xFC, 0x00, 0xFE, 0x00, 0x00, ##  000000          0000000           
            0xFC, 0x01, 0xFC, 0x00, 0x00, ##  000000         0000000            
            0xFC, 0x03, 0xF8, 0x00, 0x00, ##  000000        0000000             
            0xFC, 0x07, 0xF0, 0x00, 0x00, ##  000000       0000000              
            0xFC, 0x0F, 0xE0, 0x00, 0x00, ##  000000      0000000               
            0xFC, 0x1F, 0xC0, 0x00, 0x00, ##  000000     0000000                
            0xFC, 0x3F, 0xC0, 0x00, 0x00, ##  000000    00000000                
            0xFC, 0x7F, 0x80, 0x00, 0x00, ##  000000   00000000                 
            0xFC, 0xFF, 0x00, 0x00, 0x00, ##  000000  00000000                  
            0xFD, 0xFE, 0x00, 0x00, 0x00, ##  000000 00000000                   
            0xFF, 0xFF, 0x00, 0x00, 0x00, ##  0000000000000000                  
            0xFF, 0xFF, 0x80, 0x00, 0x00, ##  00000000000000000                 
            0xFF, 0xFF, 0x80, 0x00, 0x00, ##  00000000000000000                 
            0xFF, 0xFF, 0xC0, 0x00, 0x00, ##  000000000000000000                
            0xFF, 0xDF, 0xE0, 0x00, 0x00, ##  0000000000 00000000               
            0xFF, 0x8F, 0xE0, 0x00, 0x00, ##  000000000   0000000               
            0xFF, 0x07, 0xF0, 0x00, 0x00, ##  00000000     0000000              
            0xFE, 0x07, 0xF8, 0x00, 0x00, ##  0000000      00000000             
            0xFC, 0x03, 0xF8, 0x00, 0x00, ##  000000        0000000             
            0xFC, 0x01, 0xFC, 0x00, 0x00, ##  000000         0000000            
            0xFC, 0x01, 0xFE, 0x00, 0x00, ##  000000         00000000           
            0xFC, 0x00, 0xFE, 0x00, 0x00, ##  000000          0000000           
            0xFC, 0x00, 0x7F, 0x00, 0x00, ##  000000           0000000          
            0xFC, 0x00, 0x7F, 0x80, 0x00, ##  000000           00000000         
            0xFC, 0x00, 0x3F, 0x80, 0x00, ##  000000            0000000         
            0xFC, 0x00, 0x1F, 0xC0, 0x00, ##  000000             0000000        
            0xFC, 0x00, 0x1F, 0xE0, 0x00, ##  000000             00000000       
            0xFC, 0x00, 0x0F, 0xE0, 0x00, ##  000000              0000000       
            0xFC, 0x00, 0x07, 0xF0, 0x00, ##  000000               0000000      
            0xFC, 0x00, 0x07, 0xF8, 0x00, ##  000000               00000000     
            0xFC, 0x00, 0x03, 0xF8, 0x00, ##  000000                0000000     
            0xFC, 0x00, 0x03, 0xFC, 0x00, ##  000000                00000000    
            0xFC, 0x00, 0x01, 0xFE, 0x00, ##  000000                 00000000   
            0xFC, 0x00, 0x00, 0xFE, 0x00, ##  000000                  0000000   
            0xFC, 0x00, 0x00, 0xFF, 0x00, ##  000000                  00000000  
            0xFC, 0x00, 0x00, 0x7F, 0x80, ##  000000                   00000000 
            0xFC, 0x00, 0x00, 0x3F, 0x80, ##  000000                    0000000 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '76' => {    # 'L'
        'width'    => 29, 
        'xoffset'  => 7, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '77' => {    # 'M'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0x80, 0x00, 0xFF, 0x80, ##  000000000               000000000
            0xFF, 0x80, 0x00, 0xFF, 0x80, ##  000000000               000000000
            0xFF, 0x80, 0x00, 0xFF, 0x80, ##  000000000               000000000
            0xFF, 0xC0, 0x01, 0xFF, 0x80, ##  0000000000             0000000000
            0xFF, 0xC0, 0x01, 0xFF, 0x80, ##  0000000000             0000000000
            0xFF, 0xC0, 0x01, 0xFF, 0x80, ##  0000000000             0000000000
            0xFF, 0xE0, 0x03, 0xFF, 0x80, ##  00000000000           00000000000
            0xFD, 0xE0, 0x03, 0xDF, 0x80, ##  000000 0000           0000 000000
            0xFD, 0xE0, 0x03, 0xDF, 0x80, ##  000000 0000           0000 000000
            0xFD, 0xF0, 0x07, 0xDF, 0x80, ##  000000 00000         00000 000000
            0xFC, 0xF0, 0x07, 0x9F, 0x80, ##  000000  0000         0000  000000
            0xFC, 0xF0, 0x07, 0x9F, 0x80, ##  000000  0000         0000  000000
            0xFC, 0xF8, 0x0F, 0x9F, 0x80, ##  000000  00000       00000  000000
            0xFC, 0x78, 0x0F, 0x1F, 0x80, ##  000000   0000       0000   000000
            0xFC, 0x78, 0x0F, 0x1F, 0x80, ##  000000   0000       0000   000000
            0xFC, 0x7C, 0x1F, 0x1F, 0x80, ##  000000   00000     00000   000000
            0xFC, 0x3C, 0x1E, 0x1F, 0x80, ##  000000    0000     0000    000000
            0xFC, 0x3C, 0x1E, 0x1F, 0x80, ##  000000    0000     0000    000000
            0xFC, 0x3E, 0x3E, 0x1F, 0x80, ##  000000    00000   00000    000000
            0xFC, 0x1E, 0x3C, 0x1F, 0x80, ##  000000     0000   0000     000000
            0xFC, 0x1E, 0x3C, 0x1F, 0x80, ##  000000     0000   0000     000000
            0xFC, 0x1F, 0x7C, 0x1F, 0x80, ##  000000     00000 00000     000000
            0xFC, 0x0F, 0x78, 0x1F, 0x80, ##  000000      0000 0000      000000
            0xFC, 0x0F, 0x78, 0x1F, 0x80, ##  000000      0000 0000      000000
            0xFC, 0x0F, 0xF8, 0x1F, 0x80, ##  000000      000000000      000000
            0xFC, 0x07, 0xF0, 0x1F, 0x80, ##  000000       0000000       000000
            0xFC, 0x07, 0xF0, 0x1F, 0x80, ##  000000       0000000       000000
            0xFC, 0x07, 0xF0, 0x1F, 0x80, ##  000000       0000000       000000
            0xFC, 0x03, 0xE0, 0x1F, 0x80, ##  000000        00000        000000
            0xFC, 0x03, 0xE0, 0x1F, 0x80, ##  000000        00000        000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '78' => {    # 'N'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0x00, 0x00, 0xFC, ##  00000000                000000
            0xFF, 0x80, 0x00, 0xFC, ##  000000000               000000
            0xFF, 0x80, 0x00, 0xFC, ##  000000000               000000
            0xFF, 0x80, 0x00, 0xFC, ##  000000000               000000
            0xFF, 0xC0, 0x00, 0xFC, ##  0000000000              000000
            0xFF, 0xC0, 0x00, 0xFC, ##  0000000000              000000
            0xFF, 0xE0, 0x00, 0xFC, ##  00000000000             000000
            0xFF, 0xE0, 0x00, 0xFC, ##  00000000000             000000
            0xFF, 0xE0, 0x00, 0xFC, ##  00000000000             000000
            0xFF, 0xF0, 0x00, 0xFC, ##  000000000000            000000
            0xFD, 0xF0, 0x00, 0xFC, ##  000000 00000            000000
            0xFD, 0xF8, 0x00, 0xFC, ##  000000 000000           000000
            0xFC, 0xF8, 0x00, 0xFC, ##  000000  00000           000000
            0xFC, 0xFC, 0x00, 0xFC, ##  000000  000000          000000
            0xFC, 0x7C, 0x00, 0xFC, ##  000000   00000          000000
            0xFC, 0x7C, 0x00, 0xFC, ##  000000   00000          000000
            0xFC, 0x7E, 0x00, 0xFC, ##  000000   000000         000000
            0xFC, 0x3E, 0x00, 0xFC, ##  000000    00000         000000
            0xFC, 0x3F, 0x00, 0xFC, ##  000000    000000        000000
            0xFC, 0x1F, 0x00, 0xFC, ##  000000     00000        000000
            0xFC, 0x1F, 0x00, 0xFC, ##  000000     00000        000000
            0xFC, 0x1F, 0x80, 0xFC, ##  000000     000000       000000
            0xFC, 0x0F, 0x80, 0xFC, ##  000000      00000       000000
            0xFC, 0x0F, 0xC0, 0xFC, ##  000000      000000      000000
            0xFC, 0x07, 0xC0, 0xFC, ##  000000       00000      000000
            0xFC, 0x07, 0xE0, 0xFC, ##  000000       000000     000000
            0xFC, 0x03, 0xE0, 0xFC, ##  000000        00000     000000
            0xFC, 0x03, 0xE0, 0xFC, ##  000000        00000     000000
            0xFC, 0x03, 0xF0, 0xFC, ##  000000        000000    000000
            0xFC, 0x01, 0xF0, 0xFC, ##  000000         00000    000000
            0xFC, 0x01, 0xF8, 0xFC, ##  000000         000000   000000
            0xFC, 0x00, 0xF8, 0xFC, ##  000000          00000   000000
            0xFC, 0x00, 0xF8, 0xFC, ##  000000          00000   000000
            0xFC, 0x00, 0xFC, 0xFC, ##  000000          000000  000000
            0xFC, 0x00, 0x7C, 0xFC, ##  000000           00000  000000
            0xFC, 0x00, 0x7E, 0xFC, ##  000000           000000 000000
            0xFC, 0x00, 0x3E, 0xFC, ##  000000            00000 000000
            0xFC, 0x00, 0x3F, 0xFC, ##  000000            000000000000
            0xFC, 0x00, 0x1F, 0xFC, ##  000000             00000000000
            0xFC, 0x00, 0x1F, 0xFC, ##  000000             00000000000
            0xFC, 0x00, 0x1F, 0xFC, ##  000000             00000000000
            0xFC, 0x00, 0x0F, 0xFC, ##  000000              0000000000
            0xFC, 0x00, 0x0F, 0xFC, ##  000000              0000000000
            0xFC, 0x00, 0x07, 0xFC, ##  000000               000000000
            0xFC, 0x00, 0x07, 0xFC, ##  000000               000000000
            0xFC, 0x00, 0x07, 0xFC, ##  000000               000000000
            0xFC, 0x00, 0x03, 0xFC, ##  000000                00000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '79' => {    # 'O'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x0F, 0xF8, 0x3F, 0xE0, ##      000000000     000000000    
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000   
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x7E, 0x00, 0x00, 0xF8, ##   000000                 00000  
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0xFC, 0x00, 0x00, 0x7C, ##  000000                   00000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x80, 0x03, 0xF0, ##    0000000             000000   
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x0F, 0xF0, 0x1F, 0xE0, ##      00000000       00000000    
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '80' => {    # 'P'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xE0, 0x00, ##  0000000000000000000          
            0xFF, 0xFF, 0xFC, 0x00, ##  0000000000000000000000       
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000     
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000    
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000   
            0xFC, 0x00, 0x7F, 0xE0, ##  000000           0000000000  
            0xFC, 0x00, 0x1F, 0xE0, ##  000000             00000000  
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000 
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000 
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000 
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000 
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000 
            0xFC, 0x00, 0x1F, 0xE0, ##  000000             00000000  
            0xFC, 0x00, 0x7F, 0xE0, ##  000000           0000000000  
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000   
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000    
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000     
            0xFF, 0xFF, 0xFC, 0x00, ##  0000000000000000000000       
            0xFF, 0xFF, 0xE0, 0x00, ##  0000000000000000000          
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '81' => {    # 'Q'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x0F, 0xF8, 0x3F, 0xE0, ##      000000000     000000000    
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000   
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x7E, 0x00, 0x00, 0xF8, ##   000000                 00000  
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0xFC, 0x00, 0x00, 0x7C, ##  000000                   00000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x1F, 0x80, 0x03, 0xF8, ##     000000             0000000  
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x0F, 0xE0, 0x0F, 0xF0, ##      0000000         00000000   
            0x0F, 0xF0, 0x1F, 0xE0, ##      00000000       00000000    
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x00, 0x7F, 0xFE, 0x00, ##           00000000000000        
            0x00, 0x1F, 0xFF, 0x00, ##             0000000000000       
            0x00, 0x00, 0x7F, 0x80, ##                   00000000      
            0x00, 0x00, 0x3F, 0xC0, ##                    00000000     
            0x00, 0x00, 0x1F, 0xE0, ##                     00000000    
            0x00, 0x00, 0x0F, 0xF0, ##                      00000000   
            0x00, 0x00, 0x07, 0xF8, ##                       00000000  
            0x00, 0x00, 0x03, 0xE0, ##                        00000    
            0x00, 0x00, 0x01, 0xC0, ##                         000     
            0x00, 0x00, 0x00, 0x80, ##                          0      
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '82' => {    # 'R'
        'width'    => 34, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xC0, 0x00, 0x00, ##  000000000000000000                
            0xFF, 0xFF, 0xFC, 0x00, 0x00, ##  0000000000000000000000            
            0xFF, 0xFF, 0xFE, 0x00, 0x00, ##  00000000000000000000000           
            0xFF, 0xFF, 0xFF, 0x80, 0x00, ##  0000000000000000000000000         
            0xFF, 0xFF, 0xFF, 0xC0, 0x00, ##  00000000000000000000000000        
            0xFC, 0x00, 0x7F, 0xE0, 0x00, ##  000000           0000000000       
            0xFC, 0x00, 0x1F, 0xE0, 0x00, ##  000000             00000000       
            0xFC, 0x00, 0x07, 0xF0, 0x00, ##  000000               0000000      
            0xFC, 0x00, 0x03, 0xF0, 0x00, ##  000000                000000      
            0xFC, 0x00, 0x03, 0xF0, 0x00, ##  000000                000000      
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x03, 0xF0, 0x00, ##  000000                000000      
            0xFC, 0x00, 0x03, 0xF0, 0x00, ##  000000                000000      
            0xFC, 0x00, 0x07, 0xF0, 0x00, ##  000000               0000000      
            0xFC, 0x00, 0x0F, 0xE0, 0x00, ##  000000              0000000       
            0xFC, 0x00, 0x3F, 0xC0, 0x00, ##  000000            00000000        
            0xFF, 0xFF, 0xFF, 0x80, 0x00, ##  0000000000000000000000000         
            0xFF, 0xFF, 0xFF, 0x00, 0x00, ##  000000000000000000000000          
            0xFF, 0xFF, 0xF8, 0x00, 0x00, ##  000000000000000000000             
            0xFF, 0xFF, 0xF8, 0x00, 0x00, ##  000000000000000000000             
            0xFF, 0xFF, 0xFE, 0x00, 0x00, ##  00000000000000000000000           
            0xFC, 0x01, 0xFF, 0x00, 0x00, ##  000000         000000000          
            0xFC, 0x00, 0x7F, 0x80, 0x00, ##  000000           00000000         
            0xFC, 0x00, 0x3F, 0x80, 0x00, ##  000000            0000000         
            0xFC, 0x00, 0x1F, 0xC0, 0x00, ##  000000             0000000        
            0xFC, 0x00, 0x0F, 0xC0, 0x00, ##  000000              000000        
            0xFC, 0x00, 0x0F, 0xE0, 0x00, ##  000000              0000000       
            0xFC, 0x00, 0x07, 0xE0, 0x00, ##  000000               000000       
            0xFC, 0x00, 0x03, 0xF0, 0x00, ##  000000                000000      
            0xFC, 0x00, 0x03, 0xF8, 0x00, ##  000000                0000000     
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x01, 0xF8, 0x00, ##  000000                 000000     
            0xFC, 0x00, 0x01, 0xFC, 0x00, ##  000000                 0000000    
            0xFC, 0x00, 0x00, 0xFC, 0x00, ##  000000                  000000    
            0xFC, 0x00, 0x00, 0xFE, 0x00, ##  000000                  0000000   
            0xFC, 0x00, 0x00, 0x7E, 0x00, ##  000000                   000000   
            0xFC, 0x00, 0x00, 0x7F, 0x00, ##  000000                   0000000  
            0xFC, 0x00, 0x00, 0x3F, 0x00, ##  000000                    000000  
            0xFC, 0x00, 0x00, 0x3F, 0x80, ##  000000                    0000000 
            0xFC, 0x00, 0x00, 0x1F, 0x80, ##  000000                     000000 
            0xFC, 0x00, 0x00, 0x1F, 0xC0, ##  000000                     0000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '83' => {    # 'S'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0xF0, 0x00, ##             000000000          
            0x00, 0xFF, 0xFF, 0x80, ##          00000000000000000     
            0x03, 0xFF, 0xFF, 0xE0, ##        000000000000000000000   
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000   
            0x0F, 0xFF, 0xFF, 0xE0, ##      00000000000000000000000   
            0x1F, 0xF0, 0x0F, 0xE0, ##     000000000        0000000   
            0x3F, 0xC0, 0x01, 0xE0, ##    00000000             0000   
            0x7F, 0x00, 0x00, 0x60, ##   0000000                 00   
            0x7E, 0x00, 0x00, 0x00, ##   000000                       
            0x7E, 0x00, 0x00, 0x00, ##   000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFE, 0x00, 0x00, 0x00, ##  0000000                       
            0xFF, 0x00, 0x00, 0x00, ##  00000000                      
            0x7F, 0x80, 0x00, 0x00, ##   00000000                     
            0x7F, 0xE0, 0x00, 0x00, ##   0000000000                   
            0x3F, 0xFE, 0x00, 0x00, ##    0000000000000               
            0x3F, 0xFF, 0xE0, 0x00, ##    00000000000000000           
            0x1F, 0xFF, 0xFC, 0x00, ##     0000000000000000000        
            0x07, 0xFF, 0xFF, 0x00, ##       0000000000000000000      
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000     
            0x00, 0x7F, 0xFF, 0xC0, ##           00000000000000000    
            0x00, 0x0F, 0xFF, 0xE0, ##              000000000000000   
            0x00, 0x00, 0xFF, 0xF0, ##                  000000000000  
            0x00, 0x00, 0x1F, 0xF8, ##                     0000000000 
            0x00, 0x00, 0x07, 0xF8, ##                       00000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000 
            0x00, 0x00, 0x01, 0xFC, ##                         0000000
            0x00, 0x00, 0x01, 0xFC, ##                         0000000
            0x00, 0x00, 0x00, 0xFC, ##                          000000
            0x00, 0x00, 0x00, 0xFC, ##                          000000
            0x00, 0x00, 0x00, 0xFC, ##                          000000
            0x00, 0x00, 0x00, 0xFC, ##                          000000
            0x00, 0x00, 0x00, 0xFC, ##                          000000
            0x00, 0x00, 0x00, 0xFC, ##                          000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000 
            0x40, 0x00, 0x01, 0xF8, ##   0                     000000 
            0x70, 0x00, 0x03, 0xF8, ##   000                  0000000 
            0x7C, 0x00, 0x0F, 0xF0, ##   00000              00000000  
            0x7F, 0x80, 0x3F, 0xF0, ##   00000000         0000000000  
            0x7F, 0xFF, 0xFF, 0xE0, ##   00000000000000000000000000   
            0x7F, 0xFF, 0xFF, 0xC0, ##   0000000000000000000000000    
            0x7F, 0xFF, 0xFF, 0x00, ##   00000000000000000000000      
            0x0F, 0xFF, 0xFE, 0x00, ##      0000000000000000000       
            0x00, 0xFF, 0xE0, 0x00, ##          00000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '84' => {    # 'T'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xFF, 0xFF, 0xF0, ##  000000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0xF0, ##  000000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0xF0, ##  000000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0xF0, ##  000000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0xF0, ##  000000000000000000000000000000000000
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '85' => {    # 'U'
        'width'    => 29, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0x7C, 0x00, 0x01, 0xF8, ##   00000                 000000
            0x7C, 0x00, 0x03, 0xF0, ##   00000                000000 
            0x7E, 0x00, 0x03, 0xF0, ##   000000               000000 
            0x7F, 0x00, 0x07, 0xF0, ##   0000000             0000000 
            0x3F, 0x80, 0x0F, 0xE0, ##    0000000           0000000  
            0x3F, 0xE0, 0x3F, 0xE0, ##    000000000       000000000  
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x0F, 0xFF, 0xFF, 0x80, ##      000000000000000000000    
            0x07, 0xFF, 0xFF, 0x00, ##       0000000000000000000     
            0x01, 0xFF, 0xFC, 0x00, ##         000000000000000       
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '86' => {    # 'V'
        'width'    => 35, 
        'xoffset'  => 2, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x0F, 0xE0, ##  000000                      0000000
            0xFE, 0x00, 0x00, 0x0F, 0xC0, ##  0000000                     000000 
            0x7E, 0x00, 0x00, 0x0F, 0xC0, ##   000000                     000000 
            0x7E, 0x00, 0x00, 0x1F, 0xC0, ##   000000                    0000000 
            0x7E, 0x00, 0x00, 0x1F, 0x80, ##   000000                    000000  
            0x7F, 0x00, 0x00, 0x1F, 0x80, ##   0000000                   000000  
            0x3F, 0x00, 0x00, 0x3F, 0x80, ##    000000                  0000000  
            0x3F, 0x00, 0x00, 0x3F, 0x80, ##    000000                  0000000  
            0x3F, 0x80, 0x00, 0x3F, 0x00, ##    0000000                 000000   
            0x1F, 0x80, 0x00, 0x3F, 0x00, ##     000000                 000000   
            0x1F, 0x80, 0x00, 0x7F, 0x00, ##     000000                0000000   
            0x1F, 0x80, 0x00, 0x7E, 0x00, ##     000000                000000    
            0x1F, 0xC0, 0x00, 0x7E, 0x00, ##     0000000               000000    
            0x0F, 0xC0, 0x00, 0x7E, 0x00, ##      000000               000000    
            0x0F, 0xC0, 0x00, 0xFE, 0x00, ##      000000              0000000    
            0x0F, 0xC0, 0x00, 0xFC, 0x00, ##      000000              000000     
            0x07, 0xE0, 0x00, 0xFC, 0x00, ##       000000             000000     
            0x07, 0xE0, 0x00, 0xFC, 0x00, ##       000000             000000     
            0x07, 0xE0, 0x01, 0xF8, 0x00, ##       000000            000000      
            0x07, 0xE0, 0x01, 0xF8, 0x00, ##       000000            000000      
            0x03, 0xF0, 0x01, 0xF8, 0x00, ##        000000           000000      
            0x03, 0xF0, 0x01, 0xF8, 0x00, ##        000000           000000      
            0x03, 0xF0, 0x03, 0xF0, 0x00, ##        000000          000000       
            0x01, 0xF0, 0x03, 0xF0, 0x00, ##         00000          000000       
            0x01, 0xF8, 0x03, 0xF0, 0x00, ##         000000         000000       
            0x01, 0xF8, 0x07, 0xE0, 0x00, ##         000000        000000        
            0x01, 0xF8, 0x07, 0xE0, 0x00, ##         000000        000000        
            0x00, 0xFC, 0x07, 0xE0, 0x00, ##          000000       000000        
            0x00, 0xFC, 0x07, 0xC0, 0x00, ##          000000       00000         
            0x00, 0xFC, 0x0F, 0xC0, 0x00, ##          000000      000000         
            0x00, 0x7C, 0x0F, 0xC0, 0x00, ##           00000      000000         
            0x00, 0x7E, 0x0F, 0xC0, 0x00, ##           000000     000000         
            0x00, 0x7E, 0x0F, 0x80, 0x00, ##           000000     00000          
            0x00, 0x3E, 0x1F, 0x80, 0x00, ##            00000    000000          
            0x00, 0x3E, 0x1F, 0x80, 0x00, ##            00000    000000          
            0x00, 0x3F, 0x1F, 0x00, 0x00, ##            000000   00000           
            0x00, 0x3F, 0x1F, 0x00, 0x00, ##            000000   00000           
            0x00, 0x1F, 0x3F, 0x00, 0x00, ##             00000  000000           
            0x00, 0x1F, 0x3F, 0x00, 0x00, ##             00000  000000           
            0x00, 0x1F, 0xBE, 0x00, 0x00, ##             000000 00000            
            0x00, 0x0F, 0xBE, 0x00, 0x00, ##              00000 00000            
            0x00, 0x0F, 0xFE, 0x00, 0x00, ##              00000000000            
            0x00, 0x0F, 0xFC, 0x00, 0x00, ##              0000000000             
            0x00, 0x0F, 0xFC, 0x00, 0x00, ##              0000000000             
            0x00, 0x07, 0xFC, 0x00, 0x00, ##               000000000             
            0x00, 0x07, 0xFC, 0x00, 0x00, ##               000000000             
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000              
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '87' => {    # 'W'
        'width'    => 39, 
        'xoffset'  => 0, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, 0xFC, ##  000000                          000000 
            0xFC, 0x00, 0x00, 0x00, 0xFC, ##  000000                          000000 
            0xFC, 0x00, 0x00, 0x00, 0xFC, ##  000000                          000000 
            0x7E, 0x00, 0x00, 0x00, 0xFC, ##   000000                         000000 
            0x7E, 0x00, 0x00, 0x00, 0xFC, ##   000000                         000000 
            0x7E, 0x00, 0x00, 0x00, 0xFC, ##   000000                         000000 
            0x7E, 0x00, 0x00, 0x00, 0xFC, ##   000000                         000000 
            0x7E, 0x00, 0x00, 0x01, 0xF8, ##   000000                        000000  
            0x7E, 0x00, 0x00, 0x01, 0xF8, ##   000000                        000000  
            0x7E, 0x00, 0x00, 0x01, 0xF8, ##   000000                        000000  
            0x3E, 0x00, 0x00, 0x01, 0xF8, ##    00000                        000000  
            0x3F, 0x00, 0x00, 0x01, 0xF8, ##    000000                       000000  
            0x3F, 0x00, 0x00, 0x01, 0xF8, ##    000000                       000000  
            0x3F, 0x00, 0xFE, 0x01, 0xF8, ##    000000        0000000        000000  
            0x3F, 0x00, 0xFE, 0x01, 0xF0, ##    000000        0000000        00000   
            0x3F, 0x01, 0xFE, 0x01, 0xF0, ##    000000       00000000        00000   
            0x3F, 0x01, 0xFE, 0x03, 0xF0, ##    000000       00000000       000000   
            0x1F, 0x01, 0xFE, 0x03, 0xF0, ##     00000       00000000       000000   
            0x1F, 0x01, 0xFF, 0x03, 0xF0, ##     00000       000000000      000000   
            0x1F, 0x01, 0xFF, 0x03, 0xF0, ##     00000       000000000      000000   
            0x1F, 0x83, 0xEF, 0x03, 0xF0, ##     000000     00000 0000      000000   
            0x1F, 0x83, 0xEF, 0x03, 0xE0, ##     000000     00000 0000      00000    
            0x1F, 0x83, 0xEF, 0x83, 0xE0, ##     000000     00000 00000     00000    
            0x1F, 0x83, 0xCF, 0x83, 0xE0, ##     000000     0000  00000     00000    
            0x0F, 0x87, 0xCF, 0x87, 0xE0, ##      00000    00000  00000    000000    
            0x0F, 0x87, 0xC7, 0x87, 0xE0, ##      00000    00000   0000    000000    
            0x0F, 0x87, 0xC7, 0x87, 0xE0, ##      00000    00000   0000    000000    
            0x0F, 0x87, 0x87, 0xC7, 0xC0, ##      00000    0000    00000   00000     
            0x0F, 0x87, 0x87, 0xC7, 0xC0, ##      00000    0000    00000   00000     
            0x0F, 0xCF, 0x83, 0xC7, 0xC0, ##      000000  00000     0000   00000     
            0x07, 0xCF, 0x83, 0xC7, 0xC0, ##       00000  00000     0000   00000     
            0x07, 0xCF, 0x03, 0xC7, 0xC0, ##       00000  0000      0000   00000     
            0x07, 0xCF, 0x03, 0xE7, 0xC0, ##       00000  0000      00000  00000     
            0x07, 0xCF, 0x01, 0xEF, 0xC0, ##       00000  0000       0000 000000     
            0x07, 0xDF, 0x01, 0xEF, 0x80, ##       00000 00000       0000 00000      
            0x07, 0xDF, 0x01, 0xEF, 0x80, ##       00000 00000       0000 00000      
            0x07, 0xDE, 0x01, 0xFF, 0x80, ##       00000 0000        0000000000      
            0x03, 0xFE, 0x01, 0xFF, 0x80, ##        000000000        0000000000      
            0x03, 0xFE, 0x00, 0xFF, 0x80, ##        000000000         000000000      
            0x03, 0xFE, 0x00, 0xFF, 0x80, ##        000000000         000000000      
            0x03, 0xFC, 0x00, 0xFF, 0x80, ##        00000000          000000000      
            0x03, 0xFC, 0x00, 0xFF, 0x00, ##        00000000          00000000       
            0x03, 0xFC, 0x00, 0x7F, 0x00, ##        00000000           0000000       
            0x03, 0xFC, 0x00, 0x7F, 0x00, ##        00000000           0000000       
            0x01, 0xFC, 0x00, 0x7F, 0x00, ##         0000000           0000000       
            0x01, 0xF8, 0x00, 0x7F, 0x00, ##         000000            0000000       
            0x01, 0xF8, 0x00, 0x7F, 0x00, ##         000000            0000000       
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '88' => {    # 'X'
        'width'    => 37, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x3F, 0x80, 0x00, 0x07, 0xF0, ##    0000000                    0000000 
            0x1F, 0x80, 0x00, 0x0F, 0xE0, ##     000000                   0000000  
            0x1F, 0xC0, 0x00, 0x0F, 0xC0, ##     0000000                  000000   
            0x0F, 0xE0, 0x00, 0x1F, 0xC0, ##      0000000                0000000   
            0x0F, 0xE0, 0x00, 0x3F, 0x80, ##      0000000               0000000    
            0x07, 0xF0, 0x00, 0x3F, 0x00, ##       0000000              000000     
            0x03, 0xF0, 0x00, 0x7F, 0x00, ##        000000             0000000     
            0x03, 0xF8, 0x00, 0x7E, 0x00, ##        0000000            000000      
            0x01, 0xF8, 0x00, 0xFE, 0x00, ##         000000           0000000      
            0x01, 0xFC, 0x00, 0xFC, 0x00, ##         0000000          000000       
            0x00, 0xFE, 0x01, 0xF8, 0x00, ##          0000000        000000        
            0x00, 0x7E, 0x03, 0xF8, 0x00, ##           000000       0000000        
            0x00, 0x7F, 0x03, 0xF0, 0x00, ##           0000000      000000         
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000          
            0x00, 0x1F, 0x87, 0xE0, 0x00, ##             000000    000000          
            0x00, 0x1F, 0x8F, 0xC0, 0x00, ##             000000   000000           
            0x00, 0x0F, 0xDF, 0xC0, 0x00, ##              000000 0000000           
            0x00, 0x0F, 0xFF, 0x80, 0x00, ##              0000000000000            
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x03, 0xFF, 0x00, 0x00, ##                0000000000             
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000              
            0x00, 0x01, 0xFC, 0x00, 0x00, ##                 0000000               
            0x00, 0x01, 0xFC, 0x00, 0x00, ##                 0000000               
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000              
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000              
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x0F, 0xFF, 0x80, 0x00, ##              0000000000000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000            
            0x00, 0x1F, 0xCF, 0xC0, 0x00, ##             0000000  000000           
            0x00, 0x1F, 0x8F, 0xC0, 0x00, ##             000000   000000           
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000          
            0x00, 0x7F, 0x07, 0xF0, 0x00, ##           0000000     0000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000         
            0x00, 0xFE, 0x01, 0xF8, 0x00, ##          0000000        000000        
            0x01, 0xFC, 0x01, 0xF8, 0x00, ##         0000000         000000        
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000       
            0x03, 0xF8, 0x00, 0xFE, 0x00, ##        0000000           0000000      
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000      
            0x07, 0xF0, 0x00, 0x7F, 0x00, ##       0000000             0000000     
            0x0F, 0xE0, 0x00, 0x3F, 0x00, ##      0000000               000000     
            0x0F, 0xC0, 0x00, 0x3F, 0x80, ##      000000                0000000    
            0x1F, 0xC0, 0x00, 0x1F, 0xC0, ##     0000000                 0000000   
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000   
            0x3F, 0x80, 0x00, 0x0F, 0xE0, ##    0000000                   0000000  
            0x7F, 0x00, 0x00, 0x07, 0xE0, ##   0000000                     000000  
            0xFE, 0x00, 0x00, 0x07, 0xF0, ##  0000000                      0000000 
            0xFE, 0x00, 0x00, 0x03, 0xF8, ##  0000000                       0000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '89' => {    # 'Y'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFE, 0x00, 0x00, 0x07, 0xF0, ##  0000000                      0000000
            0x7F, 0x00, 0x00, 0x0F, 0xE0, ##   0000000                    0000000 
            0x3F, 0x00, 0x00, 0x0F, 0xE0, ##    000000                    0000000 
            0x3F, 0x80, 0x00, 0x1F, 0xC0, ##    0000000                  0000000  
            0x1F, 0x80, 0x00, 0x1F, 0x80, ##     000000                  000000   
            0x1F, 0xC0, 0x00, 0x3F, 0x80, ##     0000000                0000000   
            0x0F, 0xC0, 0x00, 0x3F, 0x00, ##      000000                000000    
            0x0F, 0xE0, 0x00, 0x7F, 0x00, ##      0000000              0000000    
            0x07, 0xE0, 0x00, 0x7E, 0x00, ##       000000              000000     
            0x03, 0xF0, 0x00, 0xFE, 0x00, ##        000000            0000000     
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xFC, 0x03, 0xF8, 0x00, ##         0000000        0000000       
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFE, 0x07, 0xF0, 0x00, ##          0000000      0000000        
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x0F, 0xFF, 0x00, 0x00, ##              000000000000            
            0x00, 0x0F, 0xFF, 0x00, 0x00, ##              000000000000            
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '90' => {    # 'Z'
        'width'    => 32, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x7F, 0xFF, 0xFF, 0xFE, ##   000000000000000000000000000000 
            0x7F, 0xFF, 0xFF, 0xFE, ##   000000000000000000000000000000 
            0x7F, 0xFF, 0xFF, 0xFE, ##   000000000000000000000000000000 
            0x7F, 0xFF, 0xFF, 0xFE, ##   000000000000000000000000000000 
            0x7F, 0xFF, 0xFF, 0xFE, ##   000000000000000000000000000000 
            0x00, 0x00, 0x01, 0xFC, ##                         0000000  
            0x00, 0x00, 0x01, 0xFC, ##                         0000000  
            0x00, 0x00, 0x03, 0xF8, ##                        0000000   
            0x00, 0x00, 0x03, 0xF0, ##                        000000    
            0x00, 0x00, 0x07, 0xF0, ##                       0000000    
            0x00, 0x00, 0x0F, 0xE0, ##                      0000000     
            0x00, 0x00, 0x0F, 0xE0, ##                      0000000     
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000      
            0x00, 0x00, 0x3F, 0x80, ##                    0000000       
            0x00, 0x00, 0x3F, 0x80, ##                    0000000       
            0x00, 0x00, 0x7F, 0x00, ##                   0000000        
            0x00, 0x00, 0xFE, 0x00, ##                  0000000         
            0x00, 0x00, 0xFE, 0x00, ##                  0000000         
            0x00, 0x01, 0xFC, 0x00, ##                 0000000          
            0x00, 0x01, 0xF8, 0x00, ##                 000000           
            0x00, 0x03, 0xF8, 0x00, ##                0000000           
            0x00, 0x07, 0xF0, 0x00, ##               0000000            
            0x00, 0x07, 0xE0, 0x00, ##               000000             
            0x00, 0x0F, 0xE0, 0x00, ##              0000000             
            0x00, 0x1F, 0xC0, 0x00, ##             0000000              
            0x00, 0x1F, 0x80, 0x00, ##             000000               
            0x00, 0x3F, 0x80, 0x00, ##            0000000               
            0x00, 0x7F, 0x00, 0x00, ##           0000000                
            0x00, 0x7F, 0x00, 0x00, ##           0000000                
            0x00, 0xFE, 0x00, 0x00, ##          0000000                 
            0x00, 0xFC, 0x00, 0x00, ##          000000                  
            0x01, 0xFC, 0x00, 0x00, ##         0000000                  
            0x03, 0xF8, 0x00, 0x00, ##        0000000                   
            0x03, 0xF0, 0x00, 0x00, ##        000000                    
            0x07, 0xF0, 0x00, 0x00, ##       0000000                    
            0x0F, 0xE0, 0x00, 0x00, ##      0000000                     
            0x0F, 0xC0, 0x00, 0x00, ##      000000                      
            0x1F, 0xC0, 0x00, 0x00, ##     0000000                      
            0x1F, 0x80, 0x00, 0x00, ##     000000                       
            0x3F, 0x00, 0x00, 0x00, ##    000000                        
            0x7F, 0x00, 0x00, 0x00, ##   0000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                         
            0xFF, 0xFF, 0xFF, 0xFF, ##  00000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, ##  00000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, ##  00000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, ##  00000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, ##  00000000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '91' => {    # '['
        'width'    => 14, 
        'xoffset'  => 14, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFC, 0x00, ##  000000        
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '92' => {    # '\'
        'width'    => 31, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x1F, 0x80, 0x00, 0x00, ##     000000                      
            0x1F, 0x80, 0x00, 0x00, ##     000000                      
            0x0F, 0xC0, 0x00, 0x00, ##      000000                     
            0x0F, 0xC0, 0x00, 0x00, ##      000000                     
            0x07, 0xE0, 0x00, 0x00, ##       000000                    
            0x07, 0xE0, 0x00, 0x00, ##       000000                    
            0x03, 0xE0, 0x00, 0x00, ##        00000                    
            0x03, 0xF0, 0x00, 0x00, ##        000000                   
            0x03, 0xF0, 0x00, 0x00, ##        000000                   
            0x01, 0xF8, 0x00, 0x00, ##         000000                  
            0x01, 0xF8, 0x00, 0x00, ##         000000                  
            0x00, 0xFC, 0x00, 0x00, ##          000000                 
            0x00, 0xFC, 0x00, 0x00, ##          000000                 
            0x00, 0x7E, 0x00, 0x00, ##           000000                
            0x00, 0x7E, 0x00, 0x00, ##           000000                
            0x00, 0x3F, 0x00, 0x00, ##            000000               
            0x00, 0x3F, 0x00, 0x00, ##            000000               
            0x00, 0x1F, 0x80, 0x00, ##             000000              
            0x00, 0x1F, 0x80, 0x00, ##             000000              
            0x00, 0x0F, 0xC0, 0x00, ##              000000             
            0x00, 0x0F, 0xC0, 0x00, ##              000000             
            0x00, 0x0F, 0xC0, 0x00, ##              000000             
            0x00, 0x07, 0xE0, 0x00, ##               000000            
            0x00, 0x07, 0xE0, 0x00, ##               000000            
            0x00, 0x03, 0xF0, 0x00, ##                000000           
            0x00, 0x03, 0xF0, 0x00, ##                000000           
            0x00, 0x01, 0xF8, 0x00, ##                 000000          
            0x00, 0x01, 0xF8, 0x00, ##                 000000          
            0x00, 0x00, 0xFC, 0x00, ##                  000000         
            0x00, 0x00, 0xFC, 0x00, ##                  000000         
            0x00, 0x00, 0x7E, 0x00, ##                   000000        
            0x00, 0x00, 0x7E, 0x00, ##                   000000        
            0x00, 0x00, 0x3F, 0x00, ##                    000000       
            0x00, 0x00, 0x3F, 0x00, ##                    000000       
            0x00, 0x00, 0x1F, 0x00, ##                     00000       
            0x00, 0x00, 0x1F, 0x80, ##                     000000      
            0x00, 0x00, 0x1F, 0x80, ##                     000000      
            0x00, 0x00, 0x0F, 0xC0, ##                      000000     
            0x00, 0x00, 0x0F, 0xC0, ##                      000000     
            0x00, 0x00, 0x07, 0xE0, ##                       000000    
            0x00, 0x00, 0x07, 0xE0, ##                       000000    
            0x00, 0x00, 0x03, 0xF0, ##                        000000   
            0x00, 0x00, 0x03, 0xF0, ##                        000000   
            0x00, 0x00, 0x01, 0xF8, ##                         000000  
            0x00, 0x00, 0x01, 0xF8, ##                         000000  
            0x00, 0x00, 0x00, 0xFC, ##                          000000 
            0x00, 0x00, 0x00, 0xFC, ##                          000000 
            0x00, 0x00, 0x00, 0x7C, ##                           00000 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '93' => {    # ']'
        'width'    => 13, 
        'xoffset'  => 11, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0x01, 0xF8, ##         000000
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '94' => {    # '^'
        'width'    => 34, 
        'xoffset'  => 2, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xF0, 0x00, 0x00, ##                000000              
            0x00, 0x03, 0xF8, 0x00, 0x00, ##                0000000             
            0x00, 0x07, 0xFC, 0x00, 0x00, ##               000000000            
            0x00, 0x0F, 0xFC, 0x00, 0x00, ##              0000000000            
            0x00, 0x1F, 0xFE, 0x00, 0x00, ##             000000000000           
            0x00, 0x3F, 0xFF, 0x00, 0x00, ##            00000000000000          
            0x00, 0x3F, 0x3F, 0x80, 0x00, ##            000000  0000000         
            0x00, 0x7F, 0x1F, 0xC0, 0x00, ##           0000000   0000000        
            0x00, 0xFE, 0x0F, 0xE0, 0x00, ##          0000000     0000000       
            0x01, 0xFC, 0x07, 0xE0, 0x00, ##         0000000       000000       
            0x03, 0xF8, 0x03, 0xF0, 0x00, ##        0000000         000000      
            0x03, 0xF0, 0x01, 0xF8, 0x00, ##        000000           000000     
            0x07, 0xE0, 0x00, 0xFC, 0x00, ##       000000             000000    
            0x0F, 0xC0, 0x00, 0x7E, 0x00, ##      000000               000000   
            0x1F, 0x80, 0x00, 0x7E, 0x00, ##     000000                000000   
            0x3F, 0x00, 0x00, 0x3F, 0x00, ##    000000                  000000  
            0x7E, 0x00, 0x00, 0x1F, 0x80, ##   000000                    000000 
            0x7C, 0x00, 0x00, 0x0F, 0xC0, ##   00000                      000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '95' => {    # '_'
        'width'    => 32, 
        'xoffset'  => 0, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xFF, 0xFF, ##  00000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, ##  00000000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '96' => {    # '`'
        'width'    => 15, 
        'xoffset'  => 9, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFC, 0x00, ##  000000         
            0x7E, 0x00, ##   000000        
            0x3F, 0x00, ##    000000       
            0x1F, 0x00, ##     00000       
            0x0F, 0x80, ##      00000      
            0x0F, 0xC0, ##      000000     
            0x07, 0xE0, ##       000000    
            0x03, 0xE0, ##        00000    
            0x01, 0xF0, ##         00000   
            0x00, 0xF8, ##          00000  
            0x00, 0x7C, ##           00000 
            0x00, 0x7C, ##           00000 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '97' => {    # 'a'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000       
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000     
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000    
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x1F, 0xC0, 0x3F, 0xE0, ##     0000000        000000000  
            0x1E, 0x00, 0x0F, 0xF0, ##     0000             00000000 
            0x10, 0x00, 0x07, 0xF0, ##     0                 0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x3F, 0xFF, 0xF8, ##            0000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x07, 0xFF, 0xFF, 0xF8, ##       000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xF8, ##     00000000000000000000000000
            0x3F, 0xFF, 0xFF, 0xF8, ##    000000000000000000000000000
            0x3F, 0xE0, 0x01, 0xF8, ##    000000000            000000
            0x7F, 0x80, 0x01, 0xF8, ##   00000000              000000
            0x7F, 0x00, 0x01, 0xF8, ##   0000000               000000
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000
            0xFE, 0x00, 0x07, 0xF8, ##  0000000              00000000
            0xFE, 0x00, 0x0F, 0xF8, ##  0000000             000000000
            0x7F, 0x00, 0x1F, 0xF8, ##   0000000           0000000000
            0x7F, 0xC0, 0xFF, 0xF8, ##   000000000      0000000000000
            0x3F, 0xFF, 0xFD, 0xF8, ##    00000000000000000000 000000
            0x1F, 0xFF, 0xF9, 0xF8, ##     000000000000000000  000000
            0x0F, 0xFF, 0xF1, 0xF8, ##      0000000000000000   000000
            0x07, 0xFF, 0xC1, 0xF8, ##       0000000000000     000000
            0x00, 0xFF, 0x00, 0x00, ##          00000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '98' => {    # 'b'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x0F, 0xE0, 0x00, ##  000000      0000000          
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000       
            0xFC, 0xFF, 0xFE, 0x00, ##  000000  000000000000000      
            0xFD, 0xFF, 0xFF, 0x00, ##  000000 00000000000000000     
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000    
            0xFF, 0xF0, 0x7F, 0xC0, ##  000000000000     000000000   
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000   
            0xFF, 0x80, 0x0F, 0xE0, ##  000000000           0000000  
            0xFF, 0x00, 0x07, 0xE0, ##  00000000             000000  
            0xFF, 0x00, 0x07, 0xF0, ##  00000000             0000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFF, 0x00, 0x07, 0xF0, ##  00000000             0000000 
            0xFF, 0x00, 0x07, 0xE0, ##  00000000             000000  
            0xFF, 0x80, 0x0F, 0xE0, ##  000000000           0000000  
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000   
            0xFF, 0xF0, 0x7F, 0xC0, ##  000000000000     000000000   
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000    
            0xFD, 0xFF, 0xFF, 0x00, ##  000000 00000000000000000     
            0xFC, 0xFF, 0xFE, 0x00, ##  000000  000000000000000      
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000       
            0x00, 0x0F, 0xE0, 0x00, ##              0000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '99' => {    # 'c'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0xF8, 0x00, ##               00000000      
            0x00, 0x7F, 0xFF, 0x00, ##           000000000000000   
            0x01, 0xFF, 0xFF, 0xE0, ##         00000000000000000000
            0x03, 0xFF, 0xFF, 0xE0, ##        000000000000000000000
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000
            0x0F, 0xFC, 0x07, 0xE0, ##      0000000000       000000
            0x1F, 0xE0, 0x00, 0xE0, ##     00000000             000
            0x1F, 0xC0, 0x00, 0x60, ##     0000000               00
            0x3F, 0x80, 0x00, 0x00, ##    0000000                  
            0x3F, 0x00, 0x00, 0x00, ##    000000                   
            0x7F, 0x00, 0x00, 0x00, ##   0000000                   
            0x7E, 0x00, 0x00, 0x00, ##   000000                    
            0x7E, 0x00, 0x00, 0x00, ##   000000                    
            0xFE, 0x00, 0x00, 0x00, ##  0000000                    
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFE, 0x00, 0x00, 0x00, ##  0000000                    
            0x7E, 0x00, 0x00, 0x00, ##   000000                    
            0x7E, 0x00, 0x00, 0x00, ##   000000                    
            0x7F, 0x00, 0x00, 0x00, ##   0000000                   
            0x3F, 0x00, 0x00, 0x00, ##    000000                   
            0x3F, 0x80, 0x00, 0x00, ##    0000000                  
            0x1F, 0xC0, 0x00, 0x60, ##     0000000               00
            0x1F, 0xE0, 0x00, 0xE0, ##     00000000             000
            0x0F, 0xF8, 0x07, 0xE0, ##      000000000        000000
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000
            0x03, 0xFF, 0xFF, 0xE0, ##        000000000000000000000
            0x01, 0xFF, 0xFF, 0xE0, ##         00000000000000000000
            0x00, 0x7F, 0xFF, 0x80, ##           0000000000000000  
            0x00, 0x07, 0xF8, 0x00, ##               00000000      
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '100' => {    # 'd'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x3F, 0x81, 0xF8, ##            0000000      000000
            0x01, 0xFF, 0xE1, 0xF8, ##         000000000000    000000
            0x03, 0xFF, 0xF9, 0xF8, ##        000000000000000  000000
            0x07, 0xFF, 0xFD, 0xF8, ##       00000000000000000 000000
            0x0F, 0xFF, 0xFD, 0xF8, ##      000000000000000000 000000
            0x1F, 0xF0, 0x7F, 0xF8, ##     000000000     000000000000
            0x1F, 0xC0, 0x1F, 0xF8, ##     0000000         0000000000
            0x3F, 0x80, 0x0F, 0xF8, ##    0000000           000000000
            0x3F, 0x00, 0x07, 0xF8, ##    000000             00000000
            0x7F, 0x00, 0x07, 0xF8, ##   0000000             00000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0xFE, 0x00, 0x03, 0xF8, ##  0000000               0000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7F, 0x00, 0x07, 0xF8, ##   0000000             00000000
            0x3F, 0x00, 0x07, 0xF8, ##    000000             00000000
            0x3F, 0x80, 0x0F, 0xF8, ##    0000000           000000000
            0x1F, 0xC0, 0x1F, 0xF8, ##     0000000         0000000000
            0x1F, 0xF0, 0x7F, 0xF8, ##     000000000     000000000000
            0x0F, 0xFF, 0xFD, 0xF8, ##      000000000000000000 000000
            0x07, 0xFF, 0xFD, 0xF8, ##       00000000000000000 000000
            0x03, 0xFF, 0xF9, 0xF8, ##        000000000000000  000000
            0x01, 0xFF, 0xE1, 0xF8, ##         000000000000    000000
            0x00, 0x3F, 0x80, 0x00, ##            0000000            
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '101' => {    # 'e'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x0F, 0xF8, 0x00, ##              000000000          
            0x00, 0x7F, 0xFE, 0x00, ##           00000000000000        
            0x01, 0xFF, 0xFF, 0x80, ##         000000000000000000      
            0x03, 0xFF, 0xFF, 0xC0, ##        00000000000000000000     
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000    
            0x0F, 0xF8, 0x1F, 0xF0, ##      000000000      000000000   
            0x1F, 0xE0, 0x03, 0xF0, ##     00000000           000000   
            0x1F, 0xC0, 0x01, 0xF8, ##     0000000             000000  
            0x3F, 0x80, 0x01, 0xF8, ##    0000000              000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0x7C, ##   000000                  00000 
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x3F, 0x80, 0x00, 0x00, ##    0000000                      
            0x1F, 0xC0, 0x00, 0x0C, ##     0000000                  00 
            0x1F, 0xE0, 0x00, 0x7C, ##     00000000              00000 
            0x0F, 0xF8, 0x03, 0xFC, ##      000000000         00000000 
            0x07, 0xFF, 0xFF, 0xFC, ##       0000000000000000000000000 
            0x03, 0xFF, 0xFF, 0xFC, ##        000000000000000000000000 
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000  
            0x00, 0x7F, 0xFF, 0xC0, ##           00000000000000000     
            0x00, 0x07, 0xFC, 0x00, ##               000000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '102' => {    # 'f'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0xFF, 0xE0, ##                  00000000000
            0x00, 0x07, 0xFF, 0xE0, ##               00000000000000
            0x00, 0x0F, 0xFF, 0xE0, ##              000000000000000
            0x00, 0x1F, 0xFF, 0xE0, ##             0000000000000000
            0x00, 0x3F, 0xFF, 0xE0, ##            00000000000000000
            0x00, 0x3F, 0x80, 0x00, ##            0000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000           
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '103' => {    # 'g'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x3F, 0x80, 0x00, ##            0000000            
            0x01, 0xFF, 0xE1, 0xF8, ##         000000000000    000000
            0x03, 0xFF, 0xF9, 0xF8, ##        000000000000000  000000
            0x07, 0xFF, 0xFD, 0xF8, ##       00000000000000000 000000
            0x0F, 0xFF, 0xFD, 0xF8, ##      000000000000000000 000000
            0x1F, 0xF0, 0x7F, 0xF8, ##     000000000     000000000000
            0x1F, 0xC0, 0x1F, 0xF8, ##     0000000         0000000000
            0x3F, 0x80, 0x0F, 0xF8, ##    0000000           000000000
            0x3F, 0x00, 0x07, 0xF8, ##    000000             00000000
            0x7F, 0x00, 0x07, 0xF8, ##   0000000             00000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7F, 0x00, 0x07, 0xF8, ##   0000000             00000000
            0x3F, 0x00, 0x07, 0xF8, ##    000000             00000000
            0x3F, 0x80, 0x0F, 0xF8, ##    0000000           000000000
            0x1F, 0xC0, 0x1F, 0xF8, ##     0000000         0000000000
            0x1F, 0xF0, 0x3F, 0xF8, ##     000000000      00000000000
            0x0F, 0xFF, 0xFD, 0xF8, ##      000000000000000000 000000
            0x07, 0xFF, 0xF9, 0xF8, ##       0000000000000000  000000
            0x03, 0xFF, 0xF9, 0xF8, ##        000000000000000  000000
            0x01, 0xFF, 0xE1, 0xF8, ##         000000000000    000000
            0x00, 0x3F, 0x81, 0xF8, ##            0000000      000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x07, 0xE0, ##                       000000  
            0x0C, 0x00, 0x0F, 0xE0, ##      00              0000000  
            0x0F, 0xC0, 0x3F, 0xC0, ##      000000        00000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000   
            0x0F, 0xFF, 0xFF, 0x80, ##      000000000000000000000    
            0x0F, 0xFF, 0xFE, 0x00, ##      0000000000000000000      
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000       
            0x00, 0x7F, 0xE0, 0x00, ##           0000000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '104' => {    # 'h'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x07, 0xF0, 0x00, ##  000000       0000000       
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000     
            0xFC, 0x7F, 0xFE, 0x00, ##  000000   00000000000000    
            0xFC, 0xFF, 0xFF, 0x00, ##  000000  0000000000000000   
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000  
            0xFF, 0xE0, 0x7F, 0x80, ##  00000000000      00000000  
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000 
            0xFF, 0x00, 0x0F, 0xC0, ##  00000000            000000 
            0xFF, 0x00, 0x0F, 0xC0, ##  00000000            000000 
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000
            0xFE, 0x00, 0x07, 0xE0, ##  0000000              000000
            0xFE, 0x00, 0x07, 0xE0, ##  0000000              000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '105' => {    # 'i'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '106' => {    # 'j'
        'width'    => 19, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x00, 0x00, ##                     
            0x00, 0x00, 0x00, ##                     
            0x00, 0x00, 0x00, ##                     
            0x00, 0x00, 0x00, ##                     
            0x00, 0x00, 0x00, ##                     
            0x00, 0x00, 0x00, ##                     
            0x1F, 0xFF, 0xE0, ##     0000000000000000
            0x1F, 0xFF, 0xE0, ##     0000000000000000
            0x1F, 0xFF, 0xE0, ##     0000000000000000
            0x1F, 0xFF, 0xE0, ##     0000000000000000
            0x1F, 0xFF, 0xE0, ##     0000000000000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x07, 0xE0, ##               000000
            0x00, 0x0F, 0xE0, ##              0000000
            0x00, 0x0F, 0xC0, ##              000000 
            0x00, 0x1F, 0xC0, ##             0000000 
            0x00, 0x3F, 0xC0, ##            00000000 
            0xFF, 0xFF, 0x80, ##  00000000000000000  
            0xFF, 0xFF, 0x00, ##  0000000000000000   
            0xFF, 0xFE, 0x00, ##  000000000000000    
            0xFF, 0xFC, 0x00, ##  00000000000000     
            0xFF, 0xF0, 0x00, ##  000000000000       
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '107' => {    # 'k'
        'width'    => 30, 
        'xoffset'  => 7, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000  
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000   
            0xFC, 0x00, 0x3F, 0xC0, ##  000000            00000000    
            0xFC, 0x00, 0x7F, 0x00, ##  000000           0000000      
            0xFC, 0x00, 0xFE, 0x00, ##  000000          0000000       
            0xFC, 0x01, 0xFC, 0x00, ##  000000         0000000        
            0xFC, 0x03, 0xF8, 0x00, ##  000000        0000000         
            0xFC, 0x07, 0xF0, 0x00, ##  000000       0000000          
            0xFC, 0x0F, 0xE0, 0x00, ##  000000      0000000           
            0xFC, 0x1F, 0xC0, 0x00, ##  000000     0000000            
            0xFC, 0x3F, 0x80, 0x00, ##  000000    0000000             
            0xFC, 0x7F, 0x00, 0x00, ##  000000   0000000              
            0xFC, 0xFE, 0x00, 0x00, ##  000000  0000000               
            0xFD, 0xFE, 0x00, 0x00, ##  000000 00000000               
            0xFF, 0xFE, 0x00, 0x00, ##  000000000000000               
            0xFF, 0xFF, 0x00, 0x00, ##  0000000000000000              
            0xFF, 0xFF, 0x80, 0x00, ##  00000000000000000             
            0xFF, 0xDF, 0x80, 0x00, ##  0000000000 000000             
            0xFF, 0x9F, 0xC0, 0x00, ##  000000000  0000000            
            0xFF, 0x0F, 0xE0, 0x00, ##  00000000    0000000           
            0xFE, 0x07, 0xF0, 0x00, ##  0000000      0000000          
            0xFC, 0x03, 0xF0, 0x00, ##  000000        000000          
            0xFC, 0x03, 0xF8, 0x00, ##  000000        0000000         
            0xFC, 0x01, 0xFC, 0x00, ##  000000         0000000        
            0xFC, 0x00, 0xFE, 0x00, ##  000000          0000000       
            0xFC, 0x00, 0xFE, 0x00, ##  000000          0000000       
            0xFC, 0x00, 0x7F, 0x00, ##  000000           0000000      
            0xFC, 0x00, 0x3F, 0x80, ##  000000            0000000     
            0xFC, 0x00, 0x1F, 0xC0, ##  000000             0000000    
            0xFC, 0x00, 0x1F, 0xC0, ##  000000             0000000    
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000   
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000  
            0xFC, 0x00, 0x07, 0xF0, ##  000000               0000000  
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000 
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '108' => {    # 'l'
        'width'    => 27, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFE, 0x00, 0x00, ##  000000000000000            
            0xFF, 0xFE, 0x00, 0x00, ##  000000000000000            
            0xFF, 0xFE, 0x00, 0x00, ##  000000000000000            
            0xFF, 0xFE, 0x00, 0x00, ##  000000000000000            
            0xFF, 0xFE, 0x00, 0x00, ##  000000000000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7E, 0x00, 0x00, ##           000000            
            0x00, 0x7F, 0x00, 0x00, ##           0000000           
            0x00, 0x3F, 0x00, 0x00, ##            000000           
            0x00, 0x3F, 0x80, 0x00, ##            0000000          
            0x00, 0x3F, 0xC0, 0x00, ##            00000000         
            0x00, 0x1F, 0xFF, 0xE0, ##             0000000000000000
            0x00, 0x0F, 0xFF, 0xE0, ##              000000000000000
            0x00, 0x07, 0xFF, 0xE0, ##               00000000000000
            0x00, 0x03, 0xFF, 0xE0, ##                0000000000000
            0x00, 0x00, 0xFF, 0xE0, ##                  00000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '109' => {    # 'm'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x7C, 0x03, 0xF0, 0x00, ##           00000        000000     
            0xF9, 0xFF, 0x0F, 0xFC, 0x00, ##  00000  000000000    0000000000   
            0xFB, 0xFF, 0x9F, 0xFE, 0x00, ##  00000 00000000000  000000000000  
            0xFF, 0xFF, 0xDF, 0xFE, 0x00, ##  000000000000000000 000000000000  
            0xFF, 0xFF, 0xFF, 0xFF, 0x00, ##  00000000000000000000000000000000 
            0xFE, 0x0F, 0xF8, 0x3F, 0x00, ##  0000000     000000000     000000 
            0xFC, 0x07, 0xF0, 0x1F, 0x00, ##  000000       0000000       00000 
            0xFC, 0x07, 0xF0, 0x1F, 0x00, ##  000000       0000000       00000 
            0xFC, 0x03, 0xF0, 0x0F, 0x80, ##  000000        000000        00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0xF8, 0x03, 0xE0, 0x0F, 0x80, ##  00000         00000         00000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '110' => {    # 'n'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0xF0, 0x00, ##               0000000       
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000     
            0xFC, 0x7F, 0xFE, 0x00, ##  000000   00000000000000    
            0xFC, 0xFF, 0xFF, 0x00, ##  000000  0000000000000000   
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000  
            0xFF, 0xE0, 0x7F, 0x80, ##  00000000000      00000000  
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000 
            0xFF, 0x00, 0x0F, 0xC0, ##  00000000            000000 
            0xFF, 0x00, 0x0F, 0xC0, ##  00000000            000000 
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000
            0xFE, 0x00, 0x07, 0xE0, ##  0000000              000000
            0xFE, 0x00, 0x07, 0xE0, ##  0000000              000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '111' => {    # 'o'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '112' => {    # 'p'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x0F, 0xE0, 0x00, ##              0000000          
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000       
            0xFC, 0xFF, 0xFE, 0x00, ##  000000  000000000000000      
            0xFD, 0xFF, 0xFF, 0x00, ##  000000 00000000000000000     
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000    
            0xFF, 0xF0, 0x7F, 0xC0, ##  000000000000     000000000   
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000   
            0xFF, 0x80, 0x0F, 0xE0, ##  000000000           0000000  
            0xFF, 0x00, 0x07, 0xE0, ##  00000000             000000  
            0xFF, 0x00, 0x07, 0xF0, ##  00000000             0000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFF, 0x00, 0x07, 0xF0, ##  00000000             0000000 
            0xFF, 0x00, 0x07, 0xE0, ##  00000000             000000  
            0xFF, 0x80, 0x0F, 0xE0, ##  000000000           0000000  
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000   
            0xFF, 0xF0, 0x7F, 0xC0, ##  000000000000     000000000   
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000    
            0xFD, 0xFF, 0xFF, 0x00, ##  000000 00000000000000000     
            0xFC, 0xFF, 0xFE, 0x00, ##  000000  000000000000000      
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000       
            0xFC, 0x0F, 0xE0, 0x00, ##  000000      0000000          
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '113' => {    # 'q'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x3F, 0x80, 0x00, ##            0000000            
            0x01, 0xFF, 0xE1, 0xF8, ##         000000000000    000000
            0x03, 0xFF, 0xF9, 0xF8, ##        000000000000000  000000
            0x07, 0xFF, 0xFD, 0xF8, ##       00000000000000000 000000
            0x0F, 0xFF, 0xFD, 0xF8, ##      000000000000000000 000000
            0x1F, 0xF0, 0x7F, 0xF8, ##     000000000     000000000000
            0x1F, 0xC0, 0x1F, 0xF8, ##     0000000         0000000000
            0x3F, 0x80, 0x0F, 0xF8, ##    0000000           000000000
            0x3F, 0x00, 0x07, 0xF8, ##    000000             00000000
            0x7F, 0x00, 0x07, 0xF8, ##   0000000             00000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFE, 0x00, 0x03, 0xF8, ##  0000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7E, 0x00, 0x03, 0xF8, ##   000000               0000000
            0x7F, 0x00, 0x07, 0xF8, ##   0000000             00000000
            0x3F, 0x00, 0x07, 0xF8, ##    000000             00000000
            0x3F, 0x80, 0x0F, 0xF8, ##    0000000           000000000
            0x1F, 0xC0, 0x1F, 0xF8, ##     0000000         0000000000
            0x1F, 0xF0, 0x7F, 0xF8, ##     000000000     000000000000
            0x0F, 0xFF, 0xFD, 0xF8, ##      000000000000000000 000000
            0x07, 0xFF, 0xFD, 0xF8, ##       00000000000000000 000000
            0x03, 0xFF, 0xF9, 0xF8, ##        000000000000000  000000
            0x01, 0xFF, 0xE1, 0xF8, ##         000000000000    000000
            0x00, 0x3F, 0x81, 0xF8, ##            0000000      000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '114' => {    # 'r'
        'width'    => 25, 
        'xoffset'  => 11, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xF8, 0x00, ##                0000000    
            0xFC, 0x1F, 0xFF, 0x00, ##  000000     0000000000000 
            0xFC, 0x3F, 0xFF, 0x80, ##  000000    000000000000000
            0xFC, 0xFF, 0xFF, 0x80, ##  000000  00000000000000000
            0xFC, 0xFF, 0xFF, 0x80, ##  000000  00000000000000000
            0xFD, 0xF8, 0x07, 0x80, ##  000000 000000        0000
            0xFF, 0xE0, 0x01, 0x80, ##  00000000000            00
            0xFF, 0xC0, 0x00, 0x00, ##  0000000000               
            0xFF, 0x80, 0x00, 0x00, ##  000000000                
            0xFF, 0x00, 0x00, 0x00, ##  00000000                 
            0xFF, 0x00, 0x00, 0x00, ##  00000000                 
            0xFE, 0x00, 0x00, 0x00, ##  0000000                  
            0xFE, 0x00, 0x00, 0x00, ##  0000000                  
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '115' => {    # 's'
        'width'    => 26, 
        'xoffset'  => 7, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0xFF, 0xE0, 0x00, ##          00000000000       
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000    
            0x0F, 0xFF, 0xFF, 0x00, ##      00000000000000000000  
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000  
            0x3F, 0xFF, 0xFF, 0x00, ##    0000000000000000000000  
            0x7F, 0xC0, 0x3F, 0x00, ##   000000000        000000  
            0x7F, 0x00, 0x07, 0x00, ##   0000000             000  
            0xFE, 0x00, 0x01, 0x00, ##  0000000                0  
            0xFC, 0x00, 0x00, 0x00, ##  000000                    
            0xFC, 0x00, 0x00, 0x00, ##  000000                    
            0xFC, 0x00, 0x00, 0x00, ##  000000                    
            0xFC, 0x00, 0x00, 0x00, ##  000000                    
            0xFE, 0x00, 0x00, 0x00, ##  0000000                   
            0xFE, 0x00, 0x00, 0x00, ##  0000000                   
            0x7F, 0x80, 0x00, 0x00, ##   00000000                 
            0x7F, 0xF8, 0x00, 0x00, ##   000000000000             
            0x3F, 0xFF, 0xC0, 0x00, ##    0000000000000000        
            0x1F, 0xFF, 0xF8, 0x00, ##     000000000000000000     
            0x07, 0xFF, 0xFE, 0x00, ##       000000000000000000   
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000  
            0x00, 0x0F, 0xFF, 0x00, ##              000000000000  
            0x00, 0x00, 0xFF, 0x80, ##                  000000000 
            0x00, 0x00, 0x3F, 0x80, ##                    0000000 
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000
            0xC0, 0x00, 0x1F, 0x80, ##  00                 000000 
            0xF0, 0x00, 0x3F, 0x80, ##  0000              0000000 
            0xFF, 0x00, 0xFF, 0x80, ##  00000000        000000000 
            0xFF, 0xFF, 0xFF, 0x00, ##  000000000000000000000000  
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000   
            0xFF, 0xFF, 0xFC, 0x00, ##  0000000000000000000000    
            0x3F, 0xFF, 0xF0, 0x00, ##    000000000000000000      
            0x01, 0xFF, 0x80, 0x00, ##         0000000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '116' => {    # 't'
        'width'    => 28, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7E, 0x00, 0x00, ##           000000             
            0x00, 0x7F, 0x00, 0x00, ##           0000000            
            0x00, 0x7F, 0x00, 0x00, ##           0000000            
            0x00, 0x3F, 0xC0, 0x00, ##            00000000          
            0x00, 0x3F, 0xFF, 0xF0, ##            000000000000000000
            0x00, 0x1F, 0xFF, 0xF0, ##             00000000000000000
            0x00, 0x0F, 0xFF, 0xF0, ##              0000000000000000
            0x00, 0x07, 0xFF, 0xF0, ##               000000000000000
            0x00, 0x00, 0xFF, 0xF0, ##                  000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '117' => {    # 'u'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7F, 0x00, 0x3F, 0xE0, ##   0000000          000000000
            0x7F, 0xC0, 0xFF, 0xE0, ##   000000000      00000000000
            0x3F, 0xFF, 0xF7, 0xE0, ##    000000000000000000 000000
            0x1F, 0xFF, 0xE7, 0xE0, ##     0000000000000000  000000
            0x1F, 0xFF, 0xC7, 0xE0, ##     000000000000000   000000
            0x07, 0xFF, 0x87, 0xE0, ##       000000000000    000000
            0x01, 0xFC, 0x00, 0x00, ##         0000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '118' => {    # 'v'
        'width'    => 32, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x3F, ##  000000                    000000
            0x7E, 0x00, 0x00, 0x3F, ##   000000                   000000
            0x7E, 0x00, 0x00, 0x3F, ##   000000                   000000
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000 
            0x3F, 0x00, 0x00, 0x7E, ##    000000                 000000 
            0x3F, 0x00, 0x00, 0x7C, ##    000000                 00000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000  
            0x1F, 0x80, 0x00, 0xFC, ##     000000               000000  
            0x1F, 0x80, 0x01, 0xF8, ##     000000              000000   
            0x0F, 0x80, 0x01, 0xF8, ##      00000              000000   
            0x0F, 0xC0, 0x01, 0xF8, ##      000000             000000   
            0x0F, 0xC0, 0x03, 0xF0, ##      000000            000000    
            0x07, 0xC0, 0x03, 0xF0, ##       00000            000000    
            0x07, 0xE0, 0x03, 0xF0, ##       000000           000000    
            0x07, 0xE0, 0x07, 0xE0, ##       000000          000000     
            0x03, 0xE0, 0x07, 0xE0, ##        00000          000000     
            0x03, 0xF0, 0x07, 0xE0, ##        000000         000000     
            0x03, 0xF0, 0x0F, 0xC0, ##        000000        000000      
            0x01, 0xF0, 0x0F, 0xC0, ##         00000        000000      
            0x01, 0xF8, 0x0F, 0x80, ##         000000       00000       
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000       
            0x00, 0xFC, 0x1F, 0x80, ##          000000     000000       
            0x00, 0xFC, 0x1F, 0x00, ##          000000     00000        
            0x00, 0xFC, 0x3F, 0x00, ##          000000    000000        
            0x00, 0x7E, 0x3F, 0x00, ##           000000   000000        
            0x00, 0x7E, 0x3E, 0x00, ##           000000   00000         
            0x00, 0x3E, 0x7E, 0x00, ##            00000  000000         
            0x00, 0x3F, 0x7E, 0x00, ##            000000 000000         
            0x00, 0x3F, 0x7C, 0x00, ##            000000 00000          
            0x00, 0x1F, 0xFC, 0x00, ##             00000000000          
            0x00, 0x1F, 0xFC, 0x00, ##             00000000000          
            0x00, 0x1F, 0xF8, 0x00, ##             0000000000           
            0x00, 0x0F, 0xF8, 0x00, ##              000000000           
            0x00, 0x0F, 0xF8, 0x00, ##              000000000           
            0x00, 0x0F, 0xF0, 0x00, ##              00000000            
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '119' => {    # 'w'
        'width'    => 39, 
        'xoffset'  => 0, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, 0x7C, ##  000000                           00000 
            0xFC, 0x00, 0x00, 0x00, 0x7C, ##  000000                           00000 
            0x7C, 0x00, 0x00, 0x00, 0xFC, ##   00000                          000000 
            0x7C, 0x00, 0x00, 0x00, 0xFC, ##   00000                          000000 
            0x7E, 0x00, 0x00, 0x00, 0xFC, ##   000000                         000000 
            0x7E, 0x00, 0x00, 0x00, 0xF8, ##   000000                         00000  
            0x3E, 0x00, 0x00, 0x01, 0xF8, ##    00000                        000000  
            0x3E, 0x00, 0x00, 0x01, 0xF8, ##    00000                        000000  
            0x3F, 0x00, 0x00, 0x01, 0xF8, ##    000000                       000000  
            0x3F, 0x00, 0x00, 0x01, 0xF0, ##    000000                       00000   
            0x3F, 0x00, 0x7C, 0x01, 0xF0, ##    000000         00000         00000   
            0x1F, 0x00, 0xFC, 0x03, 0xF0, ##     00000        000000        000000   
            0x1F, 0x00, 0xFC, 0x03, 0xF0, ##     00000        000000        000000   
            0x1F, 0x80, 0xFE, 0x03, 0xE0, ##     000000       0000000       00000    
            0x1F, 0x80, 0xFE, 0x03, 0xE0, ##     000000       0000000       00000    
            0x0F, 0x81, 0xFE, 0x07, 0xE0, ##      00000      00000000      000000    
            0x0F, 0x81, 0xEE, 0x07, 0xE0, ##      00000      0000 000      000000    
            0x0F, 0x81, 0xEF, 0x07, 0xC0, ##      00000      0000 0000     00000     
            0x0F, 0xC3, 0xCF, 0x07, 0xC0, ##      000000    0000  0000     00000     
            0x07, 0xC3, 0xCF, 0x07, 0xC0, ##       00000    0000  0000     00000     
            0x07, 0xC3, 0xC7, 0x8F, 0xC0, ##       00000    0000   0000   000000     
            0x07, 0xC3, 0xC7, 0x8F, 0xC0, ##       00000    0000   0000   000000     
            0x07, 0xE7, 0x87, 0x8F, 0x80, ##       000000  0000    0000   00000      
            0x03, 0xE7, 0x83, 0x8F, 0x80, ##        00000  0000     000   00000      
            0x03, 0xE7, 0x83, 0xCF, 0x80, ##        00000  0000     0000  00000      
            0x03, 0xE7, 0x03, 0xDF, 0x80, ##        00000  000      0000 000000      
            0x03, 0xEF, 0x03, 0xDF, 0x00, ##        00000 0000      0000 00000       
            0x03, 0xFF, 0x01, 0xFF, 0x00, ##        0000000000       000000000       
            0x01, 0xFF, 0x01, 0xFF, 0x00, ##         000000000       000000000       
            0x01, 0xFE, 0x01, 0xFF, 0x00, ##         00000000        000000000       
            0x01, 0xFE, 0x00, 0xFE, 0x00, ##         00000000         0000000        
            0x01, 0xFE, 0x00, 0xFE, 0x00, ##         00000000         0000000        
            0x00, 0xFC, 0x00, 0xFE, 0x00, ##          000000          0000000        
            0x00, 0xFC, 0x00, 0xFE, 0x00, ##          000000          0000000        
            0x00, 0xFC, 0x00, 0x7C, 0x00, ##          000000           00000         
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '120' => {    # 'x'
        'width'    => 34, 
        'xoffset'  => 2, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x3F, 0x00, 0x00, 0x3F, 0x80, ##    000000                  0000000 
            0x1F, 0x80, 0x00, 0x7F, 0x00, ##     000000                0000000  
            0x1F, 0xC0, 0x00, 0x7E, 0x00, ##     0000000               000000   
            0x0F, 0xE0, 0x00, 0xFC, 0x00, ##      0000000             000000    
            0x07, 0xE0, 0x01, 0xFC, 0x00, ##       000000            0000000    
            0x03, 0xF0, 0x03, 0xF8, 0x00, ##        000000          0000000     
            0x03, 0xF8, 0x03, 0xF0, 0x00, ##        0000000         000000      
            0x01, 0xF8, 0x07, 0xE0, 0x00, ##         000000        000000       
            0x00, 0xFC, 0x0F, 0xE0, 0x00, ##          000000      0000000       
            0x00, 0x7E, 0x0F, 0xC0, 0x00, ##           000000     000000        
            0x00, 0x7F, 0x1F, 0x80, 0x00, ##           0000000   000000         
            0x00, 0x3F, 0x3F, 0x00, 0x00, ##            000000  000000          
            0x00, 0x1F, 0xFF, 0x00, 0x00, ##             0000000000000          
            0x00, 0x0F, 0xFE, 0x00, 0x00, ##              00000000000           
            0x00, 0x0F, 0xFC, 0x00, 0x00, ##              0000000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000             
            0x00, 0x03, 0xF8, 0x00, 0x00, ##                0000000             
            0x00, 0x03, 0xF8, 0x00, 0x00, ##                0000000             
            0x00, 0x07, 0xFC, 0x00, 0x00, ##               000000000            
            0x00, 0x0F, 0xFC, 0x00, 0x00, ##              0000000000            
            0x00, 0x1F, 0xFE, 0x00, 0x00, ##             000000000000           
            0x00, 0x1F, 0xBF, 0x00, 0x00, ##             000000 000000          
            0x00, 0x3F, 0x3F, 0x80, 0x00, ##            000000  0000000         
            0x00, 0x7E, 0x1F, 0x80, 0x00, ##           000000    000000         
            0x00, 0xFE, 0x0F, 0xC0, 0x00, ##          0000000     000000        
            0x00, 0xFC, 0x07, 0xE0, 0x00, ##          000000       000000       
            0x01, 0xF8, 0x07, 0xF0, 0x00, ##         000000        0000000      
            0x03, 0xF8, 0x03, 0xF8, 0x00, ##        0000000         0000000     
            0x07, 0xF0, 0x01, 0xF8, 0x00, ##       0000000           000000     
            0x07, 0xE0, 0x01, 0xFC, 0x00, ##       000000            0000000    
            0x0F, 0xC0, 0x00, 0xFE, 0x00, ##      000000              0000000   
            0x1F, 0xC0, 0x00, 0x7F, 0x00, ##     0000000               0000000  
            0x3F, 0x80, 0x00, 0x3F, 0x00, ##    0000000                 000000  
            0x7F, 0x00, 0x00, 0x3F, 0x80, ##   0000000                  0000000 
            0x7E, 0x00, 0x00, 0x1F, 0xC0, ##   000000                    0000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '121' => {    # 'y'
        'width'    => 32, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x3F, ##  000000                    000000
            0xFC, 0x00, 0x00, 0x3F, ##  000000                    000000
            0xFC, 0x00, 0x00, 0x7F, ##  000000                   0000000
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000 
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000  
            0x1F, 0x80, 0x01, 0xF8, ##     000000              000000   
            0x1F, 0x80, 0x01, 0xF8, ##     000000              000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000    
            0x0F, 0xC0, 0x03, 0xF0, ##      000000            000000    
            0x0F, 0xC0, 0x03, 0xF0, ##      000000            000000    
            0x07, 0xE0, 0x07, 0xE0, ##       000000          000000     
            0x07, 0xE0, 0x07, 0xE0, ##       000000          000000     
            0x07, 0xE0, 0x07, 0xC0, ##       000000          00000      
            0x03, 0xF0, 0x0F, 0xC0, ##        000000        000000      
            0x03, 0xF0, 0x0F, 0xC0, ##        000000        000000      
            0x01, 0xF0, 0x1F, 0x80, ##         00000       000000       
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000       
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000       
            0x00, 0xFC, 0x3F, 0x00, ##          000000    000000        
            0x00, 0xFC, 0x3F, 0x00, ##          000000    000000        
            0x00, 0x7C, 0x3E, 0x00, ##           00000    00000         
            0x00, 0x7E, 0x7E, 0x00, ##           000000  000000         
            0x00, 0x7E, 0x7E, 0x00, ##           000000  000000         
            0x00, 0x3E, 0xFC, 0x00, ##            00000 000000          
            0x00, 0x3F, 0xFC, 0x00, ##            000000000000          
            0x00, 0x1F, 0xF8, 0x00, ##             0000000000           
            0x00, 0x1F, 0xF8, 0x00, ##             0000000000           
            0x00, 0x1F, 0xF8, 0x00, ##             0000000000           
            0x00, 0x0F, 0xF0, 0x00, ##              00000000            
            0x00, 0x0F, 0xF0, 0x00, ##              00000000            
            0x00, 0x0F, 0xF0, 0x00, ##              00000000            
            0x00, 0x07, 0xE0, 0x00, ##               000000             
            0x00, 0x07, 0xE0, 0x00, ##               000000             
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x1F, 0x80, 0x00, ##             000000               
            0x00, 0x1F, 0x80, 0x00, ##             000000               
            0x00, 0x3F, 0x00, 0x00, ##            000000                
            0x00, 0x7F, 0x00, 0x00, ##           0000000                
            0x00, 0xFF, 0x00, 0x00, ##          00000000                
            0x3F, 0xFE, 0x00, 0x00, ##    0000000000000                 
            0x3F, 0xFC, 0x00, 0x00, ##    000000000000                  
            0x3F, 0xF8, 0x00, 0x00, ##    00000000000                   
            0x3F, 0xF0, 0x00, 0x00, ##    0000000000                    
            0x3F, 0xC0, 0x00, 0x00, ##    00000000                      
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '122' => {    # 'z'
        'width'    => 26, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x7F, 0xFF, 0xFF, 0xC0, ##   0000000000000000000000000
            0x7F, 0xFF, 0xFF, 0xC0, ##   0000000000000000000000000
            0x7F, 0xFF, 0xFF, 0xC0, ##   0000000000000000000000000
            0x7F, 0xFF, 0xFF, 0xC0, ##   0000000000000000000000000
            0x7F, 0xFF, 0xFF, 0xC0, ##   0000000000000000000000000
            0x00, 0x00, 0x0F, 0xC0, ##                      000000
            0x00, 0x00, 0x1F, 0x80, ##                     000000 
            0x00, 0x00, 0x3F, 0x80, ##                    0000000 
            0x00, 0x00, 0x7F, 0x00, ##                   0000000  
            0x00, 0x00, 0xFE, 0x00, ##                  0000000   
            0x00, 0x00, 0xFC, 0x00, ##                  000000    
            0x00, 0x01, 0xF8, 0x00, ##                 000000     
            0x00, 0x03, 0xF0, 0x00, ##                000000      
            0x00, 0x07, 0xF0, 0x00, ##               0000000      
            0x00, 0x0F, 0xE0, 0x00, ##              0000000       
            0x00, 0x1F, 0xC0, 0x00, ##             0000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000         
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x7F, 0x00, 0x00, ##           0000000          
            0x00, 0xFE, 0x00, 0x00, ##          0000000           
            0x01, 0xFC, 0x00, 0x00, ##         0000000            
            0x03, 0xF8, 0x00, 0x00, ##        0000000             
            0x03, 0xF0, 0x00, 0x00, ##        000000              
            0x07, 0xF0, 0x00, 0x00, ##       0000000              
            0x0F, 0xE0, 0x00, 0x00, ##      0000000               
            0x1F, 0xC0, 0x00, 0x00, ##     0000000                
            0x3F, 0x80, 0x00, 0x00, ##    0000000                 
            0x3F, 0x00, 0x00, 0x00, ##    000000                  
            0x7E, 0x00, 0x00, 0x00, ##   000000                   
            0xFE, 0x00, 0x00, 0x00, ##  0000000                   
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '123' => {    # '{'
        'width'    => 24, 
        'xoffset'  => 7, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0xFF, ##                  00000000
            0x00, 0x07, 0xFF, ##               00000000000
            0x00, 0x1F, 0xFF, ##             0000000000000
            0x00, 0x1F, 0xFF, ##             0000000000000
            0x00, 0x3F, 0xFF, ##            00000000000000
            0x00, 0x3F, 0xC0, ##            00000000      
            0x00, 0x7F, 0x00, ##           0000000        
            0x00, 0x7F, 0x00, ##           0000000        
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0xFE, 0x00, ##          0000000         
            0x00, 0xFC, 0x00, ##          000000          
            0x01, 0xFC, 0x00, ##         0000000          
            0x07, 0xFC, 0x00, ##       000000000          
            0xFF, 0xF8, 0x00, ##  0000000000000           
            0xFF, 0xE0, 0x00, ##  00000000000             
            0xFF, 0x80, 0x00, ##  000000000               
            0xFF, 0xE0, 0x00, ##  00000000000             
            0xFF, 0xF8, 0x00, ##  0000000000000           
            0x07, 0xFC, 0x00, ##       000000000          
            0x01, 0xFC, 0x00, ##         0000000          
            0x00, 0xFC, 0x00, ##          000000          
            0x00, 0xFE, 0x00, ##          0000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x7F, 0x00, ##           0000000        
            0x00, 0x7F, 0x00, ##           0000000        
            0x00, 0x3F, 0xC0, ##            00000000      
            0x00, 0x3F, 0xFF, ##            00000000000000
            0x00, 0x1F, 0xFF, ##             0000000000000
            0x00, 0x1F, 0xFF, ##             0000000000000
            0x00, 0x07, 0xFF, ##               00000000000
            0x00, 0x00, 0xFF, ##                  00000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '124' => {    # '|'
        'width'    => 6, 
        'xoffset'  => 17, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##  
        ], 
    }, 
    '125' => {    # '}'
        'width'    => 25, 
        'xoffset'  => 7, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0x00, 0x00, 0x00, ##  00000000                 
            0xFF, 0xE0, 0x00, 0x00, ##  00000000000              
            0xFF, 0xF0, 0x00, 0x00, ##  000000000000             
            0xFF, 0xF8, 0x00, 0x00, ##  0000000000000            
            0xFF, 0xFC, 0x00, 0x00, ##  00000000000000           
            0x03, 0xFC, 0x00, 0x00, ##        00000000           
            0x00, 0xFC, 0x00, 0x00, ##          000000           
            0x00, 0xFE, 0x00, 0x00, ##          0000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7F, 0x00, 0x00, ##           0000000         
            0x00, 0x3F, 0x00, 0x00, ##            000000         
            0x00, 0x3F, 0x80, 0x00, ##            0000000        
            0x00, 0x3F, 0xE0, 0x00, ##            000000000      
            0x00, 0x1F, 0xFF, 0x80, ##             00000000000000
            0x00, 0x07, 0xFF, 0x80, ##               000000000000
            0x00, 0x01, 0xFF, 0x80, ##                 0000000000
            0x00, 0x07, 0xFF, 0x80, ##               000000000000
            0x00, 0x1F, 0xFF, 0x80, ##             00000000000000
            0x00, 0x3F, 0xE0, 0x00, ##            000000000      
            0x00, 0x3F, 0x80, 0x00, ##            0000000        
            0x00, 0x3F, 0x00, 0x00, ##            000000         
            0x00, 0x7F, 0x00, 0x00, ##           0000000         
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0x7E, 0x00, 0x00, ##           000000          
            0x00, 0xFE, 0x00, 0x00, ##          0000000          
            0x00, 0xFE, 0x00, 0x00, ##          0000000          
            0x03, 0xFC, 0x00, 0x00, ##        00000000           
            0xFF, 0xFC, 0x00, 0x00, ##  00000000000000           
            0xFF, 0xF8, 0x00, 0x00, ##  0000000000000            
            0xFF, 0xF8, 0x00, 0x00, ##  0000000000000            
            0xFF, 0xE0, 0x00, 0x00, ##  00000000000              
            0xFF, 0x00, 0x00, 0x00, ##  00000000                 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '126' => {    # '~'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x03, 0xF8, 0x00, 0x00, 0x80, ##        0000000                   0
            0x1F, 0xFF, 0x00, 0x01, 0x80, ##     0000000000000               00
            0x3F, 0xFF, 0xC0, 0x03, 0x80, ##    0000000000000000            000
            0xFF, 0xFF, 0xF8, 0x1F, 0x80, ##  000000000000000000000      000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFC, 0x07, 0xFF, 0xFF, 0x80, ##  000000       00000000000000000000
            0xE0, 0x01, 0xFF, 0xFE, 0x00, ##  000            0000000000000000  
            0xC0, 0x00, 0x3F, 0xFC, 0x00, ##  00                000000000000   
            0x80, 0x00, 0x0F, 0xE0, 0x00, ##  0                   0000000      
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '160' => {    # ' '
        'width'    => 0, 
        'xoffset'  => 0, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
        ], 
    }, 
    '161' => {    # '¡'
        'width'    => 6, 
        'xoffset'  => 16, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '162' => {    # '¢'
        'width'    => 27, 
        'xoffset'  => 7, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x0F, 0xFC, 0x00, ##              0000000000     
            0x00, 0x7F, 0xFF, 0x80, ##           0000000000000000  
            0x01, 0xFF, 0xFF, 0xE0, ##         00000000000000000000
            0x03, 0xFF, 0xFF, 0xE0, ##        000000000000000000000
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000
            0x0F, 0xF9, 0xC7, 0xE0, ##      000000000  000   000000
            0x1F, 0xE1, 0xC0, 0xE0, ##     00000000    000      000
            0x1F, 0xC1, 0xC0, 0x20, ##     0000000     000        0
            0x3F, 0x81, 0xC0, 0x00, ##    0000000      000         
            0x3F, 0x01, 0xC0, 0x00, ##    000000       000         
            0x7F, 0x01, 0xC0, 0x00, ##   0000000       000         
            0x7E, 0x01, 0xC0, 0x00, ##   000000        000         
            0x7E, 0x01, 0xC0, 0x00, ##   000000        000         
            0xFE, 0x01, 0xC0, 0x00, ##  0000000        000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFC, 0x01, 0xC0, 0x00, ##  000000         000         
            0xFE, 0x01, 0xC0, 0x00, ##  0000000        000         
            0x7E, 0x01, 0xC0, 0x00, ##   000000        000         
            0x7E, 0x01, 0xC0, 0x00, ##   000000        000         
            0x7F, 0x01, 0xC0, 0x00, ##   0000000       000         
            0x3F, 0x01, 0xC0, 0x00, ##    000000       000         
            0x3F, 0x81, 0xC0, 0x00, ##    0000000      000         
            0x1F, 0xC1, 0xC0, 0x20, ##     0000000     000        0
            0x1F, 0xE1, 0xC0, 0xE0, ##     00000000    000      000
            0x0F, 0xF1, 0xC3, 0xE0, ##      00000000   000    00000
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000
            0x03, 0xFF, 0xFF, 0xE0, ##        000000000000000000000
            0x01, 0xFF, 0xFF, 0xE0, ##         00000000000000000000
            0x00, 0x7F, 0xFF, 0x80, ##           0000000000000000  
            0x00, 0x0F, 0xFC, 0x00, ##              0000000000     
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x01, 0xC0, 0x00, ##                 000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '163' => {    # '£'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x7F, 0x80, ##                   00000000     
            0x00, 0x03, 0xFF, 0xF8, ##                000000000000000 
            0x00, 0x07, 0xFF, 0xFC, ##               00000000000000000
            0x00, 0x0F, 0xFF, 0xFC, ##              000000000000000000
            0x00, 0x1F, 0xFF, 0xFC, ##             0000000000000000000
            0x00, 0x3F, 0xE0, 0x7C, ##            000000000      00000
            0x00, 0x3F, 0x80, 0x0C, ##            0000000           00
            0x00, 0x7F, 0x00, 0x04, ##           0000000             0
            0x00, 0x7E, 0x00, 0x00, ##           000000               
            0x00, 0x7E, 0x00, 0x00, ##           000000               
            0x00, 0xFE, 0x00, 0x00, ##          0000000               
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x7F, 0xFF, 0xFF, 0x80, ##   000000000000000000000000     
            0x7F, 0xFF, 0xFF, 0x80, ##   000000000000000000000000     
            0x7F, 0xFF, 0xFF, 0x80, ##   000000000000000000000000     
            0x7F, 0xFF, 0xFF, 0x80, ##   000000000000000000000000     
            0x7F, 0xFF, 0xFF, 0x80, ##   000000000000000000000000     
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFC, ##  000000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '164' => {    # '¤'
        'width'    => 27, 
        'xoffset'  => 7, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x20, 0x00, 0x00, 0x80, ##    0                     0  
            0x70, 0x00, 0x01, 0xC0, ##   000                   000 
            0xF8, 0x00, 0x03, 0xE0, ##  00000                 00000
            0x7C, 0x1F, 0x87, 0xC0, ##   00000     000000    00000 
            0x3E, 0xFF, 0xEF, 0x80, ##    00000 00000000000 00000  
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000   
            0x0F, 0xFF, 0xFE, 0x00, ##      0000000000000000000    
            0x07, 0xE0, 0xFC, 0x00, ##       000000     000000     
            0x0F, 0x80, 0x3E, 0x00, ##      00000         00000    
            0x0F, 0x00, 0x1E, 0x00, ##      0000           0000    
            0x1F, 0x00, 0x1E, 0x00, ##     00000           0000    
            0x1E, 0x00, 0x0F, 0x00, ##     0000             0000   
            0x1E, 0x00, 0x0F, 0x00, ##     0000             0000   
            0x1E, 0x00, 0x0F, 0x00, ##     0000             0000   
            0x1E, 0x00, 0x0F, 0x00, ##     0000             0000   
            0x1E, 0x00, 0x0F, 0x00, ##     0000             0000   
            0x0F, 0x00, 0x1E, 0x00, ##      0000           0000    
            0x0F, 0x00, 0x1E, 0x00, ##      0000           0000    
            0x0F, 0x80, 0x3C, 0x00, ##      00000         0000     
            0x07, 0xE0, 0xFC, 0x00, ##       000000     000000     
            0x0F, 0xFF, 0xFE, 0x00, ##      0000000000000000000    
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000   
            0x3E, 0xFF, 0xCF, 0x80, ##    00000 0000000000  00000  
            0x7C, 0x1F, 0x07, 0xC0, ##   00000     00000     00000 
            0xF8, 0x00, 0x03, 0xE0, ##  00000                 00000
            0x70, 0x00, 0x01, 0xC0, ##   000                   000 
            0x20, 0x00, 0x00, 0x80, ##    0                     0  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '165' => {    # '¥'
        'width'    => 35, 
        'xoffset'  => 2, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x07, 0xE0, ##  000000                       000000
            0xFE, 0x00, 0x00, 0x0F, 0xE0, ##  0000000                     0000000
            0x7F, 0x00, 0x00, 0x0F, 0xC0, ##   0000000                    000000 
            0x7F, 0x00, 0x00, 0x1F, 0xC0, ##   0000000                   0000000 
            0x3F, 0x80, 0x00, 0x1F, 0x80, ##    0000000                  000000  
            0x1F, 0x80, 0x00, 0x3F, 0x80, ##     000000                 0000000  
            0x1F, 0xC0, 0x00, 0x3F, 0x00, ##     0000000                000000   
            0x0F, 0xC0, 0x00, 0x7E, 0x00, ##      000000               000000    
            0x0F, 0xE0, 0x00, 0x7E, 0x00, ##      0000000              000000    
            0x07, 0xF0, 0x00, 0xFC, 0x00, ##       0000000            000000     
            0x07, 0xF0, 0x01, 0xFC, 0x00, ##       0000000           0000000     
            0x03, 0xF8, 0x01, 0xF8, 0x00, ##        0000000          000000      
            0x01, 0xF8, 0x03, 0xF8, 0x00, ##         000000         0000000      
            0x01, 0xFC, 0x03, 0xF0, 0x00, ##         0000000        000000       
            0x00, 0xFC, 0x07, 0xE0, 0x00, ##          000000       000000        
            0x00, 0xFE, 0x07, 0xE0, 0x00, ##          0000000      000000        
            0x00, 0x7F, 0x0F, 0xC0, 0x00, ##           0000000    000000         
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000         
            0x3F, 0xFF, 0x9F, 0xFF, 0x80, ##    000000000000000  00000000000000  
            0x3F, 0xFF, 0x9F, 0xFF, 0x80, ##    000000000000000  00000000000000  
            0x3F, 0xFF, 0xFF, 0xFF, 0x80, ##    0000000000000000000000000000000  
            0x00, 0x0F, 0xFE, 0x00, 0x00, ##              00000000000            
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000            
            0x00, 0x07, 0xFC, 0x00, 0x00, ##               000000000             
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000             
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000             
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x3F, 0xFF, 0xFF, 0xFF, 0x80, ##    0000000000000000000000000000000  
            0x3F, 0xFF, 0xFF, 0xFF, 0x80, ##    0000000000000000000000000000000  
            0x3F, 0xFF, 0xFF, 0xFF, 0x80, ##    0000000000000000000000000000000  
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '166' => {    # '¦'
        'width'    => 6, 
        'xoffset'  => 17, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '167' => {    # '§'
        'width'    => 26, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x7F, 0xC0, 0x00, ##           000000000        
            0x01, 0xFF, 0xFC, 0x00, ##         000000000000000    
            0x07, 0xFF, 0xFE, 0x00, ##       000000000000000000   
            0x0F, 0xFF, 0xFE, 0x00, ##      0000000000000000000   
            0x1F, 0xFF, 0xFE, 0x00, ##     00000000000000000000   
            0x1F, 0xE0, 0x3E, 0x00, ##     00000000       00000   
            0x3F, 0x80, 0x06, 0x00, ##    0000000            00   
            0x3F, 0x80, 0x00, 0x00, ##    0000000                 
            0x3F, 0x00, 0x00, 0x00, ##    000000                  
            0x3F, 0x00, 0x00, 0x00, ##    000000                  
            0x3F, 0x00, 0x00, 0x00, ##    000000                  
            0x3F, 0x80, 0x00, 0x00, ##    0000000                 
            0x1F, 0x80, 0x00, 0x00, ##     000000                 
            0x1F, 0xE0, 0x00, 0x00, ##     00000000               
            0x0F, 0xF0, 0x00, 0x00, ##      00000000              
            0x07, 0xF8, 0x00, 0x00, ##       00000000             
            0x03, 0xFE, 0x00, 0x00, ##        000000000           
            0x0F, 0xFF, 0x80, 0x00, ##      0000000000000         
            0x1F, 0xFF, 0xE0, 0x00, ##     0000000000000000       
            0x3E, 0x1F, 0xF0, 0x00, ##    00000    000000000      
            0x7C, 0x07, 0xF8, 0x00, ##   00000       00000000     
            0x7C, 0x03, 0xFE, 0x00, ##   00000        000000000   
            0xF8, 0x00, 0xFF, 0x00, ##  00000           00000000  
            0xF8, 0x00, 0x7F, 0x80, ##  00000            00000000 
            0xF8, 0x00, 0x1F, 0x80, ##  00000              000000 
            0xF8, 0x00, 0x0F, 0xC0, ##  00000               000000
            0xFC, 0x00, 0x0F, 0xC0, ##  000000              000000
            0xFC, 0x00, 0x07, 0xC0, ##  000000               00000
            0x7E, 0x00, 0x07, 0xC0, ##   000000              00000
            0x7F, 0x00, 0x07, 0xC0, ##   0000000             00000
            0x3F, 0xC0, 0x07, 0xC0, ##    00000000           00000
            0x1F, 0xE0, 0x0F, 0x80, ##     00000000         00000 
            0x0F, 0xF8, 0x0F, 0x80, ##      000000000       00000 
            0x07, 0xFE, 0x1F, 0x00, ##       0000000000    00000  
            0x01, 0xFF, 0x7F, 0x00, ##         000000000 0000000  
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000    
            0x00, 0x3F, 0xF8, 0x00, ##            00000000000     
            0x00, 0x0F, 0xF8, 0x00, ##              000000000     
            0x00, 0x07, 0xFC, 0x00, ##               000000000    
            0x00, 0x01, 0xFE, 0x00, ##                 00000000   
            0x00, 0x00, 0xFE, 0x00, ##                  0000000   
            0x00, 0x00, 0x7F, 0x00, ##                   0000000  
            0x00, 0x00, 0x3F, 0x00, ##                    000000  
            0x00, 0x00, 0x3F, 0x00, ##                    000000  
            0x00, 0x00, 0x3F, 0x00, ##                    000000  
            0x00, 0x00, 0x3F, 0x00, ##                    000000  
            0x00, 0x00, 0x7F, 0x00, ##                   0000000  
            0x38, 0x00, 0x7E, 0x00, ##    000            000000   
            0x3F, 0x01, 0xFE, 0x00, ##    000000       00000000   
            0x3F, 0xFF, 0xFC, 0x00, ##    00000000000000000000    
            0x3F, 0xFF, 0xFC, 0x00, ##    00000000000000000000    
            0x3F, 0xFF, 0xF8, 0x00, ##    0000000000000000000     
            0x0F, 0xFF, 0xE0, 0x00, ##      000000000000000       
            0x00, 0xFF, 0x00, 0x00, ##          00000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '168' => {    # '¨'
        'width'    => 18, 
        'xoffset'  => 10, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0xFC, 0x0F, 0xC0, ##  000000      000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '169' => {    # '©'
        'width'    => 38, 
        'xoffset'  => 0, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x01, 0xFE, 0x00, 0x00, ##                 00000000               
            0x00, 0x0F, 0xFF, 0xC0, 0x00, ##              00000000000000            
            0x00, 0x3F, 0xFF, 0xF0, 0x00, ##            000000000000000000          
            0x00, 0xFE, 0x01, 0xFC, 0x00, ##          0000000        0000000        
            0x01, 0xF0, 0x00, 0x3E, 0x00, ##         00000              00000       
            0x03, 0xC0, 0x00, 0x0F, 0x00, ##        0000                  0000      
            0x07, 0x80, 0x00, 0x07, 0x80, ##       0000                    0000     
            0x0F, 0x00, 0x00, 0x03, 0xC0, ##      0000                      0000    
            0x1E, 0x00, 0xFF, 0x01, 0xE0, ##     0000         00000000       0000   
            0x1C, 0x07, 0xFF, 0xE0, 0xE0, ##     000       00000000000000     000   
            0x3C, 0x0F, 0xFF, 0xE0, 0xF0, ##    0000      000000000000000     0000  
            0x38, 0x1F, 0x80, 0xE0, 0x70, ##    000      000000       000      000  
            0x70, 0x3E, 0x00, 0x20, 0x38, ##   000      00000           0       000 
            0x70, 0x7C, 0x00, 0x00, 0x38, ##   000     00000                    000 
            0x70, 0x78, 0x00, 0x00, 0x38, ##   000     0000                     000 
            0xE0, 0x78, 0x00, 0x00, 0x1C, ##  000      0000                      000
            0xE0, 0xF0, 0x00, 0x00, 0x1C, ##  000     0000                       000
            0xE0, 0xF0, 0x00, 0x00, 0x1C, ##  000     0000                       000
            0xE0, 0xF0, 0x00, 0x00, 0x1C, ##  000     0000                       000
            0xE0, 0xF0, 0x00, 0x00, 0x1C, ##  000     0000                       000
            0xE0, 0xF0, 0x00, 0x00, 0x1C, ##  000     0000                       000
            0xE0, 0xF0, 0x00, 0x00, 0x1C, ##  000     0000                       000
            0xE0, 0xF0, 0x00, 0x00, 0x1C, ##  000     0000                       000
            0xE0, 0xF8, 0x00, 0x00, 0x1C, ##  000     00000                      000
            0x70, 0x78, 0x00, 0x00, 0x38, ##   000     0000                     000 
            0x70, 0x7C, 0x00, 0x00, 0x38, ##   000     00000                    000 
            0x70, 0x3E, 0x00, 0x00, 0x78, ##   000      00000                  0000 
            0x38, 0x1F, 0x80, 0xE0, 0x70, ##    000      000000       000      000  
            0x3C, 0x0F, 0xFF, 0xE0, 0xF0, ##    0000      000000000000000     0000  
            0x1C, 0x07, 0xFF, 0xE0, 0xE0, ##     000       00000000000000     000   
            0x1E, 0x00, 0xFF, 0x01, 0xE0, ##     0000         00000000       0000   
            0x0F, 0x00, 0x00, 0x03, 0xC0, ##      0000                      0000    
            0x07, 0x80, 0x00, 0x07, 0x80, ##       0000                    0000     
            0x03, 0xE0, 0x00, 0x1F, 0x00, ##        00000                00000      
            0x01, 0xF0, 0x00, 0x3E, 0x00, ##         00000              00000       
            0x00, 0xFE, 0x01, 0xFC, 0x00, ##          0000000        0000000        
            0x00, 0x3F, 0xFF, 0xF0, 0x00, ##            000000000000000000          
            0x00, 0x0F, 0xFF, 0xC0, 0x00, ##              00000000000000            
            0x00, 0x01, 0xFE, 0x00, 0x00, ##                 00000000               
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '170' => {    # 'ª'
        'width'    => 22, 
        'xoffset'  => 8, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x03, 0xFE, 0x00, ##        000000000       
            0x3F, 0xFF, 0xC0, ##    0000000000000000    
            0x3F, 0xFF, 0xE0, ##    00000000000000000   
            0x3E, 0x03, 0xF0, ##    00000       000000  
            0x30, 0x00, 0xF8, ##    00            00000 
            0x00, 0x00, 0x78, ##                   0000 
            0x00, 0x00, 0x38, ##                    000 
            0x00, 0x00, 0x3C, ##                    0000
            0x00, 0x00, 0x3C, ##                    0000
            0x01, 0xFF, 0xFC, ##         000000000000000
            0x0F, 0xFF, 0xFC, ##      000000000000000000
            0x1F, 0xFF, 0xFC, ##     0000000000000000000
            0x3F, 0x80, 0x3C, ##    0000000         0000
            0x7E, 0x00, 0x3C, ##   000000           0000
            0xFC, 0x00, 0x3C, ##  000000            0000
            0xF8, 0x00, 0x3C, ##  00000             0000
            0xF8, 0x00, 0x7C, ##  00000            00000
            0xF8, 0x00, 0x7C, ##  00000            00000
            0xF8, 0x00, 0x7C, ##  00000            00000
            0xFC, 0x00, 0xFC, ##  000000          000000
            0x7C, 0x01, 0xFC, ##   00000         0000000
            0x7F, 0x07, 0xFC, ##   0000000     000000000
            0x3F, 0xFF, 0xBC, ##    000000000000000 0000
            0x1F, 0xFF, 0x3C, ##     0000000000000  0000
            0x07, 0xF8, 0x3C, ##       00000000     0000
            0x00, 0x00, 0x00, ##                        
            0x00, 0x00, 0x00, ##                        
            0x00, 0x00, 0x00, ##                        
            0x7F, 0xFF, 0xFC, ##   000000000000000000000
            0x7F, 0xFF, 0xFC, ##   000000000000000000000
            0x7F, 0xFF, 0xFC, ##   000000000000000000000
            0x7F, 0xFF, 0xFC, ##   000000000000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '171' => {    # '«'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x02, 0x00, 0x08, ##                0             0
            0x00, 0x06, 0x00, 0x18, ##               00            00
            0x00, 0x1E, 0x00, 0x38, ##             0000           000
            0x00, 0x3E, 0x00, 0x78, ##            00000          0000
            0x00, 0x7E, 0x00, 0xF8, ##           000000         00000
            0x00, 0xFE, 0x03, 0xF8, ##          0000000       0000000
            0x01, 0xFC, 0x07, 0xF0, ##         0000000       0000000 
            0x03, 0xF8, 0x0F, 0xE0, ##        0000000       0000000  
            0x07, 0xE0, 0x1F, 0xC0, ##       000000        0000000   
            0x0F, 0xC0, 0x3F, 0x80, ##      000000        0000000    
            0x1F, 0x80, 0x7F, 0x00, ##     000000        0000000     
            0x3F, 0x00, 0xFC, 0x00, ##    000000        000000       
            0xFE, 0x03, 0xF8, 0x00, ##  0000000       0000000        
            0xFC, 0x03, 0xF0, 0x00, ##  000000        000000         
            0xFC, 0x03, 0xF0, 0x00, ##  000000        000000         
            0xFE, 0x03, 0xF8, 0x00, ##  0000000       0000000        
            0x7F, 0x01, 0xFC, 0x00, ##   0000000       0000000       
            0x3F, 0x80, 0xFE, 0x00, ##    0000000       0000000      
            0x1F, 0xC0, 0x7F, 0x00, ##     0000000       0000000     
            0x0F, 0xE0, 0x1F, 0x80, ##      0000000        000000    
            0x03, 0xF0, 0x0F, 0xE0, ##        000000        0000000  
            0x01, 0xF8, 0x07, 0xF0, ##         000000        0000000 
            0x00, 0xFC, 0x03, 0xF8, ##          000000        0000000
            0x00, 0x7E, 0x01, 0xF8, ##           000000        000000
            0x00, 0x3E, 0x00, 0xF8, ##            00000         00000
            0x00, 0x1E, 0x00, 0x78, ##             0000          0000
            0x00, 0x0E, 0x00, 0x18, ##              000            00
            0x00, 0x06, 0x00, 0x08, ##               00             0
            0x00, 0x02, 0x00, 0x00, ##                0              
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '172' => {    # '¬'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '173' => {    # '­'
        'width'    => 16, 
        'xoffset'  => 11, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFF, ##  0000000000000000
            0xFF, 0xFF, ##  0000000000000000
            0xFF, 0xFF, ##  0000000000000000
            0xFF, 0xFF, ##  0000000000000000
            0xFF, 0xFF, ##  0000000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '174' => {    # '®'
        'width'    => 38, 
        'xoffset'  => 0, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x01, 0xFE, 0x00, 0x00, ##                 00000000               
            0x00, 0x0F, 0xFF, 0xC0, 0x00, ##              00000000000000            
            0x00, 0x3F, 0xFF, 0xF0, 0x00, ##            000000000000000000          
            0x00, 0xFE, 0x01, 0xFC, 0x00, ##          0000000        0000000        
            0x01, 0xF0, 0x00, 0x3E, 0x00, ##         00000              00000       
            0x03, 0xC0, 0x00, 0x0F, 0x00, ##        0000                  0000      
            0x07, 0x80, 0x00, 0x07, 0x80, ##       0000                    0000     
            0x0F, 0x00, 0x00, 0x03, 0xC0, ##      0000                      0000    
            0x1E, 0x00, 0x00, 0x01, 0xE0, ##     0000                        0000   
            0x1C, 0x1F, 0xFE, 0x00, 0xE0, ##     000     000000000000         000   
            0x3C, 0x1F, 0xFF, 0xC0, 0xF0, ##    0000     000000000000000      0000  
            0x38, 0x1E, 0x03, 0xE0, 0x70, ##    000      0000       00000      000  
            0x70, 0x1E, 0x01, 0xE0, 0x38, ##   000       0000        0000       000 
            0x70, 0x1E, 0x00, 0xF0, 0x38, ##   000       0000         0000      000 
            0x70, 0x1E, 0x00, 0xF0, 0x38, ##   000       0000         0000      000 
            0xE0, 0x1E, 0x00, 0xF0, 0x1C, ##  000        0000         0000       000
            0xE0, 0x1E, 0x00, 0xF0, 0x1C, ##  000        0000         0000       000
            0xE0, 0x1E, 0x01, 0xE0, 0x1C, ##  000        0000        0000        000
            0xE0, 0x1E, 0x03, 0xE0, 0x1C, ##  000        0000       00000        000
            0xE0, 0x1F, 0xFF, 0xC0, 0x1C, ##  000        000000000000000         000
            0xE0, 0x1F, 0xFE, 0x00, 0x1C, ##  000        000000000000            000
            0xE0, 0x1E, 0x1F, 0x00, 0x1C, ##  000        0000    00000           000
            0xE0, 0x1E, 0x0F, 0x80, 0x1C, ##  000        0000     00000          000
            0xE0, 0x1E, 0x07, 0xC0, 0x1C, ##  000        0000      00000         000
            0x70, 0x1E, 0x03, 0xC0, 0x38, ##   000       0000       0000        000 
            0x70, 0x1E, 0x03, 0xE0, 0x38, ##   000       0000       00000       000 
            0x70, 0x1E, 0x01, 0xE0, 0x78, ##   000       0000        0000      0000 
            0x38, 0x1E, 0x00, 0xF0, 0x70, ##    000      0000         0000     000  
            0x3C, 0x1E, 0x00, 0xF8, 0xF0, ##    0000     0000         00000   0000  
            0x1C, 0x1E, 0x00, 0x78, 0xE0, ##     000     0000          0000   000   
            0x1E, 0x00, 0x00, 0x01, 0xE0, ##     0000                        0000   
            0x0F, 0x00, 0x00, 0x03, 0xC0, ##      0000                      0000    
            0x07, 0x80, 0x00, 0x07, 0x80, ##       0000                    0000     
            0x03, 0xE0, 0x00, 0x1F, 0x00, ##        00000                00000      
            0x01, 0xF0, 0x00, 0x3E, 0x00, ##         00000              00000       
            0x00, 0xFE, 0x01, 0xFC, 0x00, ##          0000000        0000000        
            0x00, 0x3F, 0xFF, 0xF0, 0x00, ##            000000000000000000          
            0x00, 0x0F, 0xFF, 0xC0, 0x00, ##              00000000000000            
            0x00, 0x01, 0xFE, 0x00, 0x00, ##                 00000000               
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '175' => {    # '¯'
        'width'    => 19, 
        'xoffset'  => 10, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '176' => {    # '°'
        'width'    => 20, 
        'xoffset'  => 9, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x01, 0xF8, 0x00, ##         000000       
            0x07, 0xFE, 0x00, ##       0000000000     
            0x1F, 0xFF, 0x80, ##     00000000000000   
            0x3F, 0xFF, 0xC0, ##    0000000000000000  
            0x3F, 0x0F, 0xC0, ##    000000    000000  
            0x7C, 0x03, 0xE0, ##   00000        00000 
            0x78, 0x01, 0xE0, ##   0000          0000 
            0xF8, 0x01, 0xF0, ##  00000          00000
            0xF0, 0x00, 0xF0, ##  0000            0000
            0xF0, 0x00, 0xF0, ##  0000            0000
            0xF0, 0x00, 0xF0, ##  0000            0000
            0xF0, 0x00, 0xF0, ##  0000            0000
            0xF0, 0x01, 0xF0, ##  0000           00000
            0x78, 0x01, 0xE0, ##   0000          0000 
            0x7C, 0x03, 0xE0, ##   00000        00000 
            0x7E, 0x0F, 0xC0, ##   000000     000000  
            0x3F, 0xFF, 0xC0, ##    0000000000000000  
            0x1F, 0xFF, 0x80, ##     00000000000000   
            0x0F, 0xFE, 0x00, ##      00000000000     
            0x01, 0xF8, 0x00, ##         000000       
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '177' => {    # '±'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000              
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '178' => {    # '²'
        'width'    => 18, 
        'xoffset'  => 10, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x0F, 0xF0, 0x00, ##      00000000      
            0xFF, 0xFC, 0x00, ##  00000000000000    
            0xFF, 0xFF, 0x00, ##  0000000000000000  
            0xF0, 0x3F, 0x80, ##  0000      0000000 
            0xC0, 0x0F, 0x80, ##  00          00000 
            0x00, 0x0F, 0xC0, ##              000000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x0F, 0x80, ##              00000 
            0x00, 0x0F, 0x80, ##              00000 
            0x00, 0x1F, 0x00, ##             00000  
            0x00, 0x3E, 0x00, ##            00000   
            0x00, 0x7E, 0x00, ##           000000   
            0x00, 0xFC, 0x00, ##          000000    
            0x01, 0xF8, 0x00, ##         000000     
            0x03, 0xF0, 0x00, ##        000000      
            0x07, 0xE0, 0x00, ##       000000       
            0x0F, 0xC0, 0x00, ##      000000        
            0x1F, 0x80, 0x00, ##     000000         
            0x1F, 0x00, 0x00, ##     00000          
            0x3E, 0x00, 0x00, ##    00000           
            0x7C, 0x00, 0x00, ##   00000            
            0xFF, 0xFF, 0xC0, ##  000000000000000000
            0xFF, 0xFF, 0xC0, ##  000000000000000000
            0xFF, 0xFF, 0xC0, ##  000000000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '179' => {    # '³'
        'width'    => 18, 
        'xoffset'  => 11, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x1F, 0xF0, 0x00, ##     000000000      
            0xFF, 0xFE, 0x00, ##  000000000000000   
            0xFF, 0xFF, 0x00, ##  0000000000000000  
            0xF0, 0x3F, 0x80, ##  0000      0000000 
            0x80, 0x0F, 0xC0, ##  0           000000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x0F, 0x80, ##              00000 
            0x00, 0x3F, 0x80, ##            0000000 
            0x07, 0xFE, 0x00, ##       0000000000   
            0x07, 0xF8, 0x00, ##       00000000     
            0x07, 0xFE, 0x00, ##       0000000000   
            0x00, 0x3F, 0x80, ##            0000000 
            0x00, 0x0F, 0x80, ##              00000 
            0x00, 0x0F, 0xC0, ##              000000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x07, 0xC0, ##               00000
            0x00, 0x0F, 0xC0, ##              000000
            0x00, 0x1F, 0x80, ##             000000 
            0xE0, 0x3F, 0x80, ##  000       0000000 
            0xFF, 0xFF, 0x00, ##  0000000000000000  
            0xFF, 0xFC, 0x00, ##  00000000000000    
            0x3F, 0xE0, 0x00, ##    000000000       
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '180' => {    # '´'
        'width'    => 15, 
        'xoffset'  => 15, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0xFC, ##          000000 
            0x00, 0xFC, ##          000000 
            0x01, 0xF8, ##         000000  
            0x03, 0xF0, ##        000000   
            0x07, 0xE0, ##       000000    
            0x07, 0xC0, ##       00000     
            0x0F, 0x80, ##      00000      
            0x1F, 0x00, ##     00000       
            0x3F, 0x00, ##    000000       
            0x3E, 0x00, ##    00000        
            0x7C, 0x00, ##   00000         
            0xF8, 0x00, ##  00000          
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '181' => {    # 'µ'
        'width'    => 31, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000    
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000    
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000    
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000    
            0xFF, 0x00, 0x1F, 0xE0, ##  00000000           00000000    
            0xFF, 0x80, 0x3F, 0xE0, ##  000000000         000000000    
            0xFF, 0xC0, 0xFF, 0xF2, ##  0000000000      000000000000  0
            0xFB, 0xFF, 0xFF, 0xFE, ##  00000 0000000000000000000000000
            0xFB, 0xFF, 0xFB, 0xFE, ##  00000 000000000000000 000000000
            0xF9, 0xFF, 0xF1, 0xFE, ##  00000  0000000000000   00000000
            0xF8, 0xFF, 0xE1, 0xFE, ##  00000   00000000000    00000000
            0xF8, 0x3F, 0x80, 0xF8, ##  00000     0000000       00000  
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0xF8, 0x00, 0x00, 0x00, ##  00000                          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '182' => {    # '¶'
        'width'    => 29, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x3F, 0xFF, 0xF8, ##            0000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x03, 0xFF, 0xFF, 0xF8, ##        00000000000000000000000
            0x0F, 0xFF, 0xFF, 0xF8, ##      0000000000000000000000000
            0x1F, 0xFF, 0xC0, 0x78, ##     000000000000000       0000
            0x3F, 0xFF, 0xC0, 0x78, ##    0000000000000000       0000
            0x3F, 0xFF, 0xC0, 0x78, ##    0000000000000000       0000
            0x7F, 0xFF, 0xC0, 0x78, ##   00000000000000000       0000
            0x7F, 0xFF, 0xC0, 0x78, ##   00000000000000000       0000
            0xFF, 0xFF, 0xC0, 0x78, ##  000000000000000000       0000
            0xFF, 0xFF, 0xC0, 0x78, ##  000000000000000000       0000
            0xFF, 0xFF, 0xC0, 0x78, ##  000000000000000000       0000
            0xFF, 0xFF, 0xC0, 0x78, ##  000000000000000000       0000
            0xFF, 0xFF, 0xC0, 0x78, ##  000000000000000000       0000
            0xFF, 0xFF, 0xC0, 0x78, ##  000000000000000000       0000
            0xFF, 0xFF, 0xC0, 0x78, ##  000000000000000000       0000
            0xFF, 0xFF, 0xC0, 0x78, ##  000000000000000000       0000
            0x7F, 0xFF, 0xC0, 0x78, ##   00000000000000000       0000
            0x7F, 0xFF, 0xC0, 0x78, ##   00000000000000000       0000
            0x7F, 0xFF, 0xC0, 0x78, ##   00000000000000000       0000
            0x3F, 0xFF, 0xC0, 0x78, ##    0000000000000000       0000
            0x1F, 0xFF, 0xC0, 0x78, ##     000000000000000       0000
            0x0F, 0xFF, 0xC0, 0x78, ##      00000000000000       0000
            0x07, 0xFF, 0xC0, 0x78, ##       0000000000000       0000
            0x03, 0xFF, 0xC0, 0x78, ##        000000000000       0000
            0x00, 0x7F, 0xC0, 0x78, ##           000000000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x03, 0xC0, 0x78, ##                0000       0000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '183' => {    # '·'
        'width'    => 8, 
        'xoffset'  => 15, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0xFF, ##  00000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '184' => {    # '¸'
        'width'    => 12, 
        'xoffset'  => 13, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0x80, ##       0000   
            0x03, 0xC0, ##        0000  
            0x01, 0xC0, ##         000  
            0x01, 0xE0, ##         0000 
            0x00, 0xE0, ##          000 
            0x00, 0xF0, ##          0000
            0x00, 0xF0, ##          0000
            0x00, 0xF0, ##          0000
            0x81, 0xF0, ##  0      00000
            0xFF, 0xF0, ##  000000000000
            0xFF, 0xE0, ##  00000000000 
            0xFF, 0xC0, ##  0000000000  
            0x7F, 0x00, ##   0000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '185' => {    # '¹'
        'width'    => 17, 
        'xoffset'  => 11, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x1F, 0xE0, 0x00, ##     00000000      
            0xFF, 0xE0, 0x00, ##  00000000000      
            0xFF, 0xE0, 0x00, ##  00000000000      
            0xFF, 0xE0, 0x00, ##  00000000000      
            0xC3, 0xE0, 0x00, ##  00    00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0xFF, 0xFF, 0x80, ##  00000000000000000
            0xFF, 0xFF, 0x80, ##  00000000000000000
            0xFF, 0xFF, 0x80, ##  00000000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '186' => {    # 'º'
        'width'    => 23, 
        'xoffset'  => 8, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0xFE, 0x00, ##          0000000        
            0x07, 0xFF, 0x80, ##       000000000000      
            0x0F, 0xFF, 0xE0, ##      000000000000000    
            0x1F, 0x83, 0xF0, ##     000000     000000   
            0x3F, 0x01, 0xF8, ##    000000       000000  
            0x3E, 0x00, 0xF8, ##    00000         00000  
            0x7C, 0x00, 0x7C, ##   00000           00000 
            0x7C, 0x00, 0x7C, ##   00000           00000 
            0xF8, 0x00, 0x3E, ##  00000             00000
            0xF8, 0x00, 0x3E, ##  00000             00000
            0xF8, 0x00, 0x3E, ##  00000             00000
            0xF8, 0x00, 0x3E, ##  00000             00000
            0xF8, 0x00, 0x3E, ##  00000             00000
            0xF8, 0x00, 0x3E, ##  00000             00000
            0xF8, 0x00, 0x3E, ##  00000             00000
            0xF8, 0x00, 0x3E, ##  00000             00000
            0xF8, 0x00, 0x3E, ##  00000             00000
            0x7C, 0x00, 0x7C, ##   00000           00000 
            0x7C, 0x00, 0x7C, ##   00000           00000 
            0x3E, 0x00, 0xF8, ##    00000         00000  
            0x3F, 0x01, 0xF8, ##    000000       000000  
            0x1F, 0x83, 0xF0, ##     000000     000000   
            0x0F, 0xFF, 0xE0, ##      000000000000000    
            0x07, 0xFF, 0xC0, ##       0000000000000     
            0x00, 0xFE, 0x00, ##          0000000        
            0x00, 0x00, 0x00, ##                         
            0x00, 0x00, 0x00, ##                         
            0x00, 0x00, 0x00, ##                         
            0x7F, 0xFF, 0xFC, ##   000000000000000000000 
            0x7F, 0xFF, 0xFC, ##   000000000000000000000 
            0x7F, 0xFF, 0xFC, ##   000000000000000000000 
            0x7F, 0xFF, 0xFC, ##   000000000000000000000 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '187' => {    # '»'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x80, 0x02, 0x00, 0x00, ##  0             0              
            0xC0, 0x03, 0x00, 0x00, ##  00            00             
            0xE0, 0x03, 0x80, 0x00, ##  000           000            
            0xF0, 0x03, 0xC0, 0x00, ##  0000          0000           
            0xF8, 0x03, 0xE0, 0x00, ##  00000         00000          
            0xFC, 0x03, 0xF8, 0x00, ##  000000        0000000        
            0x7E, 0x01, 0xFC, 0x00, ##   000000        0000000       
            0x3F, 0x80, 0xFE, 0x00, ##    0000000       0000000      
            0x1F, 0xC0, 0x7F, 0x00, ##     0000000       0000000     
            0x0F, 0xE0, 0x3F, 0x80, ##      0000000       0000000    
            0x07, 0xF0, 0x1F, 0xC0, ##       0000000       0000000   
            0x03, 0xF8, 0x07, 0xE0, ##        0000000        000000  
            0x01, 0xFC, 0x03, 0xF8, ##         0000000        0000000
            0x00, 0x7E, 0x01, 0xF8, ##           000000        000000
            0x00, 0x7E, 0x01, 0xF8, ##           000000        000000
            0x00, 0xFC, 0x03, 0xF8, ##          000000        0000000
            0x01, 0xF8, 0x07, 0xF0, ##         000000        0000000 
            0x03, 0xF0, 0x0F, 0xE0, ##        000000        0000000  
            0x0F, 0xE0, 0x1F, 0xC0, ##      0000000        0000000   
            0x1F, 0xC0, 0x3F, 0x00, ##     0000000        000000     
            0x3F, 0x80, 0xFE, 0x00, ##    0000000       0000000      
            0x7F, 0x01, 0xFC, 0x00, ##   0000000       0000000       
            0xFE, 0x03, 0xF8, 0x00, ##  0000000       0000000        
            0xFC, 0x03, 0xF0, 0x00, ##  000000        000000         
            0xF8, 0x03, 0xE0, 0x00, ##  00000         00000          
            0xE0, 0x03, 0xC0, 0x00, ##  000           0000           
            0xC0, 0x03, 0x00, 0x00, ##  00            00             
            0x80, 0x02, 0x00, 0x00, ##  0             0              
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '188' => {    # '¼'
        'width'    => 34, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x1F, 0xF8, 0x00, 0x00, 0x00, ##     0000000000                     
            0x7F, 0xF8, 0x00, 0x00, 0x00, ##   000000000000                     
            0x7F, 0xF8, 0x00, 0x00, 0x00, ##   000000000000                     
            0x7C, 0xF8, 0x00, 0x00, 0x00, ##   00000  00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x3F, 0xFF, 0xE0, 0x00, 0x00, ##    00000000000000000               
            0x3F, 0xFF, 0xE0, 0x00, 0x00, ##    00000000000000000               
            0x3F, 0xFF, 0xE0, 0x07, 0x80, ##    00000000000000000          0000 
            0x00, 0x00, 0x00, 0x7F, 0x80, ##                           00000000 
            0x00, 0x00, 0x07, 0xFF, 0xC0, ##                       0000000000000
            0x00, 0x00, 0x7F, 0xFE, 0x00, ##                   00000000000000   
            0x00, 0x07, 0xFF, 0xE0, 0x00, ##               00000000000000       
            0x00, 0x7F, 0xFE, 0x00, 0x00, ##           00000000000000           
            0x07, 0xFF, 0xE0, 0x00, 0x00, ##       00000000000000               
            0x7F, 0xFE, 0x00, 0x00, 0x00, ##   00000000000000                   
            0xFF, 0xE0, 0x00, 0x00, 0x00, ##  00000000000                       
            0xFF, 0x00, 0x00, 0xF8, 0x00, ##  00000000                00000     
            0xF0, 0x00, 0x01, 0xF8, 0x00, ##  0000                   000000     
            0x00, 0x00, 0x01, 0xF8, 0x00, ##                         000000     
            0x00, 0x00, 0x03, 0xF8, 0x00, ##                        0000000     
            0x00, 0x00, 0x03, 0xF8, 0x00, ##                        0000000     
            0x00, 0x00, 0x07, 0x78, 0x00, ##                       000 0000     
            0x00, 0x00, 0x0F, 0x78, 0x00, ##                      0000 0000     
            0x00, 0x00, 0x0E, 0x78, 0x00, ##                      000  0000     
            0x00, 0x00, 0x1C, 0x78, 0x00, ##                     000   0000     
            0x00, 0x00, 0x3C, 0x78, 0x00, ##                    0000   0000     
            0x00, 0x00, 0x38, 0x78, 0x00, ##                    000    0000     
            0x00, 0x00, 0x78, 0x78, 0x00, ##                   0000    0000     
            0x00, 0x00, 0xF0, 0x78, 0x00, ##                  0000     0000     
            0x00, 0x00, 0xE0, 0x78, 0x00, ##                  000      0000     
            0x00, 0x01, 0xE0, 0x78, 0x00, ##                 0000      0000     
            0x00, 0x03, 0xC0, 0x78, 0x00, ##                0000       0000     
            0x00, 0x03, 0x80, 0x78, 0x00, ##                000        0000     
            0x00, 0x07, 0x80, 0x78, 0x00, ##               0000        0000     
            0x00, 0x07, 0xFF, 0xFF, 0x80, ##               00000000000000000000 
            0x00, 0x07, 0xFF, 0xFF, 0x80, ##               00000000000000000000 
            0x00, 0x07, 0xFF, 0xFF, 0x80, ##               00000000000000000000 
            0x00, 0x00, 0x00, 0x78, 0x00, ##                           0000     
            0x00, 0x00, 0x00, 0x78, 0x00, ##                           0000     
            0x00, 0x00, 0x00, 0x78, 0x00, ##                           0000     
            0x00, 0x00, 0x00, 0x78, 0x00, ##                           0000     
            0x00, 0x00, 0x00, 0x78, 0x00, ##                           0000     
            0x00, 0x00, 0x00, 0x78, 0x00, ##                           0000     
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '189' => {    # '½'
        'width'    => 34, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x1F, 0xF8, 0x00, 0x00, 0x00, ##     0000000000                     
            0x7F, 0xF8, 0x00, 0x00, 0x00, ##   000000000000                     
            0x7F, 0xF8, 0x00, 0x00, 0x00, ##   000000000000                     
            0x7C, 0xF8, 0x00, 0x00, 0x00, ##   00000  00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x00, 0xF8, 0x00, 0x00, 0x00, ##          00000                     
            0x3F, 0xFF, 0xE0, 0x00, 0x00, ##    00000000000000000               
            0x3F, 0xFF, 0xE0, 0x00, 0x00, ##    00000000000000000               
            0x3F, 0xFF, 0xE0, 0x07, 0x80, ##    00000000000000000          0000 
            0x00, 0x00, 0x00, 0x7F, 0x80, ##                           00000000 
            0x00, 0x00, 0x07, 0xFF, 0xC0, ##                       0000000000000
            0x00, 0x00, 0x3F, 0xFE, 0x00, ##                    0000000000000   
            0x00, 0x03, 0xFF, 0xE0, 0x00, ##                0000000000000       
            0x00, 0x3F, 0xFF, 0x00, 0x00, ##            00000000000000          
            0x03, 0xFF, 0xF0, 0x00, 0x00, ##        00000000000000              
            0x3F, 0xFF, 0x00, 0x00, 0x00, ##    00000000000000                  
            0xFF, 0xF0, 0x00, 0x00, 0x00, ##  000000000000                      
            0xFF, 0x00, 0x1F, 0xE0, 0x00, ##  00000000           00000000       
            0xF0, 0x01, 0xFF, 0xF8, 0x00, ##  0000           00000000000000     
            0x00, 0x01, 0xFF, 0xFE, 0x00, ##                 0000000000000000   
            0x00, 0x01, 0xE0, 0x7F, 0x00, ##                 0000      0000000  
            0x00, 0x01, 0x80, 0x1F, 0x00, ##                 00          00000  
            0x00, 0x00, 0x00, 0x1F, 0x80, ##                             000000 
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000 
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000 
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000 
            0x00, 0x00, 0x00, 0x0F, 0x80, ##                              00000 
            0x00, 0x00, 0x00, 0x1F, 0x00, ##                             00000  
            0x00, 0x00, 0x00, 0x1F, 0x00, ##                             00000  
            0x00, 0x00, 0x00, 0x3E, 0x00, ##                            00000   
            0x00, 0x00, 0x00, 0x7C, 0x00, ##                           00000    
            0x00, 0x00, 0x00, 0xF8, 0x00, ##                          00000     
            0x00, 0x00, 0x01, 0xF8, 0x00, ##                         000000     
            0x00, 0x00, 0x03, 0xF0, 0x00, ##                        000000      
            0x00, 0x00, 0x07, 0xE0, 0x00, ##                       000000       
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000        
            0x00, 0x00, 0x1F, 0x80, 0x00, ##                     000000         
            0x00, 0x00, 0x3F, 0x00, 0x00, ##                    000000          
            0x00, 0x00, 0x3C, 0x00, 0x00, ##                    0000            
            0x00, 0x00, 0x78, 0x00, 0x00, ##                   0000             
            0x00, 0x00, 0xF0, 0x00, 0x00, ##                  0000              
            0x00, 0x01, 0xFF, 0xFF, 0x80, ##                 000000000000000000 
            0x00, 0x01, 0xFF, 0xFF, 0x80, ##                 000000000000000000 
            0x00, 0x01, 0xFF, 0xFF, 0x80, ##                 000000000000000000 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '190' => {    # '¾'
        'width'    => 35, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x03, 0xFE, 0x00, 0x00, 0x00, ##        000000000                    
            0x1F, 0xFF, 0xC0, 0x00, 0x00, ##     000000000000000                 
            0x1F, 0xFF, 0xE0, 0x00, 0x00, ##     0000000000000000                
            0x1E, 0x07, 0xF0, 0x00, 0x00, ##     0000      0000000               
            0x10, 0x01, 0xF8, 0x00, 0x00, ##     0           000000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000              
            0x00, 0x01, 0xF0, 0x00, 0x00, ##                 00000               
            0x00, 0x07, 0xF0, 0x00, 0x00, ##               0000000               
            0x00, 0xFF, 0xC0, 0x00, 0x00, ##          0000000000                 
            0x00, 0xFF, 0x00, 0x00, 0x00, ##          00000000                   
            0x00, 0xFF, 0xC0, 0x00, 0x00, ##          0000000000                 
            0x00, 0x07, 0xF0, 0x00, 0x00, ##               0000000               
            0x00, 0x01, 0xF0, 0x00, 0x00, ##                 00000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000              
            0x20, 0x03, 0xF0, 0x00, 0x00, ##    0           000000               
            0x3C, 0x07, 0xF0, 0x00, 0x00, ##    0000       0000000               
            0x3F, 0xFF, 0xE0, 0x00, 0x00, ##    00000000000000000                
            0x3F, 0xFF, 0x80, 0x00, 0x40, ##    000000000000000                0 
            0x07, 0xFC, 0x00, 0x0F, 0xC0, ##       000000000              000000 
            0x00, 0x00, 0x00, 0xFF, 0xC0, ##                          0000000000 
            0x00, 0x00, 0x0F, 0xFF, 0xC0, ##                      00000000000000 
            0x00, 0x00, 0xFF, 0xFC, 0x00, ##                  00000000000000     
            0x00, 0x0F, 0xFF, 0xC0, 0x00, ##              00000000000000         
            0x00, 0xFF, 0xFC, 0x00, 0x00, ##          00000000000000             
            0x0F, 0xFF, 0xC0, 0x00, 0x00, ##      00000000000000                 
            0xFF, 0xFC, 0x00, 0x00, 0x00, ##  00000000000000                     
            0x7F, 0xC0, 0x00, 0x00, 0x00, ##   000000000                         
            0x7C, 0x00, 0x00, 0x7C, 0x00, ##   00000                   00000     
            0x40, 0x00, 0x00, 0xFC, 0x00, ##   0                      000000     
            0x00, 0x00, 0x01, 0xFC, 0x00, ##                         0000000     
            0x00, 0x00, 0x01, 0xFC, 0x00, ##                         0000000     
            0x00, 0x00, 0x03, 0xFC, 0x00, ##                        00000000     
            0x00, 0x00, 0x07, 0xBC, 0x00, ##                       0000 0000     
            0x00, 0x00, 0x07, 0x3C, 0x00, ##                       000  0000     
            0x00, 0x00, 0x0E, 0x3C, 0x00, ##                      000   0000     
            0x00, 0x00, 0x1E, 0x3C, 0x00, ##                     0000   0000     
            0x00, 0x00, 0x1C, 0x3C, 0x00, ##                     000    0000     
            0x00, 0x00, 0x38, 0x3C, 0x00, ##                    000     0000     
            0x00, 0x00, 0x78, 0x3C, 0x00, ##                   0000     0000     
            0x00, 0x00, 0x70, 0x3C, 0x00, ##                   000      0000     
            0x00, 0x00, 0xE0, 0x3C, 0x00, ##                  000       0000     
            0x00, 0x01, 0xE0, 0x3C, 0x00, ##                 0000       0000     
            0x00, 0x03, 0xC0, 0x3C, 0x00, ##                0000        0000     
            0x00, 0x03, 0x80, 0x3C, 0x00, ##                000         0000     
            0x00, 0x03, 0xFF, 0xFF, 0xC0, ##                00000000000000000000 
            0x00, 0x03, 0xFF, 0xFF, 0xC0, ##                00000000000000000000 
            0x00, 0x03, 0xFF, 0xFF, 0xC0, ##                00000000000000000000 
            0x00, 0x00, 0x00, 0x3C, 0x00, ##                            0000     
            0x00, 0x00, 0x00, 0x3C, 0x00, ##                            0000     
            0x00, 0x00, 0x00, 0x3C, 0x00, ##                            0000     
            0x00, 0x00, 0x00, 0x3C, 0x00, ##                            0000     
            0x00, 0x00, 0x00, 0x3C, 0x00, ##                            0000     
            0x00, 0x00, 0x00, 0x3C, 0x00, ##                            0000     
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '191' => {    # '¿'
        'width'    => 25, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x00, 0x00, 0x00, ##                           
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x1F, 0x80, 0x00, ##             000000        
            0x00, 0x3F, 0x80, 0x00, ##            0000000        
            0x00, 0x3F, 0x00, 0x00, ##            000000         
            0x00, 0x7F, 0x00, 0x00, ##           0000000         
            0x00, 0xFE, 0x00, 0x00, ##          0000000          
            0x01, 0xFC, 0x00, 0x00, ##         0000000           
            0x03, 0xF8, 0x00, 0x00, ##        0000000            
            0x07, 0xF0, 0x00, 0x00, ##       0000000             
            0x0F, 0xE0, 0x00, 0x00, ##      0000000              
            0x1F, 0xC0, 0x00, 0x00, ##     0000000               
            0x3F, 0x80, 0x00, 0x00, ##    0000000                
            0x3F, 0x00, 0x00, 0x00, ##    000000                 
            0x7F, 0x00, 0x00, 0x00, ##   0000000                 
            0x7E, 0x00, 0x00, 0x00, ##   000000                  
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFC, 0x00, 0x00, 0x00, ##  000000                   
            0xFE, 0x00, 0x00, 0x80, ##  0000000                 0
            0x7E, 0x00, 0x03, 0x80, ##   000000               000
            0x7F, 0x00, 0x0F, 0x80, ##   0000000            00000
            0x7F, 0xC0, 0x7F, 0x80, ##   000000000       00000000
            0x3F, 0xFF, 0xFF, 0x80, ##    00000000000000000000000
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000
            0x0F, 0xFF, 0xFE, 0x00, ##      0000000000000000000  
            0x03, 0xFF, 0xF8, 0x00, ##        000000000000000    
            0x00, 0xFF, 0xC0, 0x00, ##          0000000000       
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '192' => {    # 'À'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x1F, 0x80, 0x00, 0x00, ##             000000                   
            0x00, 0x0F, 0x80, 0x00, 0x00, ##              00000                   
            0x00, 0x0F, 0xC0, 0x00, 0x00, ##              000000                  
            0x00, 0x07, 0xE0, 0x00, 0x00, ##               000000                 
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000                 
            0x00, 0x01, 0xF0, 0x00, 0x00, ##                 00000                
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000               
            0x00, 0x00, 0x7C, 0x00, 0x00, ##                   00000              
            0x00, 0x00, 0x7C, 0x00, 0x00, ##                   00000              
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x0F, 0xDF, 0x00, 0x00, ##              000000 00000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000           
            0x00, 0x0F, 0x9F, 0x80, 0x00, ##              00000  000000           
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x8F, 0x80, 0x00, ##             000000   00000           
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000          
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x3F, 0x07, 0xC0, 0x00, ##            000000     00000          
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000         
            0x00, 0x3E, 0x07, 0xE0, 0x00, ##            00000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000        
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000        
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000       
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000      
            0x03, 0xF8, 0x00, 0xFC, 0x00, ##        0000000           000000      
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x03, 0xF0, 0x00, 0xFE, 0x00, ##        000000            0000000     
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000     
            0x07, 0xFF, 0xFF, 0xFE, 0x00, ##       00000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000    
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x00, ##      0000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x80, ##      00000000000000000000000000000   
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000   
            0x1F, 0xC0, 0x00, 0x1F, 0x80, ##     0000000                 000000   
            0x1F, 0x80, 0x00, 0x1F, 0x80, ##     000000                  000000   
            0x1F, 0x80, 0x00, 0x1F, 0xC0, ##     000000                  0000000  
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000  
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000  
            0x3F, 0x00, 0x00, 0x0F, 0xE0, ##    000000                    0000000 
            0x3F, 0x00, 0x00, 0x07, 0xE0, ##    000000                     000000 
            0x7F, 0x00, 0x00, 0x07, 0xE0, ##   0000000                     000000 
            0x7E, 0x00, 0x00, 0x07, 0xF0, ##   000000                      0000000
            0x7E, 0x00, 0x00, 0x07, 0xF0, ##   000000                      0000000
            0xFE, 0x00, 0x00, 0x03, 0xF0, ##  0000000                       000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '193' => {    # 'Á'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x0F, 0xC0, 0x00, ##                      000000          
            0x00, 0x00, 0x1F, 0x80, 0x00, ##                     000000           
            0x00, 0x00, 0x1F, 0x00, 0x00, ##                     00000            
            0x00, 0x00, 0x3E, 0x00, 0x00, ##                    00000             
            0x00, 0x00, 0x7C, 0x00, 0x00, ##                   00000              
            0x00, 0x00, 0xFC, 0x00, 0x00, ##                  000000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000               
            0x00, 0x01, 0xF0, 0x00, 0x00, ##                 00000                
            0x00, 0x03, 0xE0, 0x00, 0x00, ##                00000                 
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x0F, 0xDF, 0x00, 0x00, ##              000000 00000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000           
            0x00, 0x0F, 0x9F, 0x80, 0x00, ##              00000  000000           
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x8F, 0x80, 0x00, ##             000000   00000           
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000          
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x3F, 0x07, 0xC0, 0x00, ##            000000     00000          
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000         
            0x00, 0x3E, 0x07, 0xE0, 0x00, ##            00000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000        
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000        
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000       
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000      
            0x03, 0xF8, 0x00, 0xFC, 0x00, ##        0000000           000000      
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x03, 0xF0, 0x00, 0xFE, 0x00, ##        000000            0000000     
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000     
            0x07, 0xFF, 0xFF, 0xFE, 0x00, ##       00000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000    
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x00, ##      0000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x80, ##      00000000000000000000000000000   
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000   
            0x1F, 0xC0, 0x00, 0x1F, 0x80, ##     0000000                 000000   
            0x1F, 0x80, 0x00, 0x1F, 0x80, ##     000000                  000000   
            0x1F, 0x80, 0x00, 0x1F, 0xC0, ##     000000                  0000000  
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000  
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000  
            0x3F, 0x00, 0x00, 0x0F, 0xE0, ##    000000                    0000000 
            0x3F, 0x00, 0x00, 0x07, 0xE0, ##    000000                     000000 
            0x7F, 0x00, 0x00, 0x07, 0xE0, ##   0000000                     000000 
            0x7E, 0x00, 0x00, 0x07, 0xF0, ##   000000                      0000000
            0x7E, 0x00, 0x00, 0x07, 0xF0, ##   000000                      0000000
            0xFE, 0x00, 0x00, 0x03, 0xF0, ##  0000000                       000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '194' => {    # 'Â'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xFC, 0x00, 0x00, ##                 0000000              
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x0F, 0x9F, 0x00, 0x00, ##              00000  00000            
            0x00, 0x1F, 0x0F, 0x80, 0x00, ##             00000    00000           
            0x00, 0x1E, 0x07, 0xC0, 0x00, ##             0000      00000          
            0x00, 0x3C, 0x03, 0xE0, 0x00, ##            0000        00000         
            0x00, 0x7C, 0x01, 0xE0, 0x00, ##           00000         0000         
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000             
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000            
            0x00, 0x0F, 0xDF, 0x00, 0x00, ##              000000 00000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000           
            0x00, 0x0F, 0x9F, 0x80, 0x00, ##              00000  000000           
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x8F, 0x80, 0x00, ##             000000   00000           
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000          
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x3F, 0x07, 0xC0, 0x00, ##            000000     00000          
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000         
            0x00, 0x3E, 0x07, 0xE0, 0x00, ##            00000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000        
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000        
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000       
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000      
            0x03, 0xF8, 0x00, 0xFC, 0x00, ##        0000000           000000      
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x03, 0xF0, 0x00, 0xFE, 0x00, ##        000000            0000000     
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000     
            0x07, 0xFF, 0xFF, 0xFE, 0x00, ##       00000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000    
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x00, ##      0000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x80, ##      00000000000000000000000000000   
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000   
            0x1F, 0xC0, 0x00, 0x1F, 0x80, ##     0000000                 000000   
            0x1F, 0x80, 0x00, 0x1F, 0x80, ##     000000                  000000   
            0x1F, 0x80, 0x00, 0x1F, 0xC0, ##     000000                  0000000  
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000  
            0x3F, 0x80, 0x00, 0x0F, 0xC0, ##    0000000                   000000  
            0x3F, 0x00, 0x00, 0x0F, 0xE0, ##    000000                    0000000 
            0x3F, 0x00, 0x00, 0x07, 0xE0, ##    000000                     000000 
            0x7F, 0x00, 0x00, 0x07, 0xE0, ##   0000000                     000000 
            0x7E, 0x00, 0x00, 0x07, 0xF0, ##   000000                      0000000
            0x7E, 0x00, 0x00, 0x07, 0xF0, ##   000000                      0000000
            0xFE, 0x00, 0x00, 0x03, 0xF0, ##  0000000                       000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '195' => {    # 'Ã'
        'width'    => 37, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0x80, 0x78, 0x00, ##             000000        0000        
            0x00, 0x3F, 0xE0, 0x78, 0x00, ##            000000000      0000        
            0x00, 0x7F, 0xF8, 0xF8, 0x00, ##           000000000000   00000        
            0x00, 0xF8, 0xFF, 0xF0, 0x00, ##          00000   000000000000         
            0x00, 0xF0, 0x3F, 0xE0, 0x00, ##          0000      000000000          
            0x00, 0xF0, 0x0F, 0xC0, 0x00, ##          0000        000000           
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                       
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                       
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                       
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                       
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                       
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                       
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000              
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000              
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000              
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x07, 0xDF, 0x00, 0x00, ##               00000 00000             
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000            
            0x00, 0x1F, 0x8F, 0xC0, 0x00, ##             000000   000000           
            0x00, 0x1F, 0x8F, 0xC0, 0x00, ##             000000   000000           
            0x00, 0x1F, 0x8F, 0xC0, 0x00, ##             000000   000000           
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000          
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000          
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000          
            0x00, 0x7F, 0x07, 0xF0, 0x00, ##           0000000     0000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000         
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000        
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000        
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000        
            0x01, 0xFC, 0x01, 0xFC, 0x00, ##         0000000         0000000       
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000       
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000       
            0x03, 0xF8, 0x00, 0xFE, 0x00, ##        0000000           0000000      
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000      
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000      
            0x03, 0xF0, 0x00, 0x7F, 0x00, ##        000000             0000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000     
            0x0F, 0xFF, 0xFF, 0xFF, 0x80, ##      00000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x80, ##      00000000000000000000000000000    
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000    
            0x1F, 0xC0, 0x00, 0x1F, 0xC0, ##     0000000                 0000000   
            0x1F, 0x80, 0x00, 0x0F, 0xC0, ##     000000                   000000   
            0x1F, 0x80, 0x00, 0x0F, 0xC0, ##     000000                   000000   
            0x3F, 0x80, 0x00, 0x0F, 0xE0, ##    0000000                   0000000  
            0x3F, 0x80, 0x00, 0x0F, 0xE0, ##    0000000                   0000000  
            0x3F, 0x00, 0x00, 0x07, 0xE0, ##    000000                     000000  
            0x3F, 0x00, 0x00, 0x07, 0xE0, ##    000000                     000000  
            0x7F, 0x00, 0x00, 0x07, 0xF0, ##   0000000                     0000000 
            0x7E, 0x00, 0x00, 0x03, 0xF0, ##   000000                       000000 
            0x7E, 0x00, 0x00, 0x03, 0xF0, ##   000000                       000000 
            0xFE, 0x00, 0x00, 0x03, 0xF8, ##  0000000                       0000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '196' => {    # 'Ä'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x0F, 0xFF, 0x00, 0x00, ##              000000000000            
            0x00, 0x0F, 0xFF, 0x00, 0x00, ##              000000000000            
            0x00, 0x0F, 0x9F, 0x00, 0x00, ##              00000  00000            
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x0F, 0x80, 0x00, ##             00000    00000           
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x3E, 0x07, 0xC0, 0x00, ##            00000      00000          
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x07, 0xF0, 0x00, 0xFE, 0x00, ##       0000000            0000000     
            0x07, 0xFF, 0xFF, 0xFE, 0x00, ##       00000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFE, 0x00, ##       00000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFE, 0x00, ##       00000000000000000000000000     
            0x0F, 0xFF, 0xFF, 0xFF, 0x00, ##      0000000000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xFF, 0x00, ##      0000000000000000000000000000    
            0x0F, 0xC0, 0x00, 0x3F, 0x00, ##      000000                000000    
            0x1F, 0xC0, 0x00, 0x3F, 0x80, ##     0000000                0000000   
            0x1F, 0x80, 0x00, 0x1F, 0x80, ##     000000                  000000   
            0x1F, 0x80, 0x00, 0x1F, 0x80, ##     000000                  000000   
            0x3F, 0x80, 0x00, 0x1F, 0xC0, ##    0000000                  0000000  
            0x3F, 0x80, 0x00, 0x1F, 0xC0, ##    0000000                  0000000  
            0x3F, 0x00, 0x00, 0x0F, 0xC0, ##    000000                    000000  
            0x3F, 0x00, 0x00, 0x0F, 0xC0, ##    000000                    000000  
            0x7F, 0x00, 0x00, 0x0F, 0xE0, ##   0000000                    0000000 
            0x7E, 0x00, 0x00, 0x07, 0xE0, ##   000000                      000000 
            0x7E, 0x00, 0x00, 0x07, 0xE0, ##   000000                      000000 
            0xFE, 0x00, 0x00, 0x07, 0xF0, ##  0000000                      0000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '197' => {    # 'Å'
        'width'    => 37, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000                
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000              
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x0F, 0xFF, 0x80, 0x00, ##              0000000000000            
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000           
            0x00, 0x1E, 0x03, 0xC0, 0x00, ##             0000       0000           
            0x00, 0x3E, 0x03, 0xE0, 0x00, ##            00000       00000          
            0x00, 0x3C, 0x01, 0xE0, 0x00, ##            0000         0000          
            0x00, 0x3C, 0x01, 0xE0, 0x00, ##            0000         0000          
            0x00, 0x3C, 0x01, 0xE0, 0x00, ##            0000         0000          
            0x00, 0x3C, 0x01, 0xE0, 0x00, ##            0000         0000          
            0x00, 0x3E, 0x03, 0xE0, 0x00, ##            00000       00000          
            0x00, 0x1F, 0x07, 0xC0, 0x00, ##             00000     00000           
            0x00, 0x1F, 0xDF, 0xC0, 0x00, ##             0000000 0000000           
            0x00, 0x0F, 0xFF, 0x80, 0x00, ##              0000000000000            
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x03, 0xFE, 0x00, 0x00, ##                000000000              
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x07, 0xFF, 0x00, 0x00, ##               00000000000             
            0x00, 0x07, 0xDF, 0x00, 0x00, ##               00000 00000             
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000            
            0x00, 0x0F, 0xDF, 0x80, 0x00, ##              000000 000000            
            0x00, 0x0F, 0x8F, 0x80, 0x00, ##              00000   00000            
            0x00, 0x1F, 0x8F, 0xC0, 0x00, ##             000000   000000           
            0x00, 0x1F, 0x8F, 0xC0, 0x00, ##             000000   000000           
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000           
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000          
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000          
            0x00, 0x3F, 0x07, 0xE0, 0x00, ##            000000     000000          
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000         
            0x00, 0x7E, 0x03, 0xF0, 0x00, ##           000000       000000         
            0x00, 0xFE, 0x03, 0xF0, 0x00, ##          0000000       000000         
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000        
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000        
            0x00, 0xFC, 0x01, 0xF8, 0x00, ##          000000         000000        
            0x01, 0xF8, 0x01, 0xFC, 0x00, ##         000000          0000000       
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000       
            0x01, 0xF8, 0x00, 0xFC, 0x00, ##         000000           000000       
            0x03, 0xF8, 0x00, 0xFE, 0x00, ##        0000000           0000000      
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000      
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000      
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000     
            0x07, 0xFF, 0xFF, 0xFF, 0x00, ##       000000000000000000000000000     
            0x0F, 0xFF, 0xFF, 0xFF, 0x80, ##      00000000000000000000000000000    
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000    
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000    
            0x1F, 0xC0, 0x00, 0x1F, 0xC0, ##     0000000                 0000000   
            0x1F, 0x80, 0x00, 0x0F, 0xC0, ##     000000                   000000   
            0x1F, 0x80, 0x00, 0x0F, 0xC0, ##     000000                   000000   
            0x3F, 0x80, 0x00, 0x0F, 0xE0, ##    0000000                   0000000  
            0x3F, 0x80, 0x00, 0x0F, 0xE0, ##    0000000                   0000000  
            0x3F, 0x00, 0x00, 0x07, 0xE0, ##    000000                     000000  
            0x3F, 0x00, 0x00, 0x07, 0xE0, ##    000000                     000000  
            0x7F, 0x00, 0x00, 0x07, 0xF0, ##   0000000                     0000000 
            0x7E, 0x00, 0x00, 0x03, 0xF0, ##   000000                       000000 
            0x7E, 0x00, 0x00, 0x03, 0xF0, ##   000000                       000000 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '198' => {    # 'Æ'
        'width'    => 37, 
        'xoffset'  => 0, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0xFF, 0xFF, 0xF8, ##               000000000000000000000000
            0x00, 0x0F, 0xFF, 0xFF, 0xF8, ##              0000000000000000000000000
            0x00, 0x0F, 0xFF, 0xFF, 0xF8, ##              0000000000000000000000000
            0x00, 0x0F, 0xFF, 0xFF, 0xF8, ##              0000000000000000000000000
            0x00, 0x0F, 0xFF, 0xFF, 0xF8, ##              0000000000000000000000000
            0x00, 0x1F, 0x8F, 0xC0, 0x00, ##             000000   000000           
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000           
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000           
            0x00, 0x1F, 0x0F, 0xC0, 0x00, ##             00000    000000           
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000           
            0x00, 0x3E, 0x0F, 0xC0, 0x00, ##            00000     000000           
            0x00, 0x3E, 0x0F, 0xC0, 0x00, ##            00000     000000           
            0x00, 0x7E, 0x0F, 0xC0, 0x00, ##           000000     000000           
            0x00, 0x7E, 0x0F, 0xC0, 0x00, ##           000000     000000           
            0x00, 0x7C, 0x0F, 0xC0, 0x00, ##           00000      000000           
            0x00, 0x7C, 0x0F, 0xC0, 0x00, ##           00000      000000           
            0x00, 0xFC, 0x0F, 0xC0, 0x00, ##          000000      000000           
            0x00, 0xFC, 0x0F, 0xC0, 0x00, ##          000000      000000           
            0x00, 0xF8, 0x0F, 0xC0, 0x00, ##          00000       000000           
            0x00, 0xF8, 0x0F, 0xC0, 0x00, ##          00000       000000           
            0x01, 0xF8, 0x0F, 0xFF, 0xF0, ##         000000       0000000000000000 
            0x01, 0xF8, 0x0F, 0xFF, 0xF0, ##         000000       0000000000000000 
            0x01, 0xF0, 0x0F, 0xFF, 0xF0, ##         00000        0000000000000000 
            0x03, 0xF0, 0x0F, 0xFF, 0xF0, ##        000000        0000000000000000 
            0x03, 0xF0, 0x0F, 0xFF, 0xF0, ##        000000        0000000000000000 
            0x03, 0xE0, 0x0F, 0xC0, 0x00, ##        00000         000000           
            0x03, 0xE0, 0x0F, 0xC0, 0x00, ##        00000         000000           
            0x07, 0xE0, 0x0F, 0xC0, 0x00, ##       000000         000000           
            0x07, 0xE0, 0x0F, 0xC0, 0x00, ##       000000         000000           
            0x07, 0xC0, 0x0F, 0xC0, 0x00, ##       00000          000000           
            0x07, 0xFF, 0xFF, 0xC0, 0x00, ##       000000000000000000000           
            0x0F, 0xFF, 0xFF, 0xC0, 0x00, ##      0000000000000000000000           
            0x0F, 0xFF, 0xFF, 0xC0, 0x00, ##      0000000000000000000000           
            0x0F, 0xFF, 0xFF, 0xC0, 0x00, ##      0000000000000000000000           
            0x1F, 0xFF, 0xFF, 0xC0, 0x00, ##     00000000000000000000000           
            0x1F, 0x80, 0x0F, 0xC0, 0x00, ##     000000           000000           
            0x1F, 0x80, 0x0F, 0xC0, 0x00, ##     000000           000000           
            0x1F, 0x00, 0x0F, 0xC0, 0x00, ##     00000            000000           
            0x3F, 0x00, 0x0F, 0xC0, 0x00, ##    000000            000000           
            0x3F, 0x00, 0x0F, 0xC0, 0x00, ##    000000            000000           
            0x3F, 0x00, 0x0F, 0xC0, 0x00, ##    000000            000000           
            0x3E, 0x00, 0x0F, 0xC0, 0x00, ##    00000             000000           
            0x7E, 0x00, 0x0F, 0xFF, 0xF8, ##   000000             00000000000000000
            0x7E, 0x00, 0x0F, 0xFF, 0xF8, ##   000000             00000000000000000
            0x7E, 0x00, 0x0F, 0xFF, 0xF8, ##   000000             00000000000000000
            0xFC, 0x00, 0x0F, 0xFF, 0xF8, ##  000000              00000000000000000
            0xFC, 0x00, 0x0F, 0xFF, 0xF8, ##  000000              00000000000000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '199' => {    # 'Ç'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xFE, 0x00, ##                000000000      
            0x00, 0x1F, 0xFF, 0xE0, ##             0000000000000000  
            0x00, 0x7F, 0xFF, 0xF8, ##           00000000000000000000
            0x00, 0xFF, 0xFF, 0xF8, ##          000000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x03, 0xFE, 0x03, 0xF8, ##        000000000       0000000
            0x07, 0xF0, 0x00, 0x78, ##       0000000             0000
            0x0F, 0xE0, 0x00, 0x18, ##      0000000                00
            0x1F, 0xC0, 0x00, 0x08, ##     0000000                  0
            0x1F, 0x80, 0x00, 0x00, ##     000000                    
            0x3F, 0x80, 0x00, 0x00, ##    0000000                    
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x7E, 0x00, 0x00, 0x00, ##   000000                      
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x00, 0x00, 0x00, ##    000000                     
            0x3F, 0x80, 0x00, 0x00, ##    0000000                    
            0x1F, 0x80, 0x00, 0x00, ##     000000                    
            0x1F, 0xC0, 0x00, 0x08, ##     0000000                  0
            0x0F, 0xE0, 0x00, 0x18, ##      0000000                00
            0x07, 0xF0, 0x00, 0x78, ##       0000000             0000
            0x03, 0xFE, 0x03, 0xF8, ##        000000000       0000000
            0x03, 0xFF, 0xFF, 0xF8, ##        00000000000000000000000
            0x00, 0xFF, 0xFF, 0xF8, ##          000000000000000000000
            0x00, 0x7F, 0xFF, 0xF8, ##           00000000000000000000
            0x00, 0x1F, 0xFF, 0xE0, ##             0000000000000000  
            0x00, 0x03, 0xFE, 0x00, ##                000000000      
            0x00, 0x00, 0x3C, 0x00, ##                    0000       
            0x00, 0x00, 0x1C, 0x00, ##                     000       
            0x00, 0x00, 0x1E, 0x00, ##                     0000      
            0x00, 0x00, 0x0E, 0x00, ##                      000      
            0x00, 0x00, 0x0F, 0x00, ##                      0000     
            0x00, 0x00, 0x0F, 0x00, ##                      0000     
            0x00, 0x00, 0x0F, 0x00, ##                      0000     
            0x00, 0x10, 0x1F, 0x00, ##             0       00000     
            0x00, 0x1F, 0xFF, 0x00, ##             0000000000000     
            0x00, 0x1F, 0xFE, 0x00, ##             000000000000      
            0x00, 0x1F, 0xFC, 0x00, ##             00000000000       
            0x00, 0x0F, 0xF0, 0x00, ##              00000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '200' => {    # 'È'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x03, 0xF0, 0x00, 0x00, ##        000000                 
            0x01, 0xF8, 0x00, 0x00, ##         000000                
            0x00, 0xF8, 0x00, 0x00, ##          00000                
            0x00, 0x7C, 0x00, 0x00, ##           00000               
            0x00, 0x3E, 0x00, 0x00, ##            00000              
            0x00, 0x3F, 0x00, 0x00, ##            000000             
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x0F, 0x80, 0x00, ##              00000            
            0x00, 0x07, 0xC0, 0x00, ##               00000           
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '201' => {    # 'É'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x01, 0xF8, 0x00, ##                 000000        
            0x00, 0x01, 0xF0, 0x00, ##                 00000         
            0x00, 0x03, 0xE0, 0x00, ##                00000          
            0x00, 0x07, 0xE0, 0x00, ##               000000          
            0x00, 0x0F, 0xC0, 0x00, ##              000000           
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x00, 0x00, ##             00000             
            0x00, 0x3E, 0x00, 0x00, ##            00000              
            0x00, 0x7C, 0x00, 0x00, ##           00000               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '202' => {    # 'Ê'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x3F, 0x80, 0x00, ##            0000000            
            0x00, 0x7F, 0xC0, 0x00, ##           000000000           
            0x00, 0xFB, 0xE0, 0x00, ##          00000 00000          
            0x01, 0xF1, 0xF0, 0x00, ##         00000   00000         
            0x03, 0xE0, 0xF8, 0x00, ##        00000     00000        
            0x03, 0xC0, 0x7C, 0x00, ##        0000       00000       
            0x07, 0x80, 0x3E, 0x00, ##       0000         00000      
            0x0F, 0x00, 0x1E, 0x00, ##      0000           0000      
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '203' => {    # 'Ë'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFF, 0xFF, 0xFF, 0xF0, ##  0000000000000000000000000000 
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000  
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '204' => {    # 'Ì'
        'width'    => 26, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x03, 0xE0, 0x00, 0x00, ##        00000               
            0x01, 0xF0, 0x00, 0x00, ##         00000              
            0x01, 0xF8, 0x00, 0x00, ##         000000             
            0x00, 0xFC, 0x00, 0x00, ##          000000            
            0x00, 0x7C, 0x00, 0x00, ##           00000            
            0x00, 0x3E, 0x00, 0x00, ##            00000           
            0x00, 0x1F, 0x00, 0x00, ##             00000          
            0x00, 0x0F, 0x80, 0x00, ##              00000         
            0x00, 0x07, 0x80, 0x00, ##               0000         
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '205' => {    # 'Í'
        'width'    => 26, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x01, 0xF8, 0x00, ##                 000000     
            0x00, 0x03, 0xF0, 0x00, ##                000000      
            0x00, 0x07, 0xE0, 0x00, ##               000000       
            0x00, 0x0F, 0xC0, 0x00, ##              000000        
            0x00, 0x0F, 0x80, 0x00, ##              00000         
            0x00, 0x1F, 0x00, 0x00, ##             00000          
            0x00, 0x3E, 0x00, 0x00, ##            00000           
            0x00, 0x7C, 0x00, 0x00, ##           00000            
            0x00, 0x78, 0x00, 0x00, ##           0000             
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '206' => {    # 'Î'
        'width'    => 26, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x7F, 0x80, 0x00, ##           00000000         
            0x00, 0x7F, 0xC0, 0x00, ##           000000000        
            0x00, 0xFF, 0xC0, 0x00, ##          0000000000        
            0x01, 0xF3, 0xE0, 0x00, ##         00000  00000       
            0x03, 0xE1, 0xF0, 0x00, ##        00000    00000      
            0x07, 0xC0, 0xF8, 0x00, ##       00000      00000     
            0x0F, 0x80, 0x7C, 0x00, ##      00000        00000    
            0x0F, 0x00, 0x3E, 0x00, ##      0000          00000   
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '207' => {    # 'Ï'
        'width'    => 26, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000    
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000    
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000    
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000    
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000    
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000    
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0x00, 0x00, 0x00, 0x00, ##                            
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0x00, 0x3F, 0x00, 0x00, ##            000000          
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '208' => {    # 'Ð'
        'width'    => 34, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x0F, 0xFF, 0xE0, 0x00, 0x00, ##      000000000000000               
            0x0F, 0xFF, 0xFE, 0x00, 0x00, ##      0000000000000000000           
            0x0F, 0xFF, 0xFF, 0x80, 0x00, ##      000000000000000000000         
            0x0F, 0xFF, 0xFF, 0xC0, 0x00, ##      0000000000000000000000        
            0x0F, 0xFF, 0xFF, 0xF0, 0x00, ##      000000000000000000000000      
            0x0F, 0xC0, 0x3F, 0xF8, 0x00, ##      000000        00000000000     
            0x0F, 0xC0, 0x07, 0xFC, 0x00, ##      000000           000000000    
            0x0F, 0xC0, 0x01, 0xFC, 0x00, ##      000000             0000000    
            0x0F, 0xC0, 0x00, 0xFE, 0x00, ##      000000              0000000   
            0x0F, 0xC0, 0x00, 0x7E, 0x00, ##      000000               000000   
            0x0F, 0xC0, 0x00, 0x3F, 0x00, ##      000000                000000  
            0x0F, 0xC0, 0x00, 0x3F, 0x00, ##      000000                000000  
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x0F, 0xC0, ##      000000                  000000
            0x0F, 0xC0, 0x00, 0x0F, 0xC0, ##      000000                  000000
            0x0F, 0xC0, 0x00, 0x0F, 0xC0, ##      000000                  000000
            0xFF, 0xFF, 0xE0, 0x0F, 0xC0, ##  0000000000000000000         000000
            0xFF, 0xFF, 0xE0, 0x0F, 0xC0, ##  0000000000000000000         000000
            0xFF, 0xFF, 0xE0, 0x0F, 0xC0, ##  0000000000000000000         000000
            0xFF, 0xFF, 0xE0, 0x0F, 0xC0, ##  0000000000000000000         000000
            0xFF, 0xFF, 0xE0, 0x0F, 0xC0, ##  0000000000000000000         000000
            0x0F, 0xC0, 0x00, 0x0F, 0xC0, ##      000000                  000000
            0x0F, 0xC0, 0x00, 0x0F, 0xC0, ##      000000                  000000
            0x0F, 0xC0, 0x00, 0x0F, 0xC0, ##      000000                  000000
            0x0F, 0xC0, 0x00, 0x0F, 0xC0, ##      000000                  000000
            0x0F, 0xC0, 0x00, 0x0F, 0xC0, ##      000000                  000000
            0x0F, 0xC0, 0x00, 0x0F, 0x80, ##      000000                  00000 
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x1F, 0x80, ##      000000                 000000 
            0x0F, 0xC0, 0x00, 0x3F, 0x00, ##      000000                000000  
            0x0F, 0xC0, 0x00, 0x3F, 0x00, ##      000000                000000  
            0x0F, 0xC0, 0x00, 0x7E, 0x00, ##      000000               000000   
            0x0F, 0xC0, 0x00, 0xFE, 0x00, ##      000000              0000000   
            0x0F, 0xC0, 0x01, 0xFC, 0x00, ##      000000             0000000    
            0x0F, 0xC0, 0x07, 0xFC, 0x00, ##      000000           000000000    
            0x0F, 0xC0, 0x3F, 0xF8, 0x00, ##      000000        00000000000     
            0x0F, 0xFF, 0xFF, 0xF0, 0x00, ##      000000000000000000000000      
            0x0F, 0xFF, 0xFF, 0xE0, 0x00, ##      00000000000000000000000       
            0x0F, 0xFF, 0xFF, 0x80, 0x00, ##      000000000000000000000         
            0x0F, 0xFF, 0xFE, 0x00, 0x00, ##      0000000000000000000           
            0x0F, 0xFF, 0xE0, 0x00, 0x00, ##      000000000000000               
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '209' => {    # 'Ñ'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x01, 0xF8, 0x07, 0x80, ##         000000        0000     
            0x03, 0xFE, 0x07, 0x80, ##        000000000      0000     
            0x07, 0xFF, 0x8F, 0x80, ##       000000000000   00000     
            0x0F, 0x8F, 0xFF, 0x00, ##      00000   000000000000      
            0x0F, 0x03, 0xFE, 0x00, ##      0000      000000000       
            0x0F, 0x00, 0xFC, 0x00, ##      0000        000000        
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0xFF, 0x00, 0x00, 0xFC, ##  00000000                000000
            0xFF, 0x80, 0x00, 0xFC, ##  000000000               000000
            0xFF, 0x80, 0x00, 0xFC, ##  000000000               000000
            0xFF, 0x80, 0x00, 0xFC, ##  000000000               000000
            0xFF, 0xC0, 0x00, 0xFC, ##  0000000000              000000
            0xFF, 0xC0, 0x00, 0xFC, ##  0000000000              000000
            0xFF, 0xE0, 0x00, 0xFC, ##  00000000000             000000
            0xFF, 0xE0, 0x00, 0xFC, ##  00000000000             000000
            0xFF, 0xF0, 0x00, 0xFC, ##  000000000000            000000
            0xFF, 0xF0, 0x00, 0xFC, ##  000000000000            000000
            0xFD, 0xF0, 0x00, 0xFC, ##  000000 00000            000000
            0xFD, 0xF8, 0x00, 0xFC, ##  000000 000000           000000
            0xFC, 0xF8, 0x00, 0xFC, ##  000000  00000           000000
            0xFC, 0xFC, 0x00, 0xFC, ##  000000  000000          000000
            0xFC, 0x7C, 0x00, 0xFC, ##  000000   00000          000000
            0xFC, 0x7C, 0x00, 0xFC, ##  000000   00000          000000
            0xFC, 0x7E, 0x00, 0xFC, ##  000000   000000         000000
            0xFC, 0x3E, 0x00, 0xFC, ##  000000    00000         000000
            0xFC, 0x3F, 0x00, 0xFC, ##  000000    000000        000000
            0xFC, 0x1F, 0x00, 0xFC, ##  000000     00000        000000
            0xFC, 0x1F, 0x00, 0xFC, ##  000000     00000        000000
            0xFC, 0x1F, 0x80, 0xFC, ##  000000     000000       000000
            0xFC, 0x0F, 0x80, 0xFC, ##  000000      00000       000000
            0xFC, 0x0F, 0xC0, 0xFC, ##  000000      000000      000000
            0xFC, 0x07, 0xC0, 0xFC, ##  000000       00000      000000
            0xFC, 0x07, 0xE0, 0xFC, ##  000000       000000     000000
            0xFC, 0x03, 0xE0, 0xFC, ##  000000        00000     000000
            0xFC, 0x03, 0xE0, 0xFC, ##  000000        00000     000000
            0xFC, 0x03, 0xF0, 0xFC, ##  000000        000000    000000
            0xFC, 0x01, 0xF0, 0xFC, ##  000000         00000    000000
            0xFC, 0x01, 0xF8, 0xFC, ##  000000         000000   000000
            0xFC, 0x00, 0xF8, 0xFC, ##  000000          00000   000000
            0xFC, 0x00, 0xF8, 0xFC, ##  000000          00000   000000
            0xFC, 0x00, 0xFC, 0xFC, ##  000000          000000  000000
            0xFC, 0x00, 0x7C, 0xFC, ##  000000           00000  000000
            0xFC, 0x00, 0x7E, 0xFC, ##  000000           000000 000000
            0xFC, 0x00, 0x3E, 0xFC, ##  000000            00000 000000
            0xFC, 0x00, 0x3F, 0xFC, ##  000000            000000000000
            0xFC, 0x00, 0x1F, 0xFC, ##  000000             00000000000
            0xFC, 0x00, 0x1F, 0xFC, ##  000000             00000000000
            0xFC, 0x00, 0x1F, 0xFC, ##  000000             00000000000
            0xFC, 0x00, 0x0F, 0xFC, ##  000000              0000000000
            0xFC, 0x00, 0x0F, 0xFC, ##  000000              0000000000
            0xFC, 0x00, 0x07, 0xFC, ##  000000               000000000
            0xFC, 0x00, 0x07, 0xFC, ##  000000               000000000
            0xFC, 0x00, 0x07, 0xFC, ##  000000               000000000
            0xFC, 0x00, 0x03, 0xFC, ##  000000                00000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '210' => {    # 'Ò'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0xFC, 0x00, 0x00, ##          000000                 
            0x00, 0xFC, 0x00, 0x00, ##          000000                 
            0x00, 0x7E, 0x00, 0x00, ##           000000                
            0x00, 0x3F, 0x00, 0x00, ##            000000               
            0x00, 0x1F, 0x80, 0x00, ##             000000              
            0x00, 0x0F, 0x80, 0x00, ##              00000              
            0x00, 0x07, 0xC0, 0x00, ##               00000             
            0x00, 0x03, 0xE0, 0x00, ##                00000            
            0x00, 0x01, 0xF0, 0x00, ##                 00000           
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x0F, 0xF8, 0x3F, 0xE0, ##      000000000     000000000    
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000   
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x7E, 0x00, 0x00, 0xF8, ##   000000                 00000  
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0xFC, 0x00, 0x00, 0x7C, ##  000000                   00000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x80, 0x03, 0xF0, ##    0000000             000000   
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x0F, 0xF0, 0x1F, 0xE0, ##      00000000       00000000    
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '211' => {    # 'Ó'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x7E, 0x00, ##                   000000        
            0x00, 0x00, 0x7E, 0x00, ##                   000000        
            0x00, 0x00, 0xFC, 0x00, ##                  000000         
            0x00, 0x01, 0xF8, 0x00, ##                 000000          
            0x00, 0x03, 0xF0, 0x00, ##                000000           
            0x00, 0x07, 0xE0, 0x00, ##               000000            
            0x00, 0x07, 0xC0, 0x00, ##               00000             
            0x00, 0x0F, 0x80, 0x00, ##              00000              
            0x00, 0x1F, 0x00, 0x00, ##             00000               
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x0F, 0xF8, 0x3F, 0xE0, ##      000000000     000000000    
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000   
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x7E, 0x00, 0x00, 0xF8, ##   000000                 00000  
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0xFC, 0x00, 0x00, 0x7C, ##  000000                   00000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x80, 0x03, 0xF0, ##    0000000             000000   
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x0F, 0xF0, 0x1F, 0xE0, ##      00000000       00000000    
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '212' => {    # 'Ô'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x0F, 0xE0, 0x00, ##              0000000            
            0x00, 0x0F, 0xE0, 0x00, ##              0000000            
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x3E, 0xF8, 0x00, ##            00000 00000          
            0x00, 0x7C, 0x7C, 0x00, ##           00000   00000         
            0x00, 0xF8, 0x3E, 0x00, ##          00000     00000        
            0x00, 0xF0, 0x1E, 0x00, ##          0000       0000        
            0x01, 0xF0, 0x0F, 0x00, ##         00000        0000       
            0x03, 0xE0, 0x0F, 0x80, ##        00000         00000      
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x0F, 0xF8, 0x3F, 0xE0, ##      000000000     000000000    
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000   
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x7E, 0x00, 0x00, 0xF8, ##   000000                 00000  
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0xFC, 0x00, 0x00, 0x7C, ##  000000                   00000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x80, 0x03, 0xF0, ##    0000000             000000   
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x0F, 0xF0, 0x1F, 0xE0, ##      00000000       00000000    
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '213' => {    # 'Õ'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0xFC, 0x03, 0xC0, ##          000000        0000     
            0x01, 0xFF, 0x03, 0xC0, ##         000000000      0000     
            0x03, 0xFF, 0xC7, 0xC0, ##        000000000000   00000     
            0x07, 0xC7, 0xFF, 0x80, ##       00000   000000000000      
            0x07, 0x81, 0xFF, 0x00, ##       0000      000000000       
            0x07, 0x80, 0x7E, 0x00, ##       0000        000000        
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x0F, 0xF8, 0x3F, 0xE0, ##      000000000     000000000    
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000   
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x7E, 0x00, 0x00, 0xF8, ##   000000                 00000  
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0xFC, 0x00, 0x00, 0x7C, ##  000000                   00000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x80, 0x03, 0xF0, ##    0000000             000000   
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x0F, 0xF0, 0x1F, 0xE0, ##      00000000       00000000    
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '214' => {    # 'Ö'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x03, 0xF0, 0x1F, 0x80, ##        000000       000000      
            0x03, 0xF0, 0x1F, 0x80, ##        000000       000000      
            0x03, 0xF0, 0x1F, 0x80, ##        000000       000000      
            0x03, 0xF0, 0x1F, 0x80, ##        000000       000000      
            0x03, 0xF0, 0x1F, 0x80, ##        000000       000000      
            0x03, 0xF0, 0x1F, 0x80, ##        000000       000000      
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x0F, 0xF8, 0x3F, 0xE0, ##      000000000     000000000    
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000   
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x7E, 0x00, 0x00, 0xF8, ##   000000                 00000  
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0xFC, 0x00, 0x00, 0x7C, ##  000000                   00000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000  
            0x3F, 0x80, 0x03, 0xF0, ##    0000000             000000   
            0x1F, 0xC0, 0x07, 0xF0, ##     0000000           0000000   
            0x0F, 0xE0, 0x0F, 0xE0, ##      0000000         0000000    
            0x0F, 0xF0, 0x1F, 0xE0, ##      00000000       00000000    
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000     
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000      
            0x01, 0xFF, 0xFF, 0x00, ##         00000000000000000       
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000         
            0x00, 0x1F, 0xF0, 0x00, ##             000000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '215' => {    # '×'
        'width'    => 29, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x10, 0x00, 0x00, 0x40, ##     0                     0   
            0x38, 0x00, 0x00, 0xC0, ##    000                   00   
            0x7C, 0x00, 0x01, 0xE0, ##   00000                 0000  
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFF, 0x00, 0x07, 0xF0, ##  00000000             0000000 
            0x7F, 0x80, 0x0F, 0xE0, ##   00000000           0000000  
            0x3F, 0xC0, 0x1F, 0xC0, ##    00000000         0000000   
            0x1F, 0xE0, 0x3F, 0x80, ##     00000000       0000000    
            0x0F, 0xF0, 0x7F, 0x00, ##      00000000     0000000     
            0x07, 0xF8, 0xFE, 0x00, ##       00000000   0000000      
            0x03, 0xFD, 0xFC, 0x00, ##        00000000 0000000       
            0x01, 0xFF, 0xF8, 0x00, ##         00000000000000        
            0x00, 0xFF, 0xF0, 0x00, ##          000000000000         
            0x00, 0x7F, 0xE0, 0x00, ##           0000000000          
            0x00, 0x3F, 0xC0, 0x00, ##            00000000           
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x00, 0x7F, 0xF0, 0x00, ##           00000000000         
            0x00, 0xFF, 0xF8, 0x00, ##          0000000000000        
            0x01, 0xFF, 0xFC, 0x00, ##         000000000000000       
            0x03, 0xF9, 0xFE, 0x00, ##        0000000  00000000      
            0x07, 0xF0, 0xFF, 0x00, ##       0000000    00000000     
            0x0F, 0xE0, 0x7F, 0x80, ##      0000000      00000000    
            0x1F, 0xC0, 0x3F, 0xC0, ##     0000000        00000000   
            0x3F, 0x80, 0x1F, 0xC0, ##    0000000          0000000   
            0x7F, 0x00, 0x0F, 0xE0, ##   0000000            0000000  
            0xFE, 0x00, 0x07, 0xF8, ##  0000000              00000000
            0xFC, 0x00, 0x03, 0xF0, ##  000000                000000 
            0x78, 0x00, 0x01, 0xE0, ##   0000                  0000  
            0x30, 0x00, 0x00, 0xC0, ##    00                    00   
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '216' => {    # 'Ø'
        'width'    => 37, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x60, ##                                   00  
            0x00, 0x01, 0xFE, 0x00, 0xF0, ##                 00000000         0000 
            0x00, 0x0F, 0xFF, 0xC0, 0xF0, ##              00000000000000      0000 
            0x00, 0x3F, 0xFF, 0xE1, 0xF0, ##            00000000000000000    00000 
            0x00, 0x7F, 0xFF, 0xF3, 0xE0, ##           0000000000000000000  00000  
            0x00, 0xFF, 0xFF, 0xFB, 0xC0, ##          000000000000000000000 0000   
            0x01, 0xFE, 0x07, 0xFF, 0xC0, ##         00000000      0000000000000   
            0x01, 0xFC, 0x01, 0xFF, 0x80, ##         0000000         0000000000    
            0x03, 0xF8, 0x00, 0xFF, 0x00, ##        0000000           00000000     
            0x03, 0xF0, 0x00, 0x7E, 0x00, ##        000000             000000      
            0x07, 0xE0, 0x00, 0x3F, 0x00, ##       000000               000000     
            0x07, 0xE0, 0x00, 0x3F, 0x00, ##       000000               000000     
            0x07, 0xC0, 0x00, 0x7F, 0x00, ##       00000               0000000     
            0x0F, 0xC0, 0x00, 0xFF, 0x80, ##      000000              000000000    
            0x0F, 0xC0, 0x00, 0xFF, 0x80, ##      000000              000000000    
            0x0F, 0xC0, 0x01, 0xFF, 0x80, ##      000000             0000000000    
            0x0F, 0xC0, 0x03, 0xFF, 0x80, ##      000000            00000000000    
            0x1F, 0x80, 0x07, 0xCF, 0x80, ##     000000            00000  00000    
            0x1F, 0x80, 0x07, 0xCF, 0xC0, ##     000000            00000  000000   
            0x1F, 0x80, 0x0F, 0x8F, 0xC0, ##     000000           00000   000000   
            0x1F, 0x80, 0x1F, 0x0F, 0xC0, ##     000000          00000    000000   
            0x1F, 0x80, 0x3F, 0x0F, 0xC0, ##     000000         000000    000000   
            0x1F, 0x80, 0x3E, 0x0F, 0xC0, ##     000000         00000     000000   
            0x1F, 0x80, 0x7C, 0x0F, 0xC0, ##     000000        00000      000000   
            0x1F, 0x80, 0xFC, 0x0F, 0xC0, ##     000000       000000      000000   
            0x1F, 0x81, 0xF8, 0x0F, 0xC0, ##     000000      000000       000000   
            0x1F, 0x81, 0xF0, 0x0F, 0xC0, ##     000000      00000        000000   
            0x1F, 0x83, 0xF0, 0x0F, 0xC0, ##     000000     000000        000000   
            0x1F, 0x87, 0xE0, 0x0F, 0xC0, ##     000000    000000         000000   
            0x1F, 0x8F, 0xC0, 0x0F, 0xC0, ##     000000   000000          000000   
            0x1F, 0x8F, 0xC0, 0x0F, 0xC0, ##     000000   000000          000000   
            0x1F, 0x9F, 0x80, 0x0F, 0xC0, ##     000000  000000           000000   
            0x1F, 0xBF, 0x00, 0x0F, 0xC0, ##     000000 000000            000000   
            0x1F, 0xFF, 0x00, 0x0F, 0x80, ##     0000000000000            00000    
            0x1F, 0xFE, 0x00, 0x1F, 0x80, ##     000000000000            000000    
            0x0F, 0xFC, 0x00, 0x1F, 0x80, ##      0000000000             000000    
            0x0F, 0xF8, 0x00, 0x1F, 0x80, ##      000000000              000000    
            0x0F, 0xF8, 0x00, 0x1F, 0x80, ##      000000000              000000    
            0x0F, 0xF0, 0x00, 0x1F, 0x00, ##      00000000               00000     
            0x0F, 0xE0, 0x00, 0x3F, 0x00, ##      0000000               000000     
            0x07, 0xF0, 0x00, 0x3F, 0x00, ##       0000000              000000     
            0x07, 0xF0, 0x00, 0x7E, 0x00, ##       0000000             000000      
            0x0F, 0xF8, 0x00, 0x7E, 0x00, ##      000000000            000000      
            0x1F, 0xFC, 0x00, 0xFC, 0x00, ##     00000000000          000000       
            0x1F, 0xFF, 0x03, 0xFC, 0x00, ##     0000000000000      00000000       
            0x3F, 0xFF, 0xFF, 0xF8, 0x00, ##    000000000000000000000000000        
            0x7C, 0xFF, 0xFF, 0xF0, 0x00, ##   00000  00000000000000000000         
            0x78, 0x7F, 0xFF, 0xE0, 0x00, ##   0000    000000000000000000          
            0xF8, 0x1F, 0xFF, 0x80, 0x00, ##  00000      00000000000000            
            0xF0, 0x03, 0xFC, 0x00, 0x00, ##  0000          00000000               
            0x20, 0x00, 0x00, 0x00, 0x00, ##    0                                  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '217' => {    # 'Ù'
        'width'    => 29, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x01, 0xF8, 0x00, 0x00, ##         000000                
            0x00, 0xF8, 0x00, 0x00, ##          00000                
            0x00, 0x7C, 0x00, 0x00, ##           00000               
            0x00, 0x7E, 0x00, 0x00, ##           000000              
            0x00, 0x3F, 0x00, 0x00, ##            000000             
            0x00, 0x1F, 0x00, 0x00, ##             00000             
            0x00, 0x0F, 0x80, 0x00, ##              00000            
            0x00, 0x07, 0xC0, 0x00, ##               00000           
            0x00, 0x03, 0xE0, 0x00, ##                00000          
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0x7C, 0x00, 0x01, 0xF8, ##   00000                 000000
            0x7C, 0x00, 0x03, 0xF0, ##   00000                000000 
            0x7E, 0x00, 0x03, 0xF0, ##   000000               000000 
            0x7F, 0x00, 0x07, 0xF0, ##   0000000             0000000 
            0x3F, 0x80, 0x0F, 0xE0, ##    0000000           0000000  
            0x3F, 0xE0, 0x3F, 0xE0, ##    000000000       000000000  
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x0F, 0xFF, 0xFF, 0x80, ##      000000000000000000000    
            0x07, 0xFF, 0xFF, 0x00, ##       0000000000000000000     
            0x01, 0xFF, 0xFC, 0x00, ##         000000000000000       
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '218' => {    # 'Ú'
        'width'    => 29, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0xFC, 0x00, ##                  000000       
            0x00, 0x00, 0xF8, 0x00, ##                  00000        
            0x00, 0x01, 0xF8, 0x00, ##                 000000        
            0x00, 0x03, 0xF0, 0x00, ##                000000         
            0x00, 0x07, 0xE0, 0x00, ##               000000          
            0x00, 0x07, 0xC0, 0x00, ##               00000           
            0x00, 0x0F, 0x80, 0x00, ##              00000            
            0x00, 0x1F, 0x00, 0x00, ##             00000             
            0x00, 0x3E, 0x00, 0x00, ##            00000              
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0x7C, 0x00, 0x01, 0xF8, ##   00000                 000000
            0x7C, 0x00, 0x03, 0xF0, ##   00000                000000 
            0x7E, 0x00, 0x03, 0xF0, ##   000000               000000 
            0x7F, 0x00, 0x07, 0xF0, ##   0000000             0000000 
            0x3F, 0x80, 0x0F, 0xE0, ##    0000000           0000000  
            0x3F, 0xE0, 0x3F, 0xE0, ##    000000000       000000000  
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x0F, 0xFF, 0xFF, 0x80, ##      000000000000000000000    
            0x07, 0xFF, 0xFF, 0x00, ##       0000000000000000000     
            0x01, 0xFF, 0xFC, 0x00, ##         000000000000000       
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '219' => {    # 'Û'
        'width'    => 29, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x1F, 0xC0, 0x00, ##             0000000           
            0x00, 0x1F, 0xC0, 0x00, ##             0000000           
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x00, 0x7D, 0xF0, 0x00, ##           00000 00000         
            0x00, 0xF8, 0xF8, 0x00, ##          00000   00000        
            0x00, 0xF0, 0x78, 0x00, ##          0000     0000        
            0x01, 0xF0, 0x7C, 0x00, ##         00000     00000       
            0x03, 0xE0, 0x3E, 0x00, ##        00000       00000      
            0x07, 0xC0, 0x1F, 0x00, ##       00000         00000     
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0x7C, 0x00, 0x01, 0xF8, ##   00000                 000000
            0x7C, 0x00, 0x03, 0xF0, ##   00000                000000 
            0x7E, 0x00, 0x03, 0xF0, ##   000000               000000 
            0x7F, 0x00, 0x07, 0xF0, ##   0000000             0000000 
            0x3F, 0x80, 0x0F, 0xE0, ##    0000000           0000000  
            0x3F, 0xE0, 0x3F, 0xE0, ##    000000000       000000000  
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x0F, 0xFF, 0xFF, 0x80, ##      000000000000000000000    
            0x07, 0xFF, 0xFF, 0x00, ##       0000000000000000000     
            0x01, 0xFF, 0xFC, 0x00, ##         000000000000000       
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '220' => {    # 'Ü'
        'width'    => 29, 
        'xoffset'  => 5, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0x7C, 0x00, 0x03, 0xF0, ##   00000                000000 
            0x7E, 0x00, 0x03, 0xF0, ##   000000               000000 
            0x7F, 0x00, 0x07, 0xF0, ##   0000000             0000000 
            0x3F, 0x80, 0x0F, 0xE0, ##    0000000           0000000  
            0x3F, 0xE0, 0x3F, 0xE0, ##    000000000       000000000  
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x0F, 0xFF, 0xFF, 0x80, ##      000000000000000000000    
            0x07, 0xFF, 0xFF, 0x00, ##       0000000000000000000     
            0x01, 0xFF, 0xFC, 0x00, ##         000000000000000       
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '221' => {    # 'Ý'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x0F, 0x80, 0x00, ##                      00000           
            0x00, 0x00, 0x1F, 0x80, 0x00, ##                     000000           
            0x00, 0x00, 0x3F, 0x00, 0x00, ##                    000000            
            0x00, 0x00, 0x7E, 0x00, 0x00, ##                   000000             
            0x00, 0x00, 0x7C, 0x00, 0x00, ##                   00000              
            0x00, 0x00, 0xF8, 0x00, 0x00, ##                  00000               
            0x00, 0x01, 0xF0, 0x00, 0x00, ##                 00000                
            0x00, 0x01, 0xE0, 0x00, 0x00, ##                 0000                 
            0x00, 0x03, 0xC0, 0x00, 0x00, ##                0000                  
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                      
            0xFE, 0x00, 0x00, 0x07, 0xF0, ##  0000000                      0000000
            0x7F, 0x00, 0x00, 0x0F, 0xE0, ##   0000000                    0000000 
            0x3F, 0x00, 0x00, 0x0F, 0xE0, ##    000000                    0000000 
            0x3F, 0x80, 0x00, 0x1F, 0xC0, ##    0000000                  0000000  
            0x1F, 0x80, 0x00, 0x1F, 0x80, ##     000000                  000000   
            0x1F, 0xC0, 0x00, 0x3F, 0x80, ##     0000000                0000000   
            0x0F, 0xC0, 0x00, 0x3F, 0x00, ##      000000                000000    
            0x0F, 0xE0, 0x00, 0x7F, 0x00, ##      0000000              0000000    
            0x07, 0xE0, 0x00, 0x7E, 0x00, ##       000000              000000     
            0x03, 0xF0, 0x00, 0xFE, 0x00, ##        000000            0000000     
            0x03, 0xF0, 0x00, 0xFC, 0x00, ##        000000            000000      
            0x01, 0xF8, 0x01, 0xF8, 0x00, ##         000000          000000       
            0x01, 0xFC, 0x03, 0xF8, 0x00, ##         0000000        0000000       
            0x00, 0xFC, 0x03, 0xF0, 0x00, ##          000000        000000        
            0x00, 0xFE, 0x07, 0xF0, 0x00, ##          0000000      0000000        
            0x00, 0x7E, 0x07, 0xE0, 0x00, ##           000000      000000         
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x3F, 0x0F, 0xC0, 0x00, ##            000000    000000          
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x1F, 0x9F, 0x80, 0x00, ##             000000  000000           
            0x00, 0x0F, 0xFF, 0x00, 0x00, ##              000000000000            
            0x00, 0x0F, 0xFF, 0x00, 0x00, ##              000000000000            
            0x00, 0x07, 0xFE, 0x00, 0x00, ##               0000000000             
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x03, 0xFC, 0x00, 0x00, ##                00000000              
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x01, 0xF8, 0x00, 0x00, ##                 000000               
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '222' => {    # 'Þ'
        'width'    => 30, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFF, 0xFF, 0xF0, 0x00, ##  00000000000000000000          
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000       
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000     
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000    
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000   
            0xFC, 0x00, 0x3F, 0xF0, ##  000000            0000000000  
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000 
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000 
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000 
            0xFC, 0x00, 0x3F, 0xF0, ##  000000            0000000000  
            0xFF, 0xFF, 0xFF, 0xE0, ##  000000000000000000000000000   
            0xFF, 0xFF, 0xFF, 0xC0, ##  00000000000000000000000000    
            0xFF, 0xFF, 0xFF, 0x80, ##  0000000000000000000000000     
            0xFF, 0xFF, 0xFE, 0x00, ##  00000000000000000000000       
            0xFF, 0xFF, 0xF0, 0x00, ##  00000000000000000000          
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0xFC, 0x00, 0x00, 0x00, ##  000000                        
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '223' => {    # 'ß'
        'width'    => 30, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x7F, 0x80, 0x00, ##           00000000             
            0x03, 0xFF, 0xF0, 0x00, ##        00000000000000          
            0x0F, 0xFF, 0xFC, 0x00, ##      000000000000000000        
            0x1F, 0xFF, 0xFE, 0x00, ##     00000000000000000000       
            0x3F, 0xFF, 0xFF, 0x00, ##    0000000000000000000000      
            0x3F, 0xC0, 0xFF, 0x00, ##    00000000      00000000      
            0x7F, 0x00, 0x3F, 0x80, ##   0000000          0000000     
            0x7E, 0x00, 0x1F, 0x80, ##   000000            000000     
            0xFE, 0x00, 0x1F, 0x80, ##  0000000            000000     
            0xFC, 0x00, 0x0F, 0xC0, ##  000000              000000    
            0xFC, 0x00, 0x0F, 0xC0, ##  000000              000000    
            0xFC, 0x00, 0x0F, 0xC0, ##  000000              000000    
            0xFC, 0x00, 0x3F, 0xC0, ##  000000            00000000    
            0xFC, 0x01, 0xFF, 0xC0, ##  000000         00000000000    
            0xFC, 0x03, 0xFC, 0x00, ##  000000        00000000        
            0xFC, 0x07, 0xF0, 0x00, ##  000000       0000000          
            0xFC, 0x0F, 0xC0, 0x00, ##  000000      000000            
            0xFC, 0x1F, 0x80, 0x00, ##  000000     000000             
            0xFC, 0x1F, 0x80, 0x00, ##  000000     000000             
            0xFC, 0x3F, 0x00, 0x00, ##  000000    000000              
            0xFC, 0x3F, 0x00, 0x00, ##  000000    000000              
            0xFC, 0x3F, 0x00, 0x00, ##  000000    000000              
            0xFC, 0x3F, 0x00, 0x00, ##  000000    000000              
            0xFC, 0x3F, 0x00, 0x00, ##  000000    000000              
            0xFC, 0x3F, 0x80, 0x00, ##  000000    0000000             
            0xFC, 0x1F, 0xC0, 0x00, ##  000000     0000000            
            0xFC, 0x1F, 0xF0, 0x00, ##  000000     000000000          
            0xFC, 0x0F, 0xF8, 0x00, ##  000000      000000000         
            0xFC, 0x07, 0xFE, 0x00, ##  000000       0000000000       
            0xFC, 0x03, 0xFF, 0x00, ##  000000        0000000000      
            0xFC, 0x00, 0xFF, 0xC0, ##  000000          0000000000    
            0xFC, 0x00, 0x7F, 0xE0, ##  000000           0000000000   
            0xFC, 0x00, 0x1F, 0xF0, ##  000000             000000000  
            0xFC, 0x00, 0x0F, 0xF0, ##  000000              00000000  
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000 
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x01, 0xFC, ##  000000                 0000000
            0xFC, 0x80, 0x03, 0xF8, ##  000000  0             0000000 
            0xFC, 0xF8, 0x0F, 0xF8, ##  000000  00000       000000000 
            0xFC, 0xFF, 0xFF, 0xF0, ##  000000  00000000000000000000  
            0xFC, 0xFF, 0xFF, 0xE0, ##  000000  0000000000000000000   
            0xFC, 0xFF, 0xFF, 0xC0, ##  000000  000000000000000000    
            0xFC, 0x7F, 0xFF, 0x00, ##  000000   000000000000000      
            0x00, 0x0F, 0xF8, 0x00, ##              000000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '224' => {    # 'à'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x07, 0xE0, 0x00, 0x00, ##       000000                  
            0x03, 0xF0, 0x00, 0x00, ##        000000                 
            0x03, 0xF0, 0x00, 0x00, ##        000000                 
            0x01, 0xF8, 0x00, 0x00, ##         000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000               
            0x00, 0x7C, 0x00, 0x00, ##           00000               
            0x00, 0x3E, 0x00, 0x00, ##            00000              
            0x00, 0x1F, 0x00, 0x00, ##             00000             
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x0F, 0x80, 0x00, ##              00000            
            0x00, 0x07, 0xC0, 0x00, ##               00000           
            0x00, 0x03, 0xE0, 0x00, ##                00000          
            0x00, 0x01, 0xE0, 0x00, ##                 0000          
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000       
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000     
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000    
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x1F, 0xC0, 0x3F, 0xE0, ##     0000000        000000000  
            0x1E, 0x00, 0x0F, 0xF0, ##     0000             00000000 
            0x10, 0x00, 0x07, 0xF0, ##     0                 0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x3F, 0xFF, 0xF8, ##            0000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x07, 0xFF, 0xFF, 0xF8, ##       000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xF8, ##     00000000000000000000000000
            0x3F, 0xFF, 0xFF, 0xF8, ##    000000000000000000000000000
            0x3F, 0xE0, 0x01, 0xF8, ##    000000000            000000
            0x7F, 0x80, 0x01, 0xF8, ##   00000000              000000
            0x7F, 0x00, 0x01, 0xF8, ##   0000000               000000
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000
            0xFE, 0x00, 0x07, 0xF8, ##  0000000              00000000
            0xFE, 0x00, 0x0F, 0xF8, ##  0000000             000000000
            0x7F, 0x00, 0x1F, 0xF8, ##   0000000           0000000000
            0x7F, 0xC0, 0xFF, 0xF8, ##   000000000      0000000000000
            0x3F, 0xFF, 0xFD, 0xF8, ##    00000000000000000000 000000
            0x1F, 0xFF, 0xF9, 0xF8, ##     000000000000000000  000000
            0x0F, 0xFF, 0xF1, 0xF8, ##      0000000000000000   000000
            0x07, 0xFF, 0xC1, 0xF8, ##       0000000000000     000000
            0x00, 0xFF, 0x00, 0x00, ##          00000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '225' => {    # 'á'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000   
            0x00, 0x00, 0x1F, 0x80, ##                     000000    
            0x00, 0x00, 0x3F, 0x00, ##                    000000     
            0x00, 0x00, 0x7E, 0x00, ##                   000000      
            0x00, 0x00, 0x7C, 0x00, ##                   00000       
            0x00, 0x00, 0xF8, 0x00, ##                  00000        
            0x00, 0x01, 0xF8, 0x00, ##                 000000        
            0x00, 0x03, 0xF0, 0x00, ##                000000         
            0x00, 0x03, 0xE0, 0x00, ##                00000          
            0x00, 0x07, 0xC0, 0x00, ##               00000           
            0x00, 0x0F, 0x80, 0x00, ##              00000            
            0x00, 0x0F, 0x00, 0x00, ##              0000             
            0x00, 0x1F, 0x00, 0x00, ##             00000             
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000       
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000     
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000    
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x1F, 0xC0, 0x3F, 0xE0, ##     0000000        000000000  
            0x1E, 0x00, 0x0F, 0xF0, ##     0000             00000000 
            0x10, 0x00, 0x07, 0xF0, ##     0                 0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x3F, 0xFF, 0xF8, ##            0000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x07, 0xFF, 0xFF, 0xF8, ##       000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xF8, ##     00000000000000000000000000
            0x3F, 0xFF, 0xFF, 0xF8, ##    000000000000000000000000000
            0x3F, 0xE0, 0x01, 0xF8, ##    000000000            000000
            0x7F, 0x80, 0x01, 0xF8, ##   00000000              000000
            0x7F, 0x00, 0x01, 0xF8, ##   0000000               000000
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000
            0xFE, 0x00, 0x07, 0xF8, ##  0000000              00000000
            0xFE, 0x00, 0x0F, 0xF8, ##  0000000             000000000
            0x7F, 0x00, 0x1F, 0xF8, ##   0000000           0000000000
            0x7F, 0xC0, 0xFF, 0xF8, ##   000000000      0000000000000
            0x3F, 0xFF, 0xFD, 0xF8, ##    00000000000000000000 000000
            0x1F, 0xFF, 0xF9, 0xF8, ##     000000000000000000  000000
            0x0F, 0xFF, 0xF1, 0xF8, ##      0000000000000000   000000
            0x07, 0xFF, 0xC1, 0xF8, ##       0000000000000     000000
            0x00, 0xFF, 0x00, 0x00, ##          00000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '226' => {    # 'â'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0x80, 0x00, ##               0000            
            0x00, 0x0F, 0xC0, 0x00, ##              000000           
            0x00, 0x0F, 0xE0, 0x00, ##              0000000          
            0x00, 0x1F, 0xE0, 0x00, ##             00000000          
            0x00, 0x3F, 0xF0, 0x00, ##            0000000000         
            0x00, 0x3E, 0xF8, 0x00, ##            00000 00000        
            0x00, 0x7C, 0xF8, 0x00, ##           00000  00000        
            0x00, 0xF8, 0x7C, 0x00, ##          00000    00000       
            0x00, 0xF0, 0x3C, 0x00, ##          0000      0000       
            0x01, 0xF0, 0x1E, 0x00, ##         00000       0000      
            0x01, 0xE0, 0x1F, 0x00, ##         0000        00000     
            0x03, 0xC0, 0x0F, 0x00, ##        0000          0000     
            0x07, 0xC0, 0x07, 0x80, ##       00000           0000    
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000       
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000     
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000    
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x1F, 0xC0, 0x3F, 0xE0, ##     0000000        000000000  
            0x1E, 0x00, 0x0F, 0xF0, ##     0000             00000000 
            0x10, 0x00, 0x07, 0xF0, ##     0                 0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x3F, 0xFF, 0xF8, ##            0000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x07, 0xFF, 0xFF, 0xF8, ##       000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xF8, ##     00000000000000000000000000
            0x3F, 0xFF, 0xFF, 0xF8, ##    000000000000000000000000000
            0x3F, 0xE0, 0x01, 0xF8, ##    000000000            000000
            0x7F, 0x80, 0x01, 0xF8, ##   00000000              000000
            0x7F, 0x00, 0x01, 0xF8, ##   0000000               000000
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000
            0xFE, 0x00, 0x07, 0xF8, ##  0000000              00000000
            0xFE, 0x00, 0x0F, 0xF8, ##  0000000             000000000
            0x7F, 0x00, 0x1F, 0xF8, ##   0000000           0000000000
            0x7F, 0xC0, 0xFF, 0xF8, ##   000000000      0000000000000
            0x3F, 0xFF, 0xFD, 0xF8, ##    00000000000000000000 000000
            0x1F, 0xFF, 0xF9, 0xF8, ##     000000000000000000  000000
            0x0F, 0xFF, 0xF1, 0xF8, ##      0000000000000000   000000
            0x07, 0xFF, 0xC1, 0xF8, ##       0000000000000     000000
            0x00, 0xFF, 0x00, 0x00, ##          00000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '227' => {    # 'ã'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x78, 0x07, 0x80, ##           0000        0000    
            0x01, 0xFC, 0x07, 0x80, ##         0000000       0000    
            0x03, 0xFF, 0x07, 0x80, ##        0000000000     0000    
            0x03, 0xFF, 0x07, 0x80, ##        0000000000     0000    
            0x03, 0xCF, 0xCF, 0x00, ##        0000  000000  0000     
            0x07, 0x87, 0xFF, 0x00, ##       0000    00000000000     
            0x07, 0x83, 0xFF, 0x00, ##       0000     0000000000     
            0x07, 0x81, 0xFE, 0x00, ##       0000      00000000      
            0x07, 0x80, 0x78, 0x00, ##       0000        0000        
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000       
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000     
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000    
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x1F, 0xC0, 0x3F, 0xE0, ##     0000000        000000000  
            0x1E, 0x00, 0x0F, 0xF0, ##     0000             00000000 
            0x10, 0x00, 0x07, 0xF0, ##     0                 0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x3F, 0xFF, 0xF8, ##            0000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x07, 0xFF, 0xFF, 0xF8, ##       000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xF8, ##     00000000000000000000000000
            0x3F, 0xFF, 0xFF, 0xF8, ##    000000000000000000000000000
            0x3F, 0xE0, 0x01, 0xF8, ##    000000000            000000
            0x7F, 0x80, 0x01, 0xF8, ##   00000000              000000
            0x7F, 0x00, 0x01, 0xF8, ##   0000000               000000
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000
            0xFE, 0x00, 0x07, 0xF8, ##  0000000              00000000
            0xFE, 0x00, 0x0F, 0xF8, ##  0000000             000000000
            0x7F, 0x00, 0x1F, 0xF8, ##   0000000           0000000000
            0x7F, 0xC0, 0xFF, 0xF8, ##   000000000      0000000000000
            0x3F, 0xFF, 0xFD, 0xF8, ##    00000000000000000000 000000
            0x1F, 0xFF, 0xF9, 0xF8, ##     000000000000000000  000000
            0x0F, 0xFF, 0xF1, 0xF8, ##      0000000000000000   000000
            0x07, 0xFF, 0xC1, 0xF8, ##       0000000000000     000000
            0x00, 0xFF, 0x00, 0x00, ##          00000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '228' => {    # 'ä'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000     
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000       
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000     
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000    
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x1F, 0xC0, 0x3F, 0xE0, ##     0000000        000000000  
            0x1E, 0x00, 0x0F, 0xF0, ##     0000             00000000 
            0x10, 0x00, 0x07, 0xF0, ##     0                 0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x3F, 0xFF, 0xF8, ##            0000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x07, 0xFF, 0xFF, 0xF8, ##       000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xF8, ##     00000000000000000000000000
            0x3F, 0xFF, 0xFF, 0xF8, ##    000000000000000000000000000
            0x3F, 0xE0, 0x01, 0xF8, ##    000000000            000000
            0x7F, 0x80, 0x01, 0xF8, ##   00000000              000000
            0x7F, 0x00, 0x01, 0xF8, ##   0000000               000000
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000
            0xFE, 0x00, 0x07, 0xF8, ##  0000000              00000000
            0xFE, 0x00, 0x0F, 0xF8, ##  0000000             000000000
            0x7F, 0x00, 0x1F, 0xF8, ##   0000000           0000000000
            0x7F, 0xC0, 0xFF, 0xF8, ##   000000000      0000000000000
            0x3F, 0xFF, 0xFD, 0xF8, ##    00000000000000000000 000000
            0x1F, 0xFF, 0xF9, 0xF8, ##     000000000000000000  000000
            0x0F, 0xFF, 0xF1, 0xF8, ##      0000000000000000   000000
            0x07, 0xFF, 0xC1, 0xF8, ##       0000000000000     000000
            0x00, 0xFF, 0x00, 0x00, ##          00000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '229' => {    # 'å'
        'width'    => 29, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x0F, 0xC0, 0x00, ##              000000           
            0x00, 0x3F, 0xF0, 0x00, ##            0000000000         
            0x00, 0x7F, 0xF8, 0x00, ##           000000000000        
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000       
            0x01, 0xF8, 0x7E, 0x00, ##         000000    000000      
            0x01, 0xE0, 0x1E, 0x00, ##         0000        0000      
            0x03, 0xC0, 0x1F, 0x00, ##        0000         00000     
            0x03, 0xC0, 0x0F, 0x00, ##        0000          0000     
            0x03, 0xC0, 0x0F, 0x00, ##        0000          0000     
            0x03, 0xC0, 0x0F, 0x00, ##        0000          0000     
            0x03, 0xC0, 0x1F, 0x00, ##        0000         00000     
            0x01, 0xE0, 0x1E, 0x00, ##         0000        0000      
            0x01, 0xF8, 0x7E, 0x00, ##         000000    000000      
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000       
            0x00, 0x7F, 0xF8, 0x00, ##           000000000000        
            0x00, 0x3F, 0xF0, 0x00, ##            0000000000         
            0x00, 0x0F, 0xC0, 0x00, ##              000000           
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x3F, 0xE0, 0x00, ##            000000000          
            0x07, 0xFF, 0xFC, 0x00, ##       00000000000000000       
            0x1F, 0xFF, 0xFF, 0x00, ##     000000000000000000000     
            0x1F, 0xFF, 0xFF, 0x80, ##     0000000000000000000000    
            0x1F, 0xFF, 0xFF, 0xC0, ##     00000000000000000000000   
            0x1F, 0xC0, 0x3F, 0xE0, ##     0000000        000000000  
            0x1E, 0x00, 0x0F, 0xF0, ##     0000             00000000 
            0x10, 0x00, 0x07, 0xF0, ##     0                 0000000 
            0x00, 0x00, 0x03, 0xF0, ##                        000000 
            0x00, 0x00, 0x03, 0xF8, ##                        0000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x00, 0x01, 0xF8, ##                         000000
            0x00, 0x3F, 0xFF, 0xF8, ##            0000000000000000000
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000
            0x07, 0xFF, 0xFF, 0xF8, ##       000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xF8, ##     00000000000000000000000000
            0x3F, 0xFF, 0xFF, 0xF8, ##    000000000000000000000000000
            0x3F, 0xE0, 0x01, 0xF8, ##    000000000            000000
            0x7F, 0x80, 0x01, 0xF8, ##   00000000              000000
            0x7F, 0x00, 0x01, 0xF8, ##   0000000               000000
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x03, 0xF8, ##  000000                0000000
            0xFC, 0x00, 0x07, 0xF8, ##  000000               00000000
            0xFE, 0x00, 0x07, 0xF8, ##  0000000              00000000
            0xFE, 0x00, 0x0F, 0xF8, ##  0000000             000000000
            0x7F, 0x00, 0x1F, 0xF8, ##   0000000           0000000000
            0x7F, 0xC0, 0xFF, 0xF8, ##   000000000      0000000000000
            0x3F, 0xFF, 0xFD, 0xF8, ##    00000000000000000000 000000
            0x1F, 0xFF, 0xF9, 0xF8, ##     000000000000000000  000000
            0x0F, 0xFF, 0xF1, 0xF8, ##      0000000000000000   000000
            0x07, 0xFF, 0xC1, 0xF8, ##       0000000000000     000000
            0x00, 0xFF, 0x00, 0x00, ##          00000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '230' => {    # 'æ'
        'width'    => 36, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x01, 0xFC, 0x01, 0xFC, 0x00, ##         0000000         0000000      
            0x0F, 0xFF, 0x07, 0xFF, 0x00, ##      000000000000     00000000000    
            0x3F, 0xFF, 0x8F, 0xFF, 0x80, ##    000000000000000   0000000000000   
            0x3F, 0xFF, 0xDF, 0xFF, 0xC0, ##    0000000000000000 000000000000000  
            0x3F, 0xFF, 0xFF, 0xFF, 0xC0, ##    00000000000000000000000000000000  
            0x3E, 0x07, 0xFF, 0x0F, 0xE0, ##    00000      00000000000    0000000 
            0x30, 0x03, 0xFE, 0x07, 0xE0, ##    00          000000000      000000 
            0x00, 0x01, 0xFC, 0x03, 0xE0, ##                 0000000        00000 
            0x00, 0x01, 0xFC, 0x03, 0xE0, ##                 0000000        00000 
            0x00, 0x00, 0xF8, 0x01, 0xF0, ##                  00000          00000
            0x00, 0x00, 0xF8, 0x01, 0xF0, ##                  00000          00000
            0x00, 0x00, 0xF8, 0x01, 0xF0, ##                  00000          00000
            0x00, 0x00, 0xF8, 0x01, 0xF0, ##                  00000          00000
            0x00, 0x00, 0xF8, 0x01, 0xF0, ##                  00000          00000
            0x00, 0x00, 0xF8, 0x01, 0xF0, ##                  00000          00000
            0x00, 0xFF, 0xFF, 0xFF, 0xF0, ##          0000000000000000000000000000
            0x07, 0xFF, 0xFF, 0xFF, 0xF0, ##       0000000000000000000000000000000
            0x0F, 0xFF, 0xFF, 0xFF, 0xF0, ##      00000000000000000000000000000000
            0x1F, 0xFF, 0xFF, 0xFF, 0xF0, ##     000000000000000000000000000000000
            0x3F, 0xFF, 0xFF, 0xFF, 0xF0, ##    0000000000000000000000000000000000
            0x7F, 0x80, 0xF8, 0x00, 0x00, ##   00000000       00000               
            0x7E, 0x00, 0xF8, 0x00, 0x00, ##   000000         00000               
            0xFC, 0x00, 0xF8, 0x00, 0x00, ##  000000          00000               
            0xF8, 0x00, 0xF8, 0x00, 0x00, ##  00000           00000               
            0xF8, 0x00, 0xF8, 0x00, 0x00, ##  00000           00000               
            0xF8, 0x00, 0xF8, 0x00, 0x00, ##  00000           00000               
            0xF8, 0x00, 0xF8, 0x00, 0x00, ##  00000           00000               
            0xF8, 0x00, 0xFC, 0x00, 0x00, ##  00000           000000              
            0xF8, 0x01, 0xFC, 0x00, 0x00, ##  00000          0000000              
            0xFC, 0x01, 0xFC, 0x00, 0x20, ##  000000         0000000            0 
            0x7C, 0x03, 0xFE, 0x00, 0x60, ##   00000        000000000          00 
            0x7F, 0x07, 0xFF, 0x81, 0xE0, ##   0000000     000000000000      0000 
            0x7F, 0xFF, 0xDF, 0xFF, 0xE0, ##   00000000000000000 0000000000000000 
            0x3F, 0xFF, 0xDF, 0xFF, 0xE0, ##    0000000000000000 0000000000000000 
            0x1F, 0xFF, 0x8F, 0xFF, 0xE0, ##     00000000000000   000000000000000 
            0x0F, 0xFF, 0x03, 0xFF, 0x80, ##      000000000000      00000000000   
            0x03, 0xF8, 0x00, 0xFE, 0x00, ##        0000000           0000000     
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '231' => {    # 'ç'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0xF8, 0x00, ##               00000000      
            0x00, 0x7F, 0xFF, 0x00, ##           000000000000000   
            0x01, 0xFF, 0xFF, 0xE0, ##         00000000000000000000
            0x03, 0xFF, 0xFF, 0xE0, ##        000000000000000000000
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000
            0x0F, 0xFC, 0x07, 0xE0, ##      0000000000       000000
            0x1F, 0xE0, 0x00, 0xE0, ##     00000000             000
            0x1F, 0xC0, 0x00, 0x60, ##     0000000               00
            0x3F, 0x80, 0x00, 0x00, ##    0000000                  
            0x3F, 0x00, 0x00, 0x00, ##    000000                   
            0x7F, 0x00, 0x00, 0x00, ##   0000000                   
            0x7E, 0x00, 0x00, 0x00, ##   000000                    
            0x7E, 0x00, 0x00, 0x00, ##   000000                    
            0xFE, 0x00, 0x00, 0x00, ##  0000000                    
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFC, 0x00, 0x00, 0x00, ##  000000                     
            0xFE, 0x00, 0x00, 0x00, ##  0000000                    
            0x7E, 0x00, 0x00, 0x00, ##   000000                    
            0x7E, 0x00, 0x00, 0x00, ##   000000                    
            0x7F, 0x00, 0x00, 0x00, ##   0000000                   
            0x3F, 0x00, 0x00, 0x00, ##    000000                   
            0x3F, 0x80, 0x00, 0x00, ##    0000000                  
            0x1F, 0xC0, 0x00, 0x60, ##     0000000               00
            0x1F, 0xE0, 0x00, 0xE0, ##     00000000             000
            0x0F, 0xF8, 0x07, 0xE0, ##      000000000        000000
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000
            0x03, 0xFF, 0xFF, 0xE0, ##        000000000000000000000
            0x01, 0xFF, 0xFF, 0xE0, ##         00000000000000000000
            0x00, 0x7F, 0xFF, 0x80, ##           0000000000000000  
            0x00, 0x0F, 0xFC, 0x00, ##              0000000000     
            0x00, 0x00, 0xF0, 0x00, ##                  0000       
            0x00, 0x00, 0x78, 0x00, ##                   0000      
            0x00, 0x00, 0x78, 0x00, ##                   0000      
            0x00, 0x00, 0x3C, 0x00, ##                    0000     
            0x00, 0x00, 0x3C, 0x00, ##                    0000     
            0x00, 0x00, 0x3C, 0x00, ##                    0000     
            0x00, 0x60, 0x7C, 0x00, ##           00      00000     
            0x00, 0x7F, 0xFC, 0x00, ##           0000000000000     
            0x00, 0x7F, 0xF8, 0x00, ##           000000000000      
            0x00, 0x7F, 0xF0, 0x00, ##           00000000000       
            0x00, 0x1F, 0xC0, 0x00, ##             0000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '232' => {    # 'è'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x07, 0xE0, 0x00, 0x00, ##       000000                    
            0x03, 0xF0, 0x00, 0x00, ##        000000                   
            0x01, 0xF8, 0x00, 0x00, ##         000000                  
            0x00, 0xFC, 0x00, 0x00, ##          000000                 
            0x00, 0x7C, 0x00, 0x00, ##           00000                 
            0x00, 0x3E, 0x00, 0x00, ##            00000                
            0x00, 0x3F, 0x00, 0x00, ##            000000               
            0x00, 0x1F, 0x80, 0x00, ##             000000              
            0x00, 0x0F, 0x80, 0x00, ##              00000              
            0x00, 0x07, 0xC0, 0x00, ##               00000             
            0x00, 0x03, 0xE0, 0x00, ##                00000            
            0x00, 0x01, 0xE0, 0x00, ##                 0000            
            0x00, 0x01, 0xF0, 0x00, ##                 00000           
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x0F, 0xF8, 0x00, ##              000000000          
            0x00, 0x7F, 0xFE, 0x00, ##           00000000000000        
            0x01, 0xFF, 0xFF, 0x80, ##         000000000000000000      
            0x03, 0xFF, 0xFF, 0xC0, ##        00000000000000000000     
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000    
            0x0F, 0xF8, 0x1F, 0xF0, ##      000000000      000000000   
            0x1F, 0xE0, 0x03, 0xF0, ##     00000000           000000   
            0x1F, 0xC0, 0x01, 0xF8, ##     0000000             000000  
            0x3F, 0x80, 0x01, 0xF8, ##    0000000              000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0x7C, ##   000000                  00000 
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x3F, 0x80, 0x00, 0x00, ##    0000000                      
            0x1F, 0xC0, 0x00, 0x0C, ##     0000000                  00 
            0x1F, 0xE0, 0x00, 0x7C, ##     00000000              00000 
            0x0F, 0xF8, 0x03, 0xFC, ##      000000000         00000000 
            0x07, 0xFF, 0xFF, 0xFC, ##       0000000000000000000000000 
            0x03, 0xFF, 0xFF, 0xFC, ##        000000000000000000000000 
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000  
            0x00, 0x7F, 0xFF, 0xC0, ##           00000000000000000     
            0x00, 0x07, 0xFC, 0x00, ##               000000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '233' => {    # 'é'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x0F, 0xC0, ##                      000000     
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000     
            0x00, 0x00, 0x1F, 0x80, ##                     000000      
            0x00, 0x00, 0x3F, 0x00, ##                    000000       
            0x00, 0x00, 0x7E, 0x00, ##                   000000        
            0x00, 0x00, 0xFC, 0x00, ##                  000000         
            0x00, 0x00, 0xF8, 0x00, ##                  00000          
            0x00, 0x01, 0xF0, 0x00, ##                 00000           
            0x00, 0x03, 0xF0, 0x00, ##                000000           
            0x00, 0x03, 0xE0, 0x00, ##                00000            
            0x00, 0x07, 0xC0, 0x00, ##               00000             
            0x00, 0x0F, 0x80, 0x00, ##              00000              
            0x00, 0x1F, 0x00, 0x00, ##             00000               
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x0F, 0xF8, 0x00, ##              000000000          
            0x00, 0x7F, 0xFE, 0x00, ##           00000000000000        
            0x01, 0xFF, 0xFF, 0x80, ##         000000000000000000      
            0x03, 0xFF, 0xFF, 0xC0, ##        00000000000000000000     
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000    
            0x0F, 0xF8, 0x1F, 0xF0, ##      000000000      000000000   
            0x1F, 0xE0, 0x03, 0xF0, ##     00000000           000000   
            0x1F, 0xC0, 0x01, 0xF8, ##     0000000             000000  
            0x3F, 0x80, 0x01, 0xF8, ##    0000000              000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0x7C, ##   000000                  00000 
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x3F, 0x80, 0x00, 0x00, ##    0000000                      
            0x1F, 0xC0, 0x00, 0x0C, ##     0000000                  00 
            0x1F, 0xE0, 0x00, 0x7C, ##     00000000              00000 
            0x0F, 0xF8, 0x03, 0xFC, ##      000000000         00000000 
            0x07, 0xFF, 0xFF, 0xFC, ##       0000000000000000000000000 
            0x03, 0xFF, 0xFF, 0xFC, ##        000000000000000000000000 
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000  
            0x00, 0x7F, 0xFF, 0xC0, ##           00000000000000000     
            0x00, 0x07, 0xFC, 0x00, ##               000000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '234' => {    # 'ê'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x03, 0xC0, 0x00, ##                0000             
            0x00, 0x07, 0xE0, 0x00, ##               000000            
            0x00, 0x0F, 0xE0, 0x00, ##              0000000            
            0x00, 0x0F, 0xF0, 0x00, ##              00000000           
            0x00, 0x1F, 0xF8, 0x00, ##             0000000000          
            0x00, 0x3E, 0xF8, 0x00, ##            00000 00000          
            0x00, 0x3E, 0x7C, 0x00, ##            00000  00000         
            0x00, 0x7C, 0x3E, 0x00, ##           00000    00000        
            0x00, 0xF8, 0x1E, 0x00, ##          00000      0000        
            0x00, 0xF0, 0x1F, 0x00, ##          0000       00000       
            0x01, 0xF0, 0x0F, 0x80, ##         00000        00000      
            0x03, 0xE0, 0x07, 0x80, ##        00000          0000      
            0x03, 0xC0, 0x07, 0xC0, ##        0000           00000     
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x0F, 0xF8, 0x00, ##              000000000          
            0x00, 0x7F, 0xFE, 0x00, ##           00000000000000        
            0x01, 0xFF, 0xFF, 0x80, ##         000000000000000000      
            0x03, 0xFF, 0xFF, 0xC0, ##        00000000000000000000     
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000    
            0x0F, 0xF8, 0x1F, 0xF0, ##      000000000      000000000   
            0x1F, 0xE0, 0x03, 0xF0, ##     00000000           000000   
            0x1F, 0xC0, 0x01, 0xF8, ##     0000000             000000  
            0x3F, 0x80, 0x01, 0xF8, ##    0000000              000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000 
            0x7E, 0x00, 0x00, 0x7C, ##   000000                  00000 
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x3F, 0x80, 0x00, 0x00, ##    0000000                      
            0x1F, 0xC0, 0x00, 0x0C, ##     0000000                  00 
            0x1F, 0xE0, 0x00, 0x7C, ##     00000000              00000 
            0x0F, 0xF8, 0x03, 0xFC, ##      000000000         00000000 
            0x07, 0xFF, 0xFF, 0xFC, ##       0000000000000000000000000 
            0x03, 0xFF, 0xFF, 0xFC, ##        000000000000000000000000 
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000  
            0x00, 0x7F, 0xFF, 0xC0, ##           00000000000000000     
            0x00, 0x07, 0xFC, 0x00, ##               000000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '235' => {    # 'ë'
        'width'    => 31, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000      
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000      
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000      
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000      
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000      
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000      
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x00, 0x00, 0x00, ##                                 
            0x00, 0x0F, 0xF8, 0x00, ##              000000000          
            0x00, 0x7F, 0xFE, 0x00, ##           00000000000000        
            0x01, 0xFF, 0xFF, 0x80, ##         000000000000000000      
            0x03, 0xFF, 0xFF, 0xC0, ##        00000000000000000000     
            0x07, 0xFF, 0xFF, 0xE0, ##       0000000000000000000000    
            0x0F, 0xF8, 0x1F, 0xF0, ##      000000000      000000000   
            0x1F, 0xE0, 0x03, 0xF0, ##     00000000           000000   
            0x1F, 0xC0, 0x01, 0xF8, ##     0000000             000000  
            0x3F, 0x80, 0x01, 0xF8, ##    0000000              000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000 
            0x7F, 0x00, 0x00, 0xFC, ##   0000000                000000 
            0x7E, 0x00, 0x00, 0x7C, ##   000000                  00000 
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000
            0xFE, 0x00, 0x00, 0x7E, ##  0000000                  000000
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFE, ##  0000000000000000000000000000000
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0xFC, 0x00, 0x00, 0x00, ##  000000                         
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x7E, 0x00, 0x00, 0x00, ##   000000                        
            0x3F, 0x00, 0x00, 0x00, ##    000000                       
            0x3F, 0x80, 0x00, 0x00, ##    0000000                      
            0x1F, 0xC0, 0x00, 0x0C, ##     0000000                  00 
            0x1F, 0xE0, 0x00, 0x7C, ##     00000000              00000 
            0x0F, 0xF8, 0x03, 0xFC, ##      000000000         00000000 
            0x07, 0xFF, 0xFF, 0xFC, ##       0000000000000000000000000 
            0x03, 0xFF, 0xFF, 0xFC, ##        000000000000000000000000 
            0x01, 0xFF, 0xFF, 0xF8, ##         0000000000000000000000  
            0x00, 0x7F, 0xFF, 0xC0, ##           00000000000000000     
            0x00, 0x07, 0xFC, 0x00, ##               000000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '236' => {    # 'ì'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x1F, 0x80, 0x00, 0x00, ##     000000                    
            0x0F, 0xC0, 0x00, 0x00, ##      000000                   
            0x07, 0xE0, 0x00, 0x00, ##       000000                  
            0x03, 0xE0, 0x00, 0x00, ##        00000                  
            0x03, 0xF0, 0x00, 0x00, ##        000000                 
            0x01, 0xF8, 0x00, 0x00, ##         000000                
            0x00, 0xFC, 0x00, 0x00, ##          000000               
            0x00, 0x7C, 0x00, 0x00, ##           00000               
            0x00, 0x3E, 0x00, 0x00, ##            00000              
            0x00, 0x3F, 0x00, 0x00, ##            000000             
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x0F, 0x80, 0x00, ##              00000            
            0x00, 0x07, 0xC0, 0x00, ##               00000           
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '237' => {    # 'í'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x3F, 0x00, ##                    000000     
            0x00, 0x00, 0x7F, 0x00, ##                   0000000     
            0x00, 0x00, 0xFE, 0x00, ##                  0000000      
            0x00, 0x00, 0xFC, 0x00, ##                  000000       
            0x00, 0x01, 0xF8, 0x00, ##                 000000        
            0x00, 0x03, 0xF0, 0x00, ##                000000         
            0x00, 0x07, 0xE0, 0x00, ##               000000          
            0x00, 0x07, 0xC0, 0x00, ##               00000           
            0x00, 0x0F, 0x80, 0x00, ##              00000            
            0x00, 0x1F, 0x00, 0x00, ##             00000             
            0x00, 0x3F, 0x00, 0x00, ##            000000             
            0x00, 0x3E, 0x00, 0x00, ##            00000              
            0x00, 0x7C, 0x00, 0x00, ##           00000               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '238' => {    # 'î'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0x00, 0x00, ##             00000             
            0x00, 0x3F, 0x00, 0x00, ##            000000             
            0x00, 0x3F, 0x80, 0x00, ##            0000000            
            0x00, 0x7F, 0xC0, 0x00, ##           000000000           
            0x00, 0x7F, 0xC0, 0x00, ##           000000000           
            0x00, 0xFB, 0xE0, 0x00, ##          00000 00000          
            0x01, 0xF1, 0xF0, 0x00, ##         00000   00000         
            0x01, 0xE0, 0xF8, 0x00, ##         0000     00000        
            0x03, 0xE0, 0xF8, 0x00, ##        00000     00000        
            0x07, 0xC0, 0x7C, 0x00, ##       00000       00000       
            0x07, 0x80, 0x3E, 0x00, ##       0000         00000      
            0x0F, 0x80, 0x1E, 0x00, ##      00000          0000      
            0x0F, 0x00, 0x1F, 0x00, ##      0000           00000     
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x3F, 0xFF, 0x80, 0x00, ##    000000000000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '239' => {    # 'ï'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x07, 0xE0, 0x7E, 0x00, ##       000000      000000      
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x00, 0x00, 0x00, 0x00, ##                               
            0x1F, 0xFF, 0x80, 0x00, ##     00000000000000            
            0x1F, 0xFF, 0x80, 0x00, ##     00000000000000            
            0x1F, 0xFF, 0x80, 0x00, ##     00000000000000            
            0x1F, 0xFF, 0x80, 0x00, ##     00000000000000            
            0x1F, 0xFF, 0x80, 0x00, ##     00000000000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0x00, 0x1F, 0x80, 0x00, ##             000000            
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xF8, ##  00000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '240' => {    # 'ð'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x07, 0xF0, 0x00, 0x00, ##       0000000                  
            0x03, 0xF8, 0x00, 0x00, ##        0000000                 
            0x01, 0xFC, 0x03, 0x80, ##         0000000        000     
            0x00, 0xFE, 0x1F, 0xC0, ##          0000000    0000000    
            0x00, 0x7F, 0xFF, 0xC0, ##           00000000000000000    
            0x00, 0x3F, 0xFE, 0x00, ##            0000000000000       
            0x00, 0x7F, 0xF0, 0x00, ##           00000000000          
            0x03, 0xFF, 0xE0, 0x00, ##        0000000000000           
            0x1F, 0xFF, 0xE0, 0x00, ##     0000000000000000           
            0x0F, 0xC3, 0xF0, 0x00, ##      000000    000000          
            0x0E, 0x01, 0xF8, 0x00, ##      000        000000         
            0x00, 0x01, 0xFC, 0x00, ##                 0000000        
            0x00, 0x00, 0xFE, 0x00, ##                  0000000       
            0x00, 0x00, 0x7E, 0x00, ##                   000000       
            0x00, 0x1F, 0xFF, 0x00, ##             0000000000000      
            0x00, 0xFF, 0xFF, 0x80, ##          00000000000000000     
            0x03, 0xFF, 0xFF, 0x80, ##        0000000000000000000     
            0x07, 0xFF, 0xFF, 0xC0, ##       000000000000000000000    
            0x0F, 0xFF, 0xFF, 0xE0, ##      00000000000000000000000   
            0x1F, 0xF0, 0x0F, 0xE0, ##     000000000        0000000   
            0x1F, 0xC0, 0x07, 0xE0, ##     0000000           000000   
            0x3F, 0x80, 0x03, 0xF0, ##    0000000             000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFE, 0x00, 0x01, 0xFC, ##  0000000                0000000
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '241' => {    # 'ñ'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x01, 0xE0, 0x1E, 0x00, ##         0000        0000    
            0x07, 0xF0, 0x1E, 0x00, ##       0000000       0000    
            0x0F, 0xFC, 0x1E, 0x00, ##      0000000000     0000    
            0x0F, 0xFC, 0x1E, 0x00, ##      0000000000     0000    
            0x0F, 0x3F, 0x3C, 0x00, ##      0000  000000  0000     
            0x1E, 0x1F, 0xFC, 0x00, ##     0000    00000000000     
            0x1E, 0x0F, 0xFC, 0x00, ##     0000     0000000000     
            0x1E, 0x07, 0xF8, 0x00, ##     0000      00000000      
            0x1E, 0x01, 0xE0, 0x00, ##     0000        0000        
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x07, 0xF0, 0x00, ##               0000000       
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000     
            0xFC, 0x7F, 0xFE, 0x00, ##  000000   00000000000000    
            0xFC, 0xFF, 0xFF, 0x00, ##  000000  0000000000000000   
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000  
            0xFF, 0xE0, 0x7F, 0x80, ##  00000000000      00000000  
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000 
            0xFF, 0x00, 0x0F, 0xC0, ##  00000000            000000 
            0xFF, 0x00, 0x0F, 0xC0, ##  00000000            000000 
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000
            0xFE, 0x00, 0x07, 0xE0, ##  0000000              000000
            0xFE, 0x00, 0x07, 0xE0, ##  0000000              000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '242' => {    # 'ò'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x0F, 0xE0, 0x00, 0x00, ##      0000000                   
            0x07, 0xE0, 0x00, 0x00, ##       000000                   
            0x03, 0xF0, 0x00, 0x00, ##        000000                  
            0x01, 0xF8, 0x00, 0x00, ##         000000                 
            0x00, 0xFC, 0x00, 0x00, ##          000000                
            0x00, 0x7C, 0x00, 0x00, ##           00000                
            0x00, 0x7E, 0x00, 0x00, ##           000000               
            0x00, 0x3F, 0x00, 0x00, ##            000000              
            0x00, 0x1F, 0x80, 0x00, ##             000000             
            0x00, 0x0F, 0x80, 0x00, ##              00000             
            0x00, 0x07, 0xC0, 0x00, ##               00000            
            0x00, 0x03, 0xE0, 0x00, ##                00000           
            0x00, 0x01, 0xE0, 0x00, ##                 0000           
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '243' => {    # 'ó'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000    
            0x00, 0x00, 0x1F, 0x80, ##                     000000     
            0x00, 0x00, 0x3F, 0x00, ##                    000000      
            0x00, 0x00, 0x7E, 0x00, ##                   000000       
            0x00, 0x00, 0xFC, 0x00, ##                  000000        
            0x00, 0x00, 0xF8, 0x00, ##                  00000         
            0x00, 0x01, 0xF8, 0x00, ##                 000000         
            0x00, 0x03, 0xF0, 0x00, ##                000000          
            0x00, 0x07, 0xE0, 0x00, ##               000000           
            0x00, 0x07, 0xC0, 0x00, ##               00000            
            0x00, 0x0F, 0x80, 0x00, ##              00000             
            0x00, 0x1F, 0x00, 0x00, ##             00000              
            0x00, 0x1E, 0x00, 0x00, ##             0000               
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '244' => {    # 'ô'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0x80, 0x00, ##               0000             
            0x00, 0x0F, 0xC0, 0x00, ##              000000            
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x3F, 0xF0, 0x00, ##            0000000000          
            0x00, 0x7C, 0xF8, 0x00, ##           00000  00000         
            0x00, 0x7C, 0xF8, 0x00, ##           00000  00000         
            0x00, 0xF8, 0x7C, 0x00, ##          00000    00000        
            0x01, 0xF0, 0x3C, 0x00, ##         00000      0000        
            0x01, 0xE0, 0x1E, 0x00, ##         0000        0000       
            0x03, 0xE0, 0x1F, 0x00, ##        00000        00000      
            0x03, 0xC0, 0x0F, 0x00, ##        0000          0000      
            0x07, 0x80, 0x07, 0x80, ##       0000            0000     
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '245' => {    # 'õ'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x78, 0x07, 0x80, ##           0000        0000     
            0x01, 0xFC, 0x07, 0x80, ##         0000000       0000     
            0x03, 0xFF, 0x07, 0x80, ##        0000000000     0000     
            0x03, 0xFF, 0x07, 0x80, ##        0000000000     0000     
            0x03, 0xCF, 0xCF, 0x00, ##        0000  000000  0000      
            0x07, 0x87, 0xFF, 0x00, ##       0000    00000000000      
            0x07, 0x83, 0xFF, 0x00, ##       0000     0000000000      
            0x07, 0x81, 0xFE, 0x00, ##       0000      00000000       
            0x07, 0x80, 0x78, 0x00, ##       0000        0000         
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '246' => {    # 'ö'
        'width'    => 30, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000      
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000      
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000      
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000      
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000      
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000      
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x00, 0x00, 0x00, ##                                
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0xFC, 0x00, 0x00, 0xFC, ##  000000                  000000
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7E, 0x00, 0x01, 0xF8, ##   000000                000000 
            0x7F, 0x00, 0x03, 0xF8, ##   0000000              0000000 
            0x3F, 0x00, 0x03, 0xF0, ##    000000              000000  
            0x3F, 0x80, 0x07, 0xF0, ##    0000000            0000000  
            0x1F, 0xC0, 0x0F, 0xE0, ##     0000000          0000000   
            0x1F, 0xF0, 0x3F, 0xE0, ##     000000000      000000000   
            0x0F, 0xFF, 0xFF, 0xC0, ##      0000000000000000000000    
            0x07, 0xFF, 0xFF, 0x80, ##       00000000000000000000     
            0x03, 0xFF, 0xFF, 0x00, ##        000000000000000000      
            0x00, 0xFF, 0xFC, 0x00, ##          00000000000000        
            0x00, 0x1F, 0xE0, 0x00, ##             00000000           
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '247' => {    # '÷'
        'width'    => 33, 
        'xoffset'  => 3, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0xFF, 0xFF, 0xFF, 0xFF, 0x80, ##  000000000000000000000000000000000
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x00, 0x00, 0x00, 0x00, ##                                   
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x07, 0xF8, 0x00, 0x00, ##               00000000            
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '248' => {    # 'ø'
        'width'    => 35, 
        'xoffset'  => 1, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x80, ##                                  0  
            0x00, 0x00, 0x00, 0x01, 0xC0, ##                                 000 
            0x00, 0x03, 0xFC, 0x03, 0xE0, ##                00000000        00000
            0x00, 0x1F, 0xFF, 0x83, 0xE0, ##             00000000000000     00000
            0x00, 0x7F, 0xFF, 0xE7, 0xC0, ##           000000000000000000  00000 
            0x00, 0xFF, 0xFF, 0xFF, 0x80, ##          0000000000000000000000000  
            0x01, 0xFF, 0xFF, 0xFF, 0x00, ##         0000000000000000000000000   
            0x03, 0xFE, 0x07, 0xFE, 0x00, ##        000000000      0000000000    
            0x03, 0xF8, 0x01, 0xFC, 0x00, ##        0000000          0000000     
            0x07, 0xF0, 0x00, 0xFE, 0x00, ##       0000000            0000000    
            0x07, 0xE0, 0x00, 0xFE, 0x00, ##       000000             0000000    
            0x0F, 0xE0, 0x01, 0xFF, 0x00, ##      0000000            000000000   
            0x0F, 0xC0, 0x03, 0xFF, 0x00, ##      000000            0000000000   
            0x0F, 0xC0, 0x07, 0xFF, 0x00, ##      000000           00000000000   
            0x1F, 0xC0, 0x0F, 0xBF, 0x00, ##     0000000          00000 000000   
            0x1F, 0x80, 0x0F, 0x9F, 0x80, ##     000000           00000  000000  
            0x1F, 0x80, 0x1F, 0x1F, 0x80, ##     000000          00000   000000  
            0x1F, 0x80, 0x3E, 0x1F, 0x80, ##     000000         00000    000000  
            0x1F, 0x80, 0x7C, 0x1F, 0x80, ##     000000        00000     000000  
            0x1F, 0x80, 0xF8, 0x1F, 0x80, ##     000000       00000      000000  
            0x1F, 0x80, 0xF0, 0x1F, 0x80, ##     000000       0000       000000  
            0x1F, 0x81, 0xF0, 0x1F, 0x80, ##     000000      00000       000000  
            0x1F, 0x83, 0xE0, 0x1F, 0x80, ##     000000     00000        000000  
            0x1F, 0x87, 0xC0, 0x1F, 0x80, ##     000000    00000         000000  
            0x1F, 0x8F, 0x80, 0x1F, 0x80, ##     000000   00000          000000  
            0x1F, 0xDF, 0x00, 0x1F, 0x80, ##     0000000 00000           000000  
            0x1F, 0xDF, 0x00, 0x3F, 0x00, ##     0000000 00000          000000   
            0x0F, 0xFE, 0x00, 0x3F, 0x00, ##      00000000000           000000   
            0x0F, 0xFC, 0x00, 0x3F, 0x00, ##      0000000000            000000   
            0x0F, 0xF8, 0x00, 0x7F, 0x00, ##      000000000            0000000   
            0x07, 0xF0, 0x00, 0x7E, 0x00, ##       0000000             000000    
            0x07, 0xF0, 0x00, 0xFE, 0x00, ##       0000000            0000000    
            0x07, 0xF8, 0x01, 0xFC, 0x00, ##       00000000          0000000     
            0x07, 0xFE, 0x07, 0xFC, 0x00, ##       0000000000      000000000     
            0x0F, 0xFF, 0xFF, 0xF8, 0x00, ##      0000000000000000000000000      
            0x1F, 0xFF, 0xFF, 0xF0, 0x00, ##     0000000000000000000000000       
            0x3E, 0x7F, 0xFF, 0xE0, 0x00, ##    00000  000000000000000000        
            0x7C, 0x1F, 0xFF, 0x80, 0x00, ##   00000     00000000000000          
            0xF8, 0x03, 0xFC, 0x00, 0x00, ##  00000         00000000             
            0x70, 0x00, 0x00, 0x00, 0x00, ##   000                               
            0x30, 0x00, 0x00, 0x00, 0x00, ##    00                               
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '249' => {    # 'ù'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x1F, 0x80, 0x00, 0x00, ##     000000                  
            0x0F, 0xC0, 0x00, 0x00, ##      000000                 
            0x0F, 0xC0, 0x00, 0x00, ##      000000                 
            0x07, 0xE0, 0x00, 0x00, ##       000000                
            0x03, 0xF0, 0x00, 0x00, ##        000000               
            0x01, 0xF8, 0x00, 0x00, ##         000000              
            0x00, 0xF8, 0x00, 0x00, ##          00000              
            0x00, 0x7C, 0x00, 0x00, ##           00000             
            0x00, 0x3E, 0x00, 0x00, ##            00000            
            0x00, 0x3F, 0x00, 0x00, ##            000000           
            0x00, 0x1F, 0x00, 0x00, ##             00000           
            0x00, 0x0F, 0x80, 0x00, ##              00000          
            0x00, 0x07, 0xC0, 0x00, ##               00000         
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7F, 0x00, 0x3F, 0xE0, ##   0000000          000000000
            0x7F, 0xC0, 0xFF, 0xE0, ##   000000000      00000000000
            0x3F, 0xFF, 0xF7, 0xE0, ##    000000000000000000 000000
            0x1F, 0xFF, 0xE7, 0xE0, ##     0000000000000000  000000
            0x1F, 0xFF, 0xC7, 0xE0, ##     000000000000000   000000
            0x07, 0xFF, 0x87, 0xE0, ##       000000000000    000000
            0x01, 0xFC, 0x00, 0x00, ##         0000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '250' => {    # 'ú'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x3F, 0x00, ##                    000000   
            0x00, 0x00, 0x7E, 0x00, ##                   000000    
            0x00, 0x00, 0xFC, 0x00, ##                  000000     
            0x00, 0x01, 0xF8, 0x00, ##                 000000      
            0x00, 0x01, 0xF0, 0x00, ##                 00000       
            0x00, 0x03, 0xF0, 0x00, ##                000000       
            0x00, 0x07, 0xE0, 0x00, ##               000000        
            0x00, 0x07, 0xC0, 0x00, ##               00000         
            0x00, 0x0F, 0x80, 0x00, ##              00000          
            0x00, 0x1F, 0x00, 0x00, ##             00000           
            0x00, 0x3E, 0x00, 0x00, ##            00000            
            0x00, 0x3E, 0x00, 0x00, ##            00000            
            0x00, 0x7C, 0x00, 0x00, ##           00000             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7F, 0x00, 0x3F, 0xE0, ##   0000000          000000000
            0x7F, 0xC0, 0xFF, 0xE0, ##   000000000      00000000000
            0x3F, 0xFF, 0xF7, 0xE0, ##    000000000000000000 000000
            0x1F, 0xFF, 0xE7, 0xE0, ##     0000000000000000  000000
            0x1F, 0xFF, 0xC7, 0xE0, ##     000000000000000   000000
            0x07, 0xFF, 0x87, 0xE0, ##       000000000000    000000
            0x01, 0xFC, 0x00, 0x00, ##         0000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '251' => {    # 'û'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x1F, 0x00, 0x00, ##             00000           
            0x00, 0x3F, 0x00, 0x00, ##            000000           
            0x00, 0x3F, 0x80, 0x00, ##            0000000          
            0x00, 0x7F, 0xC0, 0x00, ##           000000000         
            0x00, 0xFF, 0xC0, 0x00, ##          0000000000         
            0x00, 0xFB, 0xE0, 0x00, ##          00000 00000        
            0x01, 0xF1, 0xE0, 0x00, ##         00000   0000        
            0x01, 0xE1, 0xF0, 0x00, ##         0000    00000       
            0x03, 0xE0, 0xF8, 0x00, ##        00000     00000      
            0x07, 0xC0, 0x78, 0x00, ##       00000       0000      
            0x07, 0x80, 0x7C, 0x00, ##       0000        00000     
            0x0F, 0x00, 0x3E, 0x00, ##      0000          00000    
            0x1F, 0x00, 0x1E, 0x00, ##     00000           0000    
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7F, 0x00, 0x3F, 0xE0, ##   0000000          000000000
            0x7F, 0xC0, 0xFF, 0xE0, ##   000000000      00000000000
            0x3F, 0xFF, 0xF7, 0xE0, ##    000000000000000000 000000
            0x1F, 0xFF, 0xE7, 0xE0, ##     0000000000000000  000000
            0x1F, 0xFF, 0xC7, 0xE0, ##     000000000000000   000000
            0x07, 0xFF, 0x87, 0xE0, ##       000000000000    000000
            0x01, 0xFC, 0x00, 0x00, ##         0000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '252' => {    # 'ü'
        'width'    => 27, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000     
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000     
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000     
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000     
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000     
            0x0F, 0xC0, 0xFC, 0x00, ##      000000      000000     
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0x00, 0x00, 0x00, 0x00, ##                             
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x07, 0xE0, ##  000000               000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFC, 0x00, 0x0F, 0xE0, ##  000000              0000000
            0xFE, 0x00, 0x0F, 0xE0, ##  0000000             0000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7E, 0x00, 0x1F, 0xE0, ##   000000            00000000
            0x7F, 0x00, 0x3F, 0xE0, ##   0000000          000000000
            0x7F, 0xC0, 0xFF, 0xE0, ##   000000000      00000000000
            0x3F, 0xFF, 0xF7, 0xE0, ##    000000000000000000 000000
            0x1F, 0xFF, 0xE7, 0xE0, ##     0000000000000000  000000
            0x1F, 0xFF, 0xC7, 0xE0, ##     000000000000000   000000
            0x07, 0xFF, 0x87, 0xE0, ##       000000000000    000000
            0x01, 0xFC, 0x00, 0x00, ##         0000000             
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '253' => {    # 'ý'
        'width'    => 32, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x1F, 0xC0, ##                     0000000      
            0x00, 0x00, 0x1F, 0x80, ##                     000000       
            0x00, 0x00, 0x3F, 0x00, ##                    000000        
            0x00, 0x00, 0x7E, 0x00, ##                   000000         
            0x00, 0x00, 0x7C, 0x00, ##                   00000          
            0x00, 0x00, 0xF8, 0x00, ##                  00000           
            0x00, 0x01, 0xF8, 0x00, ##                 000000           
            0x00, 0x03, 0xF0, 0x00, ##                000000            
            0x00, 0x03, 0xE0, 0x00, ##                00000             
            0x00, 0x07, 0xC0, 0x00, ##               00000              
            0x00, 0x0F, 0x80, 0x00, ##              00000               
            0x00, 0x1F, 0x00, 0x00, ##             00000                
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0xFC, 0x00, 0x00, 0x3F, ##  000000                    000000
            0xFC, 0x00, 0x00, 0x3F, ##  000000                    000000
            0xFC, 0x00, 0x00, 0x7F, ##  000000                   0000000
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000 
            0x7E, 0x00, 0x00, 0x7E, ##   000000                  000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000  
            0x3F, 0x00, 0x00, 0xFC, ##    000000                000000  
            0x1F, 0x80, 0x01, 0xF8, ##     000000              000000   
            0x1F, 0x80, 0x01, 0xF8, ##     000000              000000   
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000    
            0x0F, 0xC0, 0x03, 0xF0, ##      000000            000000    
            0x0F, 0xC0, 0x03, 0xF0, ##      000000            000000    
            0x07, 0xE0, 0x07, 0xE0, ##       000000          000000     
            0x07, 0xE0, 0x07, 0xE0, ##       000000          000000     
            0x07, 0xE0, 0x07, 0xC0, ##       000000          00000      
            0x03, 0xF0, 0x0F, 0xC0, ##        000000        000000      
            0x03, 0xF0, 0x0F, 0xC0, ##        000000        000000      
            0x01, 0xF0, 0x1F, 0x80, ##         00000       000000       
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000       
            0x01, 0xF8, 0x1F, 0x80, ##         000000      000000       
            0x00, 0xFC, 0x3F, 0x00, ##          000000    000000        
            0x00, 0xFC, 0x3F, 0x00, ##          000000    000000        
            0x00, 0x7C, 0x3E, 0x00, ##           00000    00000         
            0x00, 0x7E, 0x7E, 0x00, ##           000000  000000         
            0x00, 0x7E, 0x7E, 0x00, ##           000000  000000         
            0x00, 0x3E, 0xFC, 0x00, ##            00000 000000          
            0x00, 0x3F, 0xFC, 0x00, ##            000000000000          
            0x00, 0x1F, 0xF8, 0x00, ##             0000000000           
            0x00, 0x1F, 0xF8, 0x00, ##             0000000000           
            0x00, 0x1F, 0xF8, 0x00, ##             0000000000           
            0x00, 0x0F, 0xF0, 0x00, ##              00000000            
            0x00, 0x0F, 0xF0, 0x00, ##              00000000            
            0x00, 0x0F, 0xF0, 0x00, ##              00000000            
            0x00, 0x07, 0xE0, 0x00, ##               000000             
            0x00, 0x07, 0xE0, 0x00, ##               000000             
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x1F, 0x80, 0x00, ##             000000               
            0x00, 0x1F, 0x80, 0x00, ##             000000               
            0x00, 0x3F, 0x00, 0x00, ##            000000                
            0x00, 0x7F, 0x00, 0x00, ##           0000000                
            0x00, 0xFF, 0x00, 0x00, ##          00000000                
            0x3F, 0xFE, 0x00, 0x00, ##    0000000000000                 
            0x3F, 0xFC, 0x00, 0x00, ##    000000000000                  
            0x3F, 0xF8, 0x00, 0x00, ##    00000000000                   
            0x3F, 0xF0, 0x00, 0x00, ##    0000000000                    
            0x3F, 0xC0, 0x00, 0x00, ##    00000000                      
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '254' => {    # 'þ'
        'width'    => 29, 
        'xoffset'  => 6, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x0F, 0xE0, 0x00, ##  000000      0000000          
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000       
            0xFC, 0xFF, 0xFE, 0x00, ##  000000  000000000000000      
            0xFD, 0xFF, 0xFF, 0x00, ##  000000 00000000000000000     
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000    
            0xFF, 0xF0, 0x7F, 0xC0, ##  000000000000     000000000   
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000   
            0xFF, 0x80, 0x0F, 0xE0, ##  000000000           0000000  
            0xFF, 0x00, 0x07, 0xE0, ##  00000000             000000  
            0xFF, 0x00, 0x07, 0xF0, ##  00000000             0000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFC, 0x00, 0x01, 0xF8, ##  000000                 000000
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFE, 0x00, 0x03, 0xF0, ##  0000000               000000 
            0xFF, 0x00, 0x07, 0xF0, ##  00000000             0000000 
            0xFF, 0x00, 0x07, 0xE0, ##  00000000             000000  
            0xFF, 0x80, 0x0F, 0xE0, ##  000000000           0000000  
            0xFF, 0xC0, 0x1F, 0xC0, ##  0000000000         0000000   
            0xFF, 0xF0, 0x7F, 0xC0, ##  000000000000     000000000   
            0xFD, 0xFF, 0xFF, 0x80, ##  000000 000000000000000000    
            0xFD, 0xFF, 0xFF, 0x00, ##  000000 00000000000000000     
            0xFC, 0xFF, 0xFE, 0x00, ##  000000  000000000000000      
            0xFC, 0x3F, 0xFC, 0x00, ##  000000    000000000000       
            0xFC, 0x0F, 0xE0, 0x00, ##  000000      0000000          
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0xFC, 0x00, 0x00, 0x00, ##  000000                       
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '255' => {    # 'ÿ'
        'width'    => 32, 
        'xoffset'  => 4, 
        'xadvance' => 39, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000        
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000        
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000        
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000        
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000        
            0x03, 0xF0, 0x3F, 0x00, ##        000000      000000        
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0x00, 0x00, 0x00, 0x00, ##                                  
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000 
            0xFC, 0x00, 0x00, 0x7E, ##  000000                   000000 
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000  
            0x7E, 0x00, 0x00, 0xFC, ##   000000                 000000  
            0x7E, 0x00, 0x01, 0xFC, ##   000000                0000000  
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000   
            0x3F, 0x00, 0x01, 0xF8, ##    000000               000000   
            0x1F, 0x00, 0x03, 0xF0, ##     00000              000000    
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000    
            0x1F, 0x80, 0x03, 0xF0, ##     000000             000000    
            0x0F, 0xC0, 0x07, 0xE0, ##      000000           000000     
            0x0F, 0xC0, 0x07, 0xE0, ##      000000           000000     
            0x0F, 0xC0, 0x07, 0xE0, ##      000000           000000     
            0x07, 0xE0, 0x0F, 0xC0, ##       000000         000000      
            0x07, 0xE0, 0x0F, 0xC0, ##       000000         000000      
            0x03, 0xE0, 0x0F, 0x80, ##        00000         00000       
            0x03, 0xF0, 0x1F, 0x80, ##        000000       000000       
            0x03, 0xF0, 0x1F, 0x80, ##        000000       000000       
            0x01, 0xF0, 0x3F, 0x00, ##         00000      000000        
            0x01, 0xF8, 0x3F, 0x00, ##         000000     000000        
            0x01, 0xF8, 0x3F, 0x00, ##         000000     000000        
            0x00, 0xFC, 0x7E, 0x00, ##          000000   000000         
            0x00, 0xFC, 0x7E, 0x00, ##          000000   000000         
            0x00, 0x7C, 0x7C, 0x00, ##           00000   00000          
            0x00, 0x7E, 0xFC, 0x00, ##           000000 000000          
            0x00, 0x7E, 0xFC, 0x00, ##           000000 000000          
            0x00, 0x3E, 0xF8, 0x00, ##            00000 00000           
            0x00, 0x3F, 0xF8, 0x00, ##            00000000000           
            0x00, 0x3F, 0xF8, 0x00, ##            00000000000           
            0x00, 0x1F, 0xF0, 0x00, ##             000000000            
            0x00, 0x1F, 0xF0, 0x00, ##             000000000            
            0x00, 0x0F, 0xE0, 0x00, ##              0000000             
            0x00, 0x0F, 0xE0, 0x00, ##              0000000             
            0x00, 0x0F, 0xE0, 0x00, ##              0000000             
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x0F, 0xC0, 0x00, ##              000000              
            0x00, 0x1F, 0x80, 0x00, ##             000000               
            0x00, 0x1F, 0x80, 0x00, ##             000000               
            0x00, 0x3F, 0x00, 0x00, ##            000000                
            0x00, 0x3F, 0x00, 0x00, ##            000000                
            0x00, 0x7F, 0x00, 0x00, ##           0000000                
            0x00, 0xFE, 0x00, 0x00, ##          0000000                 
            0x3F, 0xFE, 0x00, 0x00, ##    0000000000000                 
            0x3F, 0xFC, 0x00, 0x00, ##    000000000000                  
            0x3F, 0xF8, 0x00, 0x00, ##    00000000000                   
            0x3F, 0xF0, 0x00, 0x00, ##    0000000000                    
            0x3F, 0xC0, 0x00, 0x00, ##    00000000                      
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
};
 
my $kerning = {
    '33' => { },  # !
    '34' => { },  # "
    '35' => { },  # #
    '36' => { },  # $
    '37' => { },  # %
    '38' => { },  # &
    '39' => { },  # '
    '40' => { },  # (
    '41' => { },  # )
    '42' => { },  # *
    '43' => { },  # +
    '44' => { },  # ,
    '45' => { },  # -
    '46' => { },  # .
    '47' => { },  # /
    '48' => { },  # 0
    '49' => { },  # 1
    '50' => { },  # 2
    '51' => { },  # 3
    '52' => { },  # 4
    '53' => { },  # 5
    '54' => { },  # 6
    '55' => { },  # 7
    '56' => { },  # 8
    '57' => { },  # 9
    '58' => { },  # :
    '59' => { },  # ;
    '60' => { },  # <
    '61' => { },  # =
    '62' => { },  # >
    '63' => { },  # ?
    '64' => { },  # @
    '65' => { },  # A
    '66' => { },  # B
    '67' => { },  # C
    '68' => { },  # D
    '69' => { },  # E
    '70' => { },  # F
    '71' => { },  # G
    '72' => { },  # H
    '73' => { },  # I
    '74' => { },  # J
    '75' => { },  # K
    '76' => { },  # L
    '77' => { },  # M
    '78' => { },  # N
    '79' => { },  # O
    '80' => { },  # P
    '81' => { },  # Q
    '82' => { },  # R
    '83' => { },  # S
    '84' => { },  # T
    '85' => { },  # U
    '86' => { },  # V
    '87' => { },  # W
    '88' => { },  # X
    '89' => { },  # Y
    '90' => { },  # Z
    '91' => { },  # [
    '92' => { },  # \
    '93' => { },  # ]
    '94' => { },  # ^
    '95' => { },  # _
    '96' => { },  # `
    '97' => { },  # a
    '98' => { },  # b
    '99' => { },  # c
    '100' => { },  # d
    '101' => { },  # e
    '102' => { },  # f
    '103' => { },  # g
    '104' => { },  # h
    '105' => { },  # i
    '106' => { },  # j
    '107' => { },  # k
    '108' => { },  # l
    '109' => { },  # m
    '110' => { },  # n
    '111' => { },  # o
    '112' => { },  # p
    '113' => { },  # q
    '114' => { },  # r
    '115' => { },  # s
    '116' => { },  # t
    '117' => { },  # u
    '118' => { },  # v
    '119' => { },  # w
    '120' => { },  # x
    '121' => { },  # y
    '122' => { },  # z
    '123' => { },  # {
    '124' => { },  # |
    '125' => { },  # }
    '126' => { },  # ~
    '160' => { },  #  
    '161' => { },  # ¡
    '162' => { },  # ¢
    '163' => { },  # £
    '164' => { },  # ¤
    '165' => { },  # ¥
    '166' => { },  # ¦
    '167' => { },  # §
    '168' => { },  # ¨
    '169' => { },  # ©
    '170' => { },  # ª
    '171' => { },  # «
    '172' => { },  # ¬
    '173' => { },  # ­
    '174' => { },  # ®
    '175' => { },  # ¯
    '176' => { },  # °
    '177' => { },  # ±
    '178' => { },  # ²
    '179' => { },  # ³
    '180' => { },  # ´
    '181' => { },  # µ
    '182' => { },  # ¶
    '183' => { },  # ·
    '184' => { },  # ¸
    '185' => { },  # ¹
    '186' => { },  # º
    '187' => { },  # »
    '188' => { },  # ¼
    '189' => { },  # ½
    '190' => { },  # ¾
    '191' => { },  # ¿
    '192' => { },  # À
    '193' => { },  # Á
    '194' => { },  # Â
    '195' => { },  # Ã
    '196' => { },  # Ä
    '197' => { },  # Å
    '198' => { },  # Æ
    '199' => { },  # Ç
    '200' => { },  # È
    '201' => { },  # É
    '202' => { },  # Ê
    '203' => { },  # Ë
    '204' => { },  # Ì
    '205' => { },  # Í
    '206' => { },  # Î
    '207' => { },  # Ï
    '208' => { },  # Ð
    '209' => { },  # Ñ
    '210' => { },  # Ò
    '211' => { },  # Ó
    '212' => { },  # Ô
    '213' => { },  # Õ
    '214' => { },  # Ö
    '215' => { },  # ×
    '216' => { },  # Ø
    '217' => { },  # Ù
    '218' => { },  # Ú
    '219' => { },  # Û
    '220' => { },  # Ü
    '221' => { },  # Ý
    '222' => { },  # Þ
    '223' => { },  # ß
    '224' => { },  # à
    '225' => { },  # á
    '226' => { },  # â
    '227' => { },  # ã
    '228' => { },  # ä
    '229' => { },  # å
    '230' => { },  # æ
    '231' => { },  # ç
    '232' => { },  # è
    '233' => { },  # é
    '234' => { },  # ê
    '235' => { },  # ë
    '236' => { },  # ì
    '237' => { },  # í
    '238' => { },  # î
    '239' => { },  # ï
    '240' => { },  # ð
    '241' => { },  # ñ
    '242' => { },  # ò
    '243' => { },  # ó
    '244' => { },  # ô
    '245' => { },  # õ
    '246' => { },  # ö
    '247' => { },  # ÷
    '248' => { },  # ø
    '249' => { },  # ù
    '250' => { },  # ú
    '251' => { },  # û
    '252' => { },  # ü
    '253' => { },  # ý
    '254' => { },  # þ
    '255' => { },  # ÿ
};


sub new {
    my($class) = @_;
    
    my $self = $class->SUPER::new(
        name        => $name,
        char_height => $char_height,
        space_width => $space_width,
        gap_width   => $gap_width,
        symbols     => $symbols,
        kerning     => $kerning,
        line_spacing => $line_spacing,
        class       => 'hipi_2',
    );
    
    return $self;
}

1;

__END__
