#########################################################################################
# Package        HiPi::Graphics::BitmapFont::SansExtended30
# Description  : Monochrome OLED Font
# License      : This is free software; you can redistribute it and/or modify it under
#                the same terms as the Perl 5 programming language system itself.
#########################################################################################

package HiPi::Graphics::BitmapFont::SansExtended30;

#########################################################################################

use utf8;
use strict;
use warnings;
use parent qw( HiPi::Graphics::BitmapFont);

our $VERSION ='0.01';

my $gap_width = 0;
my $char_height = 30;
my $line_spacing = 0;
my $name = 'Sans 30';
my $space_width = 8;
 
my $symbols = {
    '33' => {    # '!'
        'width'    => 2, 
        'xoffset'  => 4, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '34' => {    # '"'
        'width'    => 6, 
        'xoffset'  => 2, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xCC, ##  00  00
            0xCC, ##  00  00
            0xCC, ##  00  00
            0xCC, ##  00  00
            0xCC, ##  00  00
            0xCC, ##  00  00
            0xCC, ##  00  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '35' => {    # '#'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x0C, ##        00    00  
            0x03, 0x0C, ##        00    00  
            0x03, 0x18, ##        00   00   
            0x03, 0x18, ##        00   00   
            0x06, 0x18, ##       00    00   
            0x7F, 0xFF, ##   000000000000000
            0x7F, 0xFF, ##   000000000000000
            0x06, 0x30, ##       00   00    
            0x0C, 0x30, ##      00    00    
            0x0C, 0x30, ##      00    00    
            0x0C, 0x60, ##      00   00     
            0xFF, 0xFE, ##  000000000000000 
            0xFF, 0xFE, ##  000000000000000 
            0x18, 0x60, ##     00    00     
            0x18, 0xC0, ##     00   00      
            0x18, 0xC0, ##     00   00      
            0x10, 0xC0, ##     0    00      
            0x30, 0xC0, ##    00    00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '36' => {    # '$'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x04, 0x00, ##       0     
            0x04, 0x00, ##       0     
            0x04, 0x00, ##       0     
            0x3F, 0x80, ##    0000000  
            0x7F, 0xC0, ##   000000000 
            0xE4, 0x40, ##  000  0   0 
            0xC4, 0x00, ##  00   0     
            0xC4, 0x00, ##  00   0     
            0xC4, 0x00, ##  00   0     
            0x74, 0x00, ##   000 0     
            0x3F, 0x00, ##    000000   
            0x0F, 0xC0, ##      000000 
            0x04, 0xE0, ##       0  000
            0x04, 0x60, ##       0   00
            0x04, 0x60, ##       0   00
            0x04, 0x60, ##       0   00
            0xC4, 0xE0, ##  00   0  000
            0xFF, 0xC0, ##  0000000000 
            0x3F, 0x80, ##    0000000  
            0x04, 0x00, ##       0     
            0x04, 0x00, ##       0     
            0x04, 0x00, ##       0     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '37' => {    # '%'
        'width'    => 20, 
        'xoffset'  => 1, 
        'xadvance' => 22, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x3C, 0x03, 0x00, ##    0000        00    
            0x7E, 0x02, 0x00, ##   000000       0     
            0xE7, 0x06, 0x00, ##  000  000     00     
            0xC3, 0x0C, 0x00, ##  00    00    00      
            0xC3, 0x0C, 0x00, ##  00    00    00      
            0xC3, 0x18, 0x00, ##  00    00   00       
            0xE7, 0x10, 0x00, ##  000  000   0        
            0x7E, 0x30, 0x00, ##   000000   00        
            0x3C, 0x63, 0xC0, ##    0000   00   0000  
            0x00, 0x67, 0xE0, ##           00  000000 
            0x00, 0xCE, 0x70, ##          00  000  000
            0x00, 0x8C, 0x30, ##          0   00    00
            0x01, 0x8C, 0x30, ##         00   00    00
            0x03, 0x0C, 0x30, ##        00    00    00
            0x03, 0x0C, 0x30, ##        00    00    00
            0x06, 0x0E, 0x70, ##       00     000  000
            0x04, 0x07, 0xE0, ##       0       000000 
            0x0C, 0x03, 0xC0, ##      00        0000  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '38' => {    # '&'
        'width'    => 17, 
        'xoffset'  => 2, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x0F, 0xC0, 0x00, ##      000000       
            0x1F, 0xE0, 0x00, ##     00000000      
            0x38, 0x60, 0x00, ##    000    00      
            0x30, 0x00, 0x00, ##    00             
            0x30, 0x00, 0x00, ##    00             
            0x30, 0x00, 0x00, ##    00             
            0x18, 0x00, 0x00, ##     00            
            0x3C, 0x00, 0x00, ##    0000           
            0x66, 0x07, 0x00, ##   00  00      000 
            0x63, 0x06, 0x00, ##   00   00     00  
            0xC1, 0x86, 0x00, ##  00     00    00  
            0xC0, 0xC6, 0x00, ##  00      00   00  
            0xC0, 0xEC, 0x00, ##  00      000 00   
            0xC0, 0x7C, 0x00, ##  00       00000   
            0xE0, 0x3C, 0x00, ##  000       0000   
            0x70, 0x7C, 0x00, ##   000     00000   
            0x3F, 0xEE, 0x00, ##    000000000 000  
            0x0F, 0x87, 0x00, ##      00000    000 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '39' => {    # '''
        'width'    => 2, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '40' => {    # '('
        'width'    => 5, 
        'xoffset'  => 2, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x18, ##     00
            0x30, ##    00 
            0x30, ##    00 
            0x20, ##    0  
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0x30, ##    00 
            0x30, ##    00 
            0x18, ##     00
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '41' => {    # ')'
        'width'    => 5, 
        'xoffset'  => 2, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00   
            0x60, ##   00  
            0x60, ##   00  
            0x20, ##    0  
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x60, ##   00  
            0x60, ##   00  
            0xC0, ##  00   
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '42' => {    # '*'
        'width'    => 12, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x06, 0x00, ##       00     
            0x06, 0x00, ##       00     
            0x46, 0x20, ##   0   00   0 
            0x66, 0x60, ##   00  00  00 
            0x1F, 0x80, ##     000000   
            0x06, 0x00, ##       00     
            0x1F, 0x80, ##     000000   
            0x66, 0x60, ##   00  00  00 
            0x46, 0x20, ##   0   00   0 
            0x06, 0x00, ##       00     
            0x06, 0x00, ##       00     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '43' => {    # '+'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0xFF, 0xFE, ##  000000000000000
            0xFF, 0xFE, ##  000000000000000
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '44' => {    # ','
        'width'    => 3, 
        'xoffset'  => 2, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x60, ##   00
            0x60, ##   00
            0x60, ##   00
            0x40, ##   0 
            0xC0, ##  00 
            0xC0, ##  00 
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '45' => {    # '-'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '46' => {    # '.'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '47' => {    # '/'
        'width'    => 8, 
        'xoffset'  => 0, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x03, ##        00
            0x03, ##        00
            0x06, ##       00 
            0x06, ##       00 
            0x06, ##       00 
            0x0C, ##      00  
            0x0C, ##      00  
            0x0C, ##      00  
            0x0C, ##      00  
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x60, ##   00     
            0x60, ##   00     
            0x60, ##   00     
            0x60, ##   00     
            0xC0, ##  00      
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '48' => {    # '0'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0x00, ##      0000    
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0x60, 0x60, ##   00      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x60, ##   00      00 
            0x60, 0x60, ##   00      00 
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x0F, 0x00, ##      0000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '49' => {    # '1'
        'width'    => 10, 
        'xoffset'  => 3, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x7C, 0x00, ##   00000    
            0xFC, 0x00, ##  000000    
            0xEC, 0x00, ##  000 00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0xFF, 0xC0, ##  0000000000
            0xFF, 0xC0, ##  0000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '50' => {    # '2'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3F, 0x00, ##    000000   
            0xFF, 0x80, ##  000000000  
            0xC1, 0xC0, ##  00     000 
            0x00, 0xE0, ##          000
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x00, 0xC0, ##          00 
            0x01, 0xC0, ##         000 
            0x01, 0x80, ##         00  
            0x03, 0x00, ##        00   
            0x06, 0x00, ##       00    
            0x0C, 0x00, ##      00     
            0x18, 0x00, ##     00      
            0x30, 0x00, ##    00       
            0x60, 0x00, ##   00        
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '51' => {    # '3'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x7E, 0x00, ##   000000    
            0xFF, 0x80, ##  000000000  
            0x81, 0xC0, ##  0      000 
            0x00, 0xC0, ##          00 
            0x00, 0xC0, ##          00 
            0x00, 0xC0, ##          00 
            0x01, 0x80, ##         00  
            0x3F, 0x80, ##    0000000  
            0x3E, 0x00, ##    00000    
            0x01, 0x80, ##         00  
            0x00, 0xC0, ##          00 
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x00, 0xE0, ##          000
            0x81, 0xC0, ##  0      000 
            0xFF, 0x80, ##  000000000  
            0x7E, 0x00, ##   000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '52' => {    # '4'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0xC0, ##         000   
            0x03, 0xC0, ##        0000   
            0x03, 0xC0, ##        0000   
            0x06, 0xC0, ##       00 00   
            0x06, 0xC0, ##       00 00   
            0x0C, 0xC0, ##      00  00   
            0x18, 0xC0, ##     00   00   
            0x18, 0xC0, ##     00   00   
            0x30, 0xC0, ##    00    00   
            0x70, 0xC0, ##   000    00   
            0x60, 0xC0, ##   00     00   
            0xC0, 0xC0, ##  00      00   
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0x00, 0xC0, ##          00   
            0x00, 0xC0, ##          00   
            0x00, 0xC0, ##          00   
            0x00, 0xC0, ##          00   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '53' => {    # '5'
        'width'    => 10, 
        'xoffset'  => 2, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x80, ##  000000000 
            0xFF, 0x80, ##  000000000 
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xFE, 0x00, ##  0000000   
            0xFF, 0x00, ##  00000000  
            0x83, 0x80, ##  0     000 
            0x01, 0xC0, ##         000
            0x00, 0xC0, ##          00
            0x00, 0xC0, ##          00
            0x00, 0xC0, ##          00
            0x00, 0xC0, ##          00
            0x01, 0xC0, ##         000
            0x83, 0x80, ##  0     000 
            0xFF, 0x00, ##  00000000  
            0xFE, 0x00, ##  0000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '54' => {    # '6'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xC0, ##       00000  
            0x1F, 0xE0, ##     00000000 
            0x38, 0x20, ##    000     0 
            0x60, 0x00, ##   00         
            0x60, 0x00, ##   00         
            0xC0, 0x00, ##  00          
            0xCF, 0x80, ##  00  00000   
            0xDF, 0xC0, ##  00 0000000  
            0xF0, 0xE0, ##  0000    000 
            0xE0, 0x70, ##  000      000
            0xE0, 0x30, ##  000       00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x30, ##   00       00
            0x60, 0x70, ##   00      000
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x0F, 0x80, ##      00000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '55' => {    # '7'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0xC0, ##          00 
            0x00, 0xC0, ##          00 
            0x01, 0xC0, ##         000 
            0x01, 0x80, ##         00  
            0x01, 0x80, ##         00  
            0x03, 0x80, ##        000  
            0x03, 0x00, ##        00   
            0x07, 0x00, ##       000   
            0x07, 0x00, ##       000   
            0x06, 0x00, ##       00    
            0x0E, 0x00, ##      000    
            0x0C, 0x00, ##      00     
            0x0C, 0x00, ##      00     
            0x1C, 0x00, ##     000     
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '56' => {    # '8'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x80, ##     000000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0x60, 0x60, ##   00      00 
            0x60, 0x60, ##   00      00 
            0x70, 0xC0, ##   000    00  
            0x3F, 0x80, ##    0000000   
            0x0F, 0xC0, ##      000000  
            0x30, 0xE0, ##    00    000 
            0x60, 0x70, ##   00      000
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xE0, 0x70, ##  000      000
            0x70, 0xE0, ##   000    000 
            0x7F, 0xE0, ##   0000000000 
            0x1F, 0x80, ##     000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '57' => {    # '9'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x00, ##     00000    
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0xE0, 0x60, ##  000      00 
            0xC0, 0x60, ##  00       00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x70, ##  00       000
            0xE0, 0x70, ##  000      000
            0x70, 0xF0, ##   000    0000
            0x3F, 0xB0, ##    0000000 00
            0x1F, 0x30, ##     00000  00
            0x00, 0x30, ##            00
            0x00, 0x60, ##           00 
            0x00, 0x60, ##           00 
            0x41, 0xC0, ##   0     000  
            0x7F, 0x80, ##   00000000   
            0x3E, 0x00, ##    00000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '58' => {    # ':'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '59' => {    # ';'
        'width'    => 3, 
        'xoffset'  => 2, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x60, ##   00
            0x60, ##   00
            0x60, ##   00
            0x00, ##     
            0x00, ##     
            0x00, ##     
            0x00, ##     
            0x00, ##     
            0x00, ##     
            0x00, ##     
            0x60, ##   00
            0x60, ##   00
            0x60, ##   00
            0x40, ##   0 
            0xC0, ##  00 
            0xC0, ##  00 
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '60' => {    # '<'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##                 
            0x00, 0x0E, ##              000
            0x00, 0x3E, ##            00000
            0x01, 0xF8, ##         000000  
            0x0F, 0xC0, ##      000000     
            0x3E, 0x00, ##    00000        
            0xF8, 0x00, ##  00000          
            0xF0, 0x00, ##  0000           
            0x7E, 0x00, ##   000000        
            0x1F, 0x80, ##     000000      
            0x03, 0xF0, ##        000000   
            0x00, 0x7E, ##           000000
            0x00, 0x1E, ##             0000
            0x00, 0x02, ##                0
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '61' => {    # '='
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFE, ##  000000000000000
            0xFF, 0xFE, ##  000000000000000
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0xFF, 0xFE, ##  000000000000000
            0xFF, 0xFE, ##  000000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '62' => {    # '>'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##                 
            0xE0, 0x00, ##  000            
            0xF8, 0x00, ##  00000          
            0x3F, 0x00, ##    000000       
            0x07, 0xE0, ##       000000    
            0x00, 0xF8, ##          00000  
            0x00, 0x3E, ##            00000
            0x00, 0x1E, ##             0000
            0x00, 0xFC, ##          000000 
            0x03, 0xF0, ##        000000   
            0x1F, 0x80, ##     000000      
            0xFC, 0x00, ##  000000         
            0xF0, 0x00, ##  0000           
            0x80, 0x00, ##  0              
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '63' => {    # '?'
        'width'    => 9, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0x00, ##    00000  
            0xFF, 0x00, ##  00000000 
            0xC3, 0x80, ##  00    000
            0x01, 0x80, ##         00
            0x01, 0x80, ##         00
            0x01, 0x80, ##         00
            0x03, 0x00, ##        00 
            0x06, 0x00, ##       00  
            0x0C, 0x00, ##      00   
            0x1C, 0x00, ##     000   
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x00, 0x00, ##           
            0x00, 0x00, ##           
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '64' => {    # '@'
        'width'    => 21, 
        'xoffset'  => 2, 
        'xadvance' => 25, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0xFC, 0x00, ##          000000       
            0x07, 0xFF, 0x00, ##       00000000000     
            0x0F, 0x03, 0xC0, ##      0000      0000   
            0x1C, 0x00, 0xE0, ##     000          000  
            0x38, 0x00, 0x60, ##    000            00  
            0x70, 0x00, 0x30, ##   000              00 
            0x61, 0xE0, 0x30, ##   00    0000       00 
            0x63, 0xFE, 0x18, ##   00   000000000    00
            0xC3, 0x0E, 0x18, ##  00    00    000    00
            0xC6, 0x06, 0x18, ##  00   00      00    00
            0xC6, 0x06, 0x18, ##  00   00      00    00
            0xC6, 0x06, 0x18, ##  00   00      00    00
            0xC6, 0x06, 0x38, ##  00   00      00   000
            0xC6, 0x06, 0x30, ##  00   00      00   00 
            0xE3, 0x0E, 0x60, ##  000   00    000  00  
            0x63, 0xFF, 0xC0, ##   00   000000000000   
            0x71, 0xE7, 0x00, ##   000   0000  000     
            0x38, 0x00, 0x00, ##    000                
            0x1C, 0x00, 0x00, ##     000               
            0x0F, 0x03, 0x80, ##      0000      000    
            0x07, 0xFF, 0x00, ##       00000000000     
            0x01, 0xF8, 0x00, ##         000000        
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '65' => {    # 'A'
        'width'    => 16, 
        'xoffset'  => 0, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0xC0, ##         000      
            0x03, 0xC0, ##        0000      
            0x03, 0xC0, ##        0000      
            0x03, 0x60, ##        00 00     
            0x06, 0x60, ##       00  00     
            0x06, 0x70, ##       00  000    
            0x0E, 0x30, ##      000   00    
            0x0C, 0x30, ##      00    00    
            0x0C, 0x18, ##      00     00   
            0x1C, 0x18, ##     000     00   
            0x18, 0x18, ##     00      00   
            0x1F, 0xFC, ##     00000000000  
            0x3F, 0xFC, ##    000000000000  
            0x30, 0x0E, ##    00        000 
            0x70, 0x06, ##   000         00 
            0x70, 0x06, ##   000         00 
            0x60, 0x07, ##   00          000
            0xE0, 0x03, ##  000           00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '66' => {    # 'B'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x00, ##  00000000    
            0xFF, 0xC0, ##  0000000000  
            0xC0, 0xE0, ##  00      000 
            0xC0, 0x60, ##  00       00 
            0xC0, 0x60, ##  00       00 
            0xC0, 0x60, ##  00       00 
            0xC0, 0xC0, ##  00      00  
            0xFF, 0xC0, ##  0000000000  
            0xFF, 0xC0, ##  0000000000  
            0xC0, 0xE0, ##  00      000 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0xE0, ##  00      000 
            0xFF, 0xE0, ##  00000000000 
            0xFF, 0x80, ##  000000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '67' => {    # 'C'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xF0, ##       0000000  
            0x1F, 0xFC, ##     00000000000
            0x3C, 0x1C, ##    0000     000
            0x70, 0x04, ##   000         0
            0x60, 0x00, ##   00           
            0xE0, 0x00, ##  000           
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xE0, 0x00, ##  000           
            0x60, 0x00, ##   00           
            0x70, 0x04, ##   000         0
            0x3C, 0x1C, ##    0000     000
            0x1F, 0xFC, ##     00000000000
            0x07, 0xF0, ##       0000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '68' => {    # 'D'
        'width'    => 14, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x80, ##  000000000     
            0xFF, 0xE0, ##  00000000000   
            0xC0, 0xF0, ##  00      0000  
            0xC0, 0x38, ##  00        000 
            0xC0, 0x18, ##  00         00 
            0xC0, 0x1C, ##  00         000
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x1C, ##  00         000
            0xC0, 0x18, ##  00         00 
            0xC0, 0x38, ##  00        000 
            0xC0, 0xF0, ##  00      0000  
            0xFF, 0xE0, ##  00000000000   
            0xFF, 0x80, ##  000000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '69' => {    # 'E'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '70' => {    # 'F'
        'width'    => 10, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xC0, ##  0000000000
            0xFF, 0xC0, ##  0000000000
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xFF, 0xC0, ##  0000000000
            0xFF, 0xC0, ##  0000000000
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '71' => {    # 'G'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xF0, ##       0000000   
            0x1F, 0xFC, ##     00000000000 
            0x3C, 0x0E, ##    0000      000
            0x70, 0x02, ##   000          0
            0x60, 0x00, ##   00            
            0xE0, 0x00, ##  000            
            0xC0, 0x00, ##  00             
            0xC0, 0x00, ##  00             
            0xC0, 0x7E, ##  00       000000
            0xC0, 0x7E, ##  00       000000
            0xC0, 0x06, ##  00           00
            0xC0, 0x06, ##  00           00
            0xE0, 0x06, ##  000          00
            0x60, 0x06, ##   00          00
            0x70, 0x06, ##   000         00
            0x3C, 0x0E, ##    0000      000
            0x1F, 0xFC, ##     00000000000 
            0x07, 0xF0, ##       0000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '72' => {    # 'H'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xFF, 0xF8, ##  0000000000000
            0xFF, 0xF8, ##  0000000000000
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '73' => {    # 'I'
        'width'    => 2, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '74' => {    # 'J'
        'width'    => 5, 
        'xoffset'  => -1, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x30, ##    00 
            0xF0, ##  0000 
            0xE0, ##  000  
            0x00, ##  
        ], 
    }, 
    '75' => {    # 'K'
        'width'    => 14, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x70, ##  00       000  
            0xC0, 0xE0, ##  00      000   
            0xC1, 0xC0, ##  00     000    
            0xC3, 0x80, ##  00    000     
            0xC7, 0x00, ##  00   000      
            0xCE, 0x00, ##  00  000       
            0xDC, 0x00, ##  00 000        
            0xF8, 0x00, ##  00000         
            0xF0, 0x00, ##  0000          
            0xF8, 0x00, ##  00000         
            0xDC, 0x00, ##  00 000        
            0xCE, 0x00, ##  00  000       
            0xC7, 0x00, ##  00   000      
            0xC3, 0x80, ##  00    000     
            0xC1, 0xC0, ##  00     000    
            0xC0, 0xE0, ##  00      000   
            0xC0, 0x70, ##  00       000  
            0xC0, 0x38, ##  00        000 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '76' => {    # 'L'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '77' => {    # 'M'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x07, ##  000          000
            0xF0, 0x0F, ##  0000        0000
            0xF0, 0x0F, ##  0000        0000
            0xD8, 0x1F, ##  00 00      00000
            0xD8, 0x1B, ##  00 00      00 00
            0xD8, 0x1B, ##  00 00      00 00
            0xCC, 0x33, ##  00  00    00  00
            0xCC, 0x33, ##  00  00    00  00
            0xCE, 0x73, ##  00  000  000  00
            0xC6, 0x63, ##  00   00  00   00
            0xC6, 0x63, ##  00   00  00   00
            0xC3, 0xC3, ##  00    0000    00
            0xC3, 0xC3, ##  00    0000    00
            0xC3, 0xC3, ##  00    0000    00
            0xC1, 0x83, ##  00     00     00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '78' => {    # 'N'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x18, ##  000        00
            0xF0, 0x18, ##  0000       00
            0xF0, 0x18, ##  0000       00
            0xF8, 0x18, ##  00000      00
            0xD8, 0x18, ##  00 00      00
            0xDC, 0x18, ##  00 000     00
            0xCC, 0x18, ##  00  00     00
            0xCE, 0x18, ##  00  000    00
            0xC6, 0x18, ##  00   00    00
            0xC3, 0x18, ##  00    00   00
            0xC3, 0x98, ##  00    000  00
            0xC1, 0x98, ##  00     00  00
            0xC1, 0xD8, ##  00     000 00
            0xC0, 0xD8, ##  00      00 00
            0xC0, 0xF8, ##  00      00000
            0xC0, 0x78, ##  00       0000
            0xC0, 0x78, ##  00       0000
            0xC0, 0x38, ##  00        000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '79' => {    # 'O'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xE0, ##       000000     
            0x1F, 0xF8, ##     0000000000   
            0x3C, 0x3C, ##    0000    0000  
            0x70, 0x0E, ##   000        000 
            0x60, 0x06, ##   00          00 
            0xE0, 0x07, ##  000          000
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xE0, 0x07, ##  000          000
            0x60, 0x06, ##   00          00 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1F, 0xF8, ##     0000000000   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '80' => {    # 'P'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x00, ##  00000000   
            0xFF, 0xC0, ##  0000000000 
            0xC1, 0xC0, ##  00     000 
            0xC0, 0xE0, ##  00      000
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xC1, 0xC0, ##  00     000 
            0xFF, 0xC0, ##  0000000000 
            0xFF, 0x00, ##  00000000   
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '81' => {    # 'Q'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xE0, ##       000000     
            0x1F, 0xF8, ##     0000000000   
            0x3C, 0x3C, ##    0000    0000  
            0x70, 0x0E, ##   000        000 
            0x60, 0x06, ##   00          00 
            0xE0, 0x06, ##  000          00 
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xE0, 0x07, ##  000          000
            0x60, 0x06, ##   00          00 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1F, 0xF8, ##     0000000000   
            0x07, 0xF0, ##       0000000    
            0x00, 0x30, ##            00    
            0x00, 0x38, ##            000   
            0x00, 0x1C, ##             000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '82' => {    # 'R'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x00, ##  00000000     
            0xFF, 0xC0, ##  0000000000   
            0xC0, 0xC0, ##  00      00   
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0xE0, ##  00      000  
            0xFF, 0xC0, ##  0000000000   
            0xFF, 0x00, ##  00000000     
            0xC1, 0x80, ##  00     00    
            0xC0, 0xC0, ##  00      00   
            0xC0, 0xE0, ##  00      000  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x70, ##  00       000 
            0xC0, 0x30, ##  00        00 
            0xC0, 0x38, ##  00        000
            0xC0, 0x18, ##  00         00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '83' => {    # 'S'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0xC0, ##     0000000  
            0x7F, 0xE0, ##   0000000000 
            0x70, 0x60, ##   000     00 
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xE0, 0x00, ##  000         
            0x78, 0x00, ##   0000       
            0x3F, 0x80, ##    0000000   
            0x07, 0xE0, ##       000000 
            0x00, 0xE0, ##          000 
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0xE0, 0xE0, ##  000     000 
            0xFF, 0xE0, ##  00000000000 
            0x3F, 0x80, ##    0000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '84' => {    # 'T'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFE, ##  000000000000000
            0xFF, 0xFE, ##  000000000000000
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '85' => {    # 'U'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0x60, 0x30, ##   00       00 
            0x70, 0x70, ##   000     000 
            0x3F, 0xE0, ##    000000000  
            0x0F, 0x80, ##      00000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '86' => {    # 'V'
        'width'    => 16, 
        'xoffset'  => 0, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x03, ##  000           00
            0x60, 0x07, ##   00          000
            0x70, 0x06, ##   000         00 
            0x70, 0x0E, ##   000        000 
            0x30, 0x0E, ##    00        000 
            0x38, 0x0C, ##    000       00  
            0x18, 0x1C, ##     00      000  
            0x18, 0x18, ##     00      00   
            0x1C, 0x18, ##     000     00   
            0x0C, 0x38, ##      00    000   
            0x0E, 0x30, ##      000   00    
            0x0E, 0x30, ##      000   00    
            0x06, 0x70, ##       00  000    
            0x07, 0x60, ##       000 00     
            0x03, 0xE0, ##        00000     
            0x03, 0xC0, ##        0000      
            0x03, 0xC0, ##        0000      
            0x01, 0xC0, ##         000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '87' => {    # 'W'
        'width'    => 22, 
        'xoffset'  => 1, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xC0, 0x70, 0x1C, ##  00       000       000
            0xE0, 0x78, 0x1C, ##  000      0000      000
            0xE0, 0x78, 0x18, ##  000      0000      00 
            0x60, 0x78, 0x18, ##   00      0000      00 
            0x60, 0xD8, 0x38, ##   00     00 00     000 
            0x70, 0xCC, 0x38, ##   000    00  00    000 
            0x70, 0xCC, 0x30, ##   000    00  00    00  
            0x30, 0xCC, 0x30, ##    00    00  00    00  
            0x31, 0x8C, 0x70, ##    00   00   00   000  
            0x31, 0x84, 0x70, ##    00   00    0   000  
            0x39, 0x86, 0x60, ##    000  00    00  00   
            0x19, 0x86, 0x60, ##     00  00    00  00   
            0x19, 0x06, 0x60, ##     00  0     00  00   
            0x1B, 0x02, 0xE0, ##     00 00      0 000   
            0x1F, 0x03, 0xC0, ##     00000      0000    
            0x0F, 0x03, 0xC0, ##      0000      0000    
            0x0F, 0x03, 0xC0, ##      0000      0000    
            0x0E, 0x03, 0xC0, ##      000       0000    
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '88' => {    # 'X'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x60, 0x1C, ##   00        000 
            0x70, 0x18, ##   000       00  
            0x38, 0x38, ##    000     000  
            0x18, 0x70, ##     00    000   
            0x1C, 0x60, ##     000   00    
            0x0E, 0xE0, ##      000 000    
            0x06, 0xC0, ##       00 00     
            0x07, 0x80, ##       0000      
            0x03, 0x80, ##        000      
            0x07, 0x80, ##       0000      
            0x07, 0xC0, ##       00000     
            0x0E, 0xE0, ##      000 000    
            0x1C, 0x60, ##     000   00    
            0x18, 0x70, ##     00    000   
            0x38, 0x30, ##    000     00   
            0x70, 0x18, ##   000       00  
            0x60, 0x1C, ##   00        000 
            0xE0, 0x0C, ##  000         00 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '89' => {    # 'Y'
        'width'    => 14, 
        'xoffset'  => 0, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x1C, ##  000        000
            0x60, 0x18, ##   00        00 
            0x70, 0x38, ##   000      000 
            0x38, 0x70, ##    000    000  
            0x18, 0x60, ##     00    00   
            0x1C, 0xE0, ##     000  000   
            0x0C, 0xC0, ##      00  00    
            0x07, 0x80, ##       0000     
            0x07, 0x80, ##       0000     
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '90' => {    # 'Z'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0x00, 0x18, ##             00 
            0x00, 0x38, ##            000 
            0x00, 0x70, ##           000  
            0x00, 0xE0, ##          000   
            0x01, 0xC0, ##         000    
            0x01, 0x80, ##         00     
            0x03, 0x80, ##        000     
            0x07, 0x00, ##       000      
            0x0E, 0x00, ##      000       
            0x0C, 0x00, ##      00        
            0x1C, 0x00, ##     000        
            0x38, 0x00, ##    000         
            0x70, 0x00, ##   000          
            0x60, 0x00, ##   00           
            0xFF, 0xFC, ##  00000000000000
            0xFF, 0xFC, ##  00000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '91' => {    # '['
        'width'    => 5, 
        'xoffset'  => 2, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF8, ##  00000
            0xF8, ##  00000
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xF8, ##  00000
            0xF8, ##  00000
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '92' => {    # '\'
        'width'    => 8, 
        'xoffset'  => 0, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00      
            0xC0, ##  00      
            0x60, ##   00     
            0x60, ##   00     
            0x60, ##   00     
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x0C, ##      00  
            0x0C, ##      00  
            0x0C, ##      00  
            0x06, ##       00 
            0x06, ##       00 
            0x06, ##       00 
            0x07, ##       000
            0x03, ##        00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '93' => {    # ']'
        'width'    => 5, 
        'xoffset'  => 2, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF8, ##  00000
            0xF8, ##  00000
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0xF8, ##  00000
            0xF8, ##  00000
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '94' => {    # '^'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0x80, ##       0000      
            0x07, 0xC0, ##       00000     
            0x0E, 0xC0, ##      000 00     
            0x1C, 0x60, ##     000   00    
            0x38, 0x30, ##    000     00   
            0x60, 0x18, ##   00        00  
            0xC0, 0x0C, ##  00          00 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '95' => {    # '_'
        'width'    => 12, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xF0, ##  000000000000
            0xFF, 0xF0, ##  000000000000
        ], 
    }, 
    '96' => {    # '`'
        'width'    => 6, 
        'xoffset'  => 2, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00    
            0x60, ##   00   
            0x30, ##    00  
            0x18, ##     00 
            0x18, ##     00 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '97' => {    # 'a'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3F, 0x00, ##    000000   
            0x7F, 0xC0, ##   000000000 
            0x40, 0xC0, ##   0      00 
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x1F, 0xE0, ##     00000000
            0x7F, 0xE0, ##   0000000000
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xE1, 0xE0, ##  000    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '98' => {    # 'b'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xCF, 0x80, ##  00  00000   
            0xDF, 0xC0, ##  00 0000000  
            0xF0, 0xE0, ##  0000    000 
            0xE0, 0x60, ##  000      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xE0, 0x60, ##  000      00 
            0xF0, 0xE0, ##  0000    000 
            0xDF, 0xC0, ##  00 0000000  
            0xCF, 0x80, ##  00  00000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '99' => {    # 'c'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xC0, ##      000000 
            0x3F, 0xE0, ##    000000000
            0x70, 0x60, ##   000     00
            0x60, 0x00, ##   00        
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0x60, 0x00, ##   00        
            0x70, 0x60, ##   000     00
            0x3F, 0xE0, ##    000000000
            0x0F, 0xC0, ##      000000 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '100' => {    # 'd'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x1F, 0x30, ##     00000  00
            0x3F, 0xB0, ##    0000000 00
            0x70, 0xF0, ##   000    0000
            0x60, 0x70, ##   00      000
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x70, ##   00      000
            0x70, 0xF0, ##   000    0000
            0x3F, 0xB0, ##    0000000 00
            0x1F, 0x30, ##     00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '101' => {    # 'e'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0x80, ##      00000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x30, ##   00       00
            0xC0, 0x30, ##  00        00
            0xFF, 0xF0, ##  000000000000
            0xFF, 0xF0, ##  000000000000
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0x60, 0x00, ##   00         
            0x70, 0x30, ##   000      00
            0x3F, 0xF0, ##    0000000000
            0x0F, 0xC0, ##      000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '102' => {    # 'f'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0x80, ##      00000
            0x1F, 0x80, ##     000000
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0xFF, 0x00, ##  00000000 
            0xFF, 0x00, ##  00000000 
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '103' => {    # 'g'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x30, ##     00000  00
            0x3F, 0xB0, ##    0000000 00
            0x70, 0xF0, ##   000    0000
            0x60, 0x70, ##   00      000
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x70, ##   00      000
            0x70, 0xF0, ##   000    0000
            0x3F, 0xB0, ##    0000000 00
            0x1F, 0x30, ##     00000  00
            0x00, 0x30, ##            00
            0x00, 0x60, ##           00 
            0x40, 0xE0, ##   0      000 
            0x7F, 0xC0, ##   000000000  
            0x3F, 0x80, ##    0000000   
            0x00, 0x00, ##  
        ], 
    }, 
    '104' => {    # 'h'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xCF, 0x80, ##  00  00000  
            0xDF, 0xC0, ##  00 0000000 
            0xF0, 0xC0, ##  0000    00 
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '105' => {    # 'i'
        'width'    => 2, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##    
            0x00, ##    
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '106' => {    # 'j'
        'width'    => 4, 
        'xoffset'  => 0, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x00, ##      
            0x00, ##      
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x70, ##   000
            0xE0, ##  000 
            0xC0, ##  00  
            0x00, ##  
        ], 
    }, 
    '107' => {    # 'k'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0xE0, ##  00      000
            0xC1, 0xC0, ##  00     000 
            0xC3, 0x80, ##  00    000  
            0xC6, 0x00, ##  00   00    
            0xCC, 0x00, ##  00  00     
            0xD8, 0x00, ##  00 00      
            0xF0, 0x00, ##  0000       
            0xF8, 0x00, ##  00000      
            0xDC, 0x00, ##  00 000     
            0xCE, 0x00, ##  00  000    
            0xC7, 0x00, ##  00   000   
            0xC3, 0x80, ##  00    000  
            0xC1, 0xC0, ##  00     000 
            0xC0, 0xE0, ##  00      000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '108' => {    # 'l'
        'width'    => 2, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '109' => {    # 'm'
        'width'    => 20, 
        'xoffset'  => 2, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xCF, 0x87, 0xC0, ##  00  00000    00000  
            0xDF, 0xCF, 0xE0, ##  00 0000000  0000000 
            0xF0, 0xD8, 0x60, ##  0000    00 00    00 
            0xE0, 0x70, 0x30, ##  000      000      00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0xC0, 0x60, 0x30, ##  00       00       00
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '110' => {    # 'n'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xCF, 0x80, ##  00  00000  
            0xDF, 0xC0, ##  00 0000000 
            0xF0, 0xC0, ##  0000    00 
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '111' => {    # 'o'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x80, ##     000000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x60, ##   00      00 
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x1F, 0x80, ##     000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '112' => {    # 'p'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xCF, 0x80, ##  00  00000   
            0xDF, 0xC0, ##  00 0000000  
            0xF0, 0xE0, ##  0000    000 
            0xE0, 0x60, ##  000      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xE0, 0x60, ##  000      00 
            0xF0, 0xE0, ##  0000    000 
            0xDF, 0xC0, ##  00 0000000  
            0xCF, 0x80, ##  00  00000   
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0x00, 0x00, ##  
        ], 
    }, 
    '113' => {    # 'q'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x30, ##     00000  00
            0x3F, 0xB0, ##    0000000 00
            0x70, 0xF0, ##   000    0000
            0x60, 0x70, ##   00      000
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x70, ##   00      000
            0x70, 0xF0, ##   000    0000
            0x3F, 0xB0, ##    0000000 00
            0x1F, 0x30, ##     00000  00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x30, ##            00
            0x00, 0x00, ##  
        ], 
    }, 
    '114' => {    # 'r'
        'width'    => 8, 
        'xoffset'  => 2, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xCF, ##  00  0000
            0xDF, ##  00 00000
            0xF0, ##  0000    
            0xE0, ##  000     
            0xC0, ##  00      
            0xC0, ##  00      
            0xC0, ##  00      
            0xC0, ##  00      
            0xC0, ##  00      
            0xC0, ##  00      
            0xC0, ##  00      
            0xC0, ##  00      
            0xC0, ##  00      
            0xC0, ##  00      
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '115' => {    # 's'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3F, 0x80, ##    0000000 
            0x7F, 0x80, ##   00000000 
            0xE0, 0x80, ##  000     0 
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xE0, 0x00, ##  000       
            0x7E, 0x00, ##   000000   
            0x0F, 0x80, ##      00000 
            0x01, 0xC0, ##         000
            0x00, 0xC0, ##          00
            0x00, 0xC0, ##          00
            0xC1, 0xC0, ##  00     000
            0xFF, 0x80, ##  000000000 
            0x7F, 0x00, ##   0000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '116' => {    # 't'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0xFF, ##  00000000
            0xFF, ##  00000000
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x3F, ##    000000
            0x1F, ##     00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '117' => {    # 'u'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0x61, 0xE0, ##   00    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '118' => {    # 'v'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x30, ##  00        00
            0xE0, 0x30, ##  000       00
            0x60, 0x70, ##   00      000
            0x60, 0x60, ##   00      00 
            0x70, 0x60, ##   000     00 
            0x30, 0xE0, ##    00    000 
            0x30, 0xC0, ##    00    00  
            0x38, 0xC0, ##    000   00  
            0x19, 0xC0, ##     00  000  
            0x19, 0x80, ##     00  00   
            0x1D, 0x80, ##     000 00   
            0x0F, 0x00, ##      0000    
            0x0F, 0x00, ##      0000    
            0x0F, 0x00, ##      0000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '119' => {    # 'w'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xC1, 0xC1, 0xC0, ##  00     000     000
            0xE1, 0xC1, 0x80, ##  000    000     00 
            0x61, 0xE1, 0x80, ##   00    0000    00 
            0x61, 0xE1, 0x80, ##   00    0000    00 
            0x63, 0x63, 0x80, ##   00   00 00   000 
            0x73, 0x23, 0x00, ##   000  00  0   00  
            0x33, 0x33, 0x00, ##    00  00  00  00  
            0x33, 0x33, 0x00, ##    00  00  00  00  
            0x36, 0x37, 0x00, ##    00 00   00 000  
            0x3E, 0x16, 0x00, ##    00000    0 00   
            0x1E, 0x1E, 0x00, ##     0000    0000   
            0x1E, 0x1E, 0x00, ##     0000    0000   
            0x1C, 0x1E, 0x00, ##     000     0000   
            0x1C, 0x0C, 0x00, ##     000      00    
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '120' => {    # 'x'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x70, ##  000      000
            0x70, 0x60, ##   000     00 
            0x30, 0xC0, ##    00    00  
            0x19, 0xC0, ##     00  000  
            0x1F, 0x80, ##     000000   
            0x0F, 0x00, ##      0000    
            0x07, 0x00, ##       000    
            0x0F, 0x00, ##      0000    
            0x0F, 0x80, ##      00000   
            0x19, 0x80, ##     00  00   
            0x39, 0xC0, ##    000  000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0xE0, 0x30, ##  000       00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '121' => {    # 'y'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x30, ##  00        00 
            0xE0, 0x30, ##  000       00 
            0x60, 0x70, ##   00      000 
            0x60, 0x60, ##   00      00  
            0x30, 0x60, ##    00     00  
            0x30, 0xC0, ##    00    00   
            0x38, 0xC0, ##    000   00   
            0x19, 0xC0, ##     00  000   
            0x19, 0x80, ##     00  00    
            0x0D, 0x80, ##      00 00    
            0x0F, 0x80, ##      00000    
            0x0F, 0x00, ##      0000     
            0x07, 0x00, ##       000     
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x0E, 0x00, ##      000      
            0x0C, 0x00, ##      00       
            0x7C, 0x00, ##   00000       
            0x78, 0x00, ##   0000        
            0x00, 0x00, ##  
        ], 
    }, 
    '122' => {    # 'z'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xC0, ##  0000000000
            0xFF, 0xC0, ##  0000000000
            0x01, 0xC0, ##         000
            0x03, 0x80, ##        000 
            0x03, 0x00, ##        00  
            0x06, 0x00, ##       00   
            0x0E, 0x00, ##      000   
            0x1C, 0x00, ##     000    
            0x18, 0x00, ##     00     
            0x30, 0x00, ##    00      
            0x60, 0x00, ##   00       
            0xC0, 0x00, ##  00        
            0xFF, 0xC0, ##  0000000000
            0xFF, 0xC0, ##  0000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '123' => {    # '{'
        'width'    => 9, 
        'xoffset'  => 3, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0x80, ##       0000
            0x0F, 0x80, ##      00000
            0x1C, 0x00, ##     000   
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x38, 0x00, ##    000    
            0xF0, 0x00, ##  0000     
            0xF0, 0x00, ##  0000     
            0x38, 0x00, ##    000    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x1C, 0x00, ##     000   
            0x1F, 0x80, ##     000000
            0x07, 0x80, ##       0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '124' => {    # '|'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
        ], 
    }, 
    '125' => {    # '}'
        'width'    => 9, 
        'xoffset'  => 3, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x00, ##  000      
            0xF0, 0x00, ##  0000     
            0x38, 0x00, ##    000    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x1C, 0x00, ##     000   
            0x0F, 0x80, ##      00000
            0x0F, 0x80, ##      00000
            0x1C, 0x00, ##     000   
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x18, 0x00, ##     00    
            0x38, 0x00, ##    000    
            0xF8, 0x00, ##  00000    
            0xE0, 0x00, ##  000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '126' => {    # '~'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0x02, ##    00000       0
            0x7F, 0x86, ##   00000000    00
            0xC3, 0xFC, ##  00    00000000 
            0x80, 0xF8, ##  0       00000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '160' => {    # ' '
        'width'    => 0, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
        ], 
    }, 
    '161' => {    # '¡'
        'width'    => 2, 
        'xoffset'  => 4, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '162' => {    # '¢'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x02, 0x00, ##        0    
            0x02, 0x00, ##        0    
            0x02, 0x00, ##        0    
            0x02, 0x00, ##        0    
            0x0F, 0xC0, ##      000000 
            0x3F, 0xE0, ##    000000000
            0x72, 0x60, ##   000  0  00
            0x62, 0x00, ##   00   0    
            0xE2, 0x00, ##  000   0    
            0xC2, 0x00, ##  00    0    
            0xC2, 0x00, ##  00    0    
            0xC2, 0x00, ##  00    0    
            0xC2, 0x00, ##  00    0    
            0xC2, 0x00, ##  00    0    
            0x62, 0x00, ##   00   0    
            0x72, 0x00, ##   000  0    
            0x3F, 0xE0, ##    000000000
            0x1F, 0xE0, ##     00000000
            0x02, 0x00, ##        0    
            0x02, 0x00, ##        0    
            0x02, 0x00, ##        0    
            0x02, 0x00, ##        0    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '163' => {    # '£'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xC0, ##       00000 
            0x0F, 0xE0, ##      0000000
            0x1C, 0x20, ##     000    0
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x7F, 0xC0, ##   000000000 
            0x7F, 0xC0, ##   000000000 
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0x18, 0x00, ##     00      
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '164' => {    # '¤'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##                
            0x60, 0x18, ##   00        00 
            0x77, 0xB8, ##   000 0000 000 
            0x3F, 0xF0, ##    0000000000  
            0x18, 0x60, ##     00    00   
            0x30, 0x30, ##    00      00  
            0x30, 0x30, ##    00      00  
            0x30, 0x30, ##    00      00  
            0x30, 0x30, ##    00      00  
            0x18, 0x60, ##     00    00   
            0x3F, 0xF0, ##    0000000000  
            0x77, 0xB8, ##   000 0000 000 
            0x60, 0x18, ##   00        00 
            0x00, 0x00, ##                
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '165' => {    # '¥'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x60, 0x18, ##   00        00 
            0x60, 0x18, ##   00        00 
            0x30, 0x30, ##    00      00  
            0x30, 0x30, ##    00      00  
            0x18, 0x60, ##     00    00   
            0x18, 0x60, ##     00    00   
            0x0C, 0xC0, ##      00  00    
            0x7C, 0xF8, ##   00000  00000 
            0x7F, 0xF8, ##   000000000000 
            0x07, 0x80, ##       0000     
            0x03, 0x00, ##        00      
            0x7F, 0xF8, ##   000000000000 
            0x7F, 0xF8, ##   000000000000 
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '166' => {    # '¦'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '167' => {    # '§'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x00, ##     00000  
            0x3F, 0x80, ##    0000000 
            0x70, 0x80, ##   000    0 
            0x60, 0x00, ##   00       
            0x60, 0x00, ##   00       
            0x70, 0x00, ##   000      
            0x3C, 0x00, ##    0000    
            0x6F, 0x00, ##   00 0000  
            0xC3, 0x80, ##  00    000 
            0xC1, 0xC0, ##  00     000
            0xC0, 0xC0, ##  00      00
            0xE0, 0xC0, ##  000     00
            0x78, 0xC0, ##   0000   00
            0x1F, 0x80, ##     000000 
            0x07, 0x00, ##       000  
            0x03, 0x80, ##        000 
            0x01, 0x80, ##         00 
            0x01, 0x80, ##         00 
            0x43, 0x80, ##   0    000 
            0x7F, 0x00, ##   0000000  
            0x3E, 0x00, ##    00000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '168' => {    # '¨'
        'width'    => 7, 
        'xoffset'  => 3, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC6, ##  00   00
            0xC6, ##  00   00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '169' => {    # '©'
        'width'    => 17, 
        'xoffset'  => 3, 
        'xadvance' => 23, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x03, 0xE0, 0x00, ##        00000      
            0x0C, 0x18, 0x00, ##      00     00    
            0x10, 0x04, 0x00, ##     0         0   
            0x23, 0xE2, 0x00, ##    0   00000   0  
            0x47, 0xF1, 0x00, ##   0   0000000   0 
            0x4E, 0x11, 0x00, ##   0  000    0   0 
            0x9C, 0x00, 0x80, ##  0  000          0
            0x98, 0x00, 0x80, ##  0  00           0
            0x98, 0x00, 0x80, ##  0  00           0
            0x98, 0x00, 0x80, ##  0  00           0
            0x98, 0x00, 0x80, ##  0  00           0
            0x9C, 0x00, 0x80, ##  0  000          0
            0x4E, 0x11, 0x00, ##   0  000    0   0 
            0x47, 0xF1, 0x00, ##   0   0000000   0 
            0x23, 0xE2, 0x00, ##    0   00000   0  
            0x10, 0x04, 0x00, ##     0         0   
            0x0C, 0x18, 0x00, ##      00     00    
            0x03, 0xE0, 0x00, ##        00000      
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '170' => {    # 'ª'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x7C, ##   00000  
            0x66, ##   00  00 
            0x03, ##        00
            0x03, ##        00
            0x7F, ##   0000000
            0xE3, ##  000   00
            0xC3, ##  00    00
            0xC3, ##  00    00
            0xEF, ##  000 0000
            0x7B, ##   0000 00
            0x00, ##          
            0xFF, ##  00000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '171' => {    # '«'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x04, 0x20, ##       0    0
            0x0C, 0x60, ##      00   00
            0x18, 0xC0, ##     00   00 
            0x31, 0x80, ##    00   00  
            0x63, 0x00, ##   00   00   
            0xC6, 0x00, ##  00   00    
            0xE7, 0x00, ##  000  000   
            0x73, 0x80, ##   000  000  
            0x18, 0xC0, ##     00   00 
            0x0C, 0x60, ##      00   00
            0x04, 0x20, ##       0    0
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '172' => {    # '¬'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFE, ##  000000000000000
            0xFF, 0xFE, ##  000000000000000
            0x00, 0x06, ##               00
            0x00, 0x06, ##               00
            0x00, 0x06, ##               00
            0x00, 0x06, ##               00
            0x00, 0x06, ##               00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '173' => {    # '­'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '174' => {    # '®'
        'width'    => 17, 
        'xoffset'  => 3, 
        'xadvance' => 23, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x03, 0xE0, 0x00, ##        00000      
            0x0C, 0x18, 0x00, ##      00     00    
            0x10, 0x04, 0x00, ##     0         0   
            0x20, 0x02, 0x00, ##    0           0  
            0x47, 0xF1, 0x00, ##   0   0000000   0 
            0x46, 0x19, 0x00, ##   0   00    00  0 
            0x86, 0x18, 0x80, ##  0    00    00   0
            0x86, 0x18, 0x80, ##  0    00    00   0
            0x87, 0xE0, 0x80, ##  0    000000     0
            0x86, 0x60, 0x80, ##  0    00  00     0
            0x86, 0x30, 0x80, ##  0    00   00    0
            0x86, 0x30, 0x80, ##  0    00   00    0
            0x46, 0x19, 0x00, ##   0   00    00  0 
            0x46, 0x0D, 0x00, ##   0   00     00 0 
            0x20, 0x02, 0x00, ##    0           0  
            0x10, 0x04, 0x00, ##     0         0   
            0x0C, 0x18, 0x00, ##      00     00    
            0x03, 0xE0, 0x00, ##        00000      
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '175' => {    # '¯'
        'width'    => 7, 
        'xoffset'  => 2, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFE, ##  0000000
            0xFE, ##  0000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '176' => {    # '°'
        'width'    => 8, 
        'xoffset'  => 2, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x3C, ##    0000  
            0x7E, ##   000000 
            0xE7, ##  000  000
            0xC3, ##  00    00
            0xC3, ##  00    00
            0xE7, ##  000  000
            0x7E, ##   000000 
            0x3C, ##    0000  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '177' => {    # '±'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0xFF, 0xFE, ##  000000000000000
            0xFF, 0xFE, ##  000000000000000
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x01, 0x80, ##         00      
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0xFF, 0xFE, ##  000000000000000
            0xFF, 0xFE, ##  000000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '178' => {    # '²'
        'width'    => 7, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x78, ##   0000  
            0xCE, ##  00  000
            0x06, ##       00
            0x06, ##       00
            0x0C, ##      00 
            0x1C, ##     000 
            0x38, ##    000  
            0x60, ##   00    
            0xC0, ##  00     
            0xFE, ##  0000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '179' => {    # '³'
        'width'    => 7, 
        'xoffset'  => 1, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF8, ##  00000  
            0x8E, ##  0   000
            0x06, ##       00
            0x06, ##       00
            0x38, ##    000  
            0x0C, ##      00 
            0x06, ##       00
            0x06, ##       00
            0x8E, ##  0   000
            0xF8, ##  00000  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '180' => {    # '´'
        'width'    => 6, 
        'xoffset'  => 4, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x0C, ##      00
            0x18, ##     00 
            0x30, ##    00  
            0x60, ##   00   
            0x60, ##   00   
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '181' => {    # 'µ'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0x60, ##  00       00  
            0xC0, 0xE0, ##  00      000  
            0xE1, 0xE0, ##  000    0000  
            0xFF, 0xF8, ##  0000000000000
            0xDF, 0x30, ##  00 00000  00 
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0x00, 0x00, ##  
        ], 
    }, 
    '182' => {    # '¶'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0xE0, ##     00000000
            0x7F, 0xE0, ##   0000000000
            0xFE, 0x60, ##  0000000  00
            0xFE, 0x60, ##  0000000  00
            0xFE, 0x60, ##  0000000  00
            0xFE, 0x60, ##  0000000  00
            0xFE, 0x60, ##  0000000  00
            0xFE, 0x60, ##  0000000  00
            0xFE, 0x60, ##  0000000  00
            0x7E, 0x60, ##   000000  00
            0x0E, 0x60, ##      000  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x06, 0x60, ##       00  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '183' => {    # '·'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '184' => {    # '¸'
        'width'    => 5, 
        'xoffset'  => 3, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x30, ##    00 
            0x18, ##     00
            0x18, ##     00
            0xF8, ##  00000
            0xF0, ##  0000 
            0x00, ##  
        ], 
    }, 
    '185' => {    # '¹'
        'width'    => 6, 
        'xoffset'  => 2, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF0, ##  0000  
            0xF0, ##  0000  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '186' => {    # 'º'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0x00, ##    00000  
            0x77, 0x00, ##   000 000 
            0xC1, 0x80, ##  00     00
            0xC1, 0x80, ##  00     00
            0xC1, 0x80, ##  00     00
            0xC1, 0x80, ##  00     00
            0xC1, 0x80, ##  00     00
            0xC1, 0x80, ##  00     00
            0x77, 0x00, ##   000 000 
            0x3E, 0x00, ##    00000  
            0x00, 0x00, ##           
            0x7F, 0x80, ##   00000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '187' => {    # '»'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##             
            0xC6, 0x00, ##  00   00    
            0xE7, 0x00, ##  000  000   
            0x73, 0x80, ##   000  000  
            0x39, 0xC0, ##    000  000 
            0x1C, 0xE0, ##     000  000
            0x18, 0xC0, ##     00   00 
            0x31, 0x80, ##    00   00  
            0xE7, 0x00, ##  000  000   
            0xC6, 0x00, ##  00   00    
            0x84, 0x00, ##  0    0     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '188' => {    # '¼'
        'width'    => 21, 
        'xoffset'  => 2, 
        'xadvance' => 23, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xF0, 0x03, 0x00, ##  0000          00     
            0xB0, 0x06, 0x00, ##  0 00         00      
            0x30, 0x06, 0x00, ##    00         00      
            0x30, 0x0C, 0x00, ##    00        00       
            0x30, 0x18, 0x00, ##    00       00        
            0x30, 0x18, 0x00, ##    00       00        
            0x30, 0x30, 0x00, ##    00      00         
            0x30, 0x30, 0x00, ##    00      00         
            0xFE, 0x60, 0xE0, ##  0000000  00     000  
            0xFE, 0x60, 0xE0, ##  0000000  00     000  
            0x00, 0xC1, 0x60, ##          00     0 00  
            0x01, 0x82, 0x60, ##         00     0  00  
            0x01, 0x82, 0x60, ##         00     0  00  
            0x03, 0x04, 0x60, ##        00     0   00  
            0x03, 0x07, 0xF8, ##        00     00000000
            0x06, 0x07, 0xF8, ##       00      00000000
            0x0E, 0x00, 0x60, ##      000          00  
            0x0C, 0x00, 0x60, ##      00           00  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '189' => {    # '½'
        'width'    => 20, 
        'xoffset'  => 2, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x30, 0x03, 0x00, ##    00          00    
            0xF0, 0x03, 0x00, ##  0000          00    
            0x30, 0x06, 0x00, ##    00         00     
            0x30, 0x06, 0x00, ##    00         00     
            0x30, 0x0C, 0x00, ##    00        00      
            0x30, 0x18, 0x00, ##    00       00       
            0x30, 0x18, 0x00, ##    00       00       
            0x30, 0x30, 0x00, ##    00      00        
            0x30, 0x33, 0xC0, ##    00      00  0000  
            0xFE, 0x67, 0xF0, ##  0000000  00  0000000
            0xFE, 0xE4, 0x70, ##  0000000 000  0   000
            0x00, 0xC0, 0x30, ##          00        00
            0x01, 0x80, 0x20, ##         00         0 
            0x01, 0x80, 0x60, ##         00        00 
            0x03, 0x00, 0xC0, ##        00        00  
            0x03, 0x01, 0x80, ##        00       00   
            0x06, 0x03, 0x00, ##       00       00    
            0x0E, 0x07, 0xF0, ##      000      0000000
            0x0C, 0x07, 0xF0, ##      00       0000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '190' => {    # '¾'
        'width'    => 21, 
        'xoffset'  => 2, 
        'xadvance' => 23, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xF8, 0x03, 0x00, ##  00000         00     
            0xFE, 0x06, 0x00, ##  0000000      00      
            0x0E, 0x06, 0x00, ##      000      00      
            0x06, 0x0C, 0x00, ##       00     00       
            0x0E, 0x0C, 0x00, ##      000     00       
            0x78, 0x18, 0x00, ##   0000      00        
            0x7C, 0x10, 0x00, ##   00000     0         
            0x0E, 0x30, 0x00, ##      000   00         
            0x06, 0x20, 0x00, ##       00   0          
            0x0E, 0x60, 0x60, ##      000  00      00  
            0xFC, 0xC0, 0xE0, ##  000000  00      000  
            0xF8, 0xC1, 0xE0, ##  00000   00     0000  
            0x01, 0x83, 0x60, ##         00     00 00  
            0x01, 0x82, 0x60, ##         00     0  00  
            0x03, 0x04, 0x60, ##        00     0   00  
            0x03, 0x07, 0xF8, ##        00     00000000
            0x06, 0x07, 0xF8, ##       00      00000000
            0x06, 0x00, 0x60, ##       00          00  
            0x0C, 0x00, 0x60, ##      00           00  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '191' => {    # '¿'
        'width'    => 10, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x00, 0x00, ##            
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x18, 0x00, ##     00     
            0x38, 0x00, ##    000     
            0x70, 0x00, ##   000      
            0x60, 0x00, ##   00       
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0xC0, 0x40, ##  00       0
            0xE1, 0xC0, ##  000    000
            0x7F, 0xC0, ##   000000000
            0x3F, 0x00, ##    000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '192' => {    # 'À'
        'width'    => 16, 
        'xoffset'  => 0, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x03, 0x00, ##        00        
            0x01, 0x80, ##         00       
            0x00, 0x80, ##          0       
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x01, 0xC0, ##         000      
            0x03, 0xC0, ##        0000      
            0x03, 0xC0, ##        0000      
            0x03, 0x60, ##        00 00     
            0x06, 0x60, ##       00  00     
            0x06, 0x70, ##       00  000    
            0x0E, 0x30, ##      000   00    
            0x0C, 0x30, ##      00    00    
            0x0C, 0x18, ##      00     00   
            0x1C, 0x18, ##     000     00   
            0x18, 0x18, ##     00      00   
            0x1F, 0xFC, ##     00000000000  
            0x3F, 0xFC, ##    000000000000  
            0x30, 0x0E, ##    00        000 
            0x70, 0x06, ##   000         00 
            0x70, 0x06, ##   000         00 
            0x60, 0x07, ##   00          000
            0xE0, 0x03, ##  000           00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '193' => {    # 'Á'
        'width'    => 16, 
        'xoffset'  => 0, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0xE0, ##          000     
            0x00, 0xC0, ##          00      
            0x01, 0x80, ##         00       
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x01, 0xC0, ##         000      
            0x03, 0xC0, ##        0000      
            0x03, 0xC0, ##        0000      
            0x03, 0x60, ##        00 00     
            0x06, 0x60, ##       00  00     
            0x06, 0x70, ##       00  000    
            0x0E, 0x30, ##      000   00    
            0x0C, 0x30, ##      00    00    
            0x0C, 0x18, ##      00     00   
            0x1C, 0x18, ##     000     00   
            0x18, 0x18, ##     00      00   
            0x1F, 0xFC, ##     00000000000  
            0x3F, 0xFC, ##    000000000000  
            0x30, 0x0E, ##    00        000 
            0x70, 0x06, ##   000         00 
            0x70, 0x06, ##   000         00 
            0x60, 0x07, ##   00          000
            0xE0, 0x03, ##  000           00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '194' => {    # 'Â'
        'width'    => 16, 
        'xoffset'  => 0, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x01, 0xC0, ##         000      
            0x03, 0x60, ##        00 00     
            0x06, 0x20, ##       00   0     
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x01, 0xC0, ##         000      
            0x03, 0xC0, ##        0000      
            0x03, 0xC0, ##        0000      
            0x03, 0x60, ##        00 00     
            0x06, 0x60, ##       00  00     
            0x06, 0x70, ##       00  000    
            0x0E, 0x30, ##      000   00    
            0x0C, 0x30, ##      00    00    
            0x0C, 0x18, ##      00     00   
            0x1C, 0x18, ##     000     00   
            0x18, 0x18, ##     00      00   
            0x1F, 0xFC, ##     00000000000  
            0x3F, 0xFC, ##    000000000000  
            0x30, 0x0E, ##    00        000 
            0x70, 0x06, ##   000         00 
            0x70, 0x06, ##   000         00 
            0x60, 0x07, ##   00          000
            0xE0, 0x03, ##  000           00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '195' => {    # 'Ã'
        'width'    => 16, 
        'xoffset'  => 0, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x07, 0x20, ##       000  0     
            0x0F, 0xE0, ##      0000000     
            0x0C, 0xE0, ##      00  000     
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x03, 0x80, ##        000       
            0x03, 0xC0, ##        0000      
            0x03, 0xC0, ##        0000      
            0x06, 0xC0, ##       00 00      
            0x06, 0x60, ##       00  00     
            0x0E, 0x60, ##      000  00     
            0x0C, 0x60, ##      00   00     
            0x0C, 0x30, ##      00    00    
            0x1C, 0x30, ##     000    00    
            0x18, 0x38, ##     00     000   
            0x18, 0x18, ##     00      00   
            0x3F, 0xF8, ##    00000000000   
            0x3F, 0xFC, ##    000000000000  
            0x70, 0x0C, ##   000        00  
            0x60, 0x0C, ##   00         00  
            0x60, 0x0E, ##   00         000 
            0xE0, 0x06, ##  000          00 
            0xE0, 0x06, ##  000          00 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '196' => {    # 'Ä'
        'width'    => 17, 
        'xoffset'  => 0, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x06, 0x30, 0x00, ##       00   00     
            0x06, 0x30, 0x00, ##       00   00     
            0x00, 0x00, 0x00, ##                   
            0x00, 0x00, 0x00, ##                   
            0x00, 0x00, 0x00, ##                   
            0x01, 0xC0, 0x00, ##         000       
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0x60, 0x00, ##        00 00      
            0x03, 0x60, 0x00, ##        00 00      
            0x07, 0x70, 0x00, ##       000 000     
            0x06, 0x30, 0x00, ##       00   00     
            0x0E, 0x30, 0x00, ##      000   00     
            0x0E, 0x18, 0x00, ##      000    00    
            0x0C, 0x18, 0x00, ##      00     00    
            0x1C, 0x1C, 0x00, ##     000     000   
            0x18, 0x0C, 0x00, ##     00       00   
            0x1F, 0xFC, 0x00, ##     00000000000   
            0x3F, 0xFE, 0x00, ##    0000000000000  
            0x30, 0x06, 0x00, ##    00         00  
            0x30, 0x06, 0x00, ##    00         00  
            0x70, 0x07, 0x00, ##   000         000 
            0x60, 0x03, 0x00, ##   00           00 
            0x60, 0x03, 0x00, ##   00           00 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '197' => {    # 'Å'
        'width'    => 17, 
        'xoffset'  => 0, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x01, 0xC0, 0x00, ##         000       
            0x03, 0xE0, 0x00, ##        00000      
            0x06, 0x30, 0x00, ##       00   00     
            0x06, 0x30, 0x00, ##       00   00     
            0x06, 0x30, 0x00, ##       00   00     
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0x60, 0x00, ##        00 00      
            0x03, 0x60, 0x00, ##        00 00      
            0x07, 0x70, 0x00, ##       000 000     
            0x06, 0x30, 0x00, ##       00   00     
            0x0E, 0x38, 0x00, ##      000   000    
            0x0C, 0x18, 0x00, ##      00     00    
            0x0C, 0x18, 0x00, ##      00     00    
            0x1C, 0x1C, 0x00, ##     000     000   
            0x18, 0x0C, 0x00, ##     00       00   
            0x1F, 0xFC, 0x00, ##     00000000000   
            0x3F, 0xFE, 0x00, ##    0000000000000  
            0x30, 0x06, 0x00, ##    00         00  
            0x70, 0x07, 0x00, ##   000         000 
            0x70, 0x03, 0x00, ##   000          00 
            0x60, 0x03, 0x00, ##   00           00 
            0xE0, 0x03, 0x80, ##  000           000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '198' => {    # 'Æ'
        'width'    => 21, 
        'xoffset'  => 1, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x01, 0xFF, 0xF8, ##         00000000000000
            0x03, 0xFF, 0xF8, ##        000000000000000
            0x03, 0x30, 0x00, ##        00  00         
            0x07, 0x30, 0x00, ##       000  00         
            0x06, 0x30, 0x00, ##       00   00         
            0x06, 0x30, 0x00, ##       00   00         
            0x0E, 0x30, 0x00, ##      000   00         
            0x0C, 0x3F, 0xF8, ##      00    00000000000
            0x1C, 0x3F, 0xF8, ##     000    00000000000
            0x18, 0x30, 0x00, ##     00     00         
            0x18, 0x30, 0x00, ##     00     00         
            0x3F, 0xF0, 0x00, ##    0000000000         
            0x3F, 0xF0, 0x00, ##    0000000000         
            0x70, 0x30, 0x00, ##   000      00         
            0x60, 0x30, 0x00, ##   00       00         
            0x60, 0x30, 0x00, ##   00       00         
            0xE0, 0x3F, 0xF8, ##  000       00000000000
            0xC0, 0x3F, 0xF8, ##  00        00000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '199' => {    # 'Ç'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xF0, ##       0000000  
            0x1F, 0xFC, ##     00000000000
            0x3C, 0x1C, ##    0000     000
            0x70, 0x04, ##   000         0
            0x60, 0x00, ##   00           
            0xE0, 0x00, ##  000           
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xC0, 0x00, ##  00            
            0xE0, 0x00, ##  000           
            0x60, 0x00, ##   00           
            0x70, 0x04, ##   000         0
            0x3C, 0x1C, ##    0000     000
            0x1F, 0xFC, ##     00000000000
            0x07, 0xF0, ##       0000000  
            0x00, 0xC0, ##          00    
            0x00, 0x60, ##           00   
            0x00, 0x60, ##           00   
            0x07, 0xE0, ##       000000   
            0x07, 0xC0, ##       00000    
            0x00, 0x00, ##  
        ], 
    }, 
    '200' => {    # 'È'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x18, 0x00, ##     00      
            0x0C, 0x00, ##      00     
            0x04, 0x00, ##       0     
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '201' => {    # 'É'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x07, 0x00, ##       000   
            0x06, 0x00, ##       00    
            0x0C, 0x00, ##      00     
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '202' => {    # 'Ê'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x0E, 0x00, ##      000    
            0x1B, 0x00, ##     00 00   
            0x31, 0x00, ##    00   0   
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '203' => {    # 'Ë'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x31, 0x80, ##    00   00  
            0x31, 0x80, ##    00   00  
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0xE0, ##  00000000000
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '204' => {    # 'Ì'
        'width'    => 4, 
        'xoffset'  => 0, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x60, ##   00 
            0x20, ##    0 
            0x30, ##    00
            0x00, ##      
            0x00, ##      
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '205' => {    # 'Í'
        'width'    => 4, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x60, ##   00 
            0x40, ##   0  
            0xC0, ##  00  
            0x00, ##      
            0x00, ##      
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0xC0, ##  00  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '206' => {    # 'Î'
        'width'    => 6, 
        'xoffset'  => 0, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x30, ##    00  
            0x78, ##   0000 
            0xCC, ##  00  00
            0x00, ##        
            0x00, ##        
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '207' => {    # 'Ï'
        'width'    => 7, 
        'xoffset'  => 1, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0xC6, ##  00   00
            0xC6, ##  00   00
            0x00, ##         
            0x00, ##         
            0x00, ##         
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '208' => {    # 'Ð'
        'width'    => 17, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x1F, 0xF0, 0x00, ##     000000000     
            0x1F, 0xFC, 0x00, ##     00000000000   
            0x18, 0x1E, 0x00, ##     00      0000  
            0x18, 0x07, 0x00, ##     00        000 
            0x18, 0x03, 0x00, ##     00         00 
            0x18, 0x03, 0x80, ##     00         000
            0x18, 0x01, 0x80, ##     00          00
            0x18, 0x01, 0x80, ##     00          00
            0xFF, 0x81, 0x80, ##  000000000      00
            0xFF, 0x81, 0x80, ##  000000000      00
            0x18, 0x01, 0x80, ##     00          00
            0x18, 0x01, 0x80, ##     00          00
            0x18, 0x03, 0x80, ##     00         000
            0x18, 0x03, 0x00, ##     00         00 
            0x18, 0x07, 0x00, ##     00        000 
            0x18, 0x1E, 0x00, ##     00      0000  
            0x1F, 0xFC, 0x00, ##     00000000000   
            0x1F, 0xF0, 0x00, ##     000000000     
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '209' => {    # 'Ñ'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x1E, 0x40, ##     0000  0   
            0x1F, 0xC0, ##     0000000   
            0x33, 0xC0, ##    00  0000   
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xE0, 0x18, ##  000        00
            0xF0, 0x18, ##  0000       00
            0xF0, 0x18, ##  0000       00
            0xF8, 0x18, ##  00000      00
            0xD8, 0x18, ##  00 00      00
            0xDC, 0x18, ##  00 000     00
            0xCC, 0x18, ##  00  00     00
            0xCE, 0x18, ##  00  000    00
            0xC6, 0x18, ##  00   00    00
            0xC3, 0x18, ##  00    00   00
            0xC3, 0x98, ##  00    000  00
            0xC1, 0x98, ##  00     00  00
            0xC1, 0xD8, ##  00     000 00
            0xC0, 0xD8, ##  00      00 00
            0xC0, 0xF8, ##  00      00000
            0xC0, 0x78, ##  00       0000
            0xC0, 0x78, ##  00       0000
            0xC0, 0x38, ##  00        000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '210' => {    # 'Ò'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x06, 0x00, ##       00         
            0x03, 0x00, ##        00        
            0x01, 0x80, ##         00       
            0x00, 0xC0, ##          00      
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x07, 0xE0, ##       000000     
            0x1F, 0xF8, ##     0000000000   
            0x3C, 0x3C, ##    0000    0000  
            0x70, 0x0E, ##   000        000 
            0x60, 0x06, ##   00          00 
            0xE0, 0x07, ##  000          000
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xE0, 0x07, ##  000          000
            0x60, 0x06, ##   00          00 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1F, 0xF8, ##     0000000000   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '211' => {    # 'Ó'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x60, ##           00     
            0x00, 0xC0, ##          00      
            0x01, 0x80, ##         00       
            0x03, 0x00, ##        00        
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x07, 0xE0, ##       000000     
            0x1F, 0xF8, ##     0000000000   
            0x3C, 0x3C, ##    0000    0000  
            0x70, 0x0E, ##   000        000 
            0x60, 0x06, ##   00          00 
            0xE0, 0x07, ##  000          000
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xE0, 0x07, ##  000          000
            0x60, 0x06, ##   00          00 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1F, 0xF8, ##     0000000000   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '212' => {    # 'Ô'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x01, 0x80, ##         00       
            0x03, 0xC0, ##        0000      
            0x06, 0x60, ##       00  00     
            0x0C, 0x30, ##      00    00    
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x07, 0xE0, ##       000000     
            0x1F, 0xF8, ##     0000000000   
            0x3C, 0x3C, ##    0000    0000  
            0x70, 0x0E, ##   000        000 
            0x60, 0x06, ##   00          00 
            0xE0, 0x07, ##  000          000
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xE0, 0x07, ##  000          000
            0x60, 0x06, ##   00          00 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1F, 0xF8, ##     0000000000   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '213' => {    # 'Õ'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x07, 0x10, ##       000   0    
            0x0F, 0xB0, ##      00000 00    
            0x0D, 0xF0, ##      00 00000    
            0x08, 0xE0, ##      0   000     
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x07, 0xE0, ##       000000     
            0x1F, 0xF8, ##     0000000000   
            0x3C, 0x3C, ##    0000    0000  
            0x70, 0x0E, ##   000        000 
            0x60, 0x06, ##   00          00 
            0xE0, 0x07, ##  000          000
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xE0, 0x07, ##  000          000
            0x60, 0x06, ##   00          00 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1F, 0xF8, ##     0000000000   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '214' => {    # 'Ö'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x06, 0x60, ##       00  00     
            0x06, 0x60, ##       00  00     
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0x07, 0xE0, ##       000000     
            0x1F, 0xF8, ##     0000000000   
            0x3C, 0x3C, ##    0000    0000  
            0x70, 0x0E, ##   000        000 
            0x60, 0x06, ##   00          00 
            0xE0, 0x07, ##  000          000
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xC0, 0x03, ##  00            00
            0xE0, 0x07, ##  000          000
            0x60, 0x06, ##   00          00 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1F, 0xF8, ##     0000000000   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '215' => {    # '×'
        'width'    => 14, 
        'xoffset'  => 3, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x40, 0x08, ##   0          0 
            0xE0, 0x1C, ##  000        000
            0x70, 0x38, ##   000      000 
            0x38, 0x70, ##    000    000  
            0x1C, 0xE0, ##     000  000   
            0x0F, 0xC0, ##      000000    
            0x07, 0x80, ##       0000     
            0x07, 0x80, ##       0000     
            0x0F, 0xC0, ##      000000    
            0x1C, 0xE0, ##     000  000   
            0x38, 0x70, ##    000    000  
            0x70, 0x38, ##   000      000 
            0x60, 0x1C, ##   00        000
            0x40, 0x08, ##   0          0 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '216' => {    # 'Ø'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xE3, ##       000000   00
            0x1F, 0xFB, ##     0000000000 00
            0x38, 0x3E, ##    000     00000 
            0x70, 0x1E, ##   000       0000 
            0x60, 0x1E, ##   00        0000 
            0xE0, 0x33, ##  000       00  00
            0xC0, 0x63, ##  00       00   00
            0xC0, 0xC3, ##  00      00    00
            0xC1, 0x83, ##  00     00     00
            0xC3, 0x03, ##  00    00      00
            0xC7, 0x03, ##  00   000      00
            0xCE, 0x03, ##  00  000       00
            0x6C, 0x07, ##   00 00       000
            0x78, 0x06, ##   0000        00 
            0x70, 0x0E, ##   000        000 
            0x7C, 0x3C, ##   00000    0000  
            0x5F, 0xF8, ##   0 0000000000   
            0xC7, 0xE0, ##  00   000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '217' => {    # 'Ù'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x0C, 0x00, ##      00       
            0x0E, 0x00, ##      000      
            0x06, 0x00, ##       00      
            0x03, 0x00, ##        00     
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0x60, 0x30, ##   00       00 
            0x70, 0x70, ##   000     000 
            0x3F, 0xE0, ##    000000000  
            0x0F, 0x80, ##      00000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '218' => {    # 'Ú'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x01, 0x80, ##         00    
            0x03, 0x80, ##        000    
            0x03, 0x00, ##        00     
            0x06, 0x00, ##       00      
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0x60, 0x30, ##   00       00 
            0x70, 0x70, ##   000     000 
            0x3F, 0xE0, ##    000000000  
            0x0F, 0x80, ##      00000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '219' => {    # 'Û'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x07, 0x00, ##       000     
            0x0F, 0x80, ##      00000    
            0x0C, 0x80, ##      00  0    
            0x10, 0x40, ##     0     0   
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0x60, 0x30, ##   00       00 
            0x70, 0x70, ##   000     000 
            0x3F, 0xE0, ##    000000000  
            0x0F, 0x80, ##      00000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '220' => {    # 'Ü'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x18, 0xC0, ##     00   00   
            0x18, 0xC0, ##     00   00   
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0x60, 0x30, ##   00       00 
            0x70, 0x70, ##   000     000 
            0x3F, 0xE0, ##    000000000  
            0x0F, 0x80, ##      00000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '221' => {    # 'Ý'
        'width'    => 14, 
        'xoffset'  => 0, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x01, 0x80, ##         00     
            0x01, 0x00, ##         0      
            0x03, 0x00, ##        00      
            0x00, 0x00, ##                
            0x00, 0x00, ##                
            0xE0, 0x1C, ##  000        000
            0x60, 0x18, ##   00        00 
            0x70, 0x38, ##   000      000 
            0x38, 0x70, ##    000    000  
            0x18, 0x60, ##     00    00   
            0x1C, 0xE0, ##     000  000   
            0x0C, 0xC0, ##      00  00    
            0x07, 0x80, ##       0000     
            0x07, 0x80, ##       0000     
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x03, 0x00, ##        00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '222' => {    # 'Þ'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xFF, 0x00, ##  00000000   
            0xFF, 0xC0, ##  0000000000 
            0xC1, 0xC0, ##  00     000 
            0xC0, 0xE0, ##  00      000
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xC1, 0xC0, ##  00     000 
            0xFF, 0xC0, ##  0000000000 
            0xFF, 0x00, ##  00000000   
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '223' => {    # 'ß'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x00, ##     00000    
            0x7F, 0x80, ##   00000000   
            0x61, 0xC0, ##   00    000  
            0xC0, 0xC0, ##  00      00  
            0xC0, 0x60, ##  00       00 
            0xC3, 0xE0, ##  00    00000 
            0xC7, 0x00, ##  00   000    
            0xC6, 0x00, ##  00   00     
            0xC6, 0x00, ##  00   00     
            0xC7, 0x00, ##  00   000    
            0xC3, 0x80, ##  00    000   
            0xC1, 0xC0, ##  00     000  
            0xC0, 0xE0, ##  00      000 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x70, ##  00       000
            0xCF, 0xE0, ##  00  0000000 
            0xCF, 0xC0, ##  00  000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '224' => {    # 'à'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x70, 0x00, ##   000       
            0x30, 0x00, ##    00       
            0x18, 0x00, ##     00      
            0x0C, 0x00, ##      00     
            0x06, 0x00, ##       00    
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x3F, 0x00, ##    000000   
            0x7F, 0xC0, ##   000000000 
            0x40, 0xC0, ##   0      00 
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x1F, 0xE0, ##     00000000
            0x7F, 0xE0, ##   0000000000
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xE1, 0xE0, ##  000    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '225' => {    # 'á'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0xC0, ##         000 
            0x03, 0x80, ##        000  
            0x03, 0x00, ##        00   
            0x06, 0x00, ##       00    
            0x0C, 0x00, ##      00     
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x3F, 0x00, ##    000000   
            0x7F, 0xC0, ##   000000000 
            0x40, 0xC0, ##   0      00 
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x1F, 0xE0, ##     00000000
            0x7F, 0xE0, ##   0000000000
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xE1, 0xE0, ##  000    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '226' => {    # 'â'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x04, 0x00, ##       0     
            0x0E, 0x00, ##      000    
            0x1B, 0x00, ##     00 00   
            0x11, 0x00, ##     0   0   
            0x31, 0x80, ##    00   00  
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x3F, 0x00, ##    000000   
            0x7F, 0xC0, ##   000000000 
            0x40, 0xC0, ##   0      00 
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x1F, 0xE0, ##     00000000
            0x7F, 0xE0, ##   0000000000
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xE1, 0xE0, ##  000    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '227' => {    # 'ã'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3C, 0xC0, ##    0000  00 
            0x3F, 0xC0, ##    00000000 
            0x67, 0x80, ##   00  0000  
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x3F, 0x00, ##    000000   
            0x7F, 0xC0, ##   000000000 
            0x40, 0xC0, ##   0      00 
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x1F, 0xE0, ##     00000000
            0x7F, 0xE0, ##   0000000000
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xE1, 0xE0, ##  000    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '228' => {    # 'ä'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x31, 0x80, ##    00   00  
            0x31, 0x80, ##    00   00  
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x3F, 0x00, ##    000000   
            0x7F, 0xC0, ##   000000000 
            0x40, 0xC0, ##   0      00 
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x1F, 0xE0, ##     00000000
            0x7F, 0xE0, ##   0000000000
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xE1, 0xE0, ##  000    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '229' => {    # 'å'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x0E, 0x00, ##      000    
            0x1F, 0x00, ##     00000   
            0x3B, 0x80, ##    000 000  
            0x31, 0x80, ##    00   00  
            0x31, 0x80, ##    00   00  
            0x33, 0x80, ##    00  000  
            0x1F, 0x00, ##     00000   
            0x0E, 0x00, ##      000    
            0x00, 0x00, ##             
            0x3F, 0x00, ##    000000   
            0x7F, 0xC0, ##   000000000 
            0x40, 0xC0, ##   0      00 
            0x00, 0x60, ##           00
            0x00, 0x60, ##           00
            0x1F, 0xE0, ##     00000000
            0x7F, 0xE0, ##   0000000000
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0xE1, 0xE0, ##  000    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '230' => {    # 'æ'
        'width'    => 21, 
        'xoffset'  => 1, 
        'xadvance' => 23, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x3F, 0x07, 0xC0, ##    000000     00000   
            0x7F, 0xDF, 0xE0, ##   000000000 00000000  
            0x40, 0xF8, 0x70, ##   0      00000    000 
            0x00, 0x70, 0x18, ##           000       00
            0x00, 0x60, 0x18, ##           00        00
            0x1F, 0xFF, 0xF8, ##     000000000000000000
            0x7F, 0xFF, 0xF8, ##   00000000000000000000
            0xE0, 0x60, 0x00, ##  000      00          
            0xC0, 0x60, 0x00, ##  00       00          
            0xC0, 0x60, 0x00, ##  00       00          
            0xC0, 0xF0, 0x00, ##  00      0000         
            0xE1, 0xB8, 0x18, ##  000    00 000      00
            0x7F, 0x9F, 0xF8, ##   00000000  0000000000
            0x3E, 0x07, 0xE0, ##    00000      000000  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '231' => {    # 'ç'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xC0, ##      000000 
            0x3F, 0xE0, ##    000000000
            0x70, 0x60, ##   000     00
            0x60, 0x00, ##   00        
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0xC0, 0x00, ##  00         
            0x60, 0x00, ##   00        
            0x70, 0x60, ##   000     00
            0x3F, 0xE0, ##    000000000
            0x0F, 0xC0, ##      000000 
            0x03, 0x00, ##        00   
            0x01, 0x80, ##         00  
            0x01, 0x80, ##         00  
            0x0F, 0x80, ##      00000  
            0x0F, 0x00, ##      0000   
            0x00, 0x00, ##  
        ], 
    }, 
    '232' => {    # 'è'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x30, 0x00, ##    00        
            0x18, 0x00, ##     00       
            0x0C, 0x00, ##      00      
            0x06, 0x00, ##       00     
            0x02, 0x00, ##        0     
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x0F, 0x80, ##      00000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x30, ##   00       00
            0xC0, 0x30, ##  00        00
            0xFF, 0xF0, ##  000000000000
            0xFF, 0xF0, ##  000000000000
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0x60, 0x00, ##   00         
            0x70, 0x30, ##   000      00
            0x3F, 0xF0, ##    0000000000
            0x0F, 0xC0, ##      000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '233' => {    # 'é'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0xC0, ##          00  
            0x01, 0x80, ##         00   
            0x03, 0x80, ##        000   
            0x03, 0x00, ##        00    
            0x06, 0x00, ##       00     
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x0F, 0x80, ##      00000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x30, ##   00       00
            0xC0, 0x30, ##  00        00
            0xFF, 0xF0, ##  000000000000
            0xFF, 0xF0, ##  000000000000
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0x60, 0x00, ##   00         
            0x70, 0x30, ##   000      00
            0x3F, 0xF0, ##    0000000000
            0x0F, 0xC0, ##      000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '234' => {    # 'ê'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x06, 0x00, ##       00     
            0x07, 0x00, ##       000    
            0x0F, 0x00, ##      0000    
            0x19, 0x80, ##     00  00   
            0x10, 0xC0, ##     0    00  
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x0F, 0x80, ##      00000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x30, ##   00       00
            0xC0, 0x30, ##  00        00
            0xFF, 0xF0, ##  000000000000
            0xFF, 0xF0, ##  000000000000
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0x60, 0x00, ##   00         
            0x70, 0x30, ##   000      00
            0x3F, 0xF0, ##    0000000000
            0x0F, 0xC0, ##      000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '235' => {    # 'ë'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x18, 0xC0, ##     00   00  
            0x18, 0xC0, ##     00   00  
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x0F, 0x80, ##      00000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x30, ##   00       00
            0xC0, 0x30, ##  00        00
            0xFF, 0xF0, ##  000000000000
            0xFF, 0xF0, ##  000000000000
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0x60, 0x00, ##   00         
            0x70, 0x30, ##   000      00
            0x3F, 0xF0, ##    0000000000
            0x0F, 0xC0, ##      000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '236' => {    # 'ì'
        'width'    => 6, 
        'xoffset'  => -1, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xE0, ##  000   
            0x60, ##   00   
            0x30, ##    00  
            0x18, ##     00 
            0x0C, ##      00
            0x00, ##        
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '237' => {    # 'í'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x18, ##     00 
            0x38, ##    000 
            0x30, ##    00  
            0x60, ##   00   
            0xC0, ##  00    
            0x00, ##        
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x60, ##   00   
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '238' => {    # 'î'
        'width'    => 8, 
        'xoffset'  => -1, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x18, ##     00   
            0x3C, ##    0000  
            0x24, ##    0  0  
            0x66, ##   00  00 
            0xC3, ##  00    00
            0x00, ##          
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '239' => {    # 'ï'
        'width'    => 7, 
        'xoffset'  => 0, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC6, ##  00   00
            0xC6, ##  00   00
            0x00, ##         
            0x00, ##         
            0x00, ##         
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x30, ##    00   
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '240' => {    # 'ð'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x18, 0x20, ##     00     0 
            0x0D, 0xE0, ##      00 0000 
            0x1E, 0x00, ##     0000     
            0x73, 0x00, ##   000  00    
            0x01, 0x80, ##         00   
            0x1F, 0xC0, ##     0000000  
            0x3F, 0xC0, ##    00000000  
            0x70, 0x60, ##   000     00 
            0x60, 0x60, ##   00      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x60, ##   00      00 
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x0F, 0x80, ##      00000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '241' => {    # 'ñ'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3C, 0xC0, ##    0000  00 
            0x7F, 0xC0, ##   000000000 
            0x67, 0x80, ##   00  0000  
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xCF, 0x80, ##  00  00000  
            0xDF, 0xC0, ##  00 0000000 
            0xF0, 0xC0, ##  0000    00 
            0xE0, 0x60, ##  000      00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '242' => {    # 'ò'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x30, 0x00, ##    00        
            0x18, 0x00, ##     00       
            0x0C, 0x00, ##      00      
            0x0E, 0x00, ##      000     
            0x06, 0x00, ##       00     
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x1F, 0x80, ##     000000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x60, ##   00      00 
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x1F, 0x80, ##     000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '243' => {    # 'ó'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0xC0, ##          00  
            0x01, 0x80, ##         00   
            0x03, 0x00, ##        00    
            0x07, 0x00, ##       000    
            0x06, 0x00, ##       00     
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x1F, 0x80, ##     000000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x60, ##   00      00 
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x1F, 0x80, ##     000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '244' => {    # 'ô'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x06, 0x00, ##       00     
            0x0F, 0x00, ##      0000    
            0x0F, 0x00, ##      0000    
            0x19, 0x80, ##     00  00   
            0x30, 0xC0, ##    00    00  
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x1F, 0x80, ##     000000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x60, ##   00      00 
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x1F, 0x80, ##     000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '245' => {    # 'õ'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1C, 0xC0, ##     000  00  
            0x3F, 0xC0, ##    00000000  
            0x33, 0x80, ##    00  000   
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x1F, 0x80, ##     000000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x60, ##   00      00 
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x1F, 0x80, ##     000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '246' => {    # 'ö'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x19, 0x80, ##     00  00   
            0x19, 0x80, ##     00  00   
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0x1F, 0x80, ##     000000   
            0x3F, 0xC0, ##    00000000  
            0x70, 0xE0, ##   000    000 
            0x60, 0x60, ##   00      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0x60, 0x60, ##   00      00 
            0x70, 0xE0, ##   000    000 
            0x3F, 0xC0, ##    00000000  
            0x1F, 0x80, ##     000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '247' => {    # '÷'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0xFF, 0xFE, ##  000000000000000
            0xFF, 0xFE, ##  000000000000000
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '248' => {    # 'ø'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x10, ##             0
            0x0F, 0x90, ##      00000  0
            0x3F, 0xF0, ##    0000000000
            0x70, 0xE0, ##   000    000 
            0x60, 0xE0, ##   00     000 
            0xC1, 0xB0, ##  00     00 00
            0xC3, 0x30, ##  00    00  00
            0xC6, 0x30, ##  00   00   00
            0xCC, 0x30, ##  00  00    00
            0xCC, 0x30, ##  00  00    00
            0xD8, 0x30, ##  00 00     00
            0x70, 0x60, ##   000     00 
            0x70, 0xE0, ##   000    000 
            0x7F, 0xC0, ##   000000000  
            0x9F, 0x80, ##  0  000000   
            0x80, 0x00, ##  0           
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '249' => {    # 'ù'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x70, 0x00, ##   000       
            0x30, 0x00, ##    00       
            0x18, 0x00, ##     00      
            0x0C, 0x00, ##      00     
            0x06, 0x00, ##       00    
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0x61, 0xE0, ##   00    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '250' => {    # 'ú'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0x80, ##         00  
            0x03, 0x80, ##        000  
            0x03, 0x00, ##        00   
            0x06, 0x00, ##       00    
            0x0C, 0x00, ##      00     
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0x61, 0xE0, ##   00    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '251' => {    # 'û'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0C, 0x00, ##      00     
            0x0E, 0x00, ##      000    
            0x1B, 0x00, ##     00 00   
            0x13, 0x00, ##     0  00   
            0x31, 0x80, ##    00   00  
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0x61, 0xE0, ##   00    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '252' => {    # 'ü'
        'width'    => 11, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x31, 0x80, ##    00   00  
            0x31, 0x80, ##    00   00  
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0x60, ##  00       00
            0xC0, 0xE0, ##  00      000
            0x61, 0xE0, ##   00    0000
            0x7F, 0x60, ##   0000000 00
            0x3E, 0x60, ##    00000  00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '253' => {    # 'ý'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0xC0, ##         000   
            0x01, 0x80, ##         00    
            0x03, 0x00, ##        00     
            0x06, 0x00, ##       00      
            0x04, 0x00, ##       0       
            0x00, 0x00, ##               
            0xC0, 0x30, ##  00        00 
            0xE0, 0x30, ##  000       00 
            0x60, 0x70, ##   00      000 
            0x60, 0x60, ##   00      00  
            0x30, 0x60, ##    00     00  
            0x30, 0xC0, ##    00    00   
            0x38, 0xC0, ##    000   00   
            0x19, 0xC0, ##     00  000   
            0x19, 0x80, ##     00  00    
            0x0D, 0x80, ##      00 00    
            0x0F, 0x80, ##      00000    
            0x0F, 0x00, ##      0000     
            0x07, 0x00, ##       000     
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x0E, 0x00, ##      000      
            0x0C, 0x00, ##      00       
            0x7C, 0x00, ##   00000       
            0x78, 0x00, ##   0000        
            0x00, 0x00, ##  
        ], 
    }, 
    '254' => {    # 'þ'
        'width'    => 12, 
        'xoffset'  => 2, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xCF, 0x80, ##  00  00000   
            0xDF, 0xC0, ##  00 0000000  
            0xF0, 0xE0, ##  0000    000 
            0xE0, 0x60, ##  000      00 
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xC0, 0x30, ##  00        00
            0xE0, 0x60, ##  000      00 
            0xF0, 0xE0, ##  0000    000 
            0xDF, 0xC0, ##  00 0000000  
            0xCF, 0x80, ##  00  00000   
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0xC0, 0x00, ##  00          
            0x00, 0x00, ##  
        ], 
    }, 
    '255' => {    # 'ÿ'
        'width'    => 13, 
        'xoffset'  => 0, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x18, 0xC0, ##     00   00   
            0x18, 0xC0, ##     00   00   
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xE0, 0x38, ##  000       000
            0x60, 0x30, ##   00       00 
            0x60, 0x30, ##   00       00 
            0x30, 0x70, ##    00     000 
            0x30, 0x60, ##    00     00  
            0x38, 0xE0, ##    000   000  
            0x18, 0xC0, ##     00   00   
            0x18, 0xC0, ##     00   00   
            0x1D, 0xC0, ##     000 000   
            0x0D, 0x80, ##      00 00    
            0x0D, 0x80, ##      00 00    
            0x0F, 0x80, ##      00000    
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x06, 0x00, ##       00      
            0x0E, 0x00, ##      000      
            0x0E, 0x00, ##      000      
            0x7C, 0x00, ##   00000       
            0x78, 0x00, ##   0000        
            0x00, 0x00, ##  
        ], 
    }, 
};
 
my $kerning = {
    '33' => { },  # !
    '34' => { },  # "
    '35' => { },  # #
    '36' => { },  # $
    '37' => { },  # %
    '38' => { },  # &
    '39' => { },  # '
    '40' => { },  # (
    '41' => { },  # )
    '42' => { },  # *
    '43' => { },  # +
    '44' => { },  # ,
    '45' => { '65' => -1, '66' => -1, '71' => 1, '74' => 1, '79' => 1, '81' => 1, '84' => -2, '86' => -1, '87' => -1, '88' => -1, '89' => -3, '118' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '210' => 1, '211' => 1, '212' => 1, '213' => 1, '214' => 1, '221' => -3, },  # -
    '46' => { },  # .
    '47' => { },  # /
    '48' => { },  # 0
    '49' => { },  # 1
    '50' => { },  # 2
    '51' => { },  # 3
    '52' => { },  # 4
    '53' => { },  # 5
    '54' => { },  # 6
    '55' => { },  # 7
    '56' => { },  # 8
    '57' => { },  # 9
    '58' => { },  # :
    '59' => { },  # ;
    '60' => { },  # <
    '61' => { },  # =
    '62' => { },  # >
    '63' => { },  # ?
    '64' => { },  # @
    '65' => { '45' => -1, '84' => -2, '86' => -1, '87' => -1, '89' => -2, '102' => -1, '118' => -1, '119' => -1, '121' => -2, '171' => -1, '192' => 1, '193' => 1, '194' => 1, '195' => 1, '196' => 1, '221' => -2, '253' => -2, '255' => -2, },  # A
    '66' => { '86' => -1, '87' => -1, '89' => -1, '171' => -1, '221' => -1, },  # B
    '67' => { },  # C
    '68' => { '89' => -1, '221' => -1, },  # D
    '69' => { },  # E
    '70' => { '46' => -4, '58' => -2, '65' => -2, '97' => -2, '101' => -1, '105' => -2, '111' => -1, '114' => -2, '117' => -1, '121' => -2, '192' => -2, '193' => -2, '194' => -2, '195' => -2, '196' => -2, '224' => -2, '225' => -2, '226' => -2, '227' => -2, '228' => -2, '229' => -2, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, '253' => -2, '255' => -2, },  # F
    '71' => { '84' => -1, '89' => -1, '221' => -1, },  # G
    '72' => { },  # H
    '73' => { },  # I
    '74' => { '45' => -1, },  # J
    '75' => { '45' => -2, '67' => -1, '79' => -1, '84' => -2, '85' => -1, '87' => -1, '89' => -1, '101' => -1, '111' => -1, '117' => -1, '121' => -2, '171' => -1, '199' => -1, '210' => -1, '211' => -1, '212' => -1, '213' => -1, '214' => -1, '217' => -1, '218' => -1, '219' => -1, '220' => -1, '221' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, '253' => -2, '255' => -2, },  # K
    '76' => { '65' => 1, '79' => -1, '84' => -3, '85' => -1, '86' => -3, '87' => -2, '89' => -3, '121' => -2, '192' => 1, '193' => 1, '194' => 1, '195' => 1, '196' => 1, '210' => -1, '211' => -1, '212' => -1, '213' => -1, '214' => -1, '217' => -1, '218' => -1, '219' => -1, '220' => -1, '221' => -3, '253' => -2, '255' => -2, },  # L
    '77' => { },  # M
    '78' => { },  # N
    '79' => { '45' => 1, '46' => -1, '88' => -1, '89' => -1, '221' => -1, },  # O
    '80' => { '45' => -1, '46' => -4, '65' => -1, '89' => -1, '97' => -1, '101' => -1, '105' => -1, '111' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '221' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, },  # P
    '81' => { '45' => 1, },  # Q
    '82' => { '45' => -1, '46' => -1, '58' => -1, '65' => -1, '67' => -1, '84' => -2, '86' => -1, '87' => -1, '89' => -1, '97' => -1, '101' => -1, '111' => -1, '117' => -1, '121' => -1, '171' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '199' => -1, '221' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, '253' => -1, '255' => -1, },  # R
    '83' => { },  # S
    '84' => { '45' => -2, '46' => -3, '58' => -3, '65' => -2, '67' => -1, '97' => -4, '99' => -4, '101' => -4, '105' => -1, '111' => -4, '114' => -3, '115' => -4, '117' => -3, '119' => -4, '121' => -4, '171' => -2, '187' => -1, '192' => -2, '193' => -2, '194' => -2, '195' => -2, '196' => -2, '199' => -1, '224' => -4, '225' => -4, '226' => -4, '227' => -4, '228' => -4, '229' => -4, '231' => -4, '232' => -4, '233' => -4, '234' => -4, '235' => -4, '242' => -4, '243' => -4, '244' => -4, '245' => -4, '246' => -4, '249' => -3, '250' => -3, '251' => -3, '252' => -3, '253' => -4, '255' => -4, },  # T
    '85' => { },  # U
    '86' => { '45' => -1, '46' => -3, '58' => -2, '65' => -1, '97' => -2, '101' => -2, '105' => -1, '111' => -2, '117' => -2, '121' => -1, '171' => -2, '187' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -2, '225' => -2, '226' => -2, '227' => -2, '228' => -2, '229' => -2, '232' => -2, '233' => -2, '234' => -2, '235' => -2, '242' => -2, '243' => -2, '244' => -2, '245' => -2, '246' => -2, '249' => -2, '250' => -2, '251' => -2, '252' => -2, '253' => -1, '255' => -1, },  # V
    '87' => { '45' => -1, '46' => -3, '58' => -1, '65' => -1, '97' => -1, '101' => -1, '105' => -1, '111' => -1, '114' => -1, '117' => -1, '171' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, },  # W
    '88' => { '45' => -1, '67' => -2, '79' => -1, '101' => -1, '171' => -1, '199' => -2, '210' => -1, '211' => -1, '212' => -1, '213' => -1, '214' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, },  # X
    '89' => { '45' => -3, '46' => -5, '58' => -3, '65' => -2, '67' => -1, '79' => -1, '97' => -3, '101' => -3, '105' => -1, '111' => -3, '117' => -3, '171' => -3, '187' => -2, '192' => -2, '193' => -2, '194' => -2, '195' => -2, '196' => -2, '199' => -1, '210' => -1, '211' => -1, '212' => -1, '213' => -1, '214' => -1, '224' => -3, '225' => -3, '226' => -3, '227' => -3, '228' => -3, '229' => -3, '232' => -3, '233' => -3, '234' => -3, '235' => -3, '242' => -3, '243' => -3, '244' => -3, '245' => -3, '246' => -3, '249' => -3, '250' => -3, '251' => -3, '252' => -3, },  # Y
    '90' => { },  # Z
    '91' => { },  # [
    '92' => { },  # \
    '93' => { },  # ]
    '94' => { },  # ^
    '95' => { },  # _
    '96' => { },  # `
    '97' => { },  # a
    '98' => { },  # b
    '99' => { },  # c
    '100' => { },  # d
    '101' => { },  # e
    '102' => { '45' => -1, '46' => -2, '58' => -1, '171' => -1, },  # f
    '103' => { },  # g
    '104' => { },  # h
    '105' => { },  # i
    '106' => { },  # j
    '107' => { '101' => -1, '111' => -1, '117' => -1, '121' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, '253' => -1, '255' => -1, },  # k
    '108' => { },  # l
    '109' => { },  # m
    '110' => { },  # n
    '111' => { '120' => -1, },  # o
    '112' => { },  # p
    '113' => { },  # q
    '114' => { '45' => -1, '46' => -2, '99' => -1, '101' => -1, '111' => -1, '120' => -1, '171' => -1, '231' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, },  # r
    '115' => { },  # s
    '116' => { },  # t
    '117' => { },  # u
    '118' => { '45' => -1, '46' => -2, '58' => -1, },  # v
    '119' => { '46' => -2, '58' => -1, },  # w
    '120' => { '101' => -1, '111' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, },  # x
    '121' => { '46' => -3, '58' => -2, },  # y
    '122' => { },  # z
    '123' => { },  # {
    '124' => { },  # |
    '125' => { },  # }
    '126' => { },  # ~
    '160' => { },  #  
    '161' => { },  # ¡
    '162' => { },  # ¢
    '163' => { },  # £
    '164' => { },  # ¤
    '165' => { },  # ¥
    '166' => { },  # ¦
    '167' => { },  # §
    '168' => { },  # ¨
    '169' => { },  # ©
    '170' => { },  # ª
    '171' => { '84' => -1, '86' => -1, '89' => -2, '198' => 2, '221' => -2, },  # «
    '172' => { },  # ¬
    '173' => { },  # ­
    '174' => { },  # ®
    '175' => { },  # ¯
    '176' => { },  # °
    '177' => { },  # ±
    '178' => { },  # ²
    '179' => { },  # ³
    '180' => { },  # ´
    '181' => { },  # µ
    '182' => { },  # ¶
    '183' => { },  # ·
    '184' => { },  # ¸
    '185' => { },  # ¹
    '186' => { },  # º
    '187' => { '65' => -1, '66' => -1, '84' => -2, '86' => -2, '87' => -1, '88' => -1, '89' => -3, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '221' => -3, },  # »
    '188' => { },  # ¼
    '189' => { },  # ½
    '190' => { },  # ¾
    '191' => { },  # ¿
    '192' => { '45' => -1, '65' => 1, '84' => -2, '86' => -1, '87' => -1, '89' => -2, '102' => -1, '118' => -1, '119' => -1, '121' => -2, '171' => -1, '193' => 1, '194' => 1, '195' => 1, '196' => 1, '221' => -2, '253' => -2, '255' => -2, },  # À
    '193' => { '45' => -1, '65' => 1, '84' => -2, '86' => -1, '87' => -1, '89' => -2, '102' => -1, '118' => -1, '119' => -1, '121' => -2, '171' => -1, '192' => 1, '194' => 1, '195' => 1, '196' => 1, '221' => -2, '253' => -2, '255' => -2, },  # Á
    '194' => { '45' => -1, '65' => 1, '84' => -2, '86' => -1, '87' => -1, '89' => -2, '102' => -1, '118' => -1, '119' => -1, '121' => -2, '171' => -1, '192' => 1, '193' => 1, '195' => 1, '196' => 1, '221' => -2, '253' => -2, '255' => -2, },  # Â
    '195' => { '45' => -1, '65' => 1, '84' => -2, '86' => -1, '87' => -1, '89' => -2, '102' => -1, '118' => -1, '119' => -1, '121' => -2, '171' => -1, '192' => 1, '193' => 1, '194' => 1, '196' => 1, '221' => -2, '253' => -2, '255' => -2, },  # Ã
    '196' => { '45' => -1, '65' => 1, '84' => -2, '86' => -1, '87' => -1, '89' => -2, '102' => -1, '118' => -1, '119' => -1, '121' => -2, '171' => -1, '192' => 1, '193' => 1, '194' => 1, '195' => 1, '221' => -2, '253' => -2, '255' => -2, },  # Ä
    '197' => { },  # Å
    '198' => { },  # Æ
    '199' => { },  # Ç
    '200' => { },  # È
    '201' => { },  # É
    '202' => { },  # Ê
    '203' => { },  # Ë
    '204' => { },  # Ì
    '205' => { },  # Í
    '206' => { },  # Î
    '207' => { },  # Ï
    '208' => { },  # Ð
    '209' => { },  # Ñ
    '210' => { '45' => 1, '46' => -1, '88' => -1, '89' => -1, '221' => -1, },  # Ò
    '211' => { '45' => 1, '46' => -1, '88' => -1, '89' => -1, '221' => -1, },  # Ó
    '212' => { '45' => 1, '46' => -1, '88' => -1, '89' => -1, '221' => -1, },  # Ô
    '213' => { '45' => 1, '46' => -1, '88' => -1, '89' => -1, '221' => -1, },  # Õ
    '214' => { '45' => 1, '46' => -1, '88' => -1, '89' => -1, '221' => -1, },  # Ö
    '215' => { },  # ×
    '216' => { },  # Ø
    '217' => { },  # Ù
    '218' => { },  # Ú
    '219' => { },  # Û
    '220' => { },  # Ü
    '221' => { '45' => -3, '46' => -5, '58' => -3, '65' => -2, '67' => -1, '79' => -1, '97' => -3, '101' => -3, '105' => -1, '111' => -3, '117' => -3, '171' => -3, '187' => -2, '192' => -2, '193' => -2, '194' => -2, '195' => -2, '196' => -2, '199' => -1, '210' => -1, '211' => -1, '212' => -1, '213' => -1, '214' => -1, '224' => -3, '225' => -3, '226' => -3, '227' => -3, '228' => -3, '229' => -3, '232' => -3, '233' => -3, '234' => -3, '235' => -3, '242' => -3, '243' => -3, '244' => -3, '245' => -3, '246' => -3, '249' => -3, '250' => -3, '251' => -3, '252' => -3, },  # Ý
    '222' => { '46' => -2, '58' => -1, },  # Þ
    '223' => { },  # ß
    '224' => { },  # à
    '225' => { },  # á
    '226' => { },  # â
    '227' => { },  # ã
    '228' => { },  # ä
    '229' => { },  # å
    '230' => { },  # æ
    '231' => { },  # ç
    '232' => { },  # è
    '233' => { },  # é
    '234' => { },  # ê
    '235' => { },  # ë
    '236' => { },  # ì
    '237' => { },  # í
    '238' => { },  # î
    '239' => { },  # ï
    '240' => { },  # ð
    '241' => { },  # ñ
    '242' => { '120' => -1, },  # ò
    '243' => { '120' => -1, },  # ó
    '244' => { '120' => -1, },  # ô
    '245' => { '120' => -1, },  # õ
    '246' => { '120' => -1, },  # ö
    '247' => { },  # ÷
    '248' => { },  # ø
    '249' => { },  # ù
    '250' => { },  # ú
    '251' => { },  # û
    '252' => { },  # ü
    '253' => { '46' => -3, '58' => -2, },  # ý
    '254' => { },  # þ
    '255' => { '46' => -3, '58' => -2, },  # ÿ
};


sub new {
    my($class) = @_;
    
    my $self = $class->SUPER::new(
        name        => $name,
        char_height => $char_height,
        space_width => $space_width,
        gap_width   => $gap_width,
        symbols     => $symbols,
        kerning     => $kerning,
        line_spacing => $line_spacing,
        class       => 'hipi_2',
    );
    
    return $self;
}

1;

__END__
