#########################################################################################
# Package        HiPi::Graphics::BitmapFont::Serif33
# Description  : Monochrome OLED Font
# License      : This is free software; you can redistribute it and/or modify it under
#                the same terms as the Perl 5 programming language system itself.
#########################################################################################

package HiPi::Graphics::BitmapFont::Serif33;

#########################################################################################

use utf8;
use strict;
use warnings;
use parent qw( HiPi::Graphics::BitmapFont);

our $VERSION ='0.01';

my $gap_width = 0;
my $char_height = 33;
my $line_spacing = 4;
my $name = 'Serif 33';
my $space_width = 10;
 
my $symbols = {
    '33' => {    # '!'
        'width'    => 4, 
        'xoffset'  => 4, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF0, ##  0000
            0xF0, ##  0000
            0xF0, ##  0000
            0xF0, ##  0000
            0xF0, ##  0000
            0xF0, ##  0000
            0x60, ##   00 
            0x60, ##   00 
            0x60, ##   00 
            0x60, ##   00 
            0x60, ##   00 
            0x60, ##   00 
            0x60, ##   00 
            0x60, ##   00 
            0x60, ##   00 
            0x60, ##   00 
            0x00, ##      
            0x00, ##      
            0x00, ##      
            0x60, ##   00 
            0xF0, ##  0000
            0xF0, ##  0000
            0x60, ##   00 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '34' => {    # '"'
        'width'    => 9, 
        'xoffset'  => 3, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE3, 0x80, ##  000   000
            0xE3, 0x80, ##  000   000
            0xE3, 0x80, ##  000   000
            0xE3, 0x80, ##  000   000
            0xE3, 0x80, ##  000   000
            0xE3, 0x80, ##  000   000
            0xE3, 0x80, ##  000   000
            0xE3, 0x80, ##  000   000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '35' => {    # '#'
        'width'    => 22, 
        'xoffset'  => 2, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x70, 0xE0, ##           000    000   
            0x00, 0x60, 0xC0, ##           00     00    
            0x00, 0xE1, 0xC0, ##          000    000    
            0x00, 0xE1, 0xC0, ##          000    000    
            0x00, 0xE1, 0x80, ##          000    00     
            0x00, 0xC1, 0x80, ##          00     00     
            0x3F, 0xFF, 0xFC, ##    00000000000000000000
            0x01, 0x83, 0x00, ##         00     00      
            0x01, 0x83, 0x00, ##         00     00      
            0x03, 0x87, 0x00, ##        000    000      
            0x03, 0x87, 0x00, ##        000    000      
            0x03, 0x87, 0x00, ##        000    000      
            0x03, 0x87, 0x00, ##        000    000      
            0x03, 0x06, 0x00, ##        00     00       
            0x03, 0x06, 0x00, ##        00     00       
            0xFF, 0xFF, 0xF0, ##  00000000000000000000  
            0x07, 0x0C, 0x00, ##       000    00        
            0x06, 0x0C, 0x00, ##       00     00        
            0x0E, 0x1C, 0x00, ##      000    000        
            0x0E, 0x1C, 0x00, ##      000    000        
            0x0E, 0x1C, 0x00, ##      000    000        
            0x0C, 0x18, 0x00, ##      00     00         
            0x0C, 0x38, 0x00, ##      00    000         
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '36' => {    # '$'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x1F, 0xF0, ##     000000000   
            0x33, 0x3C, ##    00  00  0000 
            0x63, 0x1C, ##   00   00   000 
            0xE3, 0x0C, ##  000   00    00 
            0xE3, 0x0C, ##  000   00    00 
            0xE3, 0x00, ##  000   00       
            0xF3, 0x00, ##  0000  00       
            0xFB, 0x00, ##  00000 00       
            0x7F, 0x80, ##   00000000      
            0x3F, 0xF0, ##    0000000000   
            0x0F, 0xF8, ##      000000000  
            0x03, 0xFC, ##        00000000 
            0x03, 0x3E, ##        00  00000
            0x03, 0x1E, ##        00   0000
            0xC3, 0x0E, ##  00    00    000
            0xC3, 0x0E, ##  00    00    000
            0xC3, 0x0E, ##  00    00    000
            0xE3, 0x1C, ##  000   00   000 
            0xF3, 0x38, ##  0000  00  000  
            0x3F, 0xE0, ##    000000000    
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x03, 0x00, ##        00       
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '37' => {    # '%'
        'width'    => 27, 
        'xoffset'  => 2, 
        'xadvance' => 31, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x1F, 0x00, 0x1C, 0x00, ##     00000           000     
            0x71, 0xC0, 0x18, 0x00, ##   000   000         00      
            0x71, 0xC0, 0x30, 0x00, ##   000   000        00       
            0xE0, 0xE0, 0x30, 0x00, ##  000     000       00       
            0xE0, 0xE0, 0x60, 0x00, ##  000     000      00        
            0xE0, 0xE0, 0xC0, 0x00, ##  000     000     00         
            0xE0, 0xE0, 0xC0, 0x00, ##  000     000     00         
            0xE0, 0xE1, 0x80, 0x00, ##  000     000    00          
            0x61, 0xC3, 0x00, 0x00, ##   00    000    00           
            0x71, 0xC3, 0x00, 0x00, ##   000   000    00           
            0x1F, 0x06, 0x1F, 0x00, ##     00000     00    00000   
            0x00, 0x0E, 0x31, 0x80, ##              000   00   00  
            0x00, 0x0C, 0x71, 0xC0, ##              00   000   000 
            0x00, 0x18, 0xE0, 0xC0, ##             00   000     00 
            0x00, 0x18, 0xE0, 0xE0, ##             00   000     000
            0x00, 0x30, 0xE0, 0xE0, ##            00    000     000
            0x00, 0x60, 0xE0, 0xE0, ##           00     000     000
            0x00, 0x60, 0xE0, 0xE0, ##           00     000     000
            0x00, 0xC0, 0xE0, 0xE0, ##          00      000     000
            0x01, 0x80, 0xE0, 0xE0, ##         00       000     000
            0x01, 0x80, 0x71, 0xC0, ##         00        000   000 
            0x03, 0x00, 0x31, 0x80, ##        00          00   00  
            0x07, 0x00, 0x1F, 0x00, ##       000           00000   
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '38' => {    # '&'
        'width'    => 25, 
        'xoffset'  => 2, 
        'xadvance' => 28, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x01, 0xFE, 0x00, 0x00, ##         00000000          
            0x07, 0x0F, 0x00, 0x00, ##       000    0000         
            0x0E, 0x07, 0x00, 0x00, ##      000      000         
            0x1C, 0x03, 0x00, 0x00, ##     000        00         
            0x1C, 0x00, 0x00, 0x00, ##     000                   
            0x1C, 0x00, 0x00, 0x00, ##     000                   
            0x1E, 0x00, 0x00, 0x00, ##     0000                  
            0x0F, 0x00, 0x00, 0x00, ##      0000                 
            0x0F, 0x80, 0x00, 0x00, ##      00000                
            0x1F, 0xC0, 0x00, 0x00, ##     0000000               
            0x3B, 0xE0, 0x7F, 0x00, ##    000 00000      0000000 
            0x71, 0xF0, 0x08, 0x00, ##   000   00000        0    
            0x70, 0xF8, 0x18, 0x00, ##   000    00000      00    
            0xE0, 0x7C, 0x18, 0x00, ##  000      00000     00    
            0xE0, 0x3E, 0x18, 0x00, ##  000       00000    00    
            0xE0, 0x1F, 0x30, 0x00, ##  000        00000  00     
            0xE0, 0x0F, 0xB0, 0x00, ##  000         00000 00     
            0xE0, 0x07, 0xE0, 0x00, ##  000          000000      
            0x70, 0x03, 0xE0, 0x00, ##   000          00000      
            0x70, 0x03, 0xE0, 0x00, ##   000          00000      
            0x38, 0x03, 0xF0, 0x00, ##    000         000000     
            0x1E, 0x0F, 0x78, 0x00, ##     0000     0000 0000    
            0x07, 0xF8, 0x3F, 0x80, ##       00000000     0000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '39' => {    # '''
        'width'    => 3, 
        'xoffset'  => 3, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '40' => {    # '('
        'width'    => 8, 
        'xoffset'  => 3, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x03, ##        00
            0x06, ##       00 
            0x0C, ##      00  
            0x18, ##     00   
            0x38, ##    000   
            0x30, ##    00    
            0x70, ##   000    
            0x70, ##   000    
            0x60, ##   00     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0x60, ##   00     
            0x70, ##   000    
            0x70, ##   000    
            0x30, ##    00    
            0x38, ##    000   
            0x18, ##     00   
            0x0C, ##      00  
            0x07, ##       000
            0x01, ##         0
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '41' => {    # ')'
        'width'    => 7, 
        'xoffset'  => 3, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x80, ##  0      
            0xC0, ##  00     
            0x60, ##   00    
            0x30, ##    00   
            0x38, ##    000  
            0x18, ##     00  
            0x1C, ##     000 
            0x1C, ##     000 
            0x0C, ##      00 
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x1C, ##     000 
            0x1C, ##     000 
            0x1C, ##     000 
            0x18, ##     00  
            0x38, ##    000  
            0x30, ##    00   
            0x60, ##   00    
            0xC0, ##  00     
            0x00, ##         
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '42' => {    # '*'
        'width'    => 16, 
        'xoffset'  => 0, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0x80, ##         00       
            0x01, 0x80, ##         00       
            0x01, 0x80, ##         00       
            0x61, 0x86, ##   00    00    00 
            0x79, 0x9E, ##   0000  00  0000 
            0x1F, 0xF8, ##     0000000000   
            0x07, 0xE0, ##       000000     
            0x03, 0xE0, ##        00000     
            0x1F, 0xF8, ##     0000000000   
            0x79, 0x9E, ##   0000  00  0000 
            0x61, 0x86, ##   00    00    00 
            0x01, 0x80, ##         00       
            0x01, 0x80, ##         00       
            0x01, 0x80, ##         00       
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '43' => {    # '+'
        'width'    => 20, 
        'xoffset'  => 3, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0xFF, 0xFF, 0xF0, ##  00000000000000000000
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x70, 0x00, ##           000        
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '44' => {    # ','
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x1C, ##     000
            0x1C, ##     000
            0x1C, ##     000
            0x18, ##     00 
            0x38, ##    000 
            0x70, ##   000  
            0xE0, ##  000   
            0x40, ##   0    
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '45' => {    # '-'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFF, ##  00000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '46' => {    # '.'
        'width'    => 4, 
        'xoffset'  => 3, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x60, ##   00 
            0xF0, ##  0000
            0xF0, ##  0000
            0x60, ##   00 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '47' => {    # '/'
        'width'    => 11, 
        'xoffset'  => 0, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0xE0, ##          000
            0x00, 0xC0, ##          00 
            0x01, 0xC0, ##         000 
            0x01, 0xC0, ##         000 
            0x01, 0x80, ##         00  
            0x01, 0x80, ##         00  
            0x03, 0x80, ##        000  
            0x03, 0x00, ##        00   
            0x03, 0x00, ##        00   
            0x07, 0x00, ##       000   
            0x06, 0x00, ##       00    
            0x06, 0x00, ##       00    
            0x0E, 0x00, ##      000    
            0x0C, 0x00, ##      00     
            0x0C, 0x00, ##      00     
            0x1C, 0x00, ##     000     
            0x1C, 0x00, ##     000     
            0x18, 0x00, ##     00      
            0x38, 0x00, ##    000      
            0x38, 0x00, ##    000      
            0x30, 0x00, ##    00       
            0x70, 0x00, ##   000       
            0x70, 0x00, ##   000       
            0x60, 0x00, ##   00        
            0xE0, 0x00, ##  000        
            0xE0, 0x00, ##  000        
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '48' => {    # '0'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xE0, ##       000000     
            0x0C, 0x30, ##      00    00    
            0x18, 0x18, ##     00      00   
            0x30, 0x0C, ##    00        00  
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0x60, 0x06, ##   00          00 
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0x60, 0x06, ##   00          00 
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0x30, 0x0C, ##    00        00  
            0x38, 0x1C, ##    000      000  
            0x1C, 0x38, ##     000    000   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '49' => {    # '1'
        'width'    => 11, 
        'xoffset'  => 4, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0E, 0x00, ##      000    
            0x1E, 0x00, ##     0000    
            0x7E, 0x00, ##   000000    
            0xEE, 0x00, ##  000 000    
            0xCE, 0x00, ##  00  000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0xFF, 0xE0, ##  00000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '50' => {    # '2'
        'width'    => 15, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0xC0, ##     0000000     
            0xF0, 0x70, ##  0000     000   
            0xE0, 0x38, ##  000       000  
            0xC0, 0x38, ##  00        000  
            0xC0, 0x1C, ##  00         000 
            0xC0, 0x1C, ##  00         000 
            0x00, 0x1C, ##             000 
            0x00, 0x1C, ##             000 
            0x00, 0x1C, ##             000 
            0x00, 0x38, ##            000  
            0x00, 0x38, ##            000  
            0x00, 0x70, ##           000   
            0x00, 0x70, ##           000   
            0x00, 0xE0, ##          000    
            0x01, 0xC0, ##         000     
            0x03, 0x80, ##        000      
            0x07, 0x00, ##       000       
            0x0E, 0x00, ##      000        
            0x0C, 0x00, ##      00         
            0x1C, 0x06, ##     000       00
            0x38, 0x06, ##    000        00
            0x70, 0x06, ##   000         00
            0xFF, 0xFE, ##  000000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '51' => {    # '3'
        'width'    => 15, 
        'xoffset'  => 2, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0xE0, ##     00000000    
            0x78, 0x38, ##   0000     000  
            0x60, 0x1C, ##   00        000 
            0x60, 0x0E, ##   00         000
            0x60, 0x0E, ##   00         000
            0x00, 0x0E, ##              000
            0x00, 0x0E, ##              000
            0x00, 0x1C, ##             000 
            0x00, 0x38, ##            000  
            0x07, 0xC0, ##       00000     
            0x00, 0x78, ##           0000  
            0x00, 0x1C, ##             000 
            0x00, 0x1C, ##             000 
            0x00, 0x0E, ##              000
            0x00, 0x0E, ##              000
            0x00, 0x0E, ##              000
            0x00, 0x0E, ##              000
            0xC0, 0x0E, ##  00          000
            0xC0, 0x0E, ##  00          000
            0xC0, 0x1C, ##  00         000 
            0xE0, 0x1C, ##  000        000 
            0xF0, 0x78, ##  0000     0000  
            0x3F, 0xC0, ##    00000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '52' => {    # '4'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x38, 0x00, ##            000     
            0x00, 0x78, 0x00, ##           0000     
            0x00, 0xF8, 0x00, ##          00000     
            0x00, 0xF8, 0x00, ##          00000     
            0x01, 0xB8, 0x00, ##         00 000     
            0x01, 0xB8, 0x00, ##         00 000     
            0x03, 0x38, 0x00, ##        00  000     
            0x06, 0x38, 0x00, ##       00   000     
            0x06, 0x38, 0x00, ##       00   000     
            0x0C, 0x38, 0x00, ##      00    000     
            0x1C, 0x38, 0x00, ##     000    000     
            0x18, 0x38, 0x00, ##     00     000     
            0x30, 0x38, 0x00, ##    00      000     
            0x30, 0x38, 0x00, ##    00      000     
            0x60, 0x38, 0x00, ##   00       000     
            0xC0, 0x38, 0x00, ##  00        000     
            0xFF, 0xFF, 0xC0, ##  000000000000000000
            0x00, 0x38, 0x00, ##            000     
            0x00, 0x38, 0x00, ##            000     
            0x00, 0x38, 0x00, ##            000     
            0x00, 0x38, 0x00, ##            000     
            0x00, 0x38, 0x00, ##            000     
            0x00, 0x38, 0x00, ##            000     
            0x03, 0xFF, 0x80, ##        00000000000 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '53' => {    # '5'
        'width'    => 15, 
        'xoffset'  => 3, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x7F, 0xF8, ##   000000000000  
            0x60, 0x00, ##   00            
            0x60, 0x00, ##   00            
            0x60, 0x00, ##   00            
            0x60, 0x00, ##   00            
            0x60, 0x00, ##   00            
            0x60, 0x00, ##   00            
            0x60, 0x00, ##   00            
            0x6F, 0xC0, ##   00 000000     
            0x78, 0x70, ##   0000    000   
            0x60, 0x18, ##   00        00  
            0x00, 0x1C, ##             000 
            0x00, 0x0E, ##              000
            0x00, 0x0E, ##              000
            0x00, 0x0E, ##              000
            0x00, 0x0E, ##              000
            0x00, 0x0E, ##              000
            0xC0, 0x0E, ##  00          000
            0xC0, 0x0E, ##  00          000
            0xC0, 0x1C, ##  00         000 
            0xE0, 0x38, ##  000       000  
            0xF0, 0x70, ##  0000     000   
            0x3F, 0xC0, ##    00000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '54' => {    # '6'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0xFC, ##        00000000  
            0x0E, 0x0E, ##      000     000 
            0x1C, 0x06, ##     000       00 
            0x38, 0x06, ##    000        00 
            0x30, 0x00, ##    00            
            0x70, 0x00, ##   000            
            0x70, 0x00, ##   000            
            0xF0, 0x00, ##  0000            
            0xF3, 0xF0, ##  0000  000000    
            0xFC, 0x18, ##  000000     00   
            0xF8, 0x0C, ##  00000       00  
            0xF8, 0x0E, ##  00000       000 
            0xF0, 0x07, ##  0000         000
            0xF0, 0x07, ##  0000         000
            0xF0, 0x07, ##  0000         000
            0xF0, 0x07, ##  0000         000
            0xF0, 0x07, ##  0000         000
            0x70, 0x07, ##   000         000
            0x70, 0x06, ##   000         00 
            0x38, 0x0E, ##    000       000 
            0x38, 0x0C, ##    000       00  
            0x1C, 0x18, ##     000     00   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '55' => {    # '7'
        'width'    => 16, 
        'xoffset'  => 3, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFF, ##  0000000000000000
            0xC0, 0x06, ##  00           00 
            0xC0, 0x0E, ##  00          000 
            0xC0, 0x0C, ##  00          00  
            0x00, 0x1C, ##             000  
            0x00, 0x1C, ##             000  
            0x00, 0x18, ##             00   
            0x00, 0x38, ##            000   
            0x00, 0x30, ##            00    
            0x00, 0x70, ##           000    
            0x00, 0x60, ##           00     
            0x00, 0x60, ##           00     
            0x00, 0xE0, ##          000     
            0x00, 0xC0, ##          00      
            0x01, 0xC0, ##         000      
            0x01, 0x80, ##         00       
            0x01, 0x80, ##         00       
            0x03, 0x80, ##        000       
            0x03, 0x00, ##        00        
            0x07, 0x00, ##       000        
            0x06, 0x00, ##       00         
            0x06, 0x00, ##       00         
            0x0E, 0x00, ##      000         
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '56' => {    # '8'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xE0, ##       000000     
            0x1C, 0x38, ##     000    000   
            0x38, 0x1C, ##    000      000  
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1C, 0x38, ##     000    000   
            0x03, 0xE0, ##        00000     
            0x1C, 0x38, ##     000    000   
            0x70, 0x0C, ##   000        00  
            0x70, 0x0E, ##   000        000 
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0x3C, 0x3C, ##    0000    0000  
            0x0F, 0xF0, ##      00000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '57' => {    # '9'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xE0, ##       000000     
            0x1C, 0x38, ##     000    000   
            0x30, 0x1C, ##    00       000  
            0x70, 0x0C, ##   000        00  
            0xE0, 0x0E, ##  000         000 
            0xE0, 0x0E, ##  000         000 
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x0F, ##  000         0000
            0xE0, 0x0F, ##  000         0000
            0x70, 0x0F, ##   000        0000
            0x70, 0x1F, ##   000       00000
            0x3C, 0x3F, ##    0000    000000
            0x0F, 0xE7, ##      0000000  000
            0x00, 0x07, ##               000
            0x00, 0x07, ##               000
            0x00, 0x06, ##               00 
            0x00, 0x0E, ##              000 
            0x60, 0x0C, ##   00         00  
            0x60, 0x0C, ##   00         00  
            0x60, 0x18, ##   00        00   
            0x78, 0x70, ##   0000    000    
            0x3F, 0xC0, ##    00000000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '58' => {    # ':'
        'width'    => 4, 
        'xoffset'  => 3, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x60, ##   00 
            0xF0, ##  0000
            0xF0, ##  0000
            0x60, ##   00 
            0x00, ##      
            0x00, ##      
            0x00, ##      
            0x00, ##      
            0x00, ##      
            0x00, ##      
            0x60, ##   00 
            0xF0, ##  0000
            0xF0, ##  0000
            0x60, ##   00 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '59' => {    # ';'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x18, ##     00 
            0x3C, ##    0000
            0x3C, ##    0000
            0x18, ##     00 
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x00, ##        
            0x1C, ##     000
            0x1C, ##     000
            0x1C, ##     000
            0x38, ##    000 
            0x38, ##    000 
            0x70, ##   000  
            0xE0, ##  000   
            0x40, ##   0    
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '60' => {    # '<'
        'width'    => 20, 
        'xoffset'  => 3, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##                      
            0x00, 0x00, 0x70, ##                   000
            0x00, 0x03, 0xF0, ##                000000
            0x00, 0x0F, 0xE0, ##              0000000 
            0x00, 0x7F, 0x00, ##           0000000    
            0x03, 0xF8, 0x00, ##        0000000       
            0x1F, 0xE0, 0x00, ##     00000000         
            0x7F, 0x00, 0x00, ##   0000000            
            0xF8, 0x00, 0x00, ##  00000               
            0xF8, 0x00, 0x00, ##  00000               
            0x7F, 0x00, 0x00, ##   0000000            
            0x1F, 0xE0, 0x00, ##     00000000         
            0x03, 0xF8, 0x00, ##        0000000       
            0x00, 0x7F, 0x00, ##           0000000    
            0x00, 0x0F, 0xE0, ##              0000000 
            0x00, 0x03, 0xF0, ##                000000
            0x00, 0x00, 0x70, ##                   000
            0x00, 0x00, 0x00, ##                      
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '61' => {    # '='
        'width'    => 20, 
        'xoffset'  => 3, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xF0, ##  00000000000000000000
            0x00, 0x00, 0x00, ##                      
            0x00, 0x00, 0x00, ##                      
            0x00, 0x00, 0x00, ##                      
            0x00, 0x00, 0x00, ##                      
            0x00, 0x00, 0x00, ##                      
            0x00, 0x00, 0x00, ##                      
            0xFF, 0xFF, 0xF0, ##  00000000000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '62' => {    # '>'
        'width'    => 20, 
        'xoffset'  => 3, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##                      
            0xE0, 0x00, 0x00, ##  000                 
            0xFC, 0x00, 0x00, ##  000000              
            0x7F, 0x00, 0x00, ##   0000000            
            0x0F, 0xE0, 0x00, ##      0000000         
            0x01, 0xFC, 0x00, ##         0000000      
            0x00, 0x7F, 0x80, ##           00000000   
            0x00, 0x0F, 0xE0, ##              0000000 
            0x00, 0x01, 0xF0, ##                 00000
            0x00, 0x01, 0xF0, ##                 00000
            0x00, 0x0F, 0xE0, ##              0000000 
            0x00, 0x7F, 0x80, ##           00000000   
            0x01, 0xFC, 0x00, ##         0000000      
            0x0F, 0xE0, 0x00, ##      0000000         
            0x7F, 0x00, 0x00, ##   0000000            
            0xFC, 0x00, 0x00, ##  000000              
            0xE0, 0x00, 0x00, ##  000                 
            0x00, 0x00, 0x00, ##                      
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '63' => {    # '?'
        'width'    => 13, 
        'xoffset'  => 3, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x7F, 0x80, ##   00000000    
            0xE0, 0xE0, ##  000     000  
            0xC0, 0x70, ##  00       000 
            0x80, 0x38, ##  0         000
            0x80, 0x38, ##  0         000
            0x00, 0x38, ##            000
            0x00, 0x38, ##            000
            0x00, 0x38, ##            000
            0x00, 0x70, ##           000 
            0x00, 0xF0, ##          0000 
            0x01, 0xE0, ##         0000  
            0x0F, 0xC0, ##      000000   
            0x0E, 0x00, ##      000      
            0x0C, 0x00, ##      00       
            0x0C, 0x00, ##      00       
            0x0C, 0x00, ##      00       
            0x0C, 0x00, ##      00       
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0x0C, 0x00, ##      00       
            0x1E, 0x00, ##     0000      
            0x1E, 0x00, ##     0000      
            0x0C, 0x00, ##      00       
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '64' => {    # '@'
        'width'    => 27, 
        'xoffset'  => 2, 
        'xadvance' => 31, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x3F, 0xC0, 0x00, ##            00000000         
            0x00, 0xF0, 0x30, 0x00, ##          0000      00       
            0x03, 0x80, 0x0C, 0x00, ##        000           00     
            0x07, 0x00, 0x02, 0x00, ##       000              0    
            0x0C, 0x00, 0x01, 0x00, ##      00                 0   
            0x1C, 0x00, 0x00, 0x80, ##     000                  0  
            0x38, 0x00, 0x00, 0x40, ##    000                    0 
            0x30, 0x1F, 0x00, 0x40, ##    00       00000         0 
            0x70, 0x70, 0xF8, 0x40, ##   000     000    00000    0 
            0x70, 0xE0, 0x78, 0x20, ##   000    000      0000     0
            0xE0, 0xE0, 0x38, 0x20, ##  000     000       000     0
            0xE1, 0xC0, 0x38, 0x20, ##  000    000        000     0
            0xE1, 0xC0, 0x38, 0x20, ##  000    000        000     0
            0xE1, 0xC0, 0x38, 0x20, ##  000    000        000     0
            0xE1, 0xC0, 0x38, 0x20, ##  000    000        000     0
            0xE1, 0xC0, 0x38, 0x40, ##  000    000        000    0 
            0xE1, 0xC0, 0x38, 0x40, ##  000    000        000    0 
            0xE0, 0xE0, 0x78, 0x80, ##  000     000      0000   0  
            0x70, 0xE0, 0x78, 0x80, ##   000    000      0000   0  
            0x70, 0x70, 0xFB, 0x00, ##   000     000    00000 00   
            0x70, 0x1F, 0x3C, 0x00, ##   000       00000  0000     
            0x38, 0x00, 0x00, 0x00, ##    000                      
            0x1C, 0x00, 0x00, 0x00, ##     000                     
            0x0C, 0x00, 0x00, 0x00, ##      00                     
            0x07, 0x00, 0x00, 0x00, ##       000                   
            0x03, 0x80, 0x06, 0x00, ##        000            00    
            0x00, 0xF0, 0x38, 0x00, ##          0000      000      
            0x00, 0x3F, 0xC0, 0x00, ##            00000000         
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '65' => {    # 'A'
        'width'    => 23, 
        'xoffset'  => 0, 
        'xadvance' => 23, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x38, 0x00, ##            000          
            0x00, 0x3C, 0x00, ##            0000         
            0x00, 0x3C, 0x00, ##            0000         
            0x00, 0x7C, 0x00, ##           00000         
            0x00, 0x7E, 0x00, ##           000000        
            0x00, 0xCE, 0x00, ##          00  000        
            0x00, 0xCE, 0x00, ##          00  000        
            0x00, 0xCF, 0x00, ##          00  0000       
            0x01, 0x87, 0x00, ##         00    000       
            0x01, 0x87, 0x00, ##         00    000       
            0x01, 0x87, 0x80, ##         00    0000      
            0x03, 0x03, 0x80, ##        00      000      
            0x03, 0x03, 0x80, ##        00      000      
            0x07, 0x01, 0xC0, ##       000       000     
            0x06, 0x01, 0xC0, ##       00        000     
            0x07, 0xFF, 0xE0, ##       00000000000000    
            0x0C, 0x00, 0xE0, ##      00          000    
            0x0C, 0x00, 0xE0, ##      00          000    
            0x18, 0x00, 0xF0, ##     00           0000   
            0x18, 0x00, 0x70, ##     00            000   
            0x18, 0x00, 0x70, ##     00            000   
            0x30, 0x00, 0x78, ##    00             0000  
            0xFE, 0x01, 0xFE, ##  0000000        00000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '66' => {    # 'B'
        'width'    => 20, 
        'xoffset'  => 2, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFC, 0x00, ##  00000000000000      
            0x1C, 0x07, 0x00, ##     000       000    
            0x1C, 0x03, 0x80, ##     000        000   
            0x1C, 0x01, 0xC0, ##     000         000  
            0x1C, 0x01, 0xC0, ##     000         000  
            0x1C, 0x01, 0xC0, ##     000         000  
            0x1C, 0x01, 0xC0, ##     000         000  
            0x1C, 0x01, 0xC0, ##     000         000  
            0x1C, 0x03, 0x80, ##     000        000   
            0x1C, 0x07, 0x00, ##     000       000    
            0x1F, 0xFC, 0x00, ##     00000000000      
            0x1C, 0x03, 0x80, ##     000        000   
            0x1C, 0x00, 0xE0, ##     000          000 
            0x1C, 0x00, 0xE0, ##     000          000 
            0x1C, 0x00, 0x70, ##     000           000
            0x1C, 0x00, 0x70, ##     000           000
            0x1C, 0x00, 0x70, ##     000           000
            0x1C, 0x00, 0x70, ##     000           000
            0x1C, 0x00, 0x70, ##     000           000
            0x1C, 0x00, 0xE0, ##     000          000 
            0x1C, 0x00, 0xE0, ##     000          000 
            0x1C, 0x03, 0xC0, ##     000        0000  
            0xFF, 0xFE, 0x00, ##  000000000000000     
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '67' => {    # 'C'
        'width'    => 21, 
        'xoffset'  => 2, 
        'xadvance' => 25, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0xFF, 0x00, ##          00000000     
            0x07, 0x03, 0xF0, ##       000      000000 
            0x0C, 0x00, 0xF0, ##      00          0000 
            0x18, 0x00, 0x70, ##     00            000 
            0x30, 0x00, 0x70, ##    00             000 
            0x70, 0x00, 0x30, ##   000              00 
            0x70, 0x00, 0x30, ##   000              00 
            0x60, 0x00, 0x00, ##   00                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0x60, 0x00, 0x00, ##   00                  
            0x70, 0x00, 0x00, ##   000                 
            0x70, 0x00, 0x30, ##   000              00 
            0x30, 0x00, 0x70, ##    00             000 
            0x18, 0x00, 0xE0, ##     00           000  
            0x0C, 0x00, 0xC0, ##      00          00   
            0x07, 0x03, 0x80, ##       000      000    
            0x00, 0xFE, 0x00, ##          0000000      
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '68' => {    # 'D'
        'width'    => 22, 
        'xoffset'  => 2, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFC, 0x00, ##  00000000000000        
            0x1C, 0x07, 0x00, ##     000       000      
            0x1C, 0x01, 0xC0, ##     000         000    
            0x1C, 0x00, 0xE0, ##     000          000   
            0x1C, 0x00, 0x70, ##     000           000  
            0x1C, 0x00, 0x38, ##     000            000 
            0x1C, 0x00, 0x38, ##     000            000 
            0x1C, 0x00, 0x38, ##     000            000 
            0x1C, 0x00, 0x1C, ##     000             000
            0x1C, 0x00, 0x1C, ##     000             000
            0x1C, 0x00, 0x1C, ##     000             000
            0x1C, 0x00, 0x1C, ##     000             000
            0x1C, 0x00, 0x1C, ##     000             000
            0x1C, 0x00, 0x1C, ##     000             000
            0x1C, 0x00, 0x1C, ##     000             000
            0x1C, 0x00, 0x38, ##     000            000 
            0x1C, 0x00, 0x38, ##     000            000 
            0x1C, 0x00, 0x38, ##     000            000 
            0x1C, 0x00, 0x70, ##     000           000  
            0x1C, 0x00, 0xE0, ##     000          000   
            0x1C, 0x01, 0xC0, ##     000         000    
            0x1C, 0x07, 0x00, ##     000       000      
            0xFF, 0xFC, 0x00, ##  00000000000000        
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '69' => {    # 'E'
        'width'    => 19, 
        'xoffset'  => 2, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1F, 0xFF, 0x00, ##     0000000000000   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '70' => {    # 'F'
        'width'    => 19, 
        'xoffset'  => 2, 
        'xadvance' => 22, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1F, 0xFF, 0x00, ##     0000000000000   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x03, 0x00, ##     000        00   
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0xFF, 0xC0, 0x00, ##  0000000000         
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '71' => {    # 'G'
        'width'    => 21, 
        'xoffset'  => 2, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0xFF, 0x80, ##          000000000    
            0x07, 0x03, 0xF0, ##       000      000000 
            0x0C, 0x00, 0xF0, ##      00          0000 
            0x18, 0x00, 0x70, ##     00            000 
            0x30, 0x00, 0x30, ##    00              00 
            0x70, 0x00, 0x30, ##   000              00 
            0x70, 0x00, 0x10, ##   000               0 
            0x60, 0x00, 0x00, ##   00                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x00, 0x00, ##  000                  
            0xE0, 0x07, 0xF8, ##  000          00000000
            0xE0, 0x00, 0x38, ##  000               000
            0xE0, 0x00, 0x38, ##  000               000
            0x60, 0x00, 0x38, ##   00               000
            0x70, 0x00, 0x38, ##   000              000
            0x70, 0x00, 0x38, ##   000              000
            0x38, 0x00, 0x38, ##    000             000
            0x18, 0x00, 0x38, ##     00             000
            0x0C, 0x00, 0x78, ##      00           0000
            0x07, 0x01, 0xF0, ##       000       00000 
            0x00, 0xFF, 0x80, ##          000000000    
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '72' => {    # 'H'
        'width'    => 24, 
        'xoffset'  => 2, 
        'xadvance' => 28, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x81, 0xFF, ##  000000000      000000000
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1F, 0xFF, 0xF8, ##     000000000000000000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0x1C, 0x00, 0x38, ##     000            000   
            0xFF, 0x81, 0xFF, ##  000000000      000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '73' => {    # 'I'
        'width'    => 9, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x80, ##  000000000
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0x1C, 0x00, ##     000   
            0xFF, 0x80, ##  000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '74' => {    # 'J'
        'width'    => 14, 
        'xoffset'  => -3, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xFC, ##      0000000000
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0x00, 0xE0, ##          000   
            0xC0, 0xC0, ##  00      00    
            0xC1, 0xC0, ##  00     000    
            0xE1, 0x80, ##  000    00     
            0x7F, 0x00, ##   0000000      
        ], 
    }, 
    '75' => {    # 'K'
        'width'    => 23, 
        'xoffset'  => 2, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x83, 0xFC, ##  000000000     00000000 
            0x1C, 0x00, 0xE0, ##     000          000    
            0x1C, 0x01, 0xC0, ##     000         000     
            0x1C, 0x03, 0x00, ##     000        00       
            0x1C, 0x06, 0x00, ##     000       00        
            0x1C, 0x1C, 0x00, ##     000     000         
            0x1C, 0x38, 0x00, ##     000    000          
            0x1C, 0x70, 0x00, ##     000   000           
            0x1C, 0xE0, 0x00, ##     000  000            
            0x1D, 0xC0, 0x00, ##     000 000             
            0x1F, 0x80, 0x00, ##     000000              
            0x1F, 0xC0, 0x00, ##     0000000             
            0x1F, 0xE0, 0x00, ##     00000000            
            0x1D, 0xF0, 0x00, ##     000 00000           
            0x1C, 0x78, 0x00, ##     000   0000          
            0x1C, 0x3C, 0x00, ##     000    0000         
            0x1C, 0x1E, 0x00, ##     000     0000        
            0x1C, 0x0F, 0x00, ##     000      0000       
            0x1C, 0x07, 0x80, ##     000       0000      
            0x1C, 0x03, 0xC0, ##     000        0000     
            0x1C, 0x01, 0xE0, ##     000         0000    
            0x1C, 0x00, 0xF0, ##     000          0000   
            0xFF, 0x80, 0x7E, ##  000000000        000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '76' => {    # 'L'
        'width'    => 19, 
        'xoffset'  => 2, 
        'xadvance' => 22, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x80, 0x00, ##  000000000          
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x00, ##     000             
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0x1C, 0x00, 0x60, ##     000           00
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '77' => {    # 'M'
        'width'    => 29, 
        'xoffset'  => 2, 
        'xadvance' => 33, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFE, 0x00, 0x01, 0xF8, ##  0000000                000000
            0x1E, 0x00, 0x03, 0xC0, ##     0000               0000   
            0x1F, 0x00, 0x03, 0xC0, ##     00000              0000   
            0x1F, 0x00, 0x07, 0xC0, ##     00000             00000   
            0x1B, 0x80, 0x05, 0xC0, ##     00 000            0 000   
            0x1B, 0x80, 0x0D, 0xC0, ##     00 000           00 000   
            0x19, 0xC0, 0x09, 0xC0, ##     00  000          0  000   
            0x19, 0xC0, 0x19, 0xC0, ##     00  000         00  000   
            0x18, 0xE0, 0x11, 0xC0, ##     00   000        0   000   
            0x18, 0xE0, 0x31, 0xC0, ##     00   000       00   000   
            0x18, 0xF0, 0x31, 0xC0, ##     00   0000      00   000   
            0x18, 0x70, 0x61, 0xC0, ##     00    000     00    000   
            0x18, 0x78, 0x61, 0xC0, ##     00    0000    00    000   
            0x18, 0x38, 0xC1, 0xC0, ##     00     000   00     000   
            0x18, 0x3C, 0xC1, 0xC0, ##     00     0000  00     000   
            0x18, 0x1D, 0x81, 0xC0, ##     00      000 00      000   
            0x18, 0x1F, 0x81, 0xC0, ##     00      000000      000   
            0x18, 0x0F, 0x01, 0xC0, ##     00       0000       000   
            0x18, 0x0F, 0x01, 0xC0, ##     00       0000       000   
            0x18, 0x06, 0x01, 0xC0, ##     00        00        000   
            0x18, 0x00, 0x01, 0xC0, ##     00                  000   
            0x18, 0x00, 0x01, 0xC0, ##     00                  000   
            0xFF, 0x00, 0x0F, 0xF8, ##  00000000            000000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '78' => {    # 'N'
        'width'    => 25, 
        'xoffset'  => 2, 
        'xadvance' => 28, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x7F, 0x80, ##  000000           00000000
            0x1E, 0x00, 0x0C, 0x00, ##     0000             00   
            0x1F, 0x00, 0x0C, 0x00, ##     00000            00   
            0x1F, 0x80, 0x0C, 0x00, ##     000000           00   
            0x1B, 0x80, 0x0C, 0x00, ##     00 000           00   
            0x1B, 0xC0, 0x0C, 0x00, ##     00 0000          00   
            0x19, 0xE0, 0x0C, 0x00, ##     00  0000         00   
            0x18, 0xF0, 0x0C, 0x00, ##     00   0000        00   
            0x18, 0x70, 0x0C, 0x00, ##     00    000        00   
            0x18, 0x38, 0x0C, 0x00, ##     00     000       00   
            0x18, 0x3C, 0x0C, 0x00, ##     00     0000      00   
            0x18, 0x1E, 0x0C, 0x00, ##     00      0000     00   
            0x18, 0x0E, 0x0C, 0x00, ##     00       000     00   
            0x18, 0x07, 0x0C, 0x00, ##     00        000    00   
            0x18, 0x07, 0x8C, 0x00, ##     00        0000   00   
            0x18, 0x03, 0xCC, 0x00, ##     00         0000  00   
            0x18, 0x01, 0xCC, 0x00, ##     00          000  00   
            0x18, 0x00, 0xEC, 0x00, ##     00           000 00   
            0x18, 0x00, 0x7C, 0x00, ##     00            00000   
            0x18, 0x00, 0x7C, 0x00, ##     00            00000   
            0x18, 0x00, 0x3C, 0x00, ##     00             0000   
            0x18, 0x00, 0x1C, 0x00, ##     00              000   
            0xFF, 0x00, 0x0C, 0x00, ##  00000000            00   
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '79' => {    # 'O'
        'width'    => 22, 
        'xoffset'  => 2, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x01, 0xFE, 0x00, ##         00000000       
            0x07, 0x03, 0x80, ##       000      000     
            0x0C, 0x00, 0xC0, ##      00          00    
            0x18, 0x00, 0x60, ##     00            00   
            0x30, 0x00, 0x30, ##    00              00  
            0x70, 0x00, 0x38, ##   000              000 
            0x70, 0x00, 0x38, ##   000              000 
            0x60, 0x00, 0x18, ##   00                00 
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0x60, 0x00, 0x18, ##   00                00 
            0x70, 0x00, 0x38, ##   000              000 
            0x70, 0x00, 0x38, ##   000              000 
            0x30, 0x00, 0x30, ##    00              00  
            0x18, 0x00, 0x60, ##     00            00   
            0x0C, 0x00, 0xC0, ##      00          00    
            0x07, 0x03, 0x80, ##       000      000     
            0x01, 0xFE, 0x00, ##         00000000       
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '80' => {    # 'P'
        'width'    => 18, 
        'xoffset'  => 2, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFC, 0x00, ##  00000000000000    
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x03, 0x80, ##     000        000 
            0x1C, 0x01, 0x80, ##     000         00 
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0x80, ##     000         00 
            0x1C, 0x03, 0x80, ##     000        000 
            0x1C, 0x07, 0x00, ##     000       000  
            0x1F, 0xFC, 0x00, ##     00000000000    
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0xFF, 0xC0, 0x00, ##  0000000000        
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '81' => {    # 'Q'
        'width'    => 22, 
        'xoffset'  => 2, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x01, 0xFE, 0x00, ##         00000000       
            0x07, 0x03, 0x80, ##       000      000     
            0x0C, 0x00, 0xC0, ##      00          00    
            0x18, 0x00, 0x60, ##     00            00   
            0x30, 0x00, 0x30, ##    00              00  
            0x70, 0x00, 0x38, ##   000              000 
            0x70, 0x00, 0x38, ##   000              000 
            0x60, 0x00, 0x18, ##   00                00 
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0xE0, 0x00, 0x1C, ##  000                000
            0x60, 0x00, 0x18, ##   00                00 
            0x70, 0x00, 0x38, ##   000              000 
            0x70, 0x00, 0x38, ##   000              000 
            0x30, 0x00, 0x30, ##    00              00  
            0x18, 0x00, 0x60, ##     00            00   
            0x0C, 0x00, 0xC0, ##      00          00    
            0x07, 0x03, 0x80, ##       000      000     
            0x00, 0xFE, 0x00, ##          0000000       
            0x00, 0x0C, 0x00, ##              00        
            0x00, 0x0F, 0x00, ##              0000      
            0x00, 0x07, 0xE0, ##               000000   
            0x00, 0x03, 0xE0, ##                00000   
            0x00, 0x00, 0xE0, ##                  000   
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '82' => {    # 'R'
        'width'    => 23, 
        'xoffset'  => 2, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFE, 0x00, ##  000000000000000        
            0x1C, 0x03, 0x80, ##     000        000      
            0x1C, 0x01, 0xC0, ##     000         000     
            0x1C, 0x00, 0xC0, ##     000          00     
            0x1C, 0x00, 0xE0, ##     000          000    
            0x1C, 0x00, 0xE0, ##     000          000    
            0x1C, 0x00, 0xE0, ##     000          000    
            0x1C, 0x00, 0xE0, ##     000          000    
            0x1C, 0x00, 0xE0, ##     000          000    
            0x1C, 0x01, 0xC0, ##     000         000     
            0x1C, 0x03, 0x80, ##     000        000      
            0x1F, 0xFE, 0x00, ##     000000000000        
            0x1C, 0x0E, 0x00, ##     000      000        
            0x1C, 0x07, 0x00, ##     000       000       
            0x1C, 0x03, 0x80, ##     000        000      
            0x1C, 0x03, 0x80, ##     000        000      
            0x1C, 0x01, 0xC0, ##     000         000     
            0x1C, 0x01, 0xC0, ##     000         000     
            0x1C, 0x00, 0xE0, ##     000          000    
            0x1C, 0x00, 0xE0, ##     000          000    
            0x1C, 0x00, 0x70, ##     000           000   
            0x1C, 0x00, 0x70, ##     000           000   
            0xFF, 0x80, 0x3E, ##  000000000         00000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '83' => {    # 'S'
        'width'    => 17, 
        'xoffset'  => 3, 
        'xadvance' => 22, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x0F, 0xFC, 0x00, ##      0000000000   
            0x38, 0x1F, 0x00, ##    000      00000 
            0x70, 0x07, 0x00, ##   000         000 
            0x60, 0x03, 0x00, ##   00           00 
            0xE0, 0x03, 0x00, ##  000           00 
            0xE0, 0x03, 0x00, ##  000           00 
            0xE0, 0x00, 0x00, ##  000              
            0xF0, 0x00, 0x00, ##  0000             
            0xFC, 0x00, 0x00, ##  000000           
            0x7F, 0x80, 0x00, ##   00000000        
            0x3F, 0xF0, 0x00, ##    0000000000     
            0x1F, 0xFC, 0x00, ##     00000000000   
            0x03, 0xFF, 0x00, ##        0000000000 
            0x00, 0x7F, 0x00, ##           0000000 
            0x00, 0x0F, 0x80, ##              00000
            0x00, 0x07, 0x80, ##               0000
            0x00, 0x03, 0x80, ##                000
            0xC0, 0x03, 0x80, ##  00            000
            0xC0, 0x03, 0x80, ##  00            000
            0xE0, 0x03, 0x00, ##  000           00 
            0xE0, 0x07, 0x00, ##  000          000 
            0xF8, 0x1E, 0x00, ##  00000      0000  
            0x3F, 0xF0, 0x00, ##    0000000000     
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '84' => {    # 'T'
        'width'    => 21, 
        'xoffset'  => 1, 
        'xadvance' => 23, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xF8, ##  000000000000000000000
            0xC0, 0x70, 0x18, ##  00       000       00
            0xC0, 0x70, 0x18, ##  00       000       00
            0xC0, 0x70, 0x18, ##  00       000       00
            0xC0, 0x70, 0x18, ##  00       000       00
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x00, 0x70, 0x00, ##           000         
            0x03, 0xFE, 0x00, ##        000000000      
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '85' => {    # 'U'
        'width'    => 24, 
        'xoffset'  => 1, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x80, 0xFF, ##  000000000       00000000
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x1C, 0x00, 0x18, ##     000             00   
            0x0E, 0x00, 0x30, ##      000           00    
            0x0E, 0x00, 0x30, ##      000           00    
            0x07, 0x00, 0x60, ##       000         00     
            0x03, 0x80, 0xC0, ##        000       00      
            0x00, 0xFF, 0x00, ##          00000000        
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '86' => {    # 'V'
        'width'    => 24, 
        'xoffset'  => 0, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x80, 0x7F, ##  000000000        0000000
            0x1C, 0x00, 0x1C, ##     000             000  
            0x1E, 0x00, 0x18, ##     0000            00   
            0x1E, 0x00, 0x18, ##     0000            00   
            0x0F, 0x00, 0x30, ##      0000          00    
            0x0F, 0x00, 0x30, ##      0000          00    
            0x07, 0x00, 0x30, ##       000          00    
            0x07, 0x80, 0x60, ##       0000        00     
            0x07, 0x80, 0x60, ##       0000        00     
            0x03, 0x80, 0x60, ##        000        00     
            0x03, 0xC0, 0xC0, ##        0000      00      
            0x01, 0xC0, 0xC0, ##         000      00      
            0x01, 0xE1, 0x80, ##         0000    00       
            0x01, 0xE1, 0x80, ##         0000    00       
            0x00, 0xE1, 0x80, ##          000    00       
            0x00, 0xF3, 0x00, ##          0000  00        
            0x00, 0xF3, 0x00, ##          0000  00        
            0x00, 0x73, 0x00, ##           000  00        
            0x00, 0x7E, 0x00, ##           000000         
            0x00, 0x3E, 0x00, ##            00000         
            0x00, 0x3C, 0x00, ##            0000          
            0x00, 0x3C, 0x00, ##            0000          
            0x00, 0x1C, 0x00, ##             000          
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '87' => {    # 'W'
        'width'    => 33, 
        'xoffset'  => 1, 
        'xadvance' => 35, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0x80, 0xE0, 0x3F, 0x80, ##  000000000       000       0000000
            0x1C, 0x00, 0xE0, 0x04, 0x00, ##     000          000          0   
            0x1C, 0x01, 0xE0, 0x0C, 0x00, ##     000         0000         00   
            0x1E, 0x01, 0xF0, 0x0C, 0x00, ##     0000        00000        00   
            0x1E, 0x01, 0x70, 0x0C, 0x00, ##     0000        0 000        00   
            0x0E, 0x01, 0x70, 0x08, 0x00, ##      000        0 000        0    
            0x0E, 0x03, 0x70, 0x18, 0x00, ##      000       00 000       00    
            0x0F, 0x03, 0x38, 0x18, 0x00, ##      0000      00  000      00    
            0x07, 0x02, 0x38, 0x10, 0x00, ##       000      0   000      0     
            0x07, 0x06, 0x38, 0x30, 0x00, ##       000     00   000     00     
            0x07, 0x86, 0x3C, 0x30, 0x00, ##       0000    00   0000    00     
            0x03, 0x86, 0x1C, 0x30, 0x00, ##        000    00    000    00     
            0x03, 0x84, 0x1C, 0x20, 0x00, ##        000    0     000    0      
            0x03, 0x8C, 0x1C, 0x60, 0x00, ##        000   00     000   00      
            0x03, 0xCC, 0x0E, 0x60, 0x00, ##        0000  00      000  00      
            0x01, 0xC8, 0x0E, 0x60, 0x00, ##         000  0       000  00      
            0x01, 0xD8, 0x0E, 0xC0, 0x00, ##         000 00       000 00       
            0x01, 0xF8, 0x0E, 0xC0, 0x00, ##         000000       000 00       
            0x00, 0xF8, 0x07, 0xC0, 0x00, ##          00000        00000       
            0x00, 0xF0, 0x07, 0x80, 0x00, ##          0000         0000        
            0x00, 0xF0, 0x07, 0x80, 0x00, ##          0000         0000        
            0x00, 0xF0, 0x07, 0x80, 0x00, ##          0000         0000        
            0x00, 0x70, 0x03, 0x80, 0x00, ##           000          000        
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '88' => {    # 'X'
        'width'    => 22, 
        'xoffset'  => 1, 
        'xadvance' => 24, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x83, 0xFC, ##  000000000     00000000
            0x1E, 0x00, 0x60, ##     0000          00   
            0x0F, 0x00, 0xC0, ##      0000        00    
            0x0F, 0x01, 0x80, ##      0000       00     
            0x07, 0x81, 0x80, ##       0000      00     
            0x07, 0x83, 0x00, ##       0000     00      
            0x03, 0xC6, 0x00, ##        0000   00       
            0x01, 0xEE, 0x00, ##         0000 000       
            0x01, 0xEC, 0x00, ##         0000 00        
            0x00, 0xF8, 0x00, ##          00000         
            0x00, 0xF0, 0x00, ##          0000          
            0x00, 0x78, 0x00, ##           0000         
            0x00, 0x7C, 0x00, ##           00000        
            0x00, 0xFE, 0x00, ##          0000000       
            0x01, 0xDE, 0x00, ##         000 0000       
            0x01, 0x8F, 0x00, ##         00   0000      
            0x03, 0x87, 0x80, ##        000    0000     
            0x03, 0x07, 0x80, ##        00     0000     
            0x06, 0x03, 0xC0, ##       00       0000    
            0x0E, 0x01, 0xE0, ##      000        0000   
            0x0C, 0x01, 0xE0, ##      00         0000   
            0x18, 0x00, 0xF0, ##     00           0000  
            0xFF, 0x07, 0xFC, ##  00000000     000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '89' => {    # 'Y'
        'width'    => 22, 
        'xoffset'  => 0, 
        'xadvance' => 22, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x81, 0xFC, ##  000000000      0000000
            0x3C, 0x00, 0x60, ##    0000           00   
            0x1C, 0x00, 0xE0, ##     000          000   
            0x1E, 0x00, 0xC0, ##     0000         00    
            0x0F, 0x01, 0x80, ##      0000       00     
            0x07, 0x01, 0x80, ##       000       00     
            0x07, 0x83, 0x00, ##       0000     00      
            0x03, 0x86, 0x00, ##        000    00       
            0x03, 0xC6, 0x00, ##        0000   00       
            0x01, 0xCC, 0x00, ##         000  00        
            0x01, 0xEC, 0x00, ##         0000 00        
            0x00, 0xF8, 0x00, ##          00000         
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x00, 0x70, 0x00, ##           000          
            0x03, 0xFE, 0x00, ##        000000000       
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '90' => {    # 'Z'
        'width'    => 19, 
        'xoffset'  => 2, 
        'xadvance' => 22, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0xFF, 0xC0, ##  000000000000000000 
            0xC0, 0x03, 0xC0, ##  00            0000 
            0xC0, 0x07, 0x80, ##  00           0000  
            0xC0, 0x0F, 0x00, ##  00          0000   
            0xC0, 0x0F, 0x00, ##  00          0000   
            0x00, 0x1E, 0x00, ##             0000    
            0x00, 0x3C, 0x00, ##            0000     
            0x00, 0x3C, 0x00, ##            0000     
            0x00, 0x78, 0x00, ##           0000      
            0x00, 0xF0, 0x00, ##          0000       
            0x00, 0xF0, 0x00, ##          0000       
            0x01, 0xE0, 0x00, ##         0000        
            0x03, 0xC0, 0x00, ##        0000         
            0x07, 0xC0, 0x00, ##       00000         
            0x07, 0x80, 0x00, ##       0000          
            0x0F, 0x00, 0x00, ##      0000           
            0x1F, 0x00, 0x00, ##     00000           
            0x1E, 0x00, 0x00, ##     0000            
            0x3C, 0x00, 0x60, ##    0000           00
            0x7C, 0x00, 0x60, ##   00000           00
            0x78, 0x00, 0x60, ##   0000            00
            0xF0, 0x00, 0x60, ##  0000             00
            0xFF, 0xFF, 0xE0, ##  0000000000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '91' => {    # '['
        'width'    => 8, 
        'xoffset'  => 3, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0xFF, ##  00000000
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xE0, ##  000     
            0xFF, ##  00000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '92' => {    # '\'
        'width'    => 11, 
        'xoffset'  => 0, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x00, ##  000        
            0xE0, 0x00, ##  000        
            0x60, 0x00, ##   00        
            0x70, 0x00, ##   000       
            0x70, 0x00, ##   000       
            0x30, 0x00, ##    00       
            0x38, 0x00, ##    000      
            0x38, 0x00, ##    000      
            0x18, 0x00, ##     00      
            0x1C, 0x00, ##     000     
            0x1C, 0x00, ##     000     
            0x0C, 0x00, ##      00     
            0x0C, 0x00, ##      00     
            0x0E, 0x00, ##      000    
            0x06, 0x00, ##       00    
            0x06, 0x00, ##       00    
            0x07, 0x00, ##       000   
            0x03, 0x00, ##        00   
            0x03, 0x00, ##        00   
            0x03, 0x80, ##        000  
            0x01, 0x80, ##         00  
            0x01, 0x80, ##         00  
            0x01, 0xC0, ##         000 
            0x01, 0xC0, ##         000 
            0x00, 0xC0, ##          00 
            0x00, 0xE0, ##          000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '93' => {    # ']'
        'width'    => 7, 
        'xoffset'  => 3, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0xFE, ##  0000000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0x0E, ##      000
            0xFE, ##  0000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '94' => {    # '^'
        'width'    => 20, 
        'xoffset'  => 3, 
        'xadvance' => 27, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x70, 0x00, ##           000        
            0x00, 0xF8, 0x00, ##          00000       
            0x01, 0xFC, 0x00, ##         0000000      
            0x03, 0xDE, 0x00, ##        0000 0000     
            0x07, 0x8F, 0x00, ##       0000   0000    
            0x0E, 0x07, 0x80, ##      000      0000   
            0x1C, 0x01, 0xC0, ##     000         000  
            0x38, 0x00, 0xE0, ##    000           000 
            0x60, 0x00, 0x70, ##   00              000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '95' => {    # '_'
        'width'    => 16, 
        'xoffset'  => 0, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFF, ##  0000000000000000
        ], 
    }, 
    '96' => {    # '`'
        'width'    => 7, 
        'xoffset'  => 3, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0xE0, ##  000    
            0x70, ##   000   
            0x30, ##    00   
            0x18, ##     00  
            0x0C, ##      00 
            0x04, ##       0 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '97' => {    # 'a'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0xC0, ##     0000000      
            0x70, 0x70, ##   000     000    
            0x60, 0x38, ##   00       000   
            0x60, 0x18, ##   00        00   
            0x60, 0x1C, ##   00        000  
            0x00, 0x1C, ##             000  
            0x00, 0x1C, ##             000  
            0x0F, 0xFC, ##      0000000000  
            0x38, 0x1C, ##    000      000  
            0x70, 0x1C, ##   000       000  
            0xE0, 0x1C, ##  000        000  
            0xE0, 0x1C, ##  000        000  
            0xE0, 0x1C, ##  000        000  
            0xE0, 0x1C, ##  000        000  
            0x70, 0x3C, ##   000      0000  
            0x78, 0x7C, ##   0000    00000  
            0x1F, 0xDF, ##     0000000 00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '98' => {    # 'b'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, ##  000000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0xFC, 0x00, ##     000  000000    
            0x1D, 0x0E, 0x00, ##     000 0    000   
            0x1E, 0x03, 0x00, ##     0000       00  
            0x1E, 0x03, 0x80, ##     0000       000 
            0x1C, 0x01, 0x80, ##     000         00 
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x03, 0x80, ##     000        000 
            0x1E, 0x03, 0x80, ##     0000       000 
            0x1E, 0x03, 0x00, ##     0000       00  
            0x1F, 0x0E, 0x00, ##     00000    000   
            0xFC, 0xFC, 0x00, ##  000000  000000    
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '99' => {    # 'c'
        'width'    => 15, 
        'xoffset'  => 2, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xF8, ##       00000000  
            0x1C, 0x3E, ##     000    00000
            0x38, 0x0E, ##    000       000
            0x70, 0x0E, ##   000        000
            0x70, 0x06, ##   000         00
            0xE0, 0x00, ##  000            
            0xE0, 0x00, ##  000            
            0xE0, 0x00, ##  000            
            0xE0, 0x00, ##  000            
            0xE0, 0x00, ##  000            
            0xE0, 0x00, ##  000            
            0xE0, 0x00, ##  000            
            0x60, 0x0E, ##   00         000
            0x70, 0x0C, ##   000        00 
            0x30, 0x1C, ##    00       000 
            0x1C, 0x38, ##     000    000  
            0x07, 0xE0, ##       000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '100' => {    # 'd'
        'width'    => 18, 
        'xoffset'  => 2, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x7E, 0x00, ##           000000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x0F, 0xCE, 0x00, ##      000000  000   
            0x1C, 0x2E, 0x00, ##     000    0 000   
            0x30, 0x1E, 0x00, ##    00       0000   
            0x70, 0x1E, 0x00, ##   000       0000   
            0x60, 0x0E, 0x00, ##   00         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0x60, 0x0E, 0x00, ##   00         000   
            0x70, 0x1E, 0x00, ##   000       0000   
            0x30, 0x1E, 0x00, ##    00       0000   
            0x18, 0x3E, 0x00, ##     00     00000   
            0x0F, 0xCF, 0xC0, ##      000000  000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '101' => {    # 'e'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xE0, ##       000000     
            0x1C, 0x38, ##     000    000   
            0x38, 0x0C, ##    000       00  
            0x70, 0x0E, ##   000        000 
            0x70, 0x06, ##   000         00 
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xFF, 0xFF, ##  0000000000000000
            0xE0, 0x00, ##  000             
            0xE0, 0x00, ##  000             
            0xE0, 0x00, ##  000             
            0xE0, 0x03, ##  000           00
            0x70, 0x06, ##   000         00 
            0x70, 0x06, ##   000         00 
            0x38, 0x0C, ##    000       00  
            0x1C, 0x18, ##     000     00   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '102' => {    # 'f'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0xF8, ##        0000000
            0x0E, 0x38, ##      000   000
            0x0C, 0x18, ##      00     00
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0xFF, 0xC0, ##  0000000000   
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0xFF, 0x80, ##  000000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '103' => {    # 'g'
        'width'    => 18, 
        'xoffset'  => 2, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x0F, 0xCF, 0xC0, ##      000000  000000
            0x1C, 0x2E, 0x00, ##     000    0 000   
            0x30, 0x1E, 0x00, ##    00       0000   
            0x70, 0x1E, 0x00, ##   000       0000   
            0x60, 0x0E, 0x00, ##   00         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0x60, 0x0E, 0x00, ##   00         000   
            0x70, 0x1E, 0x00, ##   000       0000   
            0x30, 0x1E, 0x00, ##    00       0000   
            0x18, 0x2E, 0x00, ##     00     0 000   
            0x0F, 0xCE, 0x00, ##      000000  000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x60, 0x0E, 0x00, ##   00         000   
            0x60, 0x1C, 0x00, ##   00        000    
            0x70, 0x18, 0x00, ##   000       00     
            0x78, 0x30, 0x00, ##   0000     00      
            0x1F, 0xE0, 0x00, ##     00000000       
        ], 
    }, 
    '104' => {    # 'h'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, ##  000000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0xF8, 0x00, ##     000  00000     
            0x1D, 0x0E, 0x00, ##     000 0    000   
            0x1E, 0x0E, 0x00, ##     0000     000   
            0x1E, 0x07, 0x00, ##     0000      000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0xFF, 0x3F, 0xC0, ##  00000000  00000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '105' => {    # 'i'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x00, ##          
            0x00, ##          
            0x00, ##          
            0xF8, ##  00000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0x38, ##    000   
            0xFF, ##  00000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '106' => {    # 'j'
        'width'    => 10, 
        'xoffset'  => -2, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x01, 0x80, ##         00 
            0x03, 0xC0, ##        0000
            0x01, 0x80, ##         00 
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x0F, 0xC0, ##      000000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x01, 0xC0, ##         000
            0x81, 0xC0, ##  0      000
            0x81, 0x80, ##  0      00 
            0xC3, 0x00, ##  00    00  
            0xFE, 0x00, ##  0000000   
        ], 
    }, 
    '107' => {    # 'k'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFC, 0x00, 0x00, ##  000000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x3F, 0xC0, ##     000    00000000
            0x1C, 0x0C, 0x00, ##     000      00    
            0x1C, 0x18, 0x00, ##     000     00     
            0x1C, 0x30, 0x00, ##     000    00      
            0x1C, 0x60, 0x00, ##     000   00       
            0x1C, 0xC0, 0x00, ##     000  00        
            0x1C, 0xC0, 0x00, ##     000  00        
            0x1D, 0xE0, 0x00, ##     000 0000       
            0x1F, 0xE0, 0x00, ##     00000000       
            0x1E, 0x70, 0x00, ##     0000  000      
            0x1C, 0x78, 0x00, ##     000   0000     
            0x1C, 0x38, 0x00, ##     000    000     
            0x1C, 0x3C, 0x00, ##     000    0000    
            0x1C, 0x1E, 0x00, ##     000     0000   
            0x1C, 0x0E, 0x00, ##     000      000   
            0x1C, 0x0F, 0x00, ##     000      0000  
            0xFF, 0x3F, 0xC0, ##  00000000  00000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '108' => {    # 'l'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0x1C, ##     000  
            0xFF, ##  00000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '109' => {    # 'm'
        'width'    => 28, 
        'xoffset'  => 1, 
        'xadvance' => 30, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFC, 0xF8, 0x1E, 0x00, ##  000000  00000      0000     
            0x1D, 0x0E, 0x63, 0x80, ##     000 0    000  00   000   
            0x1E, 0x0E, 0x83, 0x80, ##     0000     000 0     000   
            0x1E, 0x07, 0x81, 0xC0, ##     0000      0000      000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0x1C, 0x07, 0x01, 0xC0, ##     000       000       000  
            0xFF, 0x3F, 0xCF, 0xF0, ##  00000000  00000000  00000000
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '110' => {    # 'n'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFC, 0xF8, 0x00, ##  000000  00000     
            0x1D, 0x0E, 0x00, ##     000 0    000   
            0x1E, 0x0E, 0x00, ##     0000     000   
            0x1E, 0x07, 0x00, ##     0000      000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0x1C, 0x07, 0x00, ##     000       000  
            0xFF, 0x3F, 0xC0, ##  00000000  00000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '111' => {    # 'o'
        'width'    => 16, 
        'xoffset'  => 2, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x07, 0xE0, ##       000000     
            0x1C, 0x38, ##     000    000   
            0x38, 0x1C, ##    000      000  
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0xE0, 0x07, ##  000          000
            0x70, 0x0E, ##   000        000 
            0x70, 0x0E, ##   000        000 
            0x38, 0x1C, ##    000      000  
            0x1C, 0x38, ##     000    000   
            0x07, 0xE0, ##       000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '112' => {    # 'p'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFC, 0xFC, 0x00, ##  000000  000000    
            0x1F, 0x0E, 0x00, ##     00000    000   
            0x1E, 0x03, 0x00, ##     0000       00  
            0x1E, 0x03, 0x80, ##     0000       000 
            0x1C, 0x01, 0x80, ##     000         00 
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x01, 0xC0, ##     000         000
            0x1C, 0x03, 0x80, ##     000        000 
            0x1E, 0x03, 0x80, ##     0000       000 
            0x1E, 0x03, 0x00, ##     0000       00  
            0x1D, 0x0E, 0x00, ##     000 0    000   
            0x1C, 0xFC, 0x00, ##     000  000000    
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0x1C, 0x00, 0x00, ##     000            
            0xFF, 0x00, 0x00, ##  00000000          
        ], 
    }, 
    '113' => {    # 'q'
        'width'    => 18, 
        'xoffset'  => 2, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x0F, 0xCF, 0xC0, ##      000000  000000
            0x1C, 0x2E, 0x00, ##     000    0 000   
            0x30, 0x1E, 0x00, ##    00       0000   
            0x70, 0x1E, 0x00, ##   000       0000   
            0x60, 0x0E, 0x00, ##   00         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0xE0, 0x0E, 0x00, ##  000         000   
            0x60, 0x0E, 0x00, ##   00         000   
            0x70, 0x1E, 0x00, ##   000       0000   
            0x30, 0x1E, 0x00, ##    00       0000   
            0x18, 0x2E, 0x00, ##     00     0 000   
            0x0F, 0xCE, 0x00, ##      000000  000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x0E, 0x00, ##              000   
            0x00, 0x3F, 0xC0, ##            00000000
        ], 
    }, 
    '114' => {    # 'r'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFC, 0xFC, ##  000000  000000
            0x1D, 0x1C, ##     000 0   000
            0x1E, 0x0C, ##     0000     00
            0x1E, 0x0C, ##     0000     00
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0x1C, 0x00, ##     000        
            0xFF, 0x80, ##  000000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '115' => {    # 's'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0xC0, ##     0000000   
            0x70, 0xF0, ##   000    0000 
            0x60, 0x70, ##   00      000 
            0xE0, 0x30, ##  000       00 
            0xE0, 0x30, ##  000       00 
            0xF0, 0x00, ##  0000         
            0xFC, 0x00, ##  000000       
            0x7F, 0x80, ##   00000000    
            0x3F, 0xE0, ##    000000000  
            0x07, 0xF0, ##       0000000 
            0x00, 0xF8, ##          00000
            0x00, 0x78, ##           0000
            0xC0, 0x38, ##  00        000
            0xC0, 0x38, ##  00        000
            0xE0, 0x30, ##  000       00 
            0xF0, 0x60, ##  0000     00  
            0x3F, 0x80, ##    0000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '116' => {    # 't'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0xFF, 0xE0, ##  00000000000  
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x00, ##     000       
            0x1C, 0x18, ##     000     00
            0x1C, 0x18, ##     000     00
            0x0E, 0x30, ##      000   00 
            0x07, 0xE0, ##       000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '117' => {    # 'u'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xF8, 0x3E, 0x00, ##  00000     00000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x0E, 0x00, ##    000       000   
            0x38, 0x1E, 0x00, ##    000      0000   
            0x1C, 0x1E, 0x00, ##     000     0000   
            0x1C, 0x2E, 0x00, ##     000    0 000   
            0x07, 0xCF, 0xC0, ##       00000  000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '118' => {    # 'v'
        'width'    => 18, 
        'xoffset'  => 0, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x0F, 0xC0, ##  00000000    000000
            0x38, 0x03, 0x00, ##    000         00  
            0x1C, 0x03, 0x00, ##     000        00  
            0x1C, 0x06, 0x00, ##     000       00   
            0x1E, 0x06, 0x00, ##     0000      00   
            0x0E, 0x06, 0x00, ##      000      00   
            0x0E, 0x0C, 0x00, ##      000     00    
            0x07, 0x0C, 0x00, ##       000    00    
            0x07, 0x08, 0x00, ##       000    0     
            0x07, 0x18, 0x00, ##       000   00     
            0x03, 0x98, 0x00, ##        000  00     
            0x03, 0x90, 0x00, ##        000  0      
            0x01, 0xF0, 0x00, ##         00000      
            0x01, 0xF0, 0x00, ##         00000      
            0x01, 0xE0, 0x00, ##         0000       
            0x00, 0xE0, 0x00, ##          000       
            0x00, 0xE0, 0x00, ##          000       
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '119' => {    # 'w'
        'width'    => 26, 
        'xoffset'  => 1, 
        'xadvance' => 28, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0xFF, 0x06, 0x0F, 0xC0, ##  00000000     00     000000
            0x38, 0x0E, 0x03, 0x00, ##    000       000       00  
            0x3C, 0x0F, 0x03, 0x00, ##    0000      0000      00  
            0x1C, 0x0F, 0x02, 0x00, ##     000      0000      0   
            0x1C, 0x0F, 0x06, 0x00, ##     000      0000     00   
            0x1E, 0x1B, 0x06, 0x00, ##     0000    00 00     00   
            0x0E, 0x13, 0x84, 0x00, ##      000    0  000    0    
            0x0E, 0x13, 0x8C, 0x00, ##      000    0  000   00    
            0x0F, 0x31, 0x8C, 0x00, ##      0000  00   00   00    
            0x07, 0x31, 0xCC, 0x00, ##       000  00   000  00    
            0x07, 0x21, 0xC8, 0x00, ##       000  0    000  0     
            0x07, 0x61, 0xD8, 0x00, ##       000 00    000 00     
            0x03, 0xE0, 0xF8, 0x00, ##        00000     00000     
            0x03, 0xC0, 0xF0, 0x00, ##        0000      0000      
            0x03, 0xC0, 0xF0, 0x00, ##        0000      0000      
            0x01, 0xC0, 0x70, 0x00, ##         000       000      
            0x01, 0xC0, 0x60, 0x00, ##         000       00       
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '120' => {    # 'x'
        'width'    => 17, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFE, 0x3F, 0x00, ##  0000000   000000 
            0x38, 0x0C, 0x00, ##    000       00   
            0x1C, 0x18, 0x00, ##     000     00    
            0x1E, 0x30, 0x00, ##     0000   00     
            0x0F, 0x70, 0x00, ##      0000 000     
            0x0F, 0x60, 0x00, ##      0000 00      
            0x07, 0xC0, 0x00, ##       00000       
            0x03, 0xC0, 0x00, ##        0000       
            0x03, 0xC0, 0x00, ##        0000       
            0x03, 0xE0, 0x00, ##        00000      
            0x03, 0xE0, 0x00, ##        00000      
            0x06, 0xF0, 0x00, ##       00 0000     
            0x0C, 0x70, 0x00, ##      00   000     
            0x0C, 0x38, 0x00, ##      00    000    
            0x18, 0x3C, 0x00, ##     00     0000   
            0x30, 0x1C, 0x00, ##    00       000   
            0xFC, 0x7F, 0x80, ##  000000   00000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '121' => {    # 'y'
        'width'    => 18, 
        'xoffset'  => 0, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xFF, 0x0F, 0xC0, ##  00000000    000000
            0x38, 0x03, 0x00, ##    000         00  
            0x1C, 0x03, 0x00, ##     000        00  
            0x1C, 0x06, 0x00, ##     000       00   
            0x1E, 0x06, 0x00, ##     0000      00   
            0x0E, 0x04, 0x00, ##      000      0    
            0x0E, 0x0C, 0x00, ##      000     00    
            0x0F, 0x0C, 0x00, ##      0000    00    
            0x07, 0x08, 0x00, ##       000    0     
            0x07, 0x18, 0x00, ##       000   00     
            0x03, 0x98, 0x00, ##        000  00     
            0x03, 0x90, 0x00, ##        000  0      
            0x03, 0xF0, 0x00, ##        000000      
            0x01, 0xE0, 0x00, ##         0000       
            0x01, 0xE0, 0x00, ##         0000       
            0x01, 0xE0, 0x00, ##         0000       
            0x00, 0xC0, 0x00, ##          00        
            0x00, 0xC0, 0x00, ##          00        
            0x00, 0x80, 0x00, ##          0         
            0x01, 0x80, 0x00, ##         00         
            0x01, 0x80, 0x00, ##         00         
            0x61, 0x00, 0x00, ##   00    0          
            0x63, 0x00, 0x00, ##   00   00          
            0x7E, 0x00, 0x00, ##   000000           
        ], 
    }, 
    '122' => {    # 'z'
        'width'    => 14, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xFC, ##  00000000000000
            0xC0, 0x78, ##  00       0000 
            0xC0, 0x78, ##  00       0000 
            0xC0, 0xF0, ##  00      0000  
            0x01, 0xE0, ##         0000   
            0x01, 0xE0, ##         0000   
            0x03, 0xC0, ##        0000    
            0x07, 0x80, ##       0000     
            0x07, 0x00, ##       000      
            0x0F, 0x00, ##      0000      
            0x1E, 0x00, ##     0000       
            0x1C, 0x00, ##     000        
            0x3C, 0x00, ##    0000        
            0x78, 0x0C, ##   0000       00
            0x70, 0x0C, ##   000        00
            0xF0, 0x0C, ##  0000        00
            0xFF, 0xFC, ##  00000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '123' => {    # '{'
        'width'    => 13, 
        'xoffset'  => 4, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0xF8, ##          00000
            0x03, 0x80, ##        000    
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x06, 0x00, ##       00      
            0x0E, 0x00, ##      000      
            0xF0, 0x00, ##  0000         
            0x0E, 0x00, ##      000      
            0x06, 0x00, ##       00      
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x07, 0x00, ##       000     
            0x03, 0x80, ##        000    
            0x01, 0xF8, ##         000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '124' => {    # '|'
        'width'    => 3, 
        'xoffset'  => 4, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
            0xE0, ##  000
        ], 
    }, 
    '125' => {    # '}'
        'width'    => 12, 
        'xoffset'  => 4, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF0, 0x00, ##  0000        
            0x1C, 0x00, ##     000      
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x06, 0x00, ##       00     
            0x07, 0x00, ##       000    
            0x00, 0xF0, ##          0000
            0x07, 0x00, ##       000    
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x0E, 0x00, ##      000     
            0x1C, 0x00, ##     000      
            0xF8, 0x00, ##  00000       
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '126' => {    # '~'
        'width'    => 20, 
        'xoffset'  => 3, 
        'xadvance' => 26, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x3F, 0xC0, 0x30, ##    00000000        00
            0xE0, 0xFF, 0xE0, ##  000     00000000000 
            0xC0, 0x3F, 0xC0, ##  00        00000000  
            0x80, 0x0F, 0x80, ##  0           00000   
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '176' => {    # '°'
        'width'    => 10, 
        'xoffset'  => 3, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1E, 0x00, ##     0000   
            0x63, 0x80, ##   00   000 
            0xE1, 0x80, ##  000    00 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC1, 0xC0, ##  00     000
            0x61, 0x80, ##   00    00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
};
 
my $kerning = {
    '33' => { },  # !
    '34' => { },  # "
    '35' => { },  # #
    '36' => { },  # $
    '37' => { },  # %
    '38' => { },  # &
    '39' => { },  # '
    '40' => { },  # (
    '41' => { },  # )
    '42' => { },  # *
    '43' => { },  # +
    '44' => { },  # ,
    '45' => { '84' => -1, '86' => -2, '87' => -2, '88' => -1, '89' => -4, },  # -
    '46' => { },  # .
    '47' => { },  # /
    '48' => { },  # 0
    '49' => { },  # 1
    '50' => { },  # 2
    '51' => { },  # 3
    '52' => { },  # 4
    '53' => { },  # 5
    '54' => { },  # 6
    '55' => { },  # 7
    '56' => { },  # 8
    '57' => { },  # 9
    '58' => { },  # :
    '59' => { },  # ;
    '60' => { },  # <
    '61' => { },  # =
    '62' => { },  # >
    '63' => { },  # ?
    '64' => { },  # @
    '65' => { '84' => -2, '86' => -2, '87' => -1, '89' => -1, '102' => -1, '116' => -1, '118' => -1, '119' => -1, '121' => -1, },  # A
    '66' => { '45' => 1, '67' => 1, '71' => 1, '79' => 1, '89' => -1, },  # B
    '67' => { '44' => -1, '46' => -1, },  # C
    '68' => { '44' => -1, '45' => 1, '46' => -1, '86' => -1, },  # D
    '69' => { '45' => 1, },  # E
    '70' => { '44' => -5, '45' => -1, '46' => -5, '58' => -1, '59' => -1, '65' => -3, '97' => -2, '101' => -2, '111' => -2, },  # F
    '71' => { '44' => -1, '45' => 1, '46' => -1, '89' => -1, },  # G
    '72' => { },  # H
    '73' => { },  # I
    '74' => { '44' => -2, '46' => -2, '58' => -1, '59' => -1, },  # J
    '75' => { '45' => -2, '65' => -1, '67' => -1, '79' => -1, '85' => -1, '87' => -1, '89' => -1, '101' => -1, '111' => -1, '117' => -1, '121' => -2, },  # K
    '76' => { '84' => -3, '85' => -2, '86' => -4, '87' => -3, '89' => -2, '121' => -1, },  # L
    '77' => { },  # M
    '78' => { '44' => -2, '46' => -2, '58' => -1, '59' => -1, },  # N
    '79' => { '44' => -2, '45' => 1, '46' => -2, '86' => -1, '88' => -1, },  # O
    '80' => { '44' => -6, '45' => -2, '46' => -6, '58' => -1, '59' => -1, '65' => -3, '85' => -1, '97' => -1, '101' => -1, '111' => -1, '115' => -1, },  # P
    '81' => { '44' => -2, '45' => 1, '46' => -2, },  # Q
    '82' => { '84' => -1, '86' => -1, '87' => -1, '89' => -1, '97' => 1, '121' => -1, },  # R
    '83' => { '44' => -1, '45' => 1, '46' => -1, },  # S
    '84' => { '44' => -5, '45' => -4, '46' => -5, '58' => -1, '59' => -1, '65' => -2, '97' => -2, '99' => -2, '101' => -2, '111' => -2, '115' => -2, '119' => -1, },  # T
    '85' => { '44' => -3, '45' => -1, '46' => -3, '58' => -1, '59' => -1, '65' => -1, '74' => -1, },  # U
    '86' => { '44' => -6, '45' => -3, '46' => -6, '58' => -3, '59' => -3, '65' => -2, '79' => -1, '97' => -3, '101' => -3, '105' => -1, '111' => -3, '117' => -2, '121' => -1, },  # V
    '87' => { '44' => -6, '45' => -2, '46' => -6, '58' => -3, '59' => -3, '65' => -2, '97' => -3, '101' => -3, '105' => -1, '111' => -2, '114' => -1, '117' => -1, '121' => -1, },  # W
    '88' => { '45' => -1, '65' => -1, '67' => -1, '79' => -1, },  # X
    '89' => { '44' => -4, '45' => -4, '46' => -4, '58' => -4, '59' => -4, '65' => -2, '67' => -1, '97' => -2, '101' => -3, '105' => -1, '111' => -3, '117' => -3, },  # Y
    '90' => { '44' => -1, '46' => -1, },  # Z
    '91' => { },  # [
    '92' => { },  # \
    '93' => { },  # ]
    '94' => { },  # ^
    '95' => { },  # _
    '96' => { },  # `
    '97' => { },  # a
    '98' => { },  # b
    '99' => { },  # c
    '100' => { },  # d
    '101' => { },  # e
    '102' => { '44' => -1, '45' => -1, '46' => -1, },  # f
    '103' => { },  # g
    '104' => { },  # h
    '105' => { },  # i
    '106' => { },  # j
    '107' => { '45' => -1, },  # k
    '108' => { },  # l
    '109' => { },  # m
    '110' => { },  # n
    '111' => { '46' => -1, },  # o
    '112' => { },  # p
    '113' => { },  # q
    '114' => { '44' => -4, '46' => -4, },  # r
    '115' => { },  # s
    '116' => { },  # t
    '117' => { },  # u
    '118' => { '44' => -4, '46' => -4, },  # v
    '119' => { '44' => -4, '46' => -4, },  # w
    '120' => { '45' => -1, },  # x
    '121' => { '44' => -4, '46' => -4, },  # y
    '122' => { },  # z
    '123' => { },  # {
    '124' => { },  # |
    '125' => { },  # }
    '126' => { },  # ~
    '176' => { },  # °
};


sub new {
    my($class) = @_;
    
    my $self = $class->SUPER::new(
        name        => $name,
        char_height => $char_height,
        space_width => $space_width,
        gap_width   => $gap_width,
        symbols     => $symbols,
        kerning     => $kerning,
        line_spacing => $line_spacing,
        class       => 'hipi_2',
    );
    
    return $self;
}

1;

__END__
