#########################################################################################
# Package        HiPi::Graphics::BitmapFont::SerifExtended24
# Description  : Monochrome OLED Font
# License      : This is free software; you can redistribute it and/or modify it under
#                the same terms as the Perl 5 programming language system itself.
#########################################################################################

package HiPi::Graphics::BitmapFont::SerifExtended24;

#########################################################################################

use utf8;
use strict;
use warnings;
use parent qw( HiPi::Graphics::BitmapFont);

our $VERSION ='0.01';

my $gap_width = 0;
my $char_height = 24;
my $line_spacing = 0;
my $name = 'Serif 24';
my $space_width = 6;
 
my $symbols = {
    '33' => {    # '!'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x00, ##    
            0x00, ##    
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '34' => {    # '"'
        'width'    => 5, 
        'xoffset'  => 2, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xD8, ##  00 00
            0xD8, ##  00 00
            0xD8, ##  00 00
            0xD8, ##  00 00
            0xD8, ##  00 00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '35' => {    # '#'
        'width'    => 14, 
        'xoffset'  => 2, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x02, 0x30, ##        0   00  
            0x06, 0x30, ##       00   00  
            0x06, 0x20, ##       00   0   
            0x06, 0x60, ##       00  00   
            0x7F, 0xFC, ##   0000000000000
            0x0C, 0x60, ##      00   00   
            0x0C, 0x40, ##      00   0    
            0x0C, 0xC0, ##      00  00    
            0x08, 0xC0, ##      0   00    
            0x18, 0xC0, ##     00   00    
            0xFF, 0xF8, ##  0000000000000 
            0x18, 0x80, ##     00   0     
            0x11, 0x80, ##     0   00     
            0x31, 0x80, ##    00   00     
            0x31, 0x00, ##    00   0      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '36' => {    # '$'
        'width'    => 9, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x08, 0x00, ##      0    
            0x08, 0x00, ##      0    
            0x3E, 0x00, ##    00000  
            0x6B, 0x00, ##   00 0 00 
            0xC9, 0x00, ##  00  0  0 
            0xC9, 0x00, ##  00  0  0 
            0xE8, 0x00, ##  000 0    
            0x78, 0x00, ##   0000    
            0x3E, 0x00, ##    00000  
            0x0F, 0x80, ##      00000
            0x09, 0x80, ##      0  00
            0x89, 0x80, ##  0   0  00
            0x89, 0x80, ##  0   0  00
            0xCB, 0x00, ##  00  0 00 
            0x7E, 0x00, ##   000000  
            0x08, 0x00, ##      0    
            0x08, 0x00, ##      0    
            0x08, 0x00, ##      0    
            0x00, 0x00, ##  
        ], 
    }, 
    '37' => {    # '%'
        'width'    => 17, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x38, 0x08, 0x00, ##    000       0    
            0x6C, 0x08, 0x00, ##   00 00      0    
            0xC6, 0x10, 0x00, ##  00   00    0     
            0xC6, 0x30, 0x00, ##  00   00   00     
            0xC6, 0x20, 0x00, ##  00   00   0      
            0xC6, 0x40, 0x00, ##  00   00  0       
            0x6C, 0xC0, 0x00, ##   00 00  00       
            0x38, 0x8E, 0x00, ##    000   0   000  
            0x01, 0x9B, 0x00, ##         00  00 00 
            0x01, 0x31, 0x80, ##         0  00   00
            0x02, 0x31, 0x80, ##        0   00   00
            0x06, 0x31, 0x80, ##       00   00   00
            0x04, 0x31, 0x80, ##       0    00   00
            0x08, 0x1B, 0x00, ##      0      00 00 
            0x08, 0x0E, 0x00, ##      0       000  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '38' => {    # '&'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0x80, ##      00000       
            0x38, 0x80, ##    000   0       
            0x30, 0x80, ##    00    0       
            0x30, 0x00, ##    00            
            0x38, 0x00, ##    000           
            0x18, 0x00, ##     00           
            0x2C, 0x3E, ##    0 00    00000 
            0x66, 0x08, ##   00  00     0   
            0xC3, 0x08, ##  00    00    0   
            0xC1, 0x98, ##  00     00  00   
            0xC0, 0xD0, ##  00      00 0    
            0xC0, 0x70, ##  00       000    
            0x60, 0x70, ##   00      000    
            0x70, 0xF8, ##   000    00000   
            0x1F, 0x1F, ##     00000   00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '39' => {    # '''
        'width'    => 2, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '40' => {    # '('
        'width'    => 5, 
        'xoffset'  => 2, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##       
            0x18, ##     00
            0x30, ##    00 
            0x60, ##   00  
            0x60, ##   00  
            0x40, ##   0   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0x40, ##   0   
            0x60, ##   00  
            0x20, ##    0  
            0x10, ##     0 
            0x08, ##      0
            0x00, ##  
        ], 
    }, 
    '41' => {    # ')'
        'width'    => 5, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##       
            0xC0, ##  00   
            0x60, ##   00  
            0x30, ##    00 
            0x30, ##    00 
            0x10, ##     0 
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x30, ##    00 
            0x30, ##    00 
            0x20, ##    0  
            0x40, ##   0   
            0x80, ##  0    
            0x00, ##  
        ], 
    }, 
    '42' => {    # '*'
        'width'    => 9, 
        'xoffset'  => 0, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x08, 0x00, ##      0    
            0x08, 0x00, ##      0    
            0xC9, 0x80, ##  00  0  00
            0x3E, 0x00, ##    00000  
            0x08, 0x00, ##      0    
            0x3E, 0x00, ##    00000  
            0xC9, 0x80, ##  00  0  00
            0x08, 0x00, ##      0    
            0x08, 0x00, ##      0    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '43' => {    # '+'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0xFF, 0xF8, ##  0000000000000
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '44' => {    # ','
        'width'    => 4, 
        'xoffset'  => 0, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x30, ##    00
            0x30, ##    00
            0x30, ##    00
            0x60, ##   00 
            0xC0, ##  00  
            0x00, ##  
        ], 
    }, 
    '45' => {    # '-'
        'width'    => 5, 
        'xoffset'  => 1, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF8, ##  00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '46' => {    # '.'
        'width'    => 2, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '47' => {    # '/'
        'width'    => 7, 
        'xoffset'  => 0, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x06, ##       00
            0x04, ##       0 
            0x0C, ##      00 
            0x0C, ##      00 
            0x08, ##      0  
            0x18, ##     00  
            0x18, ##     00  
            0x10, ##     0   
            0x10, ##     0   
            0x30, ##    00   
            0x30, ##    00   
            0x20, ##    0    
            0x60, ##   00    
            0x60, ##   00    
            0x40, ##   0     
            0xC0, ##  00     
            0xC0, ##  00     
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '48' => {    # '0'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1E, 0x00, ##     0000   
            0x33, 0x00, ##    00  00  
            0x61, 0x80, ##   00    00 
            0x40, 0x80, ##   0      0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x40, 0x80, ##   0      0 
            0x61, 0x80, ##   00    00 
            0x33, 0x00, ##    00  00  
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '49' => {    # '1'
        'width'    => 7, 
        'xoffset'  => 3, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x18, ##     00  
            0x78, ##   0000  
            0xD8, ##  00 00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0x18, ##     00  
            0xFE, ##  0000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '50' => {    # '2'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0x00, ##    00000  
            0xC3, 0x00, ##  00    00 
            0x81, 0x80, ##  0      00
            0x81, 0x80, ##  0      00
            0x01, 0x80, ##         00
            0x01, 0x80, ##         00
            0x01, 0x00, ##         0 
            0x03, 0x00, ##        00 
            0x06, 0x00, ##       00  
            0x04, 0x00, ##       0   
            0x08, 0x00, ##      0    
            0x10, 0x00, ##     0     
            0x20, 0x80, ##    0     0
            0x60, 0x80, ##   00     0
            0xFF, 0x80, ##  000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '51' => {    # '3'
        'width'    => 10, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0x00, ##    00000   
            0xC3, 0x00, ##  00    00  
            0xC1, 0x80, ##  00     00 
            0x01, 0x80, ##         00 
            0x01, 0x80, ##         00 
            0x03, 0x00, ##        00  
            0x1C, 0x00, ##     000    
            0x03, 0x80, ##        000 
            0x01, 0x80, ##         00 
            0x00, 0xC0, ##          00
            0x00, 0xC0, ##          00
            0x80, 0xC0, ##  0       00
            0x80, 0xC0, ##  0       00
            0xC1, 0x80, ##  00     00 
            0x7E, 0x00, ##   000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '52' => {    # '4'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x00, ##        00   
            0x07, 0x00, ##       000   
            0x0F, 0x00, ##      0000   
            0x0B, 0x00, ##      0 00   
            0x1B, 0x00, ##     00 00   
            0x13, 0x00, ##     0  00   
            0x23, 0x00, ##    0   00   
            0x63, 0x00, ##   00   00   
            0x43, 0x00, ##   0    00   
            0xC3, 0x00, ##  00    00   
            0xFF, 0xE0, ##  00000000000
            0x03, 0x00, ##        00   
            0x03, 0x00, ##        00   
            0x03, 0x00, ##        00   
            0x0F, 0xE0, ##      0000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '53' => {    # '5'
        'width'    => 9, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x7F, 0x00, ##   0000000 
            0x40, 0x00, ##   0       
            0x40, 0x00, ##   0       
            0x40, 0x00, ##   0       
            0x40, 0x00, ##   0       
            0x7E, 0x00, ##   000000  
            0x43, 0x00, ##   0    00 
            0x01, 0x80, ##         00
            0x01, 0x80, ##         00
            0x01, 0x80, ##         00
            0x01, 0x80, ##         00
            0x81, 0x80, ##  0      00
            0x83, 0x80, ##  0     000
            0xC3, 0x00, ##  00    00 
            0x7C, 0x00, ##   00000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '54' => {    # '6'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0x80, ##      00000 
            0x31, 0x80, ##    00   00 
            0x60, 0x80, ##   00     0 
            0x40, 0x00, ##   0        
            0xC0, 0x00, ##  00        
            0xDF, 0x00, ##  00 00000  
            0xF1, 0x80, ##  0000   00 
            0xE0, 0x80, ##  000     0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xE0, 0xC0, ##  000     00
            0x60, 0x80, ##   00     0 
            0x31, 0x80, ##    00   00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '55' => {    # '7'
        'width'    => 10, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xC0, ##  0000000000
            0x80, 0x80, ##  0       0 
            0x81, 0x80, ##  0      00 
            0x01, 0x00, ##         0  
            0x03, 0x00, ##        00  
            0x03, 0x00, ##        00  
            0x02, 0x00, ##        0   
            0x06, 0x00, ##       00   
            0x04, 0x00, ##       0    
            0x0C, 0x00, ##      00    
            0x0C, 0x00, ##      00    
            0x08, 0x00, ##      0     
            0x18, 0x00, ##     00     
            0x10, 0x00, ##     0      
            0x30, 0x00, ##    00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '56' => {    # '8'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3F, 0x00, ##    000000  
            0x61, 0x80, ##   00    00 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0xC0, ##   00    000
            0x1F, 0x00, ##     00000  
            0x61, 0x00, ##   00    0  
            0xC0, 0x80, ##  00      0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0x80, ##   00    00 
            0x3F, 0x00, ##    000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '57' => {    # '9'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0x00, ##    00000   
            0x61, 0x00, ##   00    0  
            0xC1, 0x80, ##  00     00 
            0xC0, 0x80, ##  00      0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC1, 0xC0, ##  00     000
            0x61, 0xC0, ##   00    000
            0x3E, 0xC0, ##    00000 00
            0x00, 0xC0, ##          00
            0x00, 0xC0, ##          00
            0x00, 0x80, ##          0 
            0x41, 0x80, ##   0     00 
            0x63, 0x00, ##   00   00  
            0x7E, 0x00, ##   000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '58' => {    # ':'
        'width'    => 2, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '59' => {    # ';'
        'width'    => 3, 
        'xoffset'  => 1, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x60, ##   00
            0x60, ##   00
            0x00, ##     
            0x00, ##     
            0x00, ##     
            0x00, ##     
            0x60, ##   00
            0x60, ##   00
            0x60, ##   00
            0xC0, ##  00 
            0x80, ##  0  
            0x00, ##  
        ], 
    }, 
    '60' => {    # '<'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x18, ##             00
            0x00, 0x78, ##           0000
            0x03, 0xC0, ##        0000   
            0x1F, 0x00, ##     00000     
            0x78, 0x00, ##   0000        
            0xE0, 0x00, ##  000          
            0xF8, 0x00, ##  00000        
            0x1F, 0x00, ##     00000     
            0x03, 0xC0, ##        0000   
            0x00, 0xF8, ##          00000
            0x00, 0x18, ##             00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '61' => {    # '='
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xF8, ##  0000000000000
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xFF, 0xF8, ##  0000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '62' => {    # '>'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x80, 0x00, ##  0            
            0xF0, 0x00, ##  0000         
            0x3E, 0x00, ##    00000      
            0x07, 0x80, ##       0000    
            0x01, 0xF0, ##         00000 
            0x00, 0x38, ##            000
            0x00, 0xF0, ##          0000 
            0x07, 0xC0, ##       00000   
            0x3E, 0x00, ##    00000      
            0xF0, 0x00, ##  0000         
            0x80, 0x00, ##  0            
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '63' => {    # '?'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x7C, ##   00000  
            0xC6, ##  00   00 
            0x83, ##  0     00
            0x83, ##  0     00
            0x03, ##        00
            0x03, ##        00
            0x06, ##       00 
            0x0E, ##      000 
            0x18, ##     00   
            0x10, ##     0    
            0x10, ##     0    
            0x00, ##          
            0x00, ##          
            0x30, ##    00    
            0x30, ##    00    
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '64' => {    # '@'
        'width'    => 17, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x03, 0xF0, 0x00, ##        000000     
            0x0E, 0x0C, 0x00, ##      000     00   
            0x18, 0x02, 0x00, ##     00         0  
            0x30, 0x01, 0x00, ##    00           0 
            0x60, 0x19, 0x00, ##   00        00  0 
            0x63, 0xD8, 0x80, ##   00   0000 00   0
            0xC6, 0x38, 0x80, ##  00   00   000   0
            0xCC, 0x18, 0x80, ##  00  00     00   0
            0xCC, 0x18, 0x80, ##  00  00     00   0
            0xCC, 0x18, 0x80, ##  00  00     00   0
            0xCC, 0x19, 0x00, ##  00  00     00  0 
            0xC6, 0x3A, 0x00, ##  00   00   000 0  
            0x63, 0xDC, 0x00, ##   00   0000 000   
            0x60, 0x00, 0x00, ##   00              
            0x30, 0x00, 0x00, ##    00             
            0x18, 0x04, 0x00, ##     00        0   
            0x0E, 0x0C, 0x00, ##      000     00   
            0x03, 0xF0, 0x00, ##        000000     
        ], 
    }, 
    '65' => {    # 'A'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x07, 0xC0, ##       00000     
            0x04, 0xC0, ##       0  00     
            0x04, 0xE0, ##       0  000    
            0x08, 0x60, ##      0    00    
            0x08, 0x60, ##      0    00    
            0x18, 0x70, ##     00    000   
            0x10, 0x30, ##     0      00   
            0x1F, 0xF0, ##     000000000   
            0x20, 0x18, ##    0        00  
            0x20, 0x18, ##    0        00  
            0x60, 0x18, ##   00        00  
            0xF0, 0x3E, ##  0000      00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '66' => {    # 'B'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xC0, ##  0000000000  
            0x30, 0x60, ##    00     00 
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x60, ##    00     00 
            0x3F, 0x80, ##    0000000   
            0x30, 0x60, ##    00     00 
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x60, ##    00     00 
            0xFF, 0xC0, ##  0000000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '67' => {    # 'C'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xC0, ##      000000   
            0x18, 0x78, ##     00    0000
            0x20, 0x38, ##    0       000
            0x60, 0x18, ##   00        00
            0xC0, 0x18, ##  00         00
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0x60, 0x18, ##   00        00
            0x20, 0x30, ##    0       00 
            0x18, 0x60, ##     00    00  
            0x0F, 0xC0, ##      000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '68' => {    # 'D'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x80, ##  000000000     
            0x30, 0x60, ##    00     00   
            0x30, 0x30, ##    00      00  
            0x30, 0x18, ##    00       00 
            0x30, 0x0C, ##    00        00
            0x30, 0x0C, ##    00        00
            0x30, 0x0C, ##    00        00
            0x30, 0x0C, ##    00        00
            0x30, 0x0C, ##    00        00
            0x30, 0x0C, ##    00        00
            0x30, 0x1C, ##    00       000
            0x30, 0x18, ##    00       00 
            0x30, 0x30, ##    00      00  
            0x30, 0x60, ##    00     00   
            0xFF, 0x80, ##  000000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '69' => {    # 'E'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xF0, ##  000000000000
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0x30, 0x00, ##    00        
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x3F, 0xC0, ##    00000000  
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0xFF, 0xF0, ##  000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '70' => {    # 'F'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xF0, ##  000000000000
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0x30, 0x00, ##    00        
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x3F, 0xC0, ##    00000000  
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0xFC, 0x00, ##  000000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '71' => {    # 'G'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xE0, ##      0000000  
            0x18, 0x70, ##     00    000 
            0x20, 0x10, ##    0        0 
            0x60, 0x10, ##   00        0 
            0xC0, 0x10, ##  00         0 
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0xF8, ##  00      00000
            0xC0, 0x18, ##  00         00
            0xC0, 0x18, ##  00         00
            0x60, 0x18, ##   00        00
            0x20, 0x18, ##    0        00
            0x18, 0x38, ##     00     000
            0x0F, 0xE0, ##      0000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '72' => {    # 'H'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFC, 0x7E, ##  000000   000000
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x3F, 0xF8, ##    00000000000  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0x30, 0x18, ##    00       00  
            0xFC, 0x7E, ##  000000   000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '73' => {    # 'I'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '74' => {    # 'J'
        'width'    => 9, 
        'xoffset'  => -2, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x80, ##     000000
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x86, 0x00, ##  0    00  
            0x8C, 0x00, ##  0   00   
            0xF8, 0x00, ##  00000    
        ], 
    }, 
    '75' => {    # 'K'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFC, 0xF8, ##  000000  00000 
            0x30, 0x60, ##    00     00   
            0x30, 0xC0, ##    00    00    
            0x31, 0x80, ##    00   00     
            0x33, 0x00, ##    00  00      
            0x36, 0x00, ##    00 00       
            0x3C, 0x00, ##    0000        
            0x3C, 0x00, ##    0000        
            0x36, 0x00, ##    00 00       
            0x37, 0x00, ##    00 000      
            0x33, 0x80, ##    00  000     
            0x31, 0xC0, ##    00   000    
            0x30, 0xE0, ##    00    000   
            0x30, 0x70, ##    00     000  
            0xFC, 0x3C, ##  000000    0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '76' => {    # 'L'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFC, 0x00, ##  000000      
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0xFF, 0xF0, ##  000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '77' => {    # 'M'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xF0, 0x03, 0xC0, ##  0000          0000
            0x38, 0x07, 0x00, ##    000        000  
            0x38, 0x07, 0x00, ##    000        000  
            0x2C, 0x0B, 0x00, ##    0 00      0 00  
            0x2C, 0x0B, 0x00, ##    0 00      0 00  
            0x2E, 0x1B, 0x00, ##    0 000    00 00  
            0x26, 0x13, 0x00, ##    0  00    0  00  
            0x27, 0x33, 0x00, ##    0  000  00  00  
            0x23, 0x23, 0x00, ##    0   00  0   00  
            0x23, 0x23, 0x00, ##    0   00  0   00  
            0x21, 0xC3, 0x00, ##    0    000    00  
            0x21, 0xC3, 0x00, ##    0    000    00  
            0x20, 0x83, 0x00, ##    0     0     00  
            0x20, 0x03, 0x00, ##    0           00  
            0xF8, 0x0F, 0xC0, ##  00000       000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '78' => {    # 'N'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF0, 0x1F, ##  0000       00000
            0x38, 0x04, ##    000        0  
            0x3C, 0x04, ##    0000       0  
            0x2C, 0x04, ##    0 00       0  
            0x26, 0x04, ##    0  00      0  
            0x27, 0x04, ##    0  000     0  
            0x23, 0x84, ##    0   000    0  
            0x21, 0xC4, ##    0    000   0  
            0x20, 0xC4, ##    0     00   0  
            0x20, 0x64, ##    0      00  0  
            0x20, 0x74, ##    0      000 0  
            0x20, 0x3C, ##    0       0000  
            0x20, 0x1C, ##    0        000  
            0x20, 0x0C, ##    0         00  
            0xF8, 0x04, ##  00000        0  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '79' => {    # 'O'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xC0, ##      000000    
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x60, 0x18, ##   00        00 
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0x60, 0x18, ##   00        00 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '80' => {    # 'P'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xC0, ##  0000000000  
            0x30, 0x60, ##    00     00 
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x60, ##    00     00 
            0x3F, 0xC0, ##    00000000  
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0xFC, 0x00, ##  000000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '81' => {    # 'Q'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xC0, ##      000000    
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x60, 0x18, ##   00        00 
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0x60, 0x18, ##   00        00 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0xC0, ##          00    
            0x00, 0xF0, ##          0000  
            0x00, 0x30, ##            00  
            0x00, 0x00, ##  
        ], 
    }, 
    '82' => {    # 'R'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xC0, ##  0000000000     
            0x30, 0x60, ##    00     00    
            0x30, 0x30, ##    00      00   
            0x30, 0x30, ##    00      00   
            0x30, 0x30, ##    00      00   
            0x30, 0x30, ##    00      00   
            0x30, 0x60, ##    00     00    
            0x3F, 0x80, ##    0000000      
            0x30, 0xC0, ##    00    00     
            0x30, 0x60, ##    00     00    
            0x30, 0x60, ##    00     00    
            0x30, 0x30, ##    00      00   
            0x30, 0x30, ##    00      00   
            0x30, 0x18, ##    00       00  
            0xFC, 0x1E, ##  000000     0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '83' => {    # 'S'
        'width'    => 10, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3F, 0x00, ##    000000  
            0x61, 0x80, ##   00    00 
            0xC0, 0x80, ##  00      0 
            0xC0, 0x80, ##  00      0 
            0xC0, 0x00, ##  00        
            0xE0, 0x00, ##  000       
            0x7C, 0x00, ##   00000    
            0x3F, 0x00, ##    000000  
            0x07, 0x80, ##       0000 
            0x01, 0xC0, ##         000
            0x00, 0xC0, ##          00
            0x80, 0xC0, ##  0       00
            0x80, 0xC0, ##  0       00
            0xC1, 0x80, ##  00     00 
            0x7F, 0x00, ##   0000000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '84' => {    # 'T'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xF8, ##  0000000000000
            0x86, 0x08, ##  0    00     0
            0x86, 0x08, ##  0    00     0
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x1F, 0x80, ##     000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '85' => {    # 'U'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFC, 0x3E, ##  000000    00000
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x18, 0x10, ##     00      0   
            0x1C, 0x30, ##     000    00   
            0x07, 0xC0, ##       00000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '86' => {    # 'V'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF8, 0x1E, ##  00000      0000
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x18, 0x10, ##     00      0   
            0x18, 0x10, ##     00      0   
            0x1C, 0x30, ##     000    00   
            0x0C, 0x20, ##      00    0    
            0x0C, 0x20, ##      00    0    
            0x0E, 0x40, ##      000  0     
            0x06, 0x40, ##       00  0     
            0x07, 0xC0, ##       00000     
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '87' => {    # 'W'
        'width'    => 20, 
        'xoffset'  => 1, 
        'xadvance' => 22, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xF8, 0x60, 0xF0, ##  00000    00     0000
            0x60, 0x70, 0x60, ##   00      000     00 
            0x30, 0x70, 0x40, ##    00     000     0  
            0x30, 0x70, 0x40, ##    00     000     0  
            0x30, 0xB0, 0x40, ##    00    0 00     0  
            0x10, 0x98, 0x80, ##     0    0  00   0   
            0x18, 0x98, 0x80, ##     00   0  00   0   
            0x19, 0x98, 0x80, ##     00  00  00   0   
            0x19, 0x0C, 0x80, ##     00  0    00  0   
            0x0D, 0x0D, 0x00, ##      00 0    00 0    
            0x0D, 0x0D, 0x00, ##      00 0    00 0    
            0x0F, 0x0D, 0x00, ##      0000    00 0    
            0x0E, 0x07, 0x00, ##      000      000    
            0x06, 0x06, 0x00, ##       00      00     
            0x06, 0x06, 0x00, ##       00      00     
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '88' => {    # 'X'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFC, 0xF8, ##  000000  00000 
            0x38, 0x20, ##    000     0   
            0x18, 0x40, ##     00    0    
            0x1C, 0x40, ##     000   0    
            0x0C, 0x80, ##      00  0     
            0x07, 0x80, ##       0000     
            0x07, 0x00, ##       000      
            0x03, 0x00, ##        00      
            0x07, 0x80, ##       0000     
            0x05, 0x80, ##       0 00     
            0x09, 0xC0, ##      0  000    
            0x18, 0xE0, ##     00   000   
            0x10, 0x60, ##     0     00   
            0x20, 0x70, ##    0      000  
            0xF8, 0xFC, ##  00000   000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '89' => {    # 'Y'
        'width'    => 13, 
        'xoffset'  => 0, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF8, 0x78, ##  00000    0000
            0x30, 0x10, ##    00       0 
            0x38, 0x20, ##    000     0  
            0x18, 0x20, ##     00     0  
            0x0C, 0x40, ##      00   0   
            0x0E, 0xC0, ##      000 00   
            0x06, 0x80, ##       00 0    
            0x07, 0x00, ##       000     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x0F, 0xC0, ##      000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '90' => {    # 'Z'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xF0, ##  000000000000
            0x80, 0x60, ##  0        00 
            0x80, 0xC0, ##  0       00  
            0x01, 0xC0, ##         000  
            0x03, 0x80, ##        000   
            0x03, 0x00, ##        00    
            0x07, 0x00, ##       000    
            0x0E, 0x00, ##      000     
            0x0C, 0x00, ##      00      
            0x18, 0x00, ##     00       
            0x38, 0x00, ##    000       
            0x30, 0x00, ##    00        
            0x60, 0x10, ##   00        0
            0xE0, 0x10, ##  000        0
            0xFF, 0xF0, ##  000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '91' => {    # '['
        'width'    => 5, 
        'xoffset'  => 2, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF8, ##  00000
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xC0, ##  00   
            0xF8, ##  00000
            0x00, ##  
        ], 
    }, 
    '92' => {    # '\'
        'width'    => 7, 
        'xoffset'  => 0, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00     
            0xC0, ##  00     
            0x40, ##   0     
            0x60, ##   00    
            0x60, ##   00    
            0x20, ##    0    
            0x30, ##    00   
            0x30, ##    00   
            0x10, ##     0   
            0x10, ##     0   
            0x18, ##     00  
            0x18, ##     00  
            0x08, ##      0  
            0x0C, ##      00 
            0x0C, ##      00 
            0x04, ##       0 
            0x06, ##       00
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '93' => {    # ']'
        'width'    => 5, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF8, ##  00000
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0x18, ##     00
            0xF8, ##  00000
            0x00, ##  
        ], 
    }, 
    '94' => {    # '^'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x06, 0x00, ##       00      
            0x0F, 0x00, ##      0000     
            0x1D, 0x80, ##     000 00    
            0x18, 0xC0, ##     00   00   
            0x30, 0x60, ##    00     00  
            0x40, 0x10, ##   0         0 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '95' => {    # '_'
        'width'    => 10, 
        'xoffset'  => 0, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '96' => {    # '`'
        'width'    => 4, 
        'xoffset'  => 2, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00  
            0x60, ##   00 
            0x20, ##    0 
            0x10, ##     0
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '97' => {    # 'a'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0x00, ##    00000   
            0x43, 0x00, ##   0    00  
            0x41, 0x80, ##   0     00 
            0x01, 0x80, ##         00 
            0x3F, 0x80, ##    0000000 
            0x61, 0x80, ##   00    00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0x63, 0x80, ##   00   000 
            0x3D, 0xC0, ##    0000 000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '98' => {    # 'b'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x00, ##  000       
            0x60, 0x00, ##   00       
            0x60, 0x00, ##   00       
            0x60, 0x00, ##   00       
            0x6F, 0x00, ##   00 0000  
            0x71, 0x80, ##   000   00 
            0x60, 0x80, ##   00     0 
            0x60, 0xC0, ##   00     00
            0x60, 0xC0, ##   00     00
            0x60, 0xC0, ##   00     00
            0x60, 0xC0, ##   00     00
            0x60, 0xC0, ##   00     00
            0x60, 0x80, ##   00     0 
            0x71, 0x80, ##   000   00 
            0xEF, 0x00, ##  000 0000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '99' => {    # 'c'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x00, ##     00000 
            0x61, 0x80, ##   00    00
            0x60, 0x80, ##   00     0
            0xC0, 0x80, ##  00      0
            0xC0, 0x00, ##  00       
            0xC0, 0x00, ##  00       
            0xC0, 0x00, ##  00       
            0xC0, 0x00, ##  00       
            0x60, 0x80, ##   00     0
            0x61, 0x00, ##   00    0 
            0x1E, 0x00, ##     0000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '100' => {    # 'd'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0xC0, ##        0000  
            0x00, 0xC0, ##          00  
            0x00, 0xC0, ##          00  
            0x00, 0xC0, ##          00  
            0x3E, 0xC0, ##    00000 00  
            0x61, 0xC0, ##   00    000  
            0x60, 0xC0, ##   00     00  
            0xC0, 0xC0, ##  00      00  
            0xC0, 0xC0, ##  00      00  
            0xC0, 0xC0, ##  00      00  
            0xC0, 0xC0, ##  00      00  
            0xC0, 0xC0, ##  00      00  
            0x60, 0xC0, ##   00     00  
            0x61, 0xC0, ##   00    000  
            0x1E, 0xF0, ##     0000 0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '101' => {    # 'e'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x60, 0x80, ##   00     0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xFF, 0xC0, ##  0000000000
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0x40, 0xC0, ##   0      00
            0x61, 0x80, ##   00    00 
            0x1F, 0x00, ##     00000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '102' => {    # 'f'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x1F, ##     00000
            0x31, ##    00   0
            0x30, ##    00    
            0x30, ##    00    
            0xFC, ##  000000  
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0x30, ##    00    
            0xFC, ##  000000  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '103' => {    # 'g'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0xE0, ##    00000 000
            0x61, 0xC0, ##   00    000 
            0x60, 0xC0, ##   00     00 
            0xC0, 0xC0, ##  00      00 
            0xC0, 0xC0, ##  00      00 
            0xC0, 0xC0, ##  00      00 
            0xC0, 0xC0, ##  00      00 
            0xC0, 0xC0, ##  00      00 
            0x60, 0xC0, ##   00     00 
            0x61, 0xC0, ##   00    000 
            0x3E, 0xC0, ##    00000 00 
            0x00, 0xC0, ##          00 
            0x40, 0xC0, ##   0      00 
            0x61, 0x80, ##   00    00  
            0x3F, 0x00, ##    000000   
        ], 
    }, 
    '104' => {    # 'h'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xE0, 0x00, ##  000         
            0x60, 0x00, ##   00         
            0x60, 0x00, ##   00         
            0x60, 0x00, ##   00         
            0x6F, 0x00, ##   00 0000    
            0x71, 0x80, ##   000   00   
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0xF9, 0xF0, ##  00000  00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '105' => {    # 'i'
        'width'    => 5, 
        'xoffset'  => 1, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x60, ##   00  
            0x60, ##   00  
            0x00, ##       
            0x00, ##       
            0xE0, ##  000  
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0x60, ##   00  
            0xF8, ##  00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '106' => {    # 'j'
        'width'    => 6, 
        'xoffset'  => -2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x0C, ##      00
            0x0C, ##      00
            0x00, ##        
            0x00, ##        
            0x1C, ##     000
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x0C, ##      00
            0x8C, ##  0   00
            0x9C, ##  0  000
            0xF8, ##  00000 
        ], 
    }, 
    '107' => {    # 'k'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF0, 0x00, ##  0000       
            0x30, 0x00, ##    00       
            0x30, 0x00, ##    00       
            0x30, 0x00, ##    00       
            0x33, 0xE0, ##    00  00000
            0x31, 0x80, ##    00   00  
            0x33, 0x00, ##    00  00   
            0x32, 0x00, ##    00  0    
            0x34, 0x00, ##    00 0     
            0x3E, 0x00, ##    00000    
            0x33, 0x00, ##    00  00   
            0x33, 0x00, ##    00  00   
            0x31, 0x80, ##    00   00  
            0x31, 0xC0, ##    00   000 
            0xFB, 0xE0, ##  00000 00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '108' => {    # 'l'
        'width'    => 5, 
        'xoffset'  => 1, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF0, ##  0000 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0x30, ##    00 
            0xF8, ##  00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '109' => {    # 'm'
        'width'    => 19, 
        'xoffset'  => 1, 
        'xadvance' => 21, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xEF, 0x1E, 0x00, ##  000 0000   0000    
            0x71, 0xA3, 0x00, ##   000   00 0   00   
            0x60, 0xC1, 0x80, ##   00     00     00  
            0x60, 0xC1, 0x80, ##   00     00     00  
            0x60, 0xC1, 0x80, ##   00     00     00  
            0x60, 0xC1, 0x80, ##   00     00     00  
            0x60, 0xC1, 0x80, ##   00     00     00  
            0x60, 0xC1, 0x80, ##   00     00     00  
            0x60, 0xC1, 0x80, ##   00     00     00  
            0x60, 0xC1, 0x80, ##   00     00     00  
            0xFB, 0xE3, 0xE0, ##  00000 00000   00000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '110' => {    # 'n'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xEF, 0x00, ##  000 0000    
            0x71, 0x80, ##   000   00   
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0xF9, 0xF0, ##  00000  00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '111' => {    # 'o'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '112' => {    # 'p'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF7, 0x80, ##  0000 0000  
            0x38, 0xC0, ##    000   00 
            0x30, 0x40, ##    00     0 
            0x30, 0x60, ##    00     00
            0x30, 0x60, ##    00     00
            0x30, 0x60, ##    00     00
            0x30, 0x60, ##    00     00
            0x30, 0x60, ##    00     00
            0x30, 0x40, ##    00     0 
            0x38, 0xC0, ##    000   00 
            0x37, 0x80, ##    00 0000  
            0x30, 0x00, ##    00       
            0x30, 0x00, ##    00       
            0x30, 0x00, ##    00       
            0xF8, 0x00, ##  00000      
        ], 
    }, 
    '113' => {    # 'q'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3E, 0xE0, ##    00000 000
            0x61, 0xC0, ##   00    000 
            0x60, 0xC0, ##   00     00 
            0xC0, 0xC0, ##  00      00 
            0xC0, 0xC0, ##  00      00 
            0xC0, 0xC0, ##  00      00 
            0xC0, 0xC0, ##  00      00 
            0xC0, 0xC0, ##  00      00 
            0x60, 0xC0, ##   00     00 
            0x61, 0xC0, ##   00    000 
            0x3E, 0xC0, ##    00000 00 
            0x00, 0xC0, ##          00 
            0x00, 0xC0, ##          00 
            0x00, 0xC0, ##          00 
            0x03, 0xE0, ##        00000
        ], 
    }, 
    '114' => {    # 'r'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xEF, 0x80, ##  000 00000
            0x70, 0x80, ##   000    0
            0x70, 0x80, ##   000    0
            0x60, 0x00, ##   00      
            0x60, 0x00, ##   00      
            0x60, 0x00, ##   00      
            0x60, 0x00, ##   00      
            0x60, 0x00, ##   00      
            0x60, 0x00, ##   00      
            0x60, 0x00, ##   00      
            0xF8, 0x00, ##  00000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '115' => {    # 's'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x3E, ##    00000 
            0xC7, ##  00   000
            0xC3, ##  00    00
            0xC0, ##  00      
            0xF0, ##  0000    
            0x3E, ##    00000 
            0x0F, ##      0000
            0x03, ##        00
            0x83, ##  0     00
            0xC7, ##  00   000
            0x7C, ##   00000  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '116' => {    # 't'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0xFE, 0x00, ##  0000000  
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x30, 0x00, ##    00     
            0x31, 0x80, ##    00   00
            0x31, 0x80, ##    00   00
            0x1F, 0x00, ##     00000 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '117' => {    # 'u'
        'width'    => 12, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF1, 0xC0, ##  0000   000  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x39, 0xC0, ##    000  000  
            0x1E, 0xF0, ##     0000 0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '118' => {    # 'v'
        'width'    => 11, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF9, 0xE0, ##  00000  0000
            0x60, 0xC0, ##   00     00 
            0x30, 0x80, ##    00    0  
            0x30, 0x80, ##    00    0  
            0x11, 0x80, ##     0   00  
            0x19, 0x00, ##     00  0   
            0x19, 0x00, ##     00  0   
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x06, 0x00, ##       00    
            0x04, 0x00, ##       0     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '119' => {    # 'w'
        'width'    => 17, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0xF8, 0xC7, 0x80, ##  00000   00   0000
            0x60, 0xC3, 0x00, ##   00     00    00 
            0x31, 0xC2, 0x00, ##    00   000    0  
            0x31, 0x62, 0x00, ##    00   0 00   0  
            0x31, 0x66, 0x00, ##    00   0 00  00  
            0x19, 0x64, 0x00, ##     00  0 00  0   
            0x1A, 0x34, 0x00, ##     00 0   00 0   
            0x1A, 0x3C, 0x00, ##     00 0   0000   
            0x0E, 0x38, 0x00, ##      000   000    
            0x0C, 0x18, 0x00, ##      00     00    
            0x0C, 0x18, 0x00, ##      00     00    
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '120' => {    # 'x'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF3, 0xC0, ##  0000  0000 
            0x71, 0x00, ##   000   0   
            0x33, 0x00, ##    00  00   
            0x1A, 0x00, ##     00 0    
            0x1C, 0x00, ##     000     
            0x0C, 0x00, ##      00     
            0x0E, 0x00, ##      000    
            0x16, 0x00, ##     0 00    
            0x33, 0x00, ##    00  00   
            0x21, 0x80, ##    0    00  
            0xF3, 0xE0, ##  0000  00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '121' => {    # 'y'
        'width'    => 11, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF9, 0xE0, ##  00000  0000
            0x60, 0xC0, ##   00     00 
            0x30, 0x80, ##    00    0  
            0x30, 0x80, ##    00    0  
            0x19, 0x00, ##     00  0   
            0x19, 0x00, ##     00  0   
            0x19, 0x00, ##     00  0   
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x06, 0x00, ##       00    
            0x04, 0x00, ##       0     
            0x04, 0x00, ##       0     
            0x08, 0x00, ##      0      
            0x48, 0x00, ##   0  0      
            0x70, 0x00, ##   000       
        ], 
    }, 
    '122' => {    # 'z'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x80, ##  000000000
            0x83, 0x00, ##  0     00 
            0x87, 0x00, ##  0    000 
            0x06, 0x00, ##       00  
            0x0C, 0x00, ##      00   
            0x18, 0x00, ##     00    
            0x38, 0x00, ##    000    
            0x30, 0x00, ##    00     
            0x60, 0x80, ##   00     0
            0xC0, 0x80, ##  00      0
            0xFF, 0x80, ##  000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '123' => {    # '{'
        'width'    => 8, 
        'xoffset'  => 2, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x0F, ##      0000
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x30, ##    00    
            0xE0, ##  000     
            0x30, ##    00    
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x0F, ##      0000
        ], 
    }, 
    '124' => {    # '|'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
        ], 
    }, 
    '125' => {    # '}'
        'width'    => 8, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF0, ##  0000    
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x0C, ##      00  
            0x07, ##       000
            0x0C, ##      00  
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0x18, ##     00   
            0xF0, ##  0000    
        ], 
    }, 
    '126' => {    # '~'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x7C, 0x18, ##   00000     00
            0xC7, 0xF0, ##  00   0000000 
            0x81, 0xE0, ##  0      0000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '160' => {    # ' '
        'width'    => 0, 
        'xoffset'  => 0, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
            ##  
        ], 
    }, 
    '161' => {    # '¡'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##    
            0x00, ##    
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0x40, ##   0
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '162' => {    # '¢'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x04, 0x00, ##       0   
            0x04, 0x00, ##       0   
            0x04, 0x00, ##       0   
            0x1F, 0x00, ##     00000 
            0x35, 0x80, ##    00 0 00
            0x64, 0x80, ##   00  0  0
            0xC4, 0x80, ##  00   0  0
            0xC4, 0x00, ##  00   0   
            0xC4, 0x00, ##  00   0   
            0xC4, 0x00, ##  00   0   
            0xC4, 0x00, ##  00   0   
            0x44, 0x80, ##   0   0  0
            0x65, 0x80, ##   00  0 00
            0x3F, 0x00, ##    000000 
            0x04, 0x00, ##       0   
            0x04, 0x00, ##       0   
            0x04, 0x00, ##       0   
            0x00, 0x00, ##  
        ], 
    }, 
    '163' => {    # '£'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xC0, ##      000000
            0x18, 0xC0, ##     00   00
            0x30, 0x40, ##    00     0
            0x30, 0x00, ##    00      
            0x30, 0x00, ##    00      
            0x30, 0x00, ##    00      
            0x30, 0x00, ##    00      
            0xFF, 0x00, ##  00000000  
            0x30, 0x00, ##    00      
            0x30, 0x00, ##    00      
            0x30, 0x00, ##    00      
            0x30, 0x00, ##    00      
            0x30, 0x40, ##    00     0
            0x30, 0x40, ##    00     0
            0xFF, 0xC0, ##  0000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '164' => {    # '¤'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x20, ##  00        0
            0x7F, 0x40, ##   0000000 0 
            0x31, 0x80, ##    00   00  
            0x60, 0xC0, ##   00     00 
            0x60, 0xC0, ##   00     00 
            0x60, 0xC0, ##   00     00 
            0x60, 0xC0, ##   00     00 
            0x31, 0x80, ##    00   00  
            0x7F, 0xC0, ##   000000000 
            0xC0, 0x60, ##  00       00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '165' => {    # '¥'
        'width'    => 13, 
        'xoffset'  => 0, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF8, 0x78, ##  00000    0000
            0x30, 0x10, ##    00       0 
            0x38, 0x20, ##    000     0  
            0x18, 0x20, ##     00     0  
            0x1C, 0x40, ##     000   0   
            0x0E, 0x80, ##      000 0    
            0x3E, 0xF0, ##    00000 0000 
            0x07, 0x00, ##       000     
            0x03, 0x00, ##        00     
            0x3F, 0xF0, ##    0000000000 
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x0F, 0xC0, ##      000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '166' => {    # '¦'
        'width'    => 2, 
        'xoffset'  => 3, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0x00, ##    
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
            0xC0, ##  00
        ], 
    }, 
    '167' => {    # '§'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x3E, ##    00000 
            0x62, ##   00   0 
            0x62, ##   00   0 
            0x60, ##   00     
            0x30, ##    00    
            0x3C, ##    0000  
            0x4E, ##   0  000 
            0xC7, ##  00   000
            0xC3, ##  00    00
            0x63, ##   00   00
            0x3B, ##    000 00
            0x1C, ##     000  
            0x06, ##       00 
            0x03, ##        00
            0x43, ##   0    00
            0x47, ##   0   000
            0x7E, ##   000000 
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '168' => {    # '¨'
        'width'    => 6, 
        'xoffset'  => 2, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xCC, ##  00  00
            0xCC, ##  00  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '169' => {    # '©'
        'width'    => 14, 
        'xoffset'  => 3, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0x80, ##      00000     
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x47, 0x88, ##   0   0000   0 
            0x4C, 0x48, ##   0  00   0  0 
            0x98, 0x44, ##  0  00    0   0
            0x98, 0x04, ##  0  00        0
            0x98, 0x04, ##  0  00        0
            0x98, 0x04, ##  0  00        0
            0x98, 0x44, ##  0  00    0   0
            0x4C, 0x48, ##   0  00   0  0 
            0x47, 0x88, ##   0   0000   0 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '170' => {    # 'ª'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 9, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x7C, ##   00000  
            0xC6, ##  00   00 
            0x02, ##        0 
            0x3E, ##    00000 
            0xC2, ##  00    0 
            0xC2, ##  00    0 
            0xC6, ##  00   00 
            0x7B, ##   0000 00
            0x00, ##          
            0xFE, ##  0000000 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '171' => {    # '«'
        'width'    => 9, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x08, 0x00, ##      0    
            0x18, 0x80, ##     00   0
            0x33, 0x00, ##    00  00 
            0x66, 0x00, ##   00  00  
            0xCC, 0x00, ##  00  00   
            0xCC, 0x00, ##  00  00   
            0x66, 0x00, ##   00  00  
            0x31, 0x00, ##    00   0 
            0x18, 0x80, ##     00   0
            0x08, 0x00, ##      0    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '172' => {    # '¬'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0xF8, ##  0000000000000
            0x00, 0x18, ##             00
            0x00, 0x18, ##             00
            0x00, 0x18, ##             00
            0x00, 0x18, ##             00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '173' => {    # '­'
        'width'    => 5, 
        'xoffset'  => 1, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF8, ##  00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '174' => {    # '®'
        'width'    => 14, 
        'xoffset'  => 3, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0x80, ##      00000     
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x5F, 0xC8, ##   0 0000000  0 
            0x4C, 0x68, ##   0  00   00 0 
            0x8C, 0x64, ##  0   00   00  0
            0x8C, 0x64, ##  0   00   00  0
            0x8F, 0x84, ##  0   00000    0
            0x8C, 0xC4, ##  0   00  00   0
            0x8C, 0x64, ##  0   00   00  0
            0x4C, 0x68, ##   0  00   00 0 
            0x5E, 0x38, ##   0 0000   000 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '175' => {    # '¯'
        'width'    => 6, 
        'xoffset'  => 2, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '176' => {    # '°'
        'width'    => 7, 
        'xoffset'  => 2, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x38, ##    000  
            0xEE, ##  000 000
            0xC6, ##  00   00
            0xC6, ##  00   00
            0xCE, ##  00  000
            0x78, ##   0000  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '177' => {    # '±'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0xFF, 0xF8, ##  0000000000000
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xFF, 0xF8, ##  0000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '178' => {    # '²'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x78, ##   0000 
            0x8C, ##  0   00
            0x04, ##       0
            0x08, ##      0 
            0x08, ##      0 
            0x30, ##    00  
            0x44, ##   0   0
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '179' => {    # '³'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xF8, ##  00000 
            0x84, ##  0    0
            0x0C, ##      00
            0x30, ##    00  
            0x0C, ##      00
            0x04, ##       0
            0x8C, ##  0   00
            0xF8, ##  00000 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '180' => {    # '´'
        'width'    => 4, 
        'xoffset'  => 4, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x30, ##    00
            0x60, ##   00 
            0x40, ##   0  
            0x80, ##  0   
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '181' => {    # 'µ'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF3, 0xC0, ##  0000  0000  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x39, 0xC0, ##    000  000  
            0x3E, 0xF0, ##    00000 0000
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0xF8, 0x00, ##  00000       
        ], 
    }, 
    '182' => {    # '¶'
        'width'    => 10, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x3F, 0xC0, ##    00000000
            0xF9, 0x00, ##  00000  0  
            0xF9, 0x00, ##  00000  0  
            0xF9, 0x00, ##  00000  0  
            0xF9, 0x00, ##  00000  0  
            0xF9, 0x00, ##  00000  0  
            0xF9, 0x00, ##  00000  0  
            0x79, 0x00, ##   0000  0  
            0x09, 0x00, ##      0  0  
            0x09, 0x00, ##      0  0  
            0x09, 0x00, ##      0  0  
            0x09, 0x00, ##      0  0  
            0x09, 0x00, ##      0  0  
            0x09, 0x00, ##      0  0  
            0x09, 0x00, ##      0  0  
            0x09, 0x00, ##      0  0  
            0x09, 0x00, ##      0  0  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '183' => {    # '·'
        'width'    => 2, 
        'xoffset'  => 2, 
        'xadvance' => 6, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00
            0xC0, ##  00
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '184' => {    # '¸'
        'width'    => 5, 
        'xoffset'  => 3, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x30, ##    00 
            0x18, ##     00
            0x18, ##     00
            0xF0, ##  0000 
        ], 
    }, 
    '185' => {    # '¹'
        'width'    => 5, 
        'xoffset'  => 2, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x60, ##   00  
            0xA0, ##  0 0  
            0x20, ##    0  
            0x20, ##    0  
            0x20, ##    0  
            0x20, ##    0  
            0x20, ##    0  
            0xF8, ##  00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '186' => {    # 'º'
        'width'    => 8, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x3C, ##    0000  
            0x46, ##   0   00 
            0xC2, ##  00    0 
            0xC3, ##  00    00
            0xC3, ##  00    00
            0xC2, ##  00    0 
            0x46, ##   0   00 
            0x3C, ##    0000  
            0x00, ##          
            0xFE, ##  0000000 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '187' => {    # '»'
        'width'    => 9, 
        'xoffset'  => 2, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##           
            0x88, 0x00, ##  0   0    
            0x46, 0x00, ##   0   00  
            0x23, 0x00, ##    0   00 
            0x31, 0x80, ##    00   00
            0x31, 0x80, ##    00   00
            0x23, 0x00, ##    0   00 
            0x44, 0x00, ##   0   0   
            0x88, 0x00, ##  0   0    
            0x00, 0x00, ##           
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '188' => {    # '¼'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x30, 0x08, 0x00, ##    00        0     
            0xF0, 0x18, 0x00, ##  0000       00     
            0x30, 0x10, 0x00, ##    00       0      
            0x30, 0x20, 0x00, ##    00      0       
            0x30, 0x60, 0x00, ##    00     00       
            0x30, 0x40, 0x00, ##    00     0        
            0x30, 0xC3, 0x00, ##    00    00    00  
            0xFC, 0x87, 0x00, ##  000000  0    000  
            0x01, 0x8B, 0x00, ##         00   0 00  
            0x01, 0x0B, 0x00, ##         0    0 00  
            0x03, 0x13, 0x00, ##        00   0  00  
            0x02, 0x13, 0x00, ##        0    0  00  
            0x06, 0x3F, 0xC0, ##       00   00000000
            0x0C, 0x03, 0x00, ##      00        00  
            0x0C, 0x07, 0x80, ##      00       0000 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '189' => {    # '½'
        'width'    => 17, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x70, 0x08, 0x00, ##   000        0    
            0xB0, 0x18, 0x00, ##  0 00       00    
            0x30, 0x10, 0x00, ##    00       0     
            0x30, 0x30, 0x00, ##    00      00     
            0x30, 0x20, 0x00, ##    00      0      
            0x30, 0x60, 0x00, ##    00     00      
            0x30, 0xCF, 0x00, ##    00    00  0000 
            0xFC, 0x91, 0x80, ##  000000  0  0   00
            0x01, 0x81, 0x80, ##         00      00
            0x01, 0x01, 0x80, ##         0       00
            0x03, 0x03, 0x00, ##        00      00 
            0x02, 0x02, 0x00, ##        0       0  
            0x06, 0x04, 0x00, ##       00      0   
            0x04, 0x08, 0x80, ##       0      0   0
            0x0C, 0x1F, 0x80, ##      00     000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '190' => {    # '¾'
        'width'    => 18, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x78, 0x08, 0x00, ##   0000       0     
            0x8C, 0x10, 0x00, ##  0   00     0      
            0x0C, 0x10, 0x00, ##      00     0      
            0x30, 0x20, 0x00, ##    00      0       
            0x08, 0x60, 0x00, ##      0    00       
            0x0C, 0x40, 0x00, ##      00   0        
            0x8C, 0xC0, 0x00, ##  0   00  00        
            0x8C, 0x83, 0x00, ##  0   00  0     00  
            0xF9, 0x87, 0x00, ##  00000  00    000  
            0x01, 0x0B, 0x00, ##         0    0 00  
            0x02, 0x13, 0x00, ##        0    0  00  
            0x02, 0x13, 0x00, ##        0    0  00  
            0x04, 0x3F, 0xC0, ##       0    00000000
            0x0C, 0x03, 0x00, ##      00        00  
            0x08, 0x07, 0x80, ##      0        0000 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '191' => {    # '¿'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 10, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0C, 0x00, ##      00   
            0x0C, 0x00, ##      00   
            0x00, 0x00, ##           
            0x00, 0x00, ##           
            0x08, 0x00, ##      0    
            0x08, 0x00, ##      0    
            0x08, 0x00, ##      0    
            0x30, 0x00, ##    00     
            0x60, 0x00, ##   00      
            0xC0, 0x00, ##  00       
            0xC0, 0x00, ##  00       
            0xC0, 0x00, ##  00       
            0xC1, 0x80, ##  00     00
            0x63, 0x80, ##   00   000
            0x3E, 0x00, ##    00000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '192' => {    # 'À'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x06, 0x00, ##       00        
            0x03, 0x00, ##        00       
            0x00, 0x80, ##          0      
            0x00, 0x00, ##                 
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x07, 0xC0, ##       00000     
            0x04, 0xC0, ##       0  00     
            0x04, 0xE0, ##       0  000    
            0x08, 0x60, ##      0    00    
            0x08, 0x60, ##      0    00    
            0x18, 0x70, ##     00    000   
            0x10, 0x30, ##     0      00   
            0x1F, 0xF0, ##     000000000   
            0x20, 0x18, ##    0        00  
            0x20, 0x18, ##    0        00  
            0x60, 0x18, ##   00        00  
            0xF0, 0x3E, ##  0000      00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '193' => {    # 'Á'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0xC0, ##          00     
            0x01, 0x80, ##         00      
            0x03, 0x00, ##        00       
            0x00, 0x00, ##                 
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x07, 0xC0, ##       00000     
            0x04, 0xC0, ##       0  00     
            0x04, 0xE0, ##       0  000    
            0x08, 0x60, ##      0    00    
            0x08, 0x60, ##      0    00    
            0x18, 0x70, ##     00    000   
            0x10, 0x30, ##     0      00   
            0x1F, 0xF0, ##     000000000   
            0x20, 0x18, ##    0        00  
            0x20, 0x18, ##    0        00  
            0x60, 0x18, ##   00        00  
            0xF0, 0x3E, ##  0000      00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '194' => {    # 'Â'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x03, 0x80, ##        000      
            0x06, 0xC0, ##       00 00     
            0x08, 0x20, ##      0     0    
            0x00, 0x00, ##                 
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x07, 0xC0, ##       00000     
            0x04, 0xC0, ##       0  00     
            0x04, 0xE0, ##       0  000    
            0x08, 0x60, ##      0    00    
            0x08, 0x60, ##      0    00    
            0x18, 0x70, ##     00    000   
            0x10, 0x30, ##     0      00   
            0x1F, 0xF0, ##     000000000   
            0x20, 0x18, ##    0        00  
            0x20, 0x18, ##    0        00  
            0x60, 0x18, ##   00        00  
            0xF0, 0x3E, ##  0000      00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '195' => {    # 'Ã'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x07, 0x20, ##       000  0    
            0x09, 0xC0, ##      0  000     
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x07, 0xC0, ##       00000     
            0x04, 0xC0, ##       0  00     
            0x04, 0xE0, ##       0  000    
            0x08, 0x60, ##      0    00    
            0x08, 0x60, ##      0    00    
            0x18, 0x70, ##     00    000   
            0x10, 0x30, ##     0      00   
            0x1F, 0xF0, ##     000000000   
            0x20, 0x18, ##    0        00  
            0x20, 0x18, ##    0        00  
            0x60, 0x18, ##   00        00  
            0xF0, 0x3E, ##  0000      00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '196' => {    # 'Ä'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x0C, 0xC0, ##      00  00     
            0x0C, 0xC0, ##      00  00     
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0x03, 0x00, ##        00       
            0x07, 0x80, ##       0000      
            0x07, 0x80, ##       0000      
            0x05, 0x80, ##       0 00      
            0x0D, 0xC0, ##      00 000     
            0x08, 0xC0, ##      0   00     
            0x08, 0xE0, ##      0   000    
            0x18, 0x60, ##     00    00    
            0x10, 0x60, ##     0     00    
            0x10, 0x30, ##     0      00   
            0x3F, 0xF0, ##    0000000000   
            0x20, 0x30, ##    0       00   
            0x20, 0x38, ##    0       000  
            0x60, 0x18, ##   00        00  
            0xF0, 0x3E, ##  0000      00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '197' => {    # 'Å'
        'width'    => 15, 
        'xoffset'  => 0, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x03, 0x80, ##        000      
            0x04, 0x40, ##       0   0     
            0x04, 0x40, ##       0   0     
            0x04, 0x40, ##       0   0     
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x03, 0x80, ##        000      
            0x07, 0xC0, ##       00000     
            0x04, 0xC0, ##       0  00     
            0x0C, 0xC0, ##      00  00     
            0x08, 0x60, ##      0    00    
            0x08, 0x60, ##      0    00    
            0x18, 0x60, ##     00    00    
            0x10, 0x30, ##     0      00   
            0x1F, 0xF0, ##     000000000   
            0x20, 0x38, ##    0       000  
            0x20, 0x18, ##    0        00  
            0x60, 0x18, ##   00        00  
            0xF0, 0x3E, ##  0000      00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '198' => {    # 'Æ'
        'width'    => 19, 
        'xoffset'  => 0, 
        'xadvance' => 20, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x07, 0xFF, 0xE0, ##       00000000000000
            0x01, 0x60, 0x20, ##         0 00       0
            0x02, 0x60, 0x20, ##        0  00       0
            0x02, 0x60, 0x00, ##        0  00        
            0x06, 0x60, 0x80, ##       00  00     0  
            0x04, 0x60, 0x80, ##       0   00     0  
            0x0C, 0x7F, 0x80, ##      00   00000000  
            0x08, 0x60, 0x80, ##      0    00     0  
            0x08, 0x60, 0x80, ##      0    00     0  
            0x18, 0x60, 0x00, ##     00    00        
            0x1F, 0xE0, 0x00, ##     00000000        
            0x30, 0x60, 0x00, ##    00     00        
            0x20, 0x60, 0x20, ##    0      00       0
            0x60, 0x60, 0x20, ##   00      00       0
            0xF1, 0xFF, 0xE0, ##  0000   000000000000
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '199' => {    # 'Ç'
        'width'    => 13, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xC0, ##      000000   
            0x18, 0x78, ##     00    0000
            0x20, 0x18, ##    0        00
            0x60, 0x18, ##   00        00
            0xC0, 0x18, ##  00         00
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0xC0, 0x00, ##  00           
            0x60, 0x18, ##   00        00
            0x20, 0x30, ##    0       00 
            0x18, 0x60, ##     00    00  
            0x0F, 0xC0, ##      000000   
            0x01, 0x00, ##         0     
            0x01, 0x80, ##         00    
            0x01, 0x80, ##         00    
            0x0F, 0x00, ##      0000     
        ], 
    }, 
    '200' => {    # 'È'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x0C, 0x00, ##      00      
            0x06, 0x00, ##       00     
            0x03, 0x00, ##        00    
            0x00, 0x00, ##              
            0xFF, 0xF0, ##  000000000000
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0x30, 0x00, ##    00        
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x3F, 0xC0, ##    00000000  
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0xFF, 0xF0, ##  000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '201' => {    # 'É'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x01, 0x80, ##         00   
            0x03, 0x00, ##        00    
            0x04, 0x00, ##       0      
            0x00, 0x00, ##              
            0xFF, 0xF0, ##  000000000000
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0x30, 0x00, ##    00        
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x3F, 0xC0, ##    00000000  
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0xFF, 0xF0, ##  000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '202' => {    # 'Ê'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x07, 0x00, ##       000    
            0x0D, 0x80, ##      00 00   
            0x10, 0x40, ##     0     0  
            0x00, 0x00, ##              
            0xFF, 0xF0, ##  000000000000
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0x30, 0x00, ##    00        
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x3F, 0xC0, ##    00000000  
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0xFF, 0xF0, ##  000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '203' => {    # 'Ë'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 15, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x19, 0x80, ##     00  00   
            0x19, 0x80, ##     00  00   
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0xFF, 0xF0, ##  000000000000
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0x30, 0x00, ##    00        
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x3F, 0xC0, ##    00000000  
            0x30, 0x40, ##    00     0  
            0x30, 0x40, ##    00     0  
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x30, 0x10, ##    00       0
            0x30, 0x10, ##    00       0
            0xFF, 0xF0, ##  000000000000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '204' => {    # 'Ì'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x60, ##   00   
            0x20, ##    0   
            0x10, ##     0  
            0x00, ##        
            0xFC, ##  000000
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '205' => {    # 'Í'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x18, ##     00 
            0x10, ##     0  
            0x20, ##    0   
            0x00, ##        
            0xFC, ##  000000
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '206' => {    # 'Î'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x30, ##    00  
            0x48, ##   0  0 
            0x84, ##  0    0
            0x00, ##        
            0xFC, ##  000000
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '207' => {    # 'Ï'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0xCC, ##  00  00
            0xCC, ##  00  00
            0x00, ##        
            0x00, ##        
            0xFC, ##  000000
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0xFC, ##  000000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '208' => {    # 'Ð'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFF, 0x80, ##  000000000     
            0x30, 0x60, ##    00     00   
            0x30, 0x30, ##    00      00  
            0x30, 0x18, ##    00       00 
            0x30, 0x0C, ##    00        00
            0x30, 0x0C, ##    00        00
            0x30, 0x0C, ##    00        00
            0xFE, 0x0C, ##  0000000     00
            0x30, 0x0C, ##    00        00
            0x30, 0x0C, ##    00        00
            0x30, 0x1C, ##    00       000
            0x30, 0x18, ##    00       00 
            0x30, 0x30, ##    00      00  
            0x30, 0x60, ##    00     00   
            0xFF, 0x80, ##  000000000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '209' => {    # 'Ñ'
        'width'    => 16, 
        'xoffset'  => 1, 
        'xadvance' => 18, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x07, 0x20, ##       000  0     
            0x0C, 0xE0, ##      00  000     
            0x00, 0x00, ##                  
            0x00, 0x00, ##                  
            0xF0, 0x1F, ##  0000       00000
            0x38, 0x04, ##    000        0  
            0x3C, 0x04, ##    0000       0  
            0x2C, 0x04, ##    0 00       0  
            0x26, 0x04, ##    0  00      0  
            0x27, 0x04, ##    0  000     0  
            0x23, 0x84, ##    0   000    0  
            0x21, 0xC4, ##    0    000   0  
            0x20, 0xC4, ##    0     00   0  
            0x20, 0x64, ##    0      00  0  
            0x20, 0x74, ##    0      000 0  
            0x20, 0x3C, ##    0       0000  
            0x20, 0x1C, ##    0        000  
            0x20, 0x0C, ##    0         00  
            0xF8, 0x04, ##  00000        0  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '210' => {    # 'Ò'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x0C, 0x00, ##      00        
            0x06, 0x00, ##       00       
            0x03, 0x00, ##        00      
            0x00, 0x00, ##                
            0x00, 0x00, ##                
            0x0F, 0xC0, ##      000000    
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x60, 0x18, ##   00        00 
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0x60, 0x18, ##   00        00 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '211' => {    # 'Ó'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0xC0, ##          00    
            0x01, 0x80, ##         00     
            0x03, 0x00, ##        00      
            0x00, 0x00, ##                
            0x00, 0x00, ##                
            0x0F, 0xC0, ##      000000    
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x60, 0x18, ##   00        00 
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0x60, 0x18, ##   00        00 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '212' => {    # 'Ô'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x03, 0x00, ##        00      
            0x07, 0x80, ##       0000     
            0x0C, 0xC0, ##      00  00    
            0x00, 0x00, ##                
            0x00, 0x00, ##                
            0x0F, 0xC0, ##      000000    
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x60, 0x18, ##   00        00 
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0x60, 0x18, ##   00        00 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '213' => {    # 'Õ'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x0E, 0x40, ##      000  0    
            0x09, 0xC0, ##      0  000    
            0x00, 0x00, ##                
            0x00, 0x00, ##                
            0x0F, 0xC0, ##      000000    
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x60, 0x18, ##   00        00 
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0x60, 0x18, ##   00        00 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '214' => {    # 'Ö'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x0C, 0xC0, ##      00  00    
            0x0C, 0xC0, ##      00  00    
            0x00, 0x00, ##                
            0x00, 0x00, ##                
            0x0F, 0xC0, ##      000000    
            0x18, 0x60, ##     00    00   
            0x20, 0x10, ##    0        0  
            0x60, 0x18, ##   00        00 
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0xC0, 0x0C, ##  00          00
            0x60, 0x18, ##   00        00 
            0x20, 0x10, ##    0        0  
            0x18, 0x60, ##     00    00   
            0x0F, 0xC0, ##      000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '215' => {    # '×'
        'width'    => 11, 
        'xoffset'  => 3, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xC0, 0x60, ##  00       00
            0xE0, 0xC0, ##  000     00 
            0x71, 0x80, ##   000   00  
            0x3B, 0x00, ##    000 00   
            0x1F, 0x00, ##     00000   
            0x0E, 0x00, ##      000    
            0x1E, 0x00, ##     0000    
            0x3B, 0x00, ##    000 00   
            0x71, 0x80, ##   000   00  
            0xE0, 0xC0, ##  000     00 
            0xC0, 0x60, ##  00       00
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '216' => {    # 'Ø'
        'width'    => 14, 
        'xoffset'  => 1, 
        'xadvance' => 16, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0xC4, ##      000000   0
            0x18, 0x78, ##     00    0000 
            0x20, 0x30, ##    0       00  
            0x60, 0x38, ##   00       000 
            0xC0, 0x68, ##  00       00 0 
            0xC0, 0xCC, ##  00      00  00
            0xC1, 0x8C, ##  00     00   00
            0xC3, 0x0C, ##  00    00    00
            0xC6, 0x0C, ##  00   00     00
            0xCC, 0x0C, ##  00  00      00
            0xD8, 0x0C, ##  00 00       00
            0x70, 0x18, ##   000       00 
            0x70, 0x10, ##   000       0  
            0x78, 0x60, ##   0000    00   
            0x8F, 0xC0, ##  0   000000    
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '217' => {    # 'Ù'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x02, 0x00, ##        0        
            0x01, 0x00, ##         0       
            0x01, 0x80, ##         00      
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0xFC, 0x3E, ##  000000    00000
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x18, 0x10, ##     00      0   
            0x1C, 0x30, ##     000    00   
            0x07, 0xC0, ##       00000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '218' => {    # 'Ú'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x40, ##           0     
            0x00, 0x80, ##          0      
            0x01, 0x00, ##         0       
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0xFC, 0x3E, ##  000000    00000
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x18, 0x10, ##     00      0   
            0x1C, 0x30, ##     000    00   
            0x07, 0xC0, ##       00000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '219' => {    # 'Û'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x01, 0x80, ##         00      
            0x03, 0xC0, ##        0000     
            0x06, 0x60, ##       00  00    
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0xFC, 0x3E, ##  000000    00000
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x18, 0x10, ##     00      0   
            0x1C, 0x30, ##     000    00   
            0x07, 0xC0, ##       00000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '220' => {    # 'Ü'
        'width'    => 15, 
        'xoffset'  => 1, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x06, 0x60, ##       00  00    
            0x06, 0x60, ##       00  00    
            0x00, 0x00, ##                 
            0x00, 0x00, ##                 
            0xFC, 0x3E, ##  000000    00000
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x30, 0x08, ##    00        0  
            0x18, 0x10, ##     00      0   
            0x1C, 0x30, ##     000    00   
            0x07, 0xC0, ##       00000     
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '221' => {    # 'Ý'
        'width'    => 13, 
        'xoffset'  => 0, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x01, 0x80, ##         00    
            0x03, 0x00, ##        00     
            0x02, 0x00, ##        0      
            0x00, 0x00, ##               
            0xF8, 0x78, ##  00000    0000
            0x30, 0x10, ##    00       0 
            0x38, 0x20, ##    000     0  
            0x18, 0x20, ##     00     0  
            0x0C, 0x40, ##      00   0   
            0x0E, 0xC0, ##      000 00   
            0x06, 0x80, ##       00 0    
            0x07, 0x00, ##       000     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x03, 0x00, ##        00     
            0x0F, 0xC0, ##      000000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '222' => {    # 'Þ'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xFC, 0x00, ##  000000      
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0x3F, 0xC0, ##    00000000  
            0x30, 0x60, ##    00     00 
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x30, 0x60, ##    00     00 
            0x3F, 0xC0, ##    00000000  
            0x30, 0x00, ##    00        
            0x30, 0x00, ##    00        
            0xFC, 0x00, ##  000000      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '223' => {    # 'ß'
        'width'    => 12, 
        'xoffset'  => 0, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0F, 0x80, ##      00000   
            0x18, 0xC0, ##     00   00  
            0x30, 0x60, ##    00     00 
            0x30, 0x60, ##    00     00 
            0x31, 0x80, ##    00   00   
            0x33, 0x00, ##    00  00    
            0x33, 0x00, ##    00  00    
            0x33, 0x80, ##    00  000   
            0x31, 0xC0, ##    00   000  
            0x30, 0x60, ##    00     00 
            0x30, 0x30, ##    00      00
            0x30, 0x30, ##    00      00
            0x34, 0x30, ##    00 0    00
            0x34, 0x60, ##    00 0   00 
            0xF7, 0xC0, ##  0000 00000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '224' => {    # 'à'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x20, 0x00, ##    0       
            0x30, 0x00, ##    00      
            0x18, 0x00, ##     00     
            0x08, 0x00, ##      0     
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x3E, 0x00, ##    00000   
            0x43, 0x00, ##   0    00  
            0x01, 0x80, ##         00 
            0x01, 0x80, ##         00 
            0x3F, 0x80, ##    0000000 
            0x61, 0x80, ##   00    00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0x63, 0x80, ##   00   000 
            0x3D, 0xC0, ##    0000 000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '225' => {    # 'á'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x00, ##        00  
            0x06, 0x00, ##       00   
            0x0C, 0x00, ##      00    
            0x08, 0x00, ##      0     
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x3E, 0x00, ##    00000   
            0x43, 0x00, ##   0    00  
            0x41, 0x80, ##   0     00 
            0x01, 0x80, ##         00 
            0x3F, 0x80, ##    0000000 
            0x61, 0x80, ##   00    00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0x63, 0x80, ##   00   000 
            0x3D, 0xC0, ##    0000 000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '226' => {    # 'â'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1C, 0x00, ##     000    
            0x14, 0x00, ##     0 0    
            0x36, 0x00, ##    00 00   
            0x23, 0x00, ##    0   00  
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x3E, 0x00, ##    00000   
            0x43, 0x00, ##   0    00  
            0x41, 0x80, ##   0     00 
            0x01, 0x80, ##         00 
            0x3F, 0x80, ##    0000000 
            0x61, 0x80, ##   00    00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0x63, 0x80, ##   00   000 
            0x3D, 0xC0, ##    0000 000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '227' => {    # 'ã'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x39, 0x00, ##    000  0  
            0x4E, 0x00, ##   0  000   
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x3E, 0x00, ##    00000   
            0x43, 0x00, ##   0    00  
            0x41, 0x80, ##   0     00 
            0x01, 0x80, ##         00 
            0x3F, 0x80, ##    0000000 
            0x61, 0x80, ##   00    00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0x63, 0x80, ##   00   000 
            0x3D, 0xC0, ##    0000 000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '228' => {    # 'ä'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x36, 0x00, ##    00 00   
            0x36, 0x00, ##    00 00   
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x3E, 0x00, ##    00000   
            0x63, 0x00, ##   00   00  
            0x41, 0x80, ##   0     00 
            0x01, 0x80, ##         00 
            0x3F, 0x80, ##    0000000 
            0x61, 0x80, ##   00    00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0x63, 0x80, ##   00   000 
            0x3D, 0xC0, ##    0000 000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '229' => {    # 'å'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1C, 0x00, ##     000    
            0x22, 0x00, ##    0   0   
            0x22, 0x00, ##    0   0   
            0x22, 0x00, ##    0   0   
            0x1C, 0x00, ##     000    
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x3E, 0x00, ##    00000   
            0x63, 0x00, ##   00   00  
            0x41, 0x80, ##   0     00 
            0x01, 0x80, ##         00 
            0x3F, 0x80, ##    0000000 
            0x61, 0x80, ##   00    00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0xC1, 0x80, ##  00     00 
            0x63, 0x80, ##   00   000 
            0x3D, 0xC0, ##    0000 000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '230' => {    # 'æ'
        'width'    => 17, 
        'xoffset'  => 1, 
        'xadvance' => 19, 
        'bitmap'   => [ 
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x3E, 0x3C, 0x00, ##    00000   0000   
            0x43, 0xC3, 0x00, ##   0    0000    00 
            0x41, 0xC1, 0x00, ##   0     000     0 
            0x01, 0x81, 0x80, ##         00      00
            0x3F, 0x81, 0x80, ##    0000000      00
            0x61, 0xFF, 0x80, ##   00    0000000000
            0xC1, 0x80, 0x00, ##  00     00        
            0xC1, 0x80, 0x00, ##  00     00        
            0xC1, 0x81, 0x80, ##  00     00      00
            0x63, 0xC3, 0x00, ##   00   0000    00 
            0x3C, 0x3E, 0x00, ##    0000    00000  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
            0x00, 0x00, 0x00, ##  
        ], 
    }, 
    '231' => {    # 'ç'
        'width'    => 9, 
        'xoffset'  => 1, 
        'xadvance' => 11, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1F, 0x00, ##     00000 
            0x61, 0x80, ##   00    00
            0x60, 0x80, ##   00     0
            0xC0, 0x80, ##  00      0
            0xC0, 0x00, ##  00       
            0xC0, 0x00, ##  00       
            0xC0, 0x00, ##  00       
            0xC0, 0x00, ##  00       
            0x60, 0x80, ##   00     0
            0x61, 0x00, ##   00    0 
            0x1E, 0x00, ##     0000  
            0x04, 0x00, ##       0   
            0x06, 0x00, ##       00  
            0x06, 0x00, ##       00  
            0x1C, 0x00, ##     000   
        ], 
    }, 
    '232' => {    # 'è'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x30, 0x00, ##    00      
            0x18, 0x00, ##     00     
            0x08, 0x00, ##      0     
            0x04, 0x00, ##       0    
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x60, 0x80, ##   00     0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xFF, 0xC0, ##  0000000000
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0x40, 0xC0, ##   0      00
            0x61, 0x80, ##   00    00 
            0x1F, 0x00, ##     00000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '233' => {    # 'é'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x00, ##        00  
            0x06, 0x00, ##       00   
            0x04, 0x00, ##       0    
            0x08, 0x00, ##      0     
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x60, 0x80, ##   00     0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xFF, 0xC0, ##  0000000000
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0x40, 0xC0, ##   0      00
            0x61, 0x80, ##   00    00 
            0x1F, 0x00, ##     00000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '234' => {    # 'ê'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0C, 0x00, ##      00    
            0x1E, 0x00, ##     0000   
            0x12, 0x00, ##     0  0   
            0x21, 0x00, ##    0    0  
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x60, 0x80, ##   00     0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xFF, 0xC0, ##  0000000000
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0x40, 0xC0, ##   0      00
            0x61, 0x80, ##   00    00 
            0x1F, 0x00, ##     00000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '235' => {    # 'ë'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x33, 0x00, ##    00  00  
            0x33, 0x00, ##    00  00  
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x60, 0x80, ##   00     0 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xFF, 0xC0, ##  0000000000
            0xC0, 0x00, ##  00        
            0xC0, 0x00, ##  00        
            0x40, 0xC0, ##   0      00
            0x61, 0x80, ##   00    00 
            0x1F, 0x00, ##     00000  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '236' => {    # 'ì'
        'width'    => 6, 
        'xoffset'  => 0, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xC0, ##  00    
            0x60, ##   00   
            0x30, ##    00  
            0x10, ##     0  
            0x08, ##      0 
            0x00, ##        
            0x78, ##   0000 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x7C, ##   00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '237' => {    # 'í'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x0C, ##      00
            0x08, ##      0 
            0x10, ##     0  
            0x30, ##    00  
            0x20, ##    0   
            0x00, ##        
            0xF0, ##  0000  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0xF8, ##  00000 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '238' => {    # 'î'
        'width'    => 6, 
        'xoffset'  => 0, 
        'xadvance' => 7, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x18, ##     00 
            0x38, ##    000 
            0x2C, ##    0 00
            0x44, ##   0   0
            0xC0, ##  00    
            0x00, ##        
            0x78, ##   0000 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x18, ##     00 
            0x7C, ##   00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '239' => {    # 'ï'
        'width'    => 6, 
        'xoffset'  => 1, 
        'xadvance' => 8, 
        'bitmap'   => [ 
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0xCC, ##  00  00
            0xCC, ##  00  00
            0x00, ##        
            0x00, ##        
            0x70, ##   000  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x30, ##    00  
            0x7C, ##   00000
            0x00, ##  
            0x00, ##  
            0x00, ##  
            0x00, ##  
        ], 
    }, 
    '240' => {    # 'ð'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x70, 0x80, ##   000    0 
            0x1B, 0x00, ##     00 00  
            0x0E, 0x00, ##      000   
            0x32, 0x00, ##    00  0   
            0x03, 0x00, ##        00  
            0x1F, 0x80, ##     000000 
            0x71, 0x80, ##   000   00 
            0x60, 0xC0, ##   00     00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '241' => {    # 'ñ'
        'width'    => 12, 
        'xoffset'  => 1, 
        'xadvance' => 14, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x18, 0x80, ##     00   0   
            0x24, 0x80, ##    0  0  0   
            0x23, 0x00, ##    0   00    
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0xEF, 0x00, ##  000 0000    
            0x71, 0x80, ##   000   00   
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0x60, 0xC0, ##   00     00  
            0xF9, 0xF0, ##  00000  00000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '242' => {    # 'ò'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x30, 0x00, ##    00      
            0x18, 0x00, ##     00     
            0x08, 0x00, ##      0     
            0x04, 0x00, ##       0    
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '243' => {    # 'ó'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x00, ##        00  
            0x06, 0x00, ##       00   
            0x04, 0x00, ##       0    
            0x08, 0x00, ##      0     
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '244' => {    # 'ô'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0C, 0x00, ##      00    
            0x1E, 0x00, ##     0000   
            0x12, 0x00, ##     0  0   
            0x21, 0x00, ##    0    0  
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '245' => {    # 'õ'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x39, 0x00, ##    000  0  
            0x27, 0x00, ##    0  000  
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '246' => {    # 'ö'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x33, 0x00, ##    00  00  
            0x33, 0x00, ##    00  00  
            0x00, 0x00, ##            
            0x00, 0x00, ##            
            0x1E, 0x00, ##     0000   
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0xC0, 0xC0, ##  00      00
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0x1E, 0x00, ##     0000   
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '247' => {    # '÷'
        'width'    => 13, 
        'xoffset'  => 2, 
        'xadvance' => 17, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0xFF, 0xF8, ##  0000000000000
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0x00, 0x00, ##               
            0x06, 0x00, ##       00      
            0x06, 0x00, ##       00      
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '248' => {    # 'ø'
        'width'    => 10, 
        'xoffset'  => 1, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x40, ##           0
            0x1E, 0x40, ##     0000  0
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0xC2, 0xC0, ##  00    0 00
            0xC6, 0xC0, ##  00   00 00
            0xCC, 0xC0, ##  00  00  00
            0xD8, 0xC0, ##  00 00   00
            0xD0, 0xC0, ##  00 0    00
            0x61, 0x80, ##   00    00 
            0x61, 0x80, ##   00    00 
            0x9E, 0x00, ##  0  0000   
            0x80, 0x00, ##  0         
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '249' => {    # 'ù'
        'width'    => 12, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x18, 0x00, ##     00       
            0x18, 0x00, ##     00       
            0x0C, 0x00, ##      00      
            0x04, 0x00, ##       0      
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0xF1, 0xC0, ##  0000   000  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x39, 0xC0, ##    000  000  
            0x1E, 0xF0, ##     0000 0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '250' => {    # 'ú'
        'width'    => 12, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x00, ##        00    
            0x02, 0x00, ##        0     
            0x06, 0x00, ##       00     
            0x04, 0x00, ##       0      
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0xF1, 0xC0, ##  0000   000  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x39, 0xC0, ##    000  000  
            0x1E, 0xF0, ##     0000 0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '251' => {    # 'û'
        'width'    => 12, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x0C, 0x00, ##      00      
            0x0A, 0x00, ##      0 0     
            0x1A, 0x00, ##     00 0     
            0x11, 0x00, ##     0   0    
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0xF1, 0xC0, ##  0000   000  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x39, 0xC0, ##    000  000  
            0x1E, 0xF0, ##     0000 0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '252' => {    # 'ü'
        'width'    => 12, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x1B, 0x00, ##     00 00    
            0x1B, 0x00, ##     00 00    
            0x00, 0x00, ##              
            0x00, 0x00, ##              
            0xF1, 0xC0, ##  0000   000  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x30, 0xC0, ##    00    00  
            0x39, 0xC0, ##    000  000  
            0x1E, 0xF0, ##     0000 0000
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
        ], 
    }, 
    '253' => {    # 'ý'
        'width'    => 11, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x03, 0x00, ##        00   
            0x02, 0x00, ##        0    
            0x06, 0x00, ##       00    
            0x04, 0x00, ##       0     
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xF9, 0xE0, ##  00000  0000
            0x60, 0xC0, ##   00     00 
            0x30, 0x80, ##    00    0  
            0x30, 0x80, ##    00    0  
            0x19, 0x00, ##     00  0   
            0x19, 0x00, ##     00  0   
            0x19, 0x00, ##     00  0   
            0x0E, 0x00, ##      000    
            0x0E, 0x00, ##      000    
            0x06, 0x00, ##       00    
            0x04, 0x00, ##       0     
            0x04, 0x00, ##       0     
            0x08, 0x00, ##      0      
            0x48, 0x00, ##   0  0      
            0x70, 0x00, ##   000       
        ], 
    }, 
    '254' => {    # 'þ'
        'width'    => 11, 
        'xoffset'  => 1, 
        'xadvance' => 13, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0xF0, 0x00, ##  0000       
            0x30, 0x00, ##    00       
            0x30, 0x00, ##    00       
            0x30, 0x00, ##    00       
            0x37, 0x80, ##    00 0000  
            0x38, 0xC0, ##    000   00 
            0x30, 0x40, ##    00     0 
            0x30, 0x60, ##    00     00
            0x30, 0x60, ##    00     00
            0x30, 0x60, ##    00     00
            0x30, 0x60, ##    00     00
            0x30, 0x60, ##    00     00
            0x30, 0x40, ##    00     0 
            0x38, 0xC0, ##    000   00 
            0x37, 0x80, ##    00 0000  
            0x30, 0x00, ##    00       
            0x30, 0x00, ##    00       
            0x30, 0x00, ##    00       
            0xF8, 0x00, ##  00000      
        ], 
    }, 
    '255' => {    # 'ÿ'
        'width'    => 11, 
        'xoffset'  => 0, 
        'xadvance' => 12, 
        'bitmap'   => [ 
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x00, 0x00, ##  
            0x19, 0x80, ##     00  00  
            0x19, 0x80, ##     00  00  
            0x00, 0x00, ##             
            0x00, 0x00, ##             
            0xF9, 0xE0, ##  00000  0000
            0x30, 0x40, ##    00     0 
            0x30, 0x80, ##    00    0  
            0x30, 0x80, ##    00    0  
            0x18, 0x80, ##     00   0  
            0x19, 0x00, ##     00  0   
            0x0D, 0x00, ##      00 0   
            0x0D, 0x00, ##      00 0   
            0x0E, 0x00, ##      000    
            0x06, 0x00, ##       00    
            0x04, 0x00, ##       0     
            0x04, 0x00, ##       0     
            0x04, 0x00, ##       0     
            0x48, 0x00, ##   0  0      
            0x70, 0x00, ##   000       
        ], 
    }, 
};
 
my $kerning = {
    '33' => { },  # !
    '34' => { },  # "
    '35' => { },  # #
    '36' => { },  # $
    '37' => { },  # %
    '38' => { },  # &
    '39' => { },  # '
    '40' => { },  # (
    '41' => { },  # )
    '42' => { },  # *
    '43' => { },  # +
    '44' => { },  # ,
    '45' => { '84' => -1, '86' => -1, '87' => -1, '88' => -1, '89' => -2, '221' => -2, },  # -
    '46' => { },  # .
    '47' => { },  # /
    '48' => { },  # 0
    '49' => { },  # 1
    '50' => { },  # 2
    '51' => { },  # 3
    '52' => { },  # 4
    '53' => { },  # 5
    '54' => { },  # 6
    '55' => { },  # 7
    '56' => { },  # 8
    '57' => { },  # 9
    '58' => { },  # :
    '59' => { },  # ;
    '60' => { },  # <
    '61' => { },  # =
    '62' => { },  # >
    '63' => { },  # ?
    '64' => { },  # @
    '65' => { '84' => -1, '86' => -1, '87' => -1, '89' => -1, '118' => -1, '119' => -1, '121' => -1, '221' => -1, '253' => -1, '255' => -1, },  # A
    '66' => { },  # B
    '67' => { '44' => -1, '46' => -1, },  # C
    '68' => { '44' => -1, '46' => -1, },  # D
    '69' => { },  # E
    '70' => { '44' => -2, '45' => -1, '46' => -2, '58' => -1, '59' => -1, '65' => -1, '97' => -1, '101' => -1, '111' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '230' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '248' => -1, },  # F
    '71' => { '44' => -1, '46' => -1, },  # G
    '72' => { },  # H
    '73' => { },  # I
    '74' => { '44' => -1, '46' => -1, '58' => -1, '59' => -1, },  # J
    '75' => { '45' => -1, '65' => -1, '85' => -1, '87' => -1, '121' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '217' => -1, '218' => -1, '219' => -1, '220' => -1, '253' => -1, '255' => -1, },  # K
    '76' => { '84' => -1, '85' => -1, '86' => -2, '87' => -1, '89' => -1, '217' => -1, '218' => -1, '219' => -1, '220' => -1, '221' => -1, },  # L
    '77' => { },  # M
    '78' => { '44' => -1, '46' => -1, '58' => -1, '59' => -1, },  # N
    '79' => { '44' => -1, '45' => 1, '46' => -1, },  # O
    '80' => { '44' => -3, '45' => -1, '46' => -3, '58' => -1, '59' => -1, '65' => -1, '97' => -1, '101' => -1, '111' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '230' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '248' => -1, },  # P
    '81' => { '44' => -1, '45' => 1, '46' => -1, },  # Q
    '82' => { '86' => -1, },  # R
    '83' => { '44' => -1, '45' => 1, '46' => -1, },  # S
    '84' => { '44' => -2, '45' => -2, '46' => -2, '58' => -1, '59' => -1, '65' => -1, '97' => -1, '99' => -1, '101' => -1, '111' => -1, '115' => -1, '119' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '230' => -1, '231' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '248' => -1, },  # T
    '85' => { '44' => -1, '46' => -1, '58' => -1, '59' => -1, },  # U
    '86' => { '44' => -3, '45' => -1, '46' => -3, '58' => -2, '59' => -2, '65' => -1, '97' => -1, '101' => -1, '111' => -1, '117' => -1, '121' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '230' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '248' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, '253' => -1, '255' => -1, },  # V
    '87' => { '44' => -3, '45' => -1, '46' => -3, '58' => -1, '59' => -1, '65' => -1, '97' => -1, '101' => -1, '111' => -1, '114' => -1, '117' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '230' => -1, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '248' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, },  # W
    '88' => { '45' => -1, '65' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, },  # X
    '89' => { '44' => -2, '45' => -2, '46' => -2, '58' => -2, '59' => -2, '65' => -1, '97' => -1, '101' => -1, '111' => -1, '117' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '230' => -2, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '248' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, },  # Y
    '90' => { },  # Z
    '91' => { },  # [
    '92' => { },  # \
    '93' => { },  # ]
    '94' => { },  # ^
    '95' => { },  # _
    '96' => { },  # `
    '97' => { },  # a
    '98' => { },  # b
    '99' => { },  # c
    '100' => { },  # d
    '101' => { },  # e
    '102' => { '44' => -1, '45' => -1, '46' => -1, },  # f
    '103' => { },  # g
    '104' => { },  # h
    '105' => { },  # i
    '106' => { },  # j
    '107' => { },  # k
    '108' => { },  # l
    '109' => { },  # m
    '110' => { },  # n
    '111' => { },  # o
    '112' => { },  # p
    '113' => { },  # q
    '114' => { '44' => -2, '46' => -2, },  # r
    '115' => { },  # s
    '116' => { },  # t
    '117' => { },  # u
    '118' => { '44' => -2, '46' => -2, },  # v
    '119' => { '44' => -2, '46' => -2, },  # w
    '120' => { },  # x
    '121' => { '44' => -2, '46' => -2, },  # y
    '122' => { },  # z
    '123' => { },  # {
    '124' => { },  # |
    '125' => { },  # }
    '126' => { },  # ~
    '160' => { },  #  
    '161' => { },  # ¡
    '162' => { },  # ¢
    '163' => { },  # £
    '164' => { },  # ¤
    '165' => { },  # ¥
    '166' => { },  # ¦
    '167' => { },  # §
    '168' => { },  # ¨
    '169' => { },  # ©
    '170' => { },  # ª
    '171' => { },  # «
    '172' => { },  # ¬
    '173' => { },  # ­
    '174' => { },  # ®
    '175' => { },  # ¯
    '176' => { },  # °
    '177' => { },  # ±
    '178' => { },  # ²
    '179' => { },  # ³
    '180' => { },  # ´
    '181' => { },  # µ
    '182' => { },  # ¶
    '183' => { },  # ·
    '184' => { },  # ¸
    '185' => { },  # ¹
    '186' => { },  # º
    '187' => { },  # »
    '188' => { },  # ¼
    '189' => { },  # ½
    '190' => { },  # ¾
    '191' => { },  # ¿
    '192' => { '84' => -1, '86' => -1, '87' => -1, '89' => -1, '118' => -1, '119' => -1, '121' => -1, '221' => -1, '253' => -1, '255' => -1, },  # À
    '193' => { '84' => -1, '86' => -1, '87' => -1, '89' => -1, '118' => -1, '119' => -1, '121' => -1, '221' => -1, '253' => -1, '255' => -1, },  # Á
    '194' => { '84' => -1, '86' => -1, '87' => -1, '89' => -1, '118' => -1, '119' => -1, '121' => -1, '221' => -1, '253' => -1, '255' => -1, },  # Â
    '195' => { '84' => -1, '86' => -1, '87' => -1, '89' => -1, '118' => -1, '119' => -1, '121' => -1, '221' => -1, '253' => -1, '255' => -1, },  # Ã
    '196' => { '84' => -1, '86' => -1, '87' => -1, '89' => -1, '118' => -1, '119' => -1, '121' => -1, '221' => -1, '253' => -1, '255' => -1, },  # Ä
    '197' => { },  # Å
    '198' => { },  # Æ
    '199' => { '44' => -1, '46' => -1, },  # Ç
    '200' => { },  # È
    '201' => { },  # É
    '202' => { },  # Ê
    '203' => { },  # Ë
    '204' => { },  # Ì
    '205' => { },  # Í
    '206' => { },  # Î
    '207' => { },  # Ï
    '208' => { '44' => -1, '45' => 1, '46' => -1, },  # Ð
    '209' => { '44' => -1, '46' => -1, '58' => -1, '59' => -1, },  # Ñ
    '210' => { '44' => -1, '45' => 1, '46' => -1, },  # Ò
    '211' => { '44' => -1, '45' => 1, '46' => -1, },  # Ó
    '212' => { '44' => -1, '45' => 1, '46' => -1, },  # Ô
    '213' => { '44' => -1, '45' => 1, '46' => -1, },  # Õ
    '214' => { '44' => -1, '45' => 1, '46' => -1, },  # Ö
    '215' => { },  # ×
    '216' => { '44' => -1, '45' => 1, '46' => -1, },  # Ø
    '217' => { '44' => -1, '46' => -1, '58' => -1, '59' => -1, },  # Ù
    '218' => { '44' => -1, '46' => -1, '58' => -1, '59' => -1, },  # Ú
    '219' => { '44' => -1, '46' => -1, '58' => -1, '59' => -1, },  # Û
    '220' => { '44' => -1, '46' => -1, '58' => -1, '59' => -1, },  # Ü
    '221' => { '44' => -2, '45' => -2, '46' => -2, '58' => -2, '59' => -2, '65' => -1, '97' => -1, '101' => -1, '111' => -1, '117' => -1, '192' => -1, '193' => -1, '194' => -1, '195' => -1, '196' => -1, '224' => -1, '225' => -1, '226' => -1, '227' => -1, '228' => -1, '229' => -1, '230' => -2, '232' => -1, '233' => -1, '234' => -1, '235' => -1, '242' => -1, '243' => -1, '244' => -1, '245' => -1, '246' => -1, '248' => -1, '249' => -1, '250' => -1, '251' => -1, '252' => -1, },  # Ý
    '222' => { '44' => -3, '46' => -3, },  # Þ
    '223' => { },  # ß
    '224' => { },  # à
    '225' => { },  # á
    '226' => { },  # â
    '227' => { },  # ã
    '228' => { },  # ä
    '229' => { },  # å
    '230' => { },  # æ
    '231' => { },  # ç
    '232' => { },  # è
    '233' => { },  # é
    '234' => { },  # ê
    '235' => { },  # ë
    '236' => { },  # ì
    '237' => { },  # í
    '238' => { },  # î
    '239' => { },  # ï
    '240' => { },  # ð
    '241' => { },  # ñ
    '242' => { },  # ò
    '243' => { },  # ó
    '244' => { },  # ô
    '245' => { },  # õ
    '246' => { },  # ö
    '247' => { },  # ÷
    '248' => { },  # ø
    '249' => { },  # ù
    '250' => { },  # ú
    '251' => { },  # û
    '252' => { },  # ü
    '253' => { '44' => -2, '46' => -2, },  # ý
    '254' => { '46' => -1, },  # þ
    '255' => { '44' => -2, '46' => -2, },  # ÿ
};


sub new {
    my($class) = @_;
    
    my $self = $class->SUPER::new(
        name        => $name,
        char_height => $char_height,
        space_width => $space_width,
        gap_width   => $gap_width,
        symbols     => $symbols,
        kerning     => $kerning,
        line_spacing => $line_spacing,
        class       => 'hipi_2',
    );
    
    return $self;
}

1;

__END__
